@@ -2,7 +2,7 @@
  * Routines for RFC2630 Cryptographic Message Syntax packet dissection
  *   Ronnie Sahlberg 2004
  *
- * $Id: packet-cms-template.c 20416 2007-01-13 15:26:13Z gal $
+ * $Id: packet-cms-template.c 30516 2009-10-11 16:24:29Z stig $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -29,8 +29,8 @@
 
 #include <glib.h>
 #include <epan/packet.h>
-#include <epan/conversation.h>
-#include <epan/oid_resolv.h>
+#include <epan/oids.h>
+#include <epan/asn1.h>
 
 #include <stdio.h>
 #include <string.h>
@@ -39,6 +39,7 @@
 #include "packet-cms.h"
 #include "packet-x509af.h"
 #include "packet-x509if.h"
+#include "packet-pkcs12.h"
 
 #include <epan/crypt/crypt-sha1.h>
 #include <epan/crypt/crypt-md5.h>
@@ -48,20 +49,21 @@
 #define PFNAME "cms"
 
 /* Initialize the protocol and registered fields */
-int proto_cms = -1;
+static int proto_cms = -1;
 static int hf_cms_ci_contentType = -1;
 #include "packet-cms-hf.c"
 
 /* Initialize the subtree pointers */
 #include "packet-cms-ett.c"
 
-static int dissect_cms_OCTET_STRING(gboolean implicit_tag _U_, tvbuff_t *tvb, int offset, packet_info *pinfo _U_, proto_tree *tree, int hf_index _U_) ; /* XXX kill a compiler warning until asn2wrs stops generating these silly wrappers */
+static int dissect_cms_OCTET_STRING(gboolean implicit_tag _U_, tvbuff_t *tvb, int offset, asn1_ctx_t *actx, proto_tree *tree, int hf_index _U_) ; /* XXX kill a compiler warning until asn2wrs stops generating these silly wrappers */
 
 
 static const char *object_identifier_id;
 static tvbuff_t *content_tvb = NULL;
 
 static proto_tree *top_tree=NULL;
+static proto_tree *cap_tree=NULL;
 
 #define HASH_SHA1 "1.3.14.3.2.26"
 #define SHA1_BUFFER_SIZE  20
@@ -156,6 +158,12 @@ void proto_register_cms(void) {
   proto_register_field_array(proto_cms, hf, array_length(hf));
   proto_register_subtree_array(ett, array_length(ett));
 
+  register_ber_syntax_dissector("ContentInfo", proto_cms, dissect_ContentInfo_PDU); 
+  register_ber_oid_syntax(".p7s", NULL, "ContentInfo");
+  register_ber_oid_syntax(".p7m", NULL, "ContentInfo");
+  register_ber_oid_syntax(".p7c", NULL, "ContentInfo");
+
+
 }
 
 
@@ -163,7 +171,9 @@ void proto_register_cms(void) {
 void proto_reg_handoff_cms(void) {
 #include "packet-cms-dis-tab.c"
 
-  add_oid_str_name("1.2.840.113549.1.7.1", "id-data");
+  oid_add_from_string("id-data","1.2.840.113549.1.7.1");
+  oid_add_from_string("id-alg-des-ede3-cbc","1.2.840.113549.3.7");
+  oid_add_from_string("id-alg-des-cbc","1.3.14.3.2.7");
 
 }
 
