@@ -7,7 +7,7 @@
  *
  * Anders Broman and Ronnie Sahlberg 2005 - 2006
  *
- * $Id: packet-ftam-template.c 29344 2009-08-09 07:36:13Z krj $
+ * $Id: packet-ftam-template.c 30516 2009-10-11 16:24:29Z stig $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -49,7 +49,7 @@
 #define PFNAME "ftam"
 
 /* Initialize the protocol and registered fields */
-int proto_ftam = -1;
+static int proto_ftam = -1;
 
 static const char *object_identifier_id;
 /* Declare the function to avoid a compiler warning */
