@@ -2,7 +2,7 @@
  * Routines for GENERIC NETWORK INFORMATION MODEL Data dissection
  *
  * Copyright 2005 , Anders Broman <anders.broman [AT] ericsson.com>
- * $Id: packet-gnm-template.c 22227 2007-07-01 18:48:15Z etxrab $
+ * $Id: packet-gnm-template.c 30516 2009-10-11 16:24:29Z stig $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -33,7 +33,6 @@
 
 #include <glib.h>
 #include <epan/packet.h>
-#include <epan/conversation.h>
 #include <epan/asn1.h>
 
 #include <stdio.h>
@@ -47,7 +46,7 @@
 #define PFNAME "gnm"
 
 /* Initialize the protocol and registered fields */
-int proto_gnm = -1;
+static int proto_gnm = -1;
 
 #include "packet-gnm-hf.c"
 
