@@ -2,7 +2,7 @@
  * Routines for IEC 61850 GOOSE packet dissection
  * Martin Lutz 2008
  *
- * $Id: packet-goose-template.c 27323 2009-01-28 21:22:30Z wmeier $
+ * $Id: packet-goose-template.c 29344 2009-08-09 07:36:13Z krj $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -78,8 +78,7 @@ dissect_goose(tvbuff_t *tvb, packet_info *pinfo, proto_tree *parent_tree)
 	}
 	if (check_col(pinfo->cinfo, COL_PROTOCOL))
 		col_set_str(pinfo->cinfo, COL_PROTOCOL, PNAME);
-	if (check_col(pinfo->cinfo, COL_INFO))
-		col_clear(pinfo->cinfo, COL_INFO);
+	col_clear(pinfo->cinfo, COL_INFO);
 
 	/* APPID */
 	if (tree && tvb_reported_length_remaining(tvb, offset) >= 2) {
@@ -108,7 +107,6 @@ dissect_goose(tvbuff_t *tvb, packet_info *pinfo, proto_tree *parent_tree)
 		offset = dissect_goose_GOOSEpdu(FALSE, tvb, offset, &asn1_ctx , tree, -1);
 		if (offset == old_offset) {
 			proto_tree_add_text(tree, tvb, offset, -1, "Internal error, zero-byte GOOSE PDU");
-			offset = tvb_length(tvb);
 			break;
 		}
 	}
@@ -122,16 +120,16 @@ void proto_register_goose(void) {
   static hf_register_info hf[] =
   {
   	{ &hf_goose_appid,
-	{ "APPID",	"goose.appid", FT_UINT16, BASE_HEX_DEC, NULL, 0x0, "", HFILL }},
+	{ "APPID",	"goose.appid", FT_UINT16, BASE_HEX_DEC, NULL, 0x0, NULL, HFILL }},
 
   	{ &hf_goose_length,
-	{ "Length",	"goose.length", FT_UINT16, BASE_DEC, NULL, 0x0, "", HFILL }},
+	{ "Length",	"goose.length", FT_UINT16, BASE_DEC, NULL, 0x0, NULL, HFILL }},
 
   	{ &hf_goose_reserve1,
-	{ "Reserved 1",	"goose.reserve1", FT_UINT16, BASE_HEX_DEC, NULL, 0x0, "", HFILL }},
+	{ "Reserved 1",	"goose.reserve1", FT_UINT16, BASE_HEX_DEC, NULL, 0x0, NULL, HFILL }},
 
   	{ &hf_goose_reserve2,
-	{ "Reserved 2",	"goose.reserve2", FT_UINT16, BASE_HEX_DEC, NULL, 0x0, "", HFILL }},
+	{ "Reserved 2",	"goose.reserve2", FT_UINT16, BASE_HEX_DEC, NULL, 0x0, NULL, HFILL }},
 
 #include "packet-goose-hfarr.c"
   };
