@@ -4,7 +4,7 @@
  * 2003  Graeme Reid (graeme.reid@norwoodsystems.com)
  * Copyright 2005, Anders Broman <anders.broman@ericsson.com>
  *
- * $Id: packet-h450-template.c 26693 2008-11-04 21:42:02Z wmeier $
+ * $Id: packet-h450-template.c 28826 2009-06-24 01:40:54Z stig $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -34,7 +34,6 @@
 
 #include <glib.h>
 #include <epan/packet.h>
-#include <epan/conversation.h>
 
 #include <stdio.h>
 #include <string.h>
@@ -247,10 +246,10 @@ void proto_register_h450(void) {
   static hf_register_info hf[] = {
     { &hf_h450_operation, { "Operation", "h450.operation",
                            FT_UINT8, BASE_DEC, VALS(h450_str_operation), 0x0,
-                           "Operation", HFILL }},
+                           NULL, HFILL }},
     { &hf_h450_error,     { "Error", "h450.error",
                            FT_UINT8, BASE_DEC, VALS(h450_str_error), 0x0,
-                           "Error", HFILL }},
+                           NULL, HFILL }},
 #include "packet-h450-hfarr.c"
   };
 
