@@ -3,7 +3,7 @@
  * Copyright 2004, Tim Endean <endeant@hotmail.com>
  * Built from the gsm-map dissector Copyright 2004, Anders Broman <anders.broman@ericsson.com>
  *
- * $Id: packet-inap-template.c 29500 2009-08-21 20:32:50Z krj $
+ * $Id: packet-inap-template.c 30516 2009-10-11 16:24:29Z stig $
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
  * Copyright 1998 Gerald Combs
@@ -51,7 +51,7 @@
 #define PFNAME "inap"
 
 /* Initialize the protocol and registered fields */
-int proto_inap = -1;
+static int proto_inap = -1;
 
 /* include constants */
 #include "packet-inap-val.h"
