@@ -3,7 +3,7 @@
  *
  * See RFC 1777 (LDAP v2), RFC 2251 (LDAP v3), and RFC 2222 (SASL).
  *
- * $Id: packet-ldap-template.c 30506 2009-10-11 14:21:50Z krj $
+ * $Id: packet-ldap-template.c 30767 2009-10-30 10:21:35Z stig $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -515,9 +515,7 @@ dissect_ldap_AssertionValue(gboolean implicit_tag, tvbuff_t *tvb, int offset, as
 
 	/* convert the string into a printable string */
 	if(is_ascii){
-		ldapvalue_string=ep_alloc(len+1);
-		memcpy(ldapvalue_string,str,len);
-		ldapvalue_string[i]=0;
+		ldapvalue_string=ep_strndup(str, len);
 	} else {
 		ldapvalue_string=ep_alloc(3*len);
 		for(i=0;i<len;i++){
