@@ -2,7 +2,7 @@
  * Routines for PKCS#12: Personal Information Exchange packet dissection
  * Graeme Lunt 2006
  *
- * $Id: packet-pkcs12-template.c 29501 2009-08-21 20:40:49Z krj $
+ * $Id: packet-pkcs12-template.c 31054 2009-11-23 18:54:26Z stig $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -42,8 +42,11 @@
 #include "packet-x509if.h"
 #include "packet-cms.h"
 
-#ifndef _WIN32  
+#ifdef HAVE_SYS_TYPES_H
 #include <sys/types.h>
+#endif
+
+#ifdef HAVE_SYS_TIME_H
 #include <sys/time.h>
 #endif
 
@@ -63,7 +66,7 @@
 #define PKCS12_PBE_RC2_40_SHA1_OID	"1.2.840.113549.1.12.1.6"
 
 /* Initialize the protocol and registered fields */
-int proto_pkcs12 = -1;
+static int proto_pkcs12 = -1;
 
 static int hf_pkcs12_X509Certificate_PDU = -1;
 static gint ett_decrypted_pbe = -1;
