@@ -2,7 +2,7 @@
  * Routines for UMTS Node B Application Part(RANAP) packet dissection
  * Copyright 2005, Anders Broman <anders.broman[AT]ericsson.com>
  *
- * $Id: packet-ranap-template.c 30710 2009-10-26 15:12:32Z etxrab $
+ * $Id: packet-ranap-template.c 31058 2009-11-23 22:02:05Z etxrab $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -66,7 +66,8 @@
 static int proto_ranap = -1;
 
 /* initialise sub-dissector handles */
-static dissector_handle_t rrc_handle = NULL;
+static dissector_handle_t rrc_s_to_trnc_handle = NULL;
+static dissector_handle_t rrc_t_to_srnc_handle = NULL;
 
 static int hf_ranap_imsi_digits = -1;
 static int hf_ranap_transportLayerAddress_ipv4 = -1;
@@ -132,6 +133,10 @@ static int dissect_InitiatingMessageValue(tvbuff_t *tvb, packet_info *pinfo, pro
 static int dissect_SuccessfulOutcomeValue(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree);
 static int dissect_UnsuccessfulOutcomeValue(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree);
 static int dissect_OutcomeValue(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree);
+
+static int dissect_ranap_SourceRNC_ToTargetRNC_TransparentContainer(tvbuff_t *tvb, int offset, asn1_ctx_t *actx, proto_tree *tree, int hf_index);
+static int dissect_ranap_TargetRNC_ToSourceRNC_TransparentContainer(tvbuff_t *tvb, int offset, asn1_ctx_t *actx, proto_tree *tree, int hf_index);
+
 void proto_reg_handoff_ranap(void);
 
 #include "packet-ranap-fn.c"
@@ -155,7 +160,7 @@ static int dissect_ProtocolIEFieldValue(tvbuff_t *tvb, packet_info *pinfo, proto
 		  /* no special handling */
 		  ret = (dissector_try_port_new(ranap_ies_dissector_table, ProtocolIE_ID, tvb, pinfo, tree, FALSE)) ? tvb_length(tvb) : 0;
 		  if (ret == 0) {
-			  key = pdu_type || ProtocolIE_ID;
+			  key = pdu_type | ProtocolIE_ID;
 			  ret = (dissector_try_port_new(ranap_ies_dissector_table, key, tvb, pinfo, tree, FALSE)) ? tvb_length(tvb) : 0;
 		  }
 		  break;
@@ -339,7 +344,8 @@ proto_reg_handoff_ranap(void)
 
 	if (!initialized) {
 		ranap_handle = find_dissector("ranap");
-		rrc_handle = find_dissector("rrc.s_to_trnc_cont");
+		rrc_s_to_trnc_handle = find_dissector("rrc.s_to_trnc_cont");
+		rrc_t_to_srnc_handle = find_dissector("rrc.t_to_srnc_cont");
 		initialized = TRUE;
 #include "packet-ranap-dis-tab.c"
 	} else {
