@@ -4,7 +4,7 @@
  * (3GPP TS 25.331 version 6.7.0 Release 6) packet dissection
  * Copyright 2006, Anders Broman <anders.broman@ericsson.com>
  *
- * $Id: packet-rrc-template.c 26129 2008-09-03 17:03:30Z etxrab $
+ * $Id: packet-rrc-template.c 30838 2009-11-05 21:54:06Z etxrab $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -33,7 +33,6 @@
 
 #include <glib.h>
 #include <epan/packet.h>
-#include <epan/conversation.h>
 #include <epan/asn1.h>
 
 #include <stdio.h>
@@ -53,15 +52,20 @@
 #define PSNAME "RRC"
 #define PFNAME "rrc"
 
-static dissector_handle_t rrc_handle=NULL;
-static dissector_handle_t gsm_a_dtap_handle=NULL;
+static dissector_handle_t gsm_a_dtap_handle;
+static dissector_handle_t rrc_ue_radio_access_cap_info_handle=NULL;
+static dissector_handle_t rrc_pcch_handle=NULL;
+static dissector_handle_t rrc_ul_ccch_handle=NULL;
+static dissector_handle_t rrc_dl_ccch_handle=NULL;
+static dissector_handle_t rrc_ul_dcch_handle=NULL;
+static dissector_handle_t rrc_dl_dcch_handle=NULL;
 
 /* Include constants */
 #include "packet-rrc-val.h"
 
 /* Initialize the protocol and registered fields */
-static int proto_rrc = -1;
-
+int proto_rrc = -1;
+static int hf_test;
 #include "packet-rrc-hf.c"
 
 /* Initialize the subtree pointers */
@@ -74,6 +78,8 @@ static proto_tree *top_tree;
 
 #include "packet-rrc-fn.c"
 
+#include "packet-rrc.h"
+
 /* 
 TODO: Remove the dummy function when these functions are taken into use
 
@@ -83,54 +89,13 @@ TODO: Remove the dummy function when these functions are taken into use
  */
 
 static void
-dissect_rrc_dymmy_remove_unused_code_warnings(tvbuff_t *tvb _U_, int offset _U_, asn1_ctx_t *actx _U_, proto_tree *tree _U_, int hf_index _U_){
+dissect_rrc_dummy_remove_unused_code_warnings(tvbuff_t *tvb _U_, int offset _U_, asn1_ctx_t *actx _U_, proto_tree *tree _U_, int hf_index _U_){
 
 	/* Dummy code to keep GCC happy */
 	switch(hf_index){
 		case 0:
-			dissect_rrc_HandoverToUTRANCommand( tvb, offset, actx , tree, hf_index);
-			dissect_rrc_InterRATHandoverInfo( tvb, offset, actx , tree, hf_index);
-			dissect_rrc_UE_RadioAccessCapabilityInfo( tvb, offset, actx , tree, hf_index);
 			dissect_rrc_UL_PhysChCapabilityFDD_r6( tvb, offset, actx , tree, hf_index);
 			dissect_rrc_UE_Positioning_GANSS_Data( tvb, offset, actx , tree, hf_index);
-			dissect_rrc_MasterInformationBlock( tvb, offset, actx , tree, hf_index);
-			dissect_rrc_SysInfoType1( tvb, offset, actx , tree, hf_index);
-			dissect_rrc_SysInfoType2( tvb, offset, actx , tree, hf_index);
-			dissect_rrc_SysInfoType3( tvb, offset, actx , tree, hf_index);
-			dissect_rrc_SysInfoType4( tvb, offset, actx , tree, hf_index);
-			dissect_rrc_SysInfoType5bis( tvb, offset, actx , tree, hf_index);
-			dissect_rrc_SysInfoType6( tvb, offset, actx , tree, hf_index);
-			dissect_rrc_SysInfoType7( tvb, offset, actx , tree, hf_index);
-			dissect_rrc_SysInfoType8( tvb, offset, actx , tree, hf_index);
-			dissect_rrc_SysInfoType9( tvb, offset, actx , tree, hf_index);
-			dissect_rrc_SysInfoType10( tvb, offset, actx , tree, hf_index);
-			dissect_rrc_SysInfoType11( tvb, offset, actx , tree, hf_index);
-			dissect_rrc_SysInfoType11bis( tvb, offset, actx , tree, hf_index);
-			dissect_rrc_SysInfoType12( tvb, offset, actx , tree, hf_index);
-			dissect_rrc_SysInfoType13( tvb, offset, actx , tree, hf_index);
-			dissect_rrc_SysInfoType13_1( tvb, offset, actx , tree, hf_index);
-			dissect_rrc_SysInfoType13_2( tvb, offset, actx , tree, hf_index);
-			dissect_rrc_SysInfoType13_3( tvb, offset, actx , tree, hf_index);
-			dissect_rrc_SysInfoType13_4( tvb, offset, actx , tree, hf_index);
-			dissect_rrc_SysInfoType14( tvb, offset, actx , tree, hf_index);
-			dissect_rrc_SysInfoType15( tvb, offset, actx , tree, hf_index);
-			dissect_rrc_SysInfoType15bis( tvb, offset, actx , tree, hf_index);
-			dissect_rrc_SysInfoType15_1( tvb, offset, actx , tree, hf_index);
-			dissect_rrc_SysInfoType15_1bis( tvb, offset, actx , tree, hf_index);
-			dissect_rrc_SysInfoType15_2( tvb, offset, actx , tree, hf_index);
-			dissect_rrc_SysInfoType15_2bis( tvb, offset, actx , tree, hf_index);
-			dissect_rrc_SysInfoType15_3( tvb, offset, actx , tree, hf_index);
-			dissect_rrc_SysInfoType15_3bis( tvb, offset, actx , tree, hf_index);
-			dissect_rrc_SysInfoType15_4( tvb, offset, actx , tree, hf_index);
-			dissect_rrc_SysInfoType15_5( tvb, offset, actx , tree, hf_index);
-			dissect_rrc_SysInfoType15_6( tvb, offset, actx , tree, hf_index);
-			dissect_rrc_SysInfoType15_7( tvb, offset, actx , tree, hf_index);
-			dissect_rrc_SysInfoType15_8( tvb, offset, actx , tree, hf_index);
-			dissect_rrc_SysInfoType16( tvb, offset, actx , tree, hf_index);
-			dissect_rrc_SysInfoType17( tvb, offset, actx , tree, hf_index);
-			dissect_rrc_SysInfoType18( tvb, offset, actx , tree, hf_index);
-			dissect_rrc_SysInfoTypeSB1( tvb, offset, actx , tree, hf_index);
-			dissect_rrc_SysInfoTypeSB2( tvb, offset, actx , tree, hf_index);
 			dissect_rrc_ToTargetRNC_Container( tvb, offset, actx , tree, hf_index);
 			dissect_rrc_TargetRNC_ToSourceRNC_Container( tvb, offset, actx , tree, hf_index);
 			break;
@@ -147,17 +112,39 @@ dissect_rrc(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 	 */
 	proto_item	*rrc_item = NULL;
 	proto_tree	*rrc_tree = NULL;
+	struct rrc_info *rrcinf;
 
 	top_tree = tree;
+	rrcinf = p_get_proto_data(pinfo->fd, proto_rrc);
 
 	/* make entry in the Protocol column on summary display */
-	if (check_col(pinfo->cinfo, COL_PROTOCOL))
-		col_set_str(pinfo->cinfo, COL_PROTOCOL, "RRC");
+	col_set_str(pinfo->cinfo, COL_PROTOCOL, "RRC");
 
 	/* create the rrc protocol tree */
 	rrc_item = proto_tree_add_item(tree, proto_rrc, tvb, 0, -1, FALSE);
 	rrc_tree = proto_item_add_subtree(rrc_item, ett_rrc);
 
+	if (rrcinf) {
+		switch (rrcinf->msgtype[pinfo->fd->subnum]) {
+			case RRC_MESSAGE_TYPE_PCCH:
+				call_dissector(rrc_pcch_handle, tvb, pinfo, rrc_tree);
+				break;
+			case RRC_MESSAGE_TYPE_UL_CCCH:
+				call_dissector(rrc_ul_ccch_handle, tvb, pinfo, rrc_tree);
+				break;
+			case RRC_MESSAGE_TYPE_DL_CCCH:
+				call_dissector(rrc_dl_ccch_handle, tvb, pinfo, rrc_tree);
+				break;
+			case RRC_MESSAGE_TYPE_UL_DCCH:
+				call_dissector(rrc_ul_dcch_handle, tvb, pinfo, rrc_tree);
+				break;
+			case RRC_MESSAGE_TYPE_DL_DCCH:
+				call_dissector(rrc_dl_dcch_handle, tvb, pinfo, rrc_tree);
+				break;
+			default:
+				;
+		}
+	}
 }
 /*--- proto_register_rrc -------------------------------------------*/
 void proto_register_rrc(void) {
@@ -166,6 +153,11 @@ void proto_register_rrc(void) {
   static hf_register_info hf[] = {
 
 #include "packet-rrc-hfarr.c"
+    { &hf_test,
+      { "RAB Test", "rrc.RAB.test",
+        FT_UINT8, BASE_DEC, NULL, 0,
+        "rrc.RAB_Info_r6", HFILL }},
+
   };
 
   /* List of subtrees */
@@ -181,7 +173,6 @@ void proto_register_rrc(void) {
   proto_register_field_array(proto_rrc, hf, array_length(hf));
   proto_register_subtree_array(ett, array_length(ett));
 
-
   register_dissector("rrc", dissect_rrc, proto_rrc);
 
 #include "packet-rrc-dis-reg.c"
@@ -194,9 +185,14 @@ void
 proto_reg_handoff_rrc(void)
 {
 
-	rrc_handle = find_dissector("rrc");
 	gsm_a_dtap_handle = find_dissector("gsm_a_dtap");
-
+	rrc_pcch_handle = find_dissector("rrc.pcch");
+	rrc_ul_ccch_handle = find_dissector("rrc.ul.ccch");
+	rrc_dl_ccch_handle = find_dissector("rrc.dl.ccch");
+	rrc_ul_dcch_handle = find_dissector("rrc.ul.dcch");
+	rrc_dl_dcch_handle = find_dissector("rrc.dl.dcch");
+	rrc_ue_radio_access_cap_info_handle = find_dissector("rrc.ue_radio_access_cap_info");
+	rrc_dl_dcch_handle = find_dissector("rrc.dl.dcch");
 }
 
 
