@@ -2,7 +2,7 @@
  * Routines for X.411 (X.400 Message Transfer)  packet dissection
  * Graeme Lunt 2005
  *
- * $Id: packet-x411-template.c 26750 2008-11-11 15:05:00Z wmeier $
+ * $Id: packet-x411-template.c 30516 2009-10-11 16:24:29Z stig $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -30,7 +30,6 @@
 #include <glib.h>
 #include <epan/packet.h>
 #include <epan/prefs.h>
-#include <epan/conversation.h>
 #include <epan/oids.h>
 #include <epan/asn1.h>
 #include <epan/expert.h>
@@ -49,7 +48,6 @@
 #include "packet-x509sat.h"
 
 #include "packet-x411.h"
-#include <epan/emem.h>
 #include <epan/strutil.h>
 
 #define PNAME  "X.411 Message Transfer Service"
@@ -61,7 +59,8 @@ static dissector_handle_t tpkt_handle;
 void prefs_register_x411(void); /* forward declaration for use in preferences registration */
 
 /* Initialize the protocol and registered fields */
-int proto_x411 = -1;
+static int proto_x411 = -1;
+static int proto_p3 = -1;
 
 static struct SESSION_DATA_STRUCTURE* session = NULL;
 static int extension_id = -1; /* integer extension id */
@@ -86,6 +85,7 @@ static int hf_x411_MTABindError_PDU = -1;
 
 /* Initialize the subtree pointers */
 static gint ett_x411 = -1;
+static gint ett_p3 = -1;
 static gint ett_x411_content_unknown = -1;
 static gint ett_x411_bilateral_information = -1;
 static gint ett_x411_additional_information = -1;
@@ -99,9 +99,26 @@ static dissector_table_t x411_extension_dissector_table;
 static dissector_table_t x411_extension_attribute_dissector_table;
 static dissector_table_t x411_tokendata_dissector_table;
 
+#include "packet-x411-val.h"
+
+#include "packet-x411-table.c"   /* operation and error codes */
 
 #include "packet-x411-fn.c"
 
+#include "packet-x411-table11.c" /* operation argument/result dissectors */
+#include "packet-x411-table21.c" /* error dissector */
+
+static const ros_info_t p3_ros_info = {
+  "P3",
+  &proto_p3,
+  &ett_p3,
+  p3_opr_code_string_vals,
+  p3_opr_tab,
+  p3_err_code_string_vals,
+  p3_err_tab
+};
+
+
 char* x411_get_last_oraddress() { return oraddress; }
 
 /*
@@ -123,10 +140,8 @@ dissect_x411_mts_apdu (tvbuff_t *tvb, packet_info *pinfo, proto_tree *parent_tre
 		tree = proto_item_add_subtree(item, ett_x411);
 	}
 
-	if (check_col(pinfo->cinfo, COL_PROTOCOL))
-		col_set_str(pinfo->cinfo, COL_PROTOCOL, "P1");
-  	if (check_col(pinfo->cinfo, COL_INFO))
-  		col_set_str(pinfo->cinfo, COL_INFO, "Transfer");
+	col_set_str(pinfo->cinfo, COL_PROTOCOL, "P1");
+  	col_set_str(pinfo->cinfo, COL_INFO, "Transfer");
 
 	dissect_x411_MTS_APDU (FALSE, tvb, 0, &asn1_ctx, tree, hf_x411_MTS_APDU_PDU);
 }
@@ -165,10 +180,8 @@ dissect_x411(tvbuff_t *tvb, packet_info *pinfo, proto_tree *parent_tree)
 		item = proto_tree_add_item(parent_tree, proto_x411, tvb, 0, -1, FALSE);
 		tree = proto_item_add_subtree(item, ett_x411);
 	}
-	if (check_col(pinfo->cinfo, COL_PROTOCOL))
-		col_set_str(pinfo->cinfo, COL_PROTOCOL, "P1");
-  	if (check_col(pinfo->cinfo, COL_INFO))
-  		col_clear(pinfo->cinfo, COL_INFO);
+	col_set_str(pinfo->cinfo, COL_PROTOCOL, "P1");
+  	col_clear(pinfo->cinfo, COL_INFO);
 
 	switch(session->ros_op & ROS_OP_MASK) {
 	case (ROS_OP_BIND | ROS_OP_ARGUMENT):	/*  BindInvoke */
@@ -241,6 +254,7 @@ void proto_register_x411(void) {
   /* List of subtrees */
   static gint *ett[] = {
     &ett_x411,
+    &ett_p3,
     &ett_x411_content_unknown,
     &ett_x411_bilateral_information,
     &ett_x411_additional_information,
@@ -255,6 +269,9 @@ void proto_register_x411(void) {
   /* Register protocol */
   proto_x411 = proto_register_protocol(PNAME, PSNAME, PFNAME);
   register_dissector("x411", dissect_x411, proto_x411);
+
+  proto_p3 = proto_register_protocol("X.411 Message Access Service", "P3", "p3");
+
   /* Register fields and subtrees */
   proto_register_field_array(proto_x411, hf, array_length(hf));
   proto_register_subtree_array(ett, array_length(ett));
@@ -298,6 +315,25 @@ void proto_reg_handoff_x411(void) {
   /* remember the tpkt handler for change in preferences */
   tpkt_handle = find_dissector("tpkt");
 
+  /* APPLICATION CONTEXT */
+
+  oid_add_from_string("id-ac-mts-access-88", id_ac_mts_access_88);
+  oid_add_from_string("id-ac-mts-forced-access-88", id_ac_mts_forced_access_88);
+  oid_add_from_string("id-ac-mts-access-94", id_ac_mts_access_94);
+  oid_add_from_string("id-ac-mts-forced-access-94", id_ac_mts_forced_access_94);
+
+
+  /* Register P3 with ROS */
+  register_ros_protocol_info(id_as_msse, &p3_ros_info, 0, "id-as-msse", FALSE); 
+
+  register_ros_protocol_info(id_as_mdse_88, &p3_ros_info, 0, "id-as-mdse-88", FALSE); 
+  register_ros_protocol_info(id_as_mdse_94, &p3_ros_info, 0, "id-as-mdse-94", FALSE); 
+
+  register_ros_protocol_info(id_as_mase_88, &p3_ros_info, 0, "id-as-mase-88", FALSE); 
+  register_ros_protocol_info(id_as_mase_94, &p3_ros_info, 0, "id-as-mase-94", FALSE); 
+
+  register_ros_protocol_info(id_as_mts, &p3_ros_info, 0, "id-as-mts", FALSE); 
+
 }
 
 void prefs_register_x411(void) {
