@@ -2,7 +2,7 @@
  * Routines for X.509 Authentication Framework packet dissection
  *  Ronnie Sahlberg 2004
  *
- * $Id: packet-x509af-template.c 20414 2007-01-13 12:59:27Z gal $
+ * $Id: packet-x509af-template.c 30124 2009-09-24 19:50:43Z krj $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -29,8 +29,8 @@
 
 #include <glib.h>
 #include <epan/packet.h>
-#include <epan/conversation.h>
-#include <epan/oid_resolv.h>
+#include <epan/oids.h>
+#include <epan/asn1.h>
 
 #include <stdio.h>
 #include <string.h>
@@ -71,15 +71,12 @@ dissect_pkix_crl(tvbuff_t *tvb, packet_info *pinfo, proto_tree *parent_tree)
 {
 	proto_item *item=NULL;
 	proto_tree *tree=NULL;
+	asn1_ctx_t asn1_ctx;
+	asn1_ctx_init(&asn1_ctx, ASN1_ENC_BER, TRUE, pinfo);
 
-	if (check_col(pinfo->cinfo, COL_PROTOCOL)) 
-		col_set_str(pinfo->cinfo, COL_PROTOCOL, "PKIX-CRL");
+	col_set_str(pinfo->cinfo, COL_PROTOCOL, "PKIX-CRL");
 
-	if (check_col(pinfo->cinfo, COL_INFO)) {
-		col_clear(pinfo->cinfo, COL_INFO);
-		
-		col_add_fstr(pinfo->cinfo, COL_INFO, "Certificate Revocation List");
-	}
+	col_set_str(pinfo->cinfo, COL_INFO, "Certificate Revocation List");
 
 
 	if(parent_tree){
@@ -87,7 +84,7 @@ dissect_pkix_crl(tvbuff_t *tvb, packet_info *pinfo, proto_tree *parent_tree)
 		tree = proto_item_add_subtree(item, ett_pkix_crl);
 	}
 
-	return dissect_x509af_CertificateList(FALSE, tvb, 0, pinfo, tree, -1);
+	return dissect_x509af_CertificateList(FALSE, tvb, 0, &asn1_ctx, tree, -1);
 }
 
 /*--- proto_register_x509af ----------------------------------------------*/
@@ -98,11 +95,11 @@ void proto_register_x509af(void) {
     { &hf_x509af_algorithm_id,
       { "Algorithm Id", "x509af.algorithm.id",
         FT_OID, BASE_NONE, NULL, 0,
-        "Algorithm Id", HFILL }},
+        NULL, HFILL }},
     { &hf_x509af_extension_id,
       { "Extension Id", "x509af.extension.id",
         FT_OID, BASE_NONE, NULL, 0,
-        "Extension Id", HFILL }},
+        NULL, HFILL }},
 #include "packet-x509af-hfarr.c"
   };
 
@@ -156,11 +153,14 @@ void proto_reg_handoff_x509af(void) {
 	register_ber_oid_dissector("1.3.14.3.2.24", dissect_ber_oid_NULL_callback, proto_x509af, "md2WithRSASignature");
 	register_ber_oid_dissector("1.3.14.3.2.25", dissect_ber_oid_NULL_callback, proto_x509af, "md5WithRSASignature");
 	register_ber_oid_dissector("1.3.14.3.2.26", dissect_ber_oid_NULL_callback, proto_x509af, "SHA-1");
+	register_ber_oid_dissector("1.3.14.3.2.27", dissect_ber_oid_NULL_callback, proto_x509af, "dsaWithSHA1");
+	register_ber_oid_dissector("1.3.14.3.2.28", dissect_ber_oid_NULL_callback, proto_x509af, "dsaWithCommonSHA1");
+	register_ber_oid_dissector("1.3.14.3.2.29", dissect_ber_oid_NULL_callback, proto_x509af, "sha-1WithRSAEncryption");
 
 	/* these will generally be encoded as ";binary" in LDAP */
 
 	register_ldap_name_dissector("cACertificate", dissect_Certificate_PDU, proto_x509af);
-	register_ldap_name_dissector("certificate", dissect_Certificate_PDU, proto_x509af);
+	register_ldap_name_dissector("userCertificate", dissect_Certificate_PDU, proto_x509af);
 	
 	register_ldap_name_dissector("certificateRevocationList", dissect_CertificateList_PDU, proto_x509af);
 	register_ldap_name_dissector("crl", dissect_CertificateList_PDU, proto_x509af);
