@@ -1,7 +1,7 @@
 /* capture_sync.c
  * Synchronisation between Wireshark capture parent and child instances
  *
- * $Id: capture_sync.c 27074 2008-12-21 23:22:12Z guy $
+ * $Id: capture_sync.c 29881 2009-09-13 17:46:10Z morriss $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -355,6 +355,8 @@ sync_pipe_start(capture_options *capture_opts) {
 
     if (!capture_opts->promisc_mode)
       argv = sync_pipe_add_arg(argv, &argc, "-p");
+    if (capture_opts->use_pcapng)
+      argv = sync_pipe_add_arg(argv, &argc, "-n");
 #ifdef HAVE_PCAP_REMOTE
     if (capture_opts->datatx_udp)
       argv = sync_pipe_add_arg(argv, &argc, "-u");
@@ -1423,11 +1425,11 @@ sync_pipe_stop(capture_options *capture_opts)
 
   if (capture_opts->fork_child != -1) {
 #ifndef _WIN32
-    /* send the SIGUSR1 signal to close the capture child gracefully. */
-    int sts = kill(capture_opts->fork_child, SIGUSR1);
+    /* send the SIGINT signal to close the capture child gracefully. */
+    int sts = kill(capture_opts->fork_child, SIGINT);
     if (sts != 0) {
         g_log(LOG_DOMAIN_CAPTURE_CHILD, G_LOG_LEVEL_WARNING,
-              "Sending SIGUSR1 to child failed: %s\n", strerror(errno));
+              "Sending SIGINT to child failed: %s\n", strerror(errno));
     }
 #else
 #define STOP_SLEEP_TIME 500 /* ms */
