@@ -1,7 +1,7 @@
 /* color_filters.c
  * Routines for color filters
  *
- * $Id: color_filters.c 29729 2009-09-06 06:07:53Z krj $
+ * $Id: color_filters.c 30616 2009-10-19 14:21:11Z stig $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -92,7 +92,7 @@ color_filter_new(const gchar *name,    /* The name of the filter to create */
 }
 
 /* Add ten empty (temporary) colorfilters for easy coloring */
-void
+static void
 color_filters_add_tmp(GSList **cfl)
 {
 	gchar  *name = NULL;
@@ -291,8 +291,8 @@ color_filters_init(void)
 	/* delete all currently existing filters */
 	color_filter_list_delete(&color_filter_list);
 
-        /* start the list with the temporary colorizing rules */
-        color_filters_add_tmp(&color_filter_list);
+	/* start the list with the temporary colorizing rules */
+	color_filters_add_tmp(&color_filter_list);
 
 	/* try to read the users filters */
 	if (!read_users_filters(&color_filter_list))
@@ -441,7 +441,7 @@ color_filters_prime_edt(epan_dissect_t *edt)
 /* Colorize a single packet of the packet list (old packet list)
  *
  * Return the color_t for later use (new packet list) */
-color_filter_t *
+const color_filter_t *
 #ifdef NEW_PACKET_LIST
 color_filters_colorize_packet(epan_dissect_t *edt)
 #else
