@@ -4,7 +4,7 @@
  * for calculation of delays in camel calls
  * Copyright 2006 Florent Drouin
  *
- * $Id: camel-persistentdata.c 25255 2008-05-08 05:42:59Z etxrab $
+ * $Id: camel-persistentdata.c 29502 2009-08-21 20:51:13Z krj $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -34,13 +34,12 @@
 #include <string.h>
 
 #include <epan/emem.h>
-#include "epan/packet.h"
-#include "epan/conversation.h"
-#include "epan/tap.h"
+#include <epan/packet.h>
+#include <epan/tap.h>
 #include <epan/asn1.h>
-#include "epan/camel-persistentdata.h"
-#include "epan/dissectors/packet-tcap.h"
-#include "epan/dissectors/packet-mtp3.h"
+#include <epan/camel-persistentdata.h>
+#include <epan/dissectors/packet-tcap.h>
+#include <epan/dissectors/packet-mtp3.h>
 
 const value_string  camelSRTtype_naming[]= {
   { CAMELSRT_SESSION,         "TCAP_Session" },
