@@ -1,7 +1,7 @@
 /* column.c
  * Routines for handling column preferences
  *
- * $Id: column.c 27984 2009-04-07 16:36:52Z gerald $
+ * $Id: column.c 30534 2009-10-12 09:13:37Z stig $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -71,11 +71,11 @@ col_format_to_string(gint fmt) {
     "%I",                                       /* 21) COL_IF_DIR */
     "%XO",                                      /* 22) COL_OXID */
     "%XR",                                      /* 23) COL_RXID */
-    "%C",                                       /* 24) COL_FR_DLCI */
+    "%C",                                       /* 24) !! DEPRECATED !! - COL_FR_DLCI */
     "%F",                                       /* 25) COL_FREQ_CHAN */
-    "%l",                                       /* 26) COL_BSSGP_TLLI */
-    "%P",                                       /* 27) COL_HPUX_DEVID */
-    "%H",                                       /* 28) COL_HPUX_SUBSYS */
+    "%l",                                       /* 26) !! DEPRECATED !! - COL_BSSGP_TLLI */
+    "%P",                                       /* 27) !! DEPRECATED !! - COL_HPUX_DEVID */
+    "%H",                                       /* 28) !! DEPRECATED !! - COL_HPUX_SUBSYS */
     "%hd",                                      /* 29) COL_DEF_DL_DST */
     "%hs",                                      /* 30) COL_DEF_DL_SRC */
     "%rhd",                                     /* 31) COL_RES_DL_DST */
@@ -86,7 +86,7 @@ col_format_to_string(gint fmt) {
     "%x",                                       /* 36) COL_TX_RATE */
     "%f",                                       /* 37) COL_DSCP_VALUE */
     "%i",                                       /* 38) COL_INFO */
-    "%U",                                       /* 39) COL_COS_VALUE */
+    "%U",                                       /* 39) !! DEPRECATED !! - COL_COS_VALUE */
     "%rnd",                                     /* 40) COL_RES_NET_DST */
     "%und",                                     /* 41) COL_UNRES_NET_DST */
     "%rns",                                     /* 42) COL_RES_NET_SRC */
@@ -97,7 +97,7 @@ col_format_to_string(gint fmt) {
     "%L",                                       /* 47) COL_PACKET_LENGTH */
     "%p",                                       /* 48) COL_PROTOCOL */
     "%Rt",                                      /* 49) COL_REL_TIME */
-    "%rct",                                     /* 50) COL_REL_CONV_TIME */
+    "%rct",                                     /* 50) !! DEPRECATED !! - COL_REL_CONV_TIME */
     "%s",                                       /* 51) COL_DEF_SRC */
     "%S",                                       /* 52) COL_DEF_SRC_PORT */
     "%rs",                                      /* 53) COL_RES_SRC */
@@ -141,11 +141,11 @@ static const gchar *dlist[NUM_COL_FMTS] = {
     "FW-1 monitor if/direction",                /* 21) COL_IF_DIR */
     "Fibre Channel OXID",                       /* 22) COL_OXID */
     "Fibre Channel RXID",                       /* 23) COL_RXID */
-    "Frame Relay DLCI",                         /* 24) COL_FR_DLCI */
+    "Frame Relay DLCI",                         /* 24) !! DEPRECATED !! - COL_FR_DLCI */
     "Frequency/Channel",                        /* 25) COL_FREQ_CHAN */
-    "GPRS BSSGP TLLI",                          /* 26) COL_BSSGP_TLLI */
-    "HP-UX Device ID",                          /* 27) COL_HPUX_DEVID */
-    "HP-UX Subsystem",                          /* 28) COL_HPUX_SUBSYS */
+    "GPRS BSSGP TLLI",                          /* 26) !! DEPRECATED !! - COL_BSSGP_TLLI */
+    "HP-UX Device ID",                          /* 27) !! DEPRECATED !! - COL_HPUX_DEVID */
+    "HP-UX Subsystem",                          /* 28) !! DEPRECATED !! - COL_HPUX_SUBSYS */
     "Hardware dest addr",                       /* 29) COL_DEF_DL_DST */
     "Hardware src addr",                        /* 30) COL_DEF_DL_SRC */
     "Hw dest addr (resolved)",                  /* 31) COL_RES_DL_DST */
@@ -156,7 +156,7 @@ static const gchar *dlist[NUM_COL_FMTS] = {
     "IEEE 802.11 TX rate",                      /* 36) COL_TX_RATE */
     "IP DSCP Value",                            /* 37) COL_DSCP_VALUE */
     "Information",                              /* 38) COL_INFO */
-    "L2 COS Value (802.1p)",                    /* 39) COL_COS_VALUE */
+    "L2 COS Value (802.1p)",                    /* 39) !! DEPRECATED !! - COL_COS_VALUE */
     "Net dest addr (resolved)",                 /* 40) COL_RES_NET_DST */
     "Net dest addr (unresolved)",               /* 41) COL_UNRES_NET_DST */
     "Net src addr (resolved)",                  /* 42) COL_RES_NET_SRC */
@@ -167,7 +167,7 @@ static const gchar *dlist[NUM_COL_FMTS] = {
     "Packet length (bytes)" ,                   /* 47) COL_PACKET_LENGTH */
     "Protocol",                                 /* 48) COL_PROTOCOL */
     "Relative time",                            /* 49) COL_REL_TIME */
-    "Relative time (conversation)",             /* 50) COL_REL_CONV_TIME */
+    "Relative time (conversation)",             /* 50) !! DEPRECATED !! - COL_REL_CONV_TIME */
     "Source address",                           /* 51) COL_DEF_SRC */
     "Source port",                              /* 52) COL_DEF_SRC_PORT */
     "Src addr (resolved)",                      /* 53) COL_RES_SRC */
@@ -314,139 +314,139 @@ static const char *
 get_timestamp_column_longest_string(gint type, gint precision)
 {
 
-	switch(type) {
-	case(TS_ABSOLUTE_WITH_DATE):
-		switch(precision) {
-			case(TS_PREC_AUTO_SEC):
-			case(TS_PREC_FIXED_SEC):
-				return "0000-00-00 00:00:00";
-				break;
-			case(TS_PREC_AUTO_DSEC):
-			case(TS_PREC_FIXED_DSEC):
-				return "0000-00-00 00:00:00.0";
-				break;
-			case(TS_PREC_AUTO_CSEC):
-			case(TS_PREC_FIXED_CSEC):
-				return "0000-00-00 00:00:00.00";
-				break;
-			case(TS_PREC_AUTO_MSEC):
-			case(TS_PREC_FIXED_MSEC):
-				return "0000-00-00 00:00:00.000";
-				break;
-			case(TS_PREC_AUTO_USEC):
-			case(TS_PREC_FIXED_USEC):
-				return "0000-00-00 00:00:00.000000";
-				break;
-			case(TS_PREC_AUTO_NSEC):
-			case(TS_PREC_FIXED_NSEC):
-				return "0000-00-00 00:00:00.000000000";
-				break;
-			default:
-				g_assert_not_reached();
-		}
-			break;
-	case(TS_ABSOLUTE):
-		switch(precision) {
-			case(TS_PREC_AUTO_SEC):
-			case(TS_PREC_FIXED_SEC):
-				return "00:00:00";
-				break;
-			case(TS_PREC_AUTO_DSEC):
-			case(TS_PREC_FIXED_DSEC):
-				return "00:00:00.0";
-				break;
-			case(TS_PREC_AUTO_CSEC):
-			case(TS_PREC_FIXED_CSEC):
-				return "00:00:00.00";
-				break;
-			case(TS_PREC_AUTO_MSEC):
-			case(TS_PREC_FIXED_MSEC):
-				return "00:00:00.000";
-				break;
-			case(TS_PREC_AUTO_USEC):
-			case(TS_PREC_FIXED_USEC):
-				return "00:00:00.000000";
-				break;
-			case(TS_PREC_AUTO_NSEC):
-			case(TS_PREC_FIXED_NSEC):
-				return "00:00:00.000000000";
-				break;
-			default:
-				g_assert_not_reached();
-		}
-		break;
-	case(TS_RELATIVE):	/* fallthrough */
-	case(TS_DELTA):
-	case(TS_DELTA_DIS):
-		switch(precision) {
-			case(TS_PREC_AUTO_SEC):
-			case(TS_PREC_FIXED_SEC):
-				return "0000";
-				break;
-			case(TS_PREC_AUTO_DSEC):
-			case(TS_PREC_FIXED_DSEC):
-				return "0000.0";
-				break;
-			case(TS_PREC_AUTO_CSEC):
-			case(TS_PREC_FIXED_CSEC):
-				return "0000.00";
-				break;
-			case(TS_PREC_AUTO_MSEC):
-			case(TS_PREC_FIXED_MSEC):
-				return "0000.000";
-				break;
-			case(TS_PREC_AUTO_USEC):
-			case(TS_PREC_FIXED_USEC):
-				return "0000.000000";
-				break;
-			case(TS_PREC_AUTO_NSEC):
-			case(TS_PREC_FIXED_NSEC):
-				return "0000.000000000";
-				break;
-			default:
-				g_assert_not_reached();
-		}
-		break;
-	case(TS_EPOCH):
+    switch(type) {
+    case(TS_ABSOLUTE_WITH_DATE):
+        switch(precision) {
+            case(TS_PREC_AUTO_SEC):
+            case(TS_PREC_FIXED_SEC):
+                return "0000-00-00 00:00:00";
+                break;
+            case(TS_PREC_AUTO_DSEC):
+            case(TS_PREC_FIXED_DSEC):
+                return "0000-00-00 00:00:00.0";
+                break;
+            case(TS_PREC_AUTO_CSEC):
+            case(TS_PREC_FIXED_CSEC):
+                return "0000-00-00 00:00:00.00";
+                break;
+            case(TS_PREC_AUTO_MSEC):
+            case(TS_PREC_FIXED_MSEC):
+                return "0000-00-00 00:00:00.000";
+                break;
+            case(TS_PREC_AUTO_USEC):
+            case(TS_PREC_FIXED_USEC):
+                return "0000-00-00 00:00:00.000000";
+                break;
+            case(TS_PREC_AUTO_NSEC):
+            case(TS_PREC_FIXED_NSEC):
+                return "0000-00-00 00:00:00.000000000";
+                break;
+            default:
+                g_assert_not_reached();
+        }
+            break;
+    case(TS_ABSOLUTE):
+        switch(precision) {
+            case(TS_PREC_AUTO_SEC):
+            case(TS_PREC_FIXED_SEC):
+                return "00:00:00";
+                break;
+            case(TS_PREC_AUTO_DSEC):
+            case(TS_PREC_FIXED_DSEC):
+                return "00:00:00.0";
+                break;
+            case(TS_PREC_AUTO_CSEC):
+            case(TS_PREC_FIXED_CSEC):
+                return "00:00:00.00";
+                break;
+            case(TS_PREC_AUTO_MSEC):
+            case(TS_PREC_FIXED_MSEC):
+                return "00:00:00.000";
+                break;
+            case(TS_PREC_AUTO_USEC):
+            case(TS_PREC_FIXED_USEC):
+                return "00:00:00.000000";
+                break;
+            case(TS_PREC_AUTO_NSEC):
+            case(TS_PREC_FIXED_NSEC):
+                return "00:00:00.000000000";
+                break;
+            default:
+                g_assert_not_reached();
+        }
+        break;
+    case(TS_RELATIVE):  /* fallthrough */
+    case(TS_DELTA):
+    case(TS_DELTA_DIS):
+        switch(precision) {
+            case(TS_PREC_AUTO_SEC):
+            case(TS_PREC_FIXED_SEC):
+                return "0000";
+                break;
+            case(TS_PREC_AUTO_DSEC):
+            case(TS_PREC_FIXED_DSEC):
+                return "0000.0";
+                break;
+            case(TS_PREC_AUTO_CSEC):
+            case(TS_PREC_FIXED_CSEC):
+                return "0000.00";
+                break;
+            case(TS_PREC_AUTO_MSEC):
+            case(TS_PREC_FIXED_MSEC):
+                return "0000.000";
+                break;
+            case(TS_PREC_AUTO_USEC):
+            case(TS_PREC_FIXED_USEC):
+                return "0000.000000";
+                break;
+            case(TS_PREC_AUTO_NSEC):
+            case(TS_PREC_FIXED_NSEC):
+                return "0000.000000000";
+                break;
+            default:
+                g_assert_not_reached();
+        }
+        break;
+    case(TS_EPOCH):
         /* This is enough to represent 2^63 (signed 64-bit integer) + fractions */
-		switch(precision) {
-			case(TS_PREC_AUTO_SEC):
-			case(TS_PREC_FIXED_SEC):
-				return "0000000000000000000";
-				break;
-			case(TS_PREC_AUTO_DSEC):
-			case(TS_PREC_FIXED_DSEC):
-				return "0000000000000000000.0";
-				break;
-			case(TS_PREC_AUTO_CSEC):
-			case(TS_PREC_FIXED_CSEC):
-				return "0000000000000000000.00";
-				break;
-			case(TS_PREC_AUTO_MSEC):
-			case(TS_PREC_FIXED_MSEC):
-				return "0000000000000000000.000";
-				break;
-			case(TS_PREC_AUTO_USEC):
-			case(TS_PREC_FIXED_USEC):
-				return "0000000000000000000.000000";
-				break;
-			case(TS_PREC_AUTO_NSEC):
-			case(TS_PREC_FIXED_NSEC):
-				return "0000000000000000000.000000000";
-				break;
-			default:
-				g_assert_not_reached();
-		}
-		break;
-	case(TS_NOT_SET):
-		return "0000.000000";
-		break;
-	default:
-		g_assert_not_reached();
-	}
+        switch(precision) {
+            case(TS_PREC_AUTO_SEC):
+            case(TS_PREC_FIXED_SEC):
+                return "0000000000000000000";
+                break;
+            case(TS_PREC_AUTO_DSEC):
+            case(TS_PREC_FIXED_DSEC):
+                return "0000000000000000000.0";
+                break;
+            case(TS_PREC_AUTO_CSEC):
+            case(TS_PREC_FIXED_CSEC):
+                return "0000000000000000000.00";
+                break;
+            case(TS_PREC_AUTO_MSEC):
+            case(TS_PREC_FIXED_MSEC):
+                return "0000000000000000000.000";
+                break;
+            case(TS_PREC_AUTO_USEC):
+            case(TS_PREC_FIXED_USEC):
+                return "0000000000000000000.000000";
+                break;
+            case(TS_PREC_AUTO_NSEC):
+            case(TS_PREC_FIXED_NSEC):
+                return "0000000000000000000.000000000";
+                break;
+            default:
+                g_assert_not_reached();
+        }
+        break;
+    case(TS_NOT_SET):
+        return "0000.000000";
+        break;
+    default:
+        g_assert_not_reached();
+    }
 
-	/* never reached, satisfy compiler */
-	return "";
+    /* never reached, satisfy compiler */
+    return "";
 }
 
 /* Returns the longer string of the column title or the hard-coded width of
@@ -454,11 +454,11 @@ get_timestamp_column_longest_string(gint type, gint precision)
 const gchar *
 get_column_width_string(gint format, gint col)
 {
-	if(strlen(get_column_longest_string(format)) >
-	   strlen(get_column_title(col)))
-		return get_column_longest_string(format);
-	else
-		return get_column_title(col);
+    if(strlen(get_column_longest_string(format)) >
+       strlen(get_column_title(col)))
+        return get_column_longest_string(format);
+    else
+        return get_column_title(col);
 }
 
 /* Returns a string representing the longest possible value for a
@@ -498,8 +498,8 @@ get_column_longest_string(gint format)
     case COL_DELTA_TIME_DIS:
       return get_timestamp_column_longest_string(TS_DELTA_DIS, timestamp_get_precision());
       break;
-    case COL_REL_CONV_TIME:	/* 'abuse' TS_RELATIVE to set the time format */
-    case COL_DELTA_CONV_TIME:	/* for the conversation related time columns */
+    case COL_REL_CONV_TIME: /* 'abuse' TS_RELATIVE to set the time format */
+    case COL_DELTA_CONV_TIME:   /* for the conversation related time columns */
       return get_timestamp_column_longest_string(TS_RELATIVE, timestamp_get_precision());
       break;
     case COL_DEF_SRC:
@@ -531,7 +531,7 @@ get_column_longest_string(gint format)
       return "000000";
       break;
     case COL_PROTOCOL:
-      return "Protocol";	/* not the longest, but the longest is too long */
+      return "Protocol";    /* not the longest, but the longest is too long */
       break;
     case COL_PACKET_LENGTH:
       return "00000";
@@ -599,7 +599,7 @@ get_column_longest_string(gint format)
       return "9999 MHz [A 999]";
       break;
     case COL_CUSTOM:
-      return "0000000000";	/* not the longest, but the longest is too long */
+      return "0000000000";  /* not the longest, but the longest is too long */
       break;
     default: /* COL_INFO */
       return "Source port: kerberos-master  Destination port: kerberos-master";
@@ -616,89 +616,109 @@ get_column_char_width(gint format)
 }
 
 gint
-get_column_format(gint col) {
+get_column_format(gint col)
+{
   GList    *clp = g_list_nth(prefs.col_list, col);
   fmt_data *cfmt;
 
+  if (!clp)  /* Invalid column requested */
+    return -1;
+
   cfmt = (fmt_data *) clp->data;
 
   return(get_column_format_from_str(cfmt->fmt));
 }
 
 gint
-get_column_format_from_str(gchar *str) {
+get_column_format_from_str(gchar *str)
+{
   gint i;
 
   for (i = 0; i < NUM_COL_FMTS; i++) {
     if (strcmp(str, col_format_to_string(i)) == 0)
       return i;
   }
-  return -1;	/* illegal */
+  return -1;    /* illegal */
 }
 
 gchar *
-get_column_title(gint col) {
+get_column_title(gint col)
+{
   GList    *clp = g_list_nth(prefs.col_list, col);
   fmt_data *cfmt;
 
+  if (!clp)  /* Invalid column requested */
+    return NULL;
+
   cfmt = (fmt_data *) clp->data;
 
   return(cfmt->title);
 }
 
 const gchar *
-get_column_custom_field(gint col) {
+get_column_custom_field(gint col)
+{
   GList    *clp = g_list_nth(prefs.col_list, col);
   fmt_data *cfmt;
 
+  if (!clp)  /* Invalid column requested */
+    return NULL;
+
   cfmt = (fmt_data *) clp->data;
 
   return(cfmt->custom_field);
 }
 
 void
-build_column_format_array(column_info *cinfo, gboolean reset_fences)
+build_column_format_array(column_info *cinfo, gint num_cols, gboolean reset_fences)
 {
-  int i, j;
+  int i;
 
-  col_setup(cinfo, prefs.num_cols);
+  /* Build the column format array */
+  col_setup(cinfo, num_cols);
 
   for (i = 0; i < cinfo->num_cols; i++) {
     cinfo->col_fmt[i] = get_column_format(i);
     cinfo->col_title[i] = g_strdup(get_column_title(i));
+
     if (cinfo->col_fmt[i] == COL_CUSTOM) {
       cinfo->col_custom_field[i] = g_strdup(get_column_custom_field(i));
+      if(!dfilter_compile(cinfo->col_custom_field[i], &cinfo->col_custom_dfilter[i])) {
+        /* XXX: Should we issue a warning? */
+        g_free(cinfo->col_custom_field[i]);
+        cinfo->col_custom_field[i] = NULL;
+        cinfo->col_custom_dfilter[i] = NULL;
+      }
     } else {
       cinfo->col_custom_field[i] = NULL;
+      cinfo->col_custom_dfilter[i] = NULL;
     }
-    cinfo->fmt_matx[i] = (gboolean *) g_malloc0(sizeof(gboolean) *
-						     NUM_COL_FMTS);
-    get_column_format_matches(cinfo->fmt_matx[i],
-			      cinfo->col_fmt[i]);
+
+    cinfo->fmt_matx[i] = (gboolean *) g_malloc0(sizeof(gboolean) * NUM_COL_FMTS);
+    get_column_format_matches(cinfo->fmt_matx[i], cinfo->col_fmt[i]);
     cinfo->col_data[i] = NULL;
 
     if (cinfo->col_fmt[i] == COL_INFO)
-      cinfo->col_buf[i] = (gchar *) g_malloc(sizeof(gchar) *
-						  COL_MAX_INFO_LEN);
+      cinfo->col_buf[i] = (gchar *) g_malloc(sizeof(gchar) * COL_MAX_INFO_LEN);
     else
       cinfo->col_buf[i] = (gchar *) g_malloc(sizeof(gchar) * COL_MAX_LEN);
 
     if(reset_fences)
       cinfo->col_fence[i] = 0;
 
-    cinfo->col_expr.col_expr[i] = (gchar *) g_malloc(sizeof(gchar) *
-							    COL_MAX_LEN);
-    cinfo->col_expr.col_expr_val[i] = (gchar *) g_malloc(sizeof(gchar) *
-								COL_MAX_LEN);
+    cinfo->col_expr.col_expr[i] = (gchar *) g_malloc(sizeof(gchar) * COL_MAX_LEN);
+    cinfo->col_expr.col_expr_val[i] = (gchar *) g_malloc(sizeof(gchar) * COL_MAX_LEN);
   }
 
   cinfo->col_expr.col_expr[i] = NULL;
   cinfo->col_expr.col_expr_val[i] = NULL;
 
   for (i = 0; i < cinfo->num_cols; i++) {
+    int j;
+
     for (j = 0; j < NUM_COL_FMTS; j++) {
       if (!cinfo->fmt_matx[i][j])
-	      continue;
+          continue;
 
       if (cinfo->col_first[j] == -1)
         cinfo->col_first[j] = i;
