@@ -1,5 +1,5 @@
 /*
- * $Id: semcheck.c 29102 2009-07-15 19:22:21Z gerald $
+ * $Id: semcheck.c 30705 2009-10-26 09:06:45Z kukosa $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -535,11 +535,22 @@ check_relation_LHS_FIELD(const char *relation_string, FtypeCanFunc can_func,
 			/* Convert to a FT_PCRE */
 			fvalue = fvalue_from_unparsed(FT_PCRE, s, FALSE, dfilter_fail);
 		} else {
-			fvalue = fvalue_from_unparsed(ftype1, s, allow_partial_value, dfilter_fail);
-			if (!fvalue) {
-				/* check value_string */
-				fvalue = mk_fvalue_from_val_string(hfinfo1, s);
-			}
+			do {
+				fvalue = fvalue_from_unparsed(ftype1, s, allow_partial_value, dfilter_fail);
+				if (!fvalue) {
+					/* check value_string */
+					fvalue = mk_fvalue_from_val_string(hfinfo1, s);
+				}
+				if (!fvalue) {
+					/* Try another field with the same name */
+					if (hfinfo1->same_name_prev) {
+						hfinfo1 = hfinfo1->same_name_prev;
+						ftype1 = hfinfo1->type;
+					} else {
+						break;
+					}
+				}
+			} while (!fvalue);
 		}
 		if (!fvalue) {
 			THROW(TypeError);
@@ -597,7 +608,7 @@ check_relation_LHS_FIELD(const char *relation_string, FtypeCanFunc can_func,
 
 static void
 check_relation_LHS_STRING(const char* relation_string,
-		FtypeCanFunc can_func _U_, gboolean allow_partial_value _U_,
+		FtypeCanFunc can_func, gboolean allow_partial_value _U_,
 		stnode_t *st_node,
 		stnode_t *st_arg1, stnode_t *st_arg2)
 {
