@@ -2,7 +2,7 @@
  * Routines for AJP13 dissection
  * Copyright 2002, Christopher K. St. John <cks@distributopia.com>
  *
- * $Id: packet-ajp13.c 29344 2009-08-09 07:36:13Z krj $
+ * $Id: packet-ajp13.c 30691 2009-10-25 11:43:30Z etxrab $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -291,8 +291,7 @@ display_rsp(tvbuff_t *tvb, packet_info *pinfo, proto_tree *ajp13_tree)
    */
   mcode = tvb_get_guint8(tvb, pos);
   msg_code = val_to_str(mcode, mtype_codes, "UNKNOWN");
-  mcode_buf=ep_alloc(32);
-  g_snprintf(mcode_buf, 32, "(%d) %s", mcode, msg_code);
+  mcode_buf=ep_strdup_printf("(%d) %s", mcode, msg_code);
   if (ajp13_tree)
     proto_tree_add_string(ajp13_tree, hf_ajp13_code, tvb, pos, 1, mcode_buf);
   pos+=1;
@@ -494,14 +493,12 @@ display_req_forward(tvbuff_t *tvb, packet_info *pinfo,
     const gchar* msg_code = NULL;
     char *mcode_buf;
     msg_code = val_to_str(cod, mtype_codes, "UNKNOWN");
-    mcode_buf=ep_alloc(32);
-    g_snprintf(mcode_buf, 32, "(%d) %s", cod, msg_code);
+    mcode_buf=ep_strdup_printf("(%d) %s", cod, msg_code);
     proto_tree_add_string(ajp13_tree, hf_ajp13_code, tvb, pos, 1, mcode_buf);
   }
   pos+=1;
   if ( cod == 10 ) {
-    if(check_col(pinfo->cinfo, COL_INFO))
-      col_append_str(pinfo->cinfo, COL_INFO, "CPING" );
+    col_append_str(pinfo->cinfo, COL_INFO, "CPING" );
     return;
   }
 
@@ -513,8 +510,7 @@ display_req_forward(tvbuff_t *tvb, packet_info *pinfo,
     meth_code = val_to_str(meth, http_method_codes, "UNKNOWN");
     if (ajp13_tree) {
       char *mcode_buf;
-      mcode_buf=ep_alloc(32);
-      g_snprintf(mcode_buf, 32, "(%d) %s", meth, meth_code);
+      mcode_buf=ep_strdup_printf("(%d) %s", meth, meth_code);
       proto_tree_add_string(ajp13_tree, hf_ajp13_method, tvb, pos, 1, mcode_buf);
     }
     if(check_col(pinfo->cinfo, COL_INFO))
