@@ -1,7 +1,7 @@
 /* packet-artnet.c
  * Routines for Art-Net packet disassembly
  *
- * $Id: packet-artnet.c 27787 2009-03-18 20:56:21Z guy $
+ * $Id: packet-artnet.c 30415 2009-10-09 07:24:33Z etxrab $
  *
  * Copyright (c) 2003 by Erwin Rol <erwin@erwinrol.com>
  *
@@ -1261,7 +1261,7 @@ dissect_artnet_rdm(tvbuff_t *tvb, guint offset, proto_tree *tree,  packet_info *
   col_set_writable(pinfo->cinfo, FALSE);
 
   if (!next_tvb)
-    next_tvb = tvb_new_subset(tvb, offset, -1, -1);
+    next_tvb = tvb_new_subset_remaining(tvb, offset);
  
   call_dissector(rdm_handle, next_tvb, pinfo, tree);
 
@@ -1364,14 +1364,10 @@ dissect_artnet(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree) {
   proto_tree *ti,*hi,*si,*artnet_tree=NULL,*artnet_header_tree=NULL;
 
   /* Set the protocol column */
-  if(check_col(pinfo->cinfo,COL_PROTOCOL)){
-    col_set_str(pinfo->cinfo,COL_PROTOCOL,"ARTNET");
-  }
+  col_set_str(pinfo->cinfo, COL_PROTOCOL, "ARTNET");
 
   /* Clear out stuff in the info column */
-  if(check_col(pinfo->cinfo,COL_INFO)){
-    col_clear(pinfo->cinfo,COL_INFO);
-  }
+  col_clear(pinfo->cinfo, COL_INFO);
 
   if (tree) {
     ti = proto_tree_add_item(tree, proto_artnet, tvb, offset, -1, FALSE);
@@ -1655,20 +1651,18 @@ dissect_artnet(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree) {
       break;
 
     case ARTNET_OP_RDM:
-      if (tree) {
-	hi = proto_tree_add_item(artnet_tree,
+      hi = proto_tree_add_item(artnet_tree,
 			         hf_artnet_rdm,
 				 tvb,
 				 offset,
 				 0,
 				 FALSE);
-	si = proto_item_add_subtree(hi,ett_artnet);
+      si = proto_item_add_subtree(hi,ett_artnet);
 
-	size = dissect_artnet_rdm( tvb, offset, si, pinfo );
-	size -= offset;
+      size = dissect_artnet_rdm( tvb, offset, si, pinfo );
+      size -= offset;
 
-	proto_item_set_len( si, size );
-      }
+      proto_item_set_len( si, size );
       break;
 
     case ARTNET_OP_IP_PROG:
@@ -1743,14 +1737,14 @@ proto_register_artnet(void) {
     { &hf_artnet_filler,
       { "filler",
         "artnet.filler",
-        FT_BYTES, BASE_HEX, NULL, 0x0,
-        "filler", HFILL }},
+        FT_BYTES, BASE_NONE, NULL, 0x0,
+        NULL, HFILL }},
 
     { &hf_artnet_spare,
       { "spare",
         "artnet.spare",
-        FT_BYTES, BASE_HEX, NULL, 0x0,
-        "spare", HFILL }},
+        FT_BYTES, BASE_NONE, NULL, 0x0,
+        NULL, HFILL }},
 
     /* header */
 
@@ -1763,7 +1757,7 @@ proto_register_artnet(void) {
     { &hf_artnet_header_id,
       { "ID",
         "artnet.header.id",
-        FT_STRING, BASE_DEC, NULL, 0x0,
+        FT_STRING, BASE_NONE, NULL, 0x0,
         "ArtNET ID", HFILL }},
 
     { &hf_artnet_header_opcode,
@@ -1776,7 +1770,7 @@ proto_register_artnet(void) {
       { "ProVer",
         "artnet.header.protver",
         FT_UINT16, BASE_DEC, NULL, 0x0,
-        "Protcol revision number", HFILL }},
+        "Protocol revision number", HFILL }},
 
     /* ArtPoll */
 
@@ -1790,25 +1784,25 @@ proto_register_artnet(void) {
       { "TalkToMe",
         "artnet.poll.talktome",
         FT_UINT8, BASE_HEX, NULL, 0x0,
-        "TalkToMe", HFILL }},
+        NULL, HFILL }},
 
     { &hf_artnet_poll_talktome_reply_dest,
       { "Reply destination",
         "artnet.poll.talktome_reply_dest",
         FT_UINT8, BASE_HEX, NULL, 0x01,
-        "Reply destination", HFILL }},
+        NULL, HFILL }},
 
     { &hf_artnet_poll_talktome_reply_type,
       { "Reply type",
         "artnet.poll.talktome_reply_type",
         FT_UINT8, BASE_HEX, NULL, 0x02,
-        "Reply type", HFILL }},
+        NULL, HFILL }},
 
     { &hf_artnet_poll_talktome_unused,
       { "unused",
         "artnet.poll.talktome_unused",
         FT_UINT8, BASE_HEX, NULL, 0xfc,
-        "unused", HFILL }},
+        NULL, HFILL }},
 
     /* ArtPollReply */
 
@@ -1821,8 +1815,8 @@ proto_register_artnet(void) {
     { &hf_artnet_poll_reply_ip_address,
       { "IP Address",
         "artnet.poll_reply.ip_address",
-        FT_IPv4, BASE_DEC, NULL, 0x0,
-        "IP Address", HFILL }},
+        FT_IPv4, BASE_NONE, NULL, 0x0,
+        NULL, HFILL }},
 
     { &hf_artnet_poll_reply_port_nr,
       { "Port number",
@@ -1858,103 +1852,103 @@ proto_register_artnet(void) {
       { "Status",
         "artnet.poll_reply.status",
         FT_UINT8, BASE_HEX, NULL, 0x0,
-        "Status", HFILL }},
+        NULL, HFILL }},
 
     { &hf_artnet_poll_reply_esta_man,
       { "ESTA Code",
         "artnet.poll_reply.esta_man",
         FT_UINT16, BASE_HEX, VALS(artnet_esta_man_vals), 0x0,
-        "ESTA Code", HFILL }},
+        NULL, HFILL }},
 
     { &hf_artnet_poll_reply_short_name,
       { "Short Name",
         "artnet.poll_reply.short_name",
-        FT_STRING, BASE_DEC, NULL, 0x0,
-        "Short Name", HFILL }},
+        FT_STRING, BASE_NONE, NULL, 0x0,
+        NULL, HFILL }},
 
     { &hf_artnet_poll_reply_long_name,
       { "Long Name",
         "artnet.poll_reply.long_name",
-        FT_STRING, BASE_DEC, NULL, 0x0,
-        "Long Name", HFILL }},
+        FT_STRING, BASE_NONE, NULL, 0x0,
+        NULL, HFILL }},
 
     { &hf_artnet_poll_reply_node_report,
       { "Node Report",
         "artnet.poll_reply.node_report",
-        FT_STRING, BASE_DEC, NULL, 0x0,
-        "Node Report", HFILL }},
+        FT_STRING, BASE_NONE, NULL, 0x0,
+        NULL, HFILL }},
 
     { &hf_artnet_poll_reply_port_info,
       { "Port Info",
         "artnet.poll_reply.port_info",
         FT_NONE, BASE_NONE, NULL, 0,
-        "Port Info", HFILL }},
+        NULL, HFILL }},
 
     { &hf_artnet_poll_reply_num_ports,
       { "Number of Ports",
         "artnet.poll_reply.num_ports",
         FT_UINT16, BASE_DEC, NULL, 0x0,
-        "Number of Ports", HFILL }},
+        NULL, HFILL }},
 
     { &hf_artnet_poll_reply_port_types,
       { "Port Types",
         "artnet.poll_reply.port_types",
         FT_NONE, BASE_NONE, NULL, 0,
-        "Port Types", HFILL }},
+        NULL, HFILL }},
 
     { &hf_artnet_poll_reply_port_types_1,
       { "Type of Port 1",
         "artnet.poll_reply.port_types_1",
         FT_UINT8, BASE_HEX, NULL, 0x0,
-        "Type of Port 1", HFILL }},
+        NULL, HFILL }},
 
     { &hf_artnet_poll_reply_port_types_2,
       { "Type of Port 2",
         "artnet.poll_reply.port_types_2",
         FT_UINT8, BASE_HEX, NULL, 0x0,
-        "Type of Port 2", HFILL }},
+        NULL, HFILL }},
 
     { &hf_artnet_poll_reply_port_types_3,
       { "Type of Port 3",
         "artnet.poll_reply.port_types_3",
         FT_UINT8, BASE_HEX, NULL, 0x0,
-        "Type of Port 3", HFILL }},
+        NULL, HFILL }},
 
     { &hf_artnet_poll_reply_port_types_4,
       { "Type of Port 4",
         "artnet.poll_reply.port_types_4",
         FT_UINT8, BASE_HEX, NULL, 0x0,
-        "Type of Port 4", HFILL }},
+        NULL, HFILL }},
 
     { &hf_artnet_poll_reply_good_input,
       { "Input Status",
         "artnet.poll_reply.good_input",
         FT_NONE, BASE_NONE, NULL, 0,
-        "Input Status", HFILL }},
+        NULL, HFILL }},
 
     { &hf_artnet_poll_reply_good_input_1,
       { "Input status of Port 1",
         "artnet.poll_reply.good_input_1",
         FT_UINT8, BASE_HEX, NULL, 0x0,
-        "Input status of Port 1", HFILL }},
+        NULL, HFILL }},
 
     { &hf_artnet_poll_reply_good_input_2,
       { "Input status of Port 2",
         "artnet.poll_reply.good_input_2",
         FT_UINT8, BASE_HEX, NULL, 0x0,
-        "Input status of Port 2", HFILL }},
+        NULL, HFILL }},
 
     { &hf_artnet_poll_reply_good_input_3,
       { "Input status of Port 3",
         "artnet.poll_reply.good_input_3",
         FT_UINT8, BASE_HEX, NULL, 0x0,
-        "Input status of Port 3", HFILL }},
+        NULL, HFILL }},
 
     { &hf_artnet_poll_reply_good_input_4,
       { "Input status of Port 4",
         "artnet.poll_reply.good_input_4",
         FT_UINT8, BASE_HEX, NULL, 0x0,
-        "Input status of Port 4", HFILL }},
+        NULL, HFILL }},
 
     { &hf_artnet_poll_reply_good_output,
       { "Output Status",
@@ -1966,19 +1960,19 @@ proto_register_artnet(void) {
       { "Output status of Port 1",
         "artnet.poll_reply.good_output_1",
         FT_UINT8, BASE_HEX, NULL, 0x0,
-        "Output status of Port 1", HFILL }},
+        NULL, HFILL }},
 
     { &hf_artnet_poll_reply_good_output_2,
       { "Output status of Port 2",
         "artnet.poll_reply.good_output_2",
         FT_UINT8, BASE_HEX, NULL, 0x0,
-        "Output status of Port 2", HFILL }},
+        NULL, HFILL }},
 
     { &hf_artnet_poll_reply_good_output_3,
       { "Output status of Port 3",
         "artnet.poll_reply.good_output_3",
         FT_UINT8, BASE_HEX, NULL, 0x0,
-        "Output status of Port 3", HFILL }},
+        NULL, HFILL }},
 
     { &hf_artnet_poll_reply_good_output_4,
       { "Output status of Port 4",
@@ -1990,85 +1984,85 @@ proto_register_artnet(void) {
       { "Input Subswitch",
         "artnet.poll_reply.swin",
         FT_NONE, BASE_NONE, NULL, 0,
-        "Input Subswitch", HFILL }},
+        NULL, HFILL }},
 
     { &hf_artnet_poll_reply_swin_1,
       { "Input Subswitch of Port 1",
         "artnet.poll_reply.swin_1",
         FT_UINT8, BASE_HEX, NULL, 0x0,
-        "Input Subswitch of Port 1", HFILL }},
+        NULL, HFILL }},
 
     { &hf_artnet_poll_reply_swin_2,
       { "Input Subswitch of Port 2",
         "artnet.poll_reply.swin_2",
         FT_UINT8, BASE_HEX, NULL, 0x0,
-        "Input Subswitch of Port 2", HFILL }},
+        NULL, HFILL }},
 
     { &hf_artnet_poll_reply_swin_3,
       { "Input Subswitch of Port 3",
         "artnet.poll_reply.swin_3",
         FT_UINT8, BASE_HEX, NULL, 0x0,
-        "Input Subswitch of Port 3", HFILL }},
+        NULL, HFILL }},
 
     { &hf_artnet_poll_reply_swin_4,
       { "Input Subswitch of Port 4",
         "artnet.poll_reply.swin_4",
         FT_UINT8, BASE_HEX, NULL, 0x0,
-        "Input Subswitch of Port 4", HFILL }},
+        NULL, HFILL }},
 
     { &hf_artnet_poll_reply_swout,
       { "Output Subswitch",
         "artnet.poll_reply.swout",
         FT_NONE, BASE_NONE, NULL, 0,
-        "Output Subswitch", HFILL }},
+        NULL, HFILL }},
 
     { &hf_artnet_poll_reply_swout_1,
       { "Output Subswitch of Port 1",
         "artnet.poll_reply.swout_1",
         FT_UINT8, BASE_HEX, NULL, 0x0,
-        "Output Subswitch of Port 1", HFILL }},
+        NULL, HFILL }},
 
     { &hf_artnet_poll_reply_swout_2,
       { "Output Subswitch of Port 2",
         "artnet.poll_reply.swout_2",
         FT_UINT8, BASE_HEX, NULL, 0x0,
-        "Output Subswitch of Port 2", HFILL }},
+        NULL, HFILL }},
 
     { &hf_artnet_poll_reply_swout_3,
       { "Output Subswitch of Port 3",
         "artnet.poll_reply.swout_3",
         FT_UINT8, BASE_HEX, NULL, 0x0,
-        "Output Subswitch of Port 3", HFILL }},
+        NULL, HFILL }},
 
     { &hf_artnet_poll_reply_swout_4,
       { "Output Subswitch of Port 4",
         "artnet.poll_reply.swout_4",
         FT_UINT8, BASE_HEX, NULL, 0x0,
-        "Ouput Subswitch of Port 4", HFILL }},
+        NULL, HFILL }},
 
     { &hf_artnet_poll_reply_swvideo,
       { "SwVideo",
         "artnet.poll_reply.swvideo",
         FT_UINT8, BASE_HEX, NULL, 0x0,
-        "SwVideo", HFILL }},
+        NULL, HFILL }},
 
     { &hf_artnet_poll_reply_swmacro,
       { "SwMacro",
         "artnet.poll_reply.swmacro",
         FT_UINT8, BASE_HEX, NULL, 0x0,
-        "SwMacro", HFILL }},
+        NULL, HFILL }},
 
     { &hf_artnet_poll_reply_swremote,
       { "SwRemote",
         "artnet.poll_reply.swremote",
         FT_UINT8, BASE_HEX, NULL, 0x0,
-        "SwRemote", HFILL }},
+        NULL, HFILL }},
 
     { &hf_artnet_poll_reply_mac,
       { "MAC",
         "artnet.poll_reply.mac",
-        FT_ETHER, BASE_HEX, NULL, 0x0,
-        "MAC", HFILL }},
+        FT_ETHER, BASE_NONE, NULL, 0x0,
+        NULL, HFILL }},
 
     /* ArtOutput */
 
@@ -2082,42 +2076,42 @@ proto_register_artnet(void) {
       { "Sequence",
         "artnet.output.sequence",
         FT_UINT8, BASE_DEC, NULL, 0x0,
-        "Sequence", HFILL }},
+        NULL, HFILL }},
 
     { &hf_artnet_output_physical,
       { "Physical",
         "artnet.output.physical",
         FT_UINT8, BASE_DEC, NULL, 0x0,
-        "Physical", HFILL }},
+        NULL, HFILL }},
 
     { &hf_artnet_output_universe,
       { "Universe",
         "artnet.output.universe",
         FT_UINT16, BASE_DEC, NULL, 0x0,
-        "Universe", HFILL }},
+        NULL, HFILL }},
 
     { &hf_artnet_output_length,
       { "Length",
         "artnet.output.length",
         FT_UINT16, BASE_DEC, NULL, 0x0,
-        "Length", HFILL }},
+        NULL, HFILL }},
 
     { &hf_artnet_output_data,
       { "DMX data",
         "artnet.output.data",
-        FT_NONE, BASE_DEC, NULL, 0x0,
+        FT_NONE, BASE_NONE, NULL, 0x0,
         "DMX Data", HFILL }},
 
     { &hf_artnet_output_data_filter,
       { "DMX data filter",
         "artnet.output.data_filter",
-        FT_BYTES, BASE_DEC, NULL, 0x0,
+        FT_BYTES, BASE_NONE, NULL, 0x0,
         "DMX Data Filter", HFILL }},
 
     { &hf_artnet_output_dmx_data,
       { "DMX data",
         "artnet.output.dmx_data",
-        FT_NONE, BASE_DEC, NULL, 0x0,
+        FT_NONE, BASE_NONE, NULL, 0x0,
         "DMX Data", HFILL }},
 
     /* ArtAddress */
@@ -2131,92 +2125,92 @@ proto_register_artnet(void) {
     { &hf_artnet_address_short_name,
       { "Short Name",
         "artnet.address.short_name",
-        FT_STRING, BASE_DEC, NULL, 0x0,
-        "Short Name", HFILL }},
+        FT_STRING, BASE_NONE, NULL, 0x0,
+        NULL, HFILL }},
 
     { &hf_artnet_address_long_name,
       { "Long Name",
         "artnet.address.long_name",
-        FT_STRING, BASE_DEC, NULL, 0x0,
-        "Long Name", HFILL }},
+        FT_STRING, BASE_NONE, NULL, 0x0,
+        NULL, HFILL }},
 
     { &hf_artnet_address_swin,
       { "Input Subswitch",
         "artnet.address.swin",
         FT_NONE, BASE_NONE, NULL, 0,
-        "Input Subswitch", HFILL }},
+        NULL, HFILL }},
 
     { &hf_artnet_address_swin_1,
       { "Input Subswitch of Port 1",
         "artnet.address.swin_1",
         FT_UINT8, BASE_HEX, NULL, 0x0,
-        "Input Subswitch of Port 1", HFILL }},
+        NULL, HFILL }},
 
     { &hf_artnet_address_swin_2,
       { "Input Subswitch of Port 2",
         "artnet.address.swin_2",
         FT_UINT8, BASE_HEX, NULL, 0x0,
-        "Input Subswitch of Port 2", HFILL }},
+        NULL, HFILL }},
 
     { &hf_artnet_address_swin_3,
       { "Input Subswitch of Port 3",
         "artnet.address.swin_3",
         FT_UINT8, BASE_HEX, NULL, 0x0,
-        "Input Subswitch of Port 3", HFILL }},
+        NULL, HFILL }},
 
     { &hf_artnet_address_swin_4,
       { "Input Subswitch of Port 4",
         "artnet.address.swin_4",
         FT_UINT8, BASE_HEX, NULL, 0x0,
-        "Input Subswitch of Port 4", HFILL }},
+        NULL, HFILL }},
 
     { &hf_artnet_address_swout,
       { "Output Subswitch",
         "artnet.address.swout",
         FT_NONE, BASE_NONE, NULL, 0,
-        "Output Subswitch", HFILL }},
+        NULL, HFILL }},
 
     { &hf_artnet_address_swout_1,
       { "Output Subswitch of Port 1",
         "artnet.address.swout_1",
         FT_UINT8, BASE_HEX, NULL, 0x0,
-        "Output Subswitch of Port 1", HFILL }},
+        NULL, HFILL }},
 
     { &hf_artnet_address_swout_2,
       { "Output Subswitch of Port 2",
         "artnet.address.swout_2",
         FT_UINT8, BASE_HEX, NULL, 0x0,
-        "Output Subswitch of Port 2", HFILL }},
+        NULL, HFILL }},
 
     { &hf_artnet_address_swout_3,
       { "Output Subswitch of Port 3",
         "artnet.address.swout_3",
         FT_UINT8, BASE_HEX, NULL, 0x0,
-        "Output Subswitch of Port 3", HFILL }},
+        NULL, HFILL }},
 
     { &hf_artnet_address_swout_4,
       { "Output Subswitch of Port 4",
         "artnet.address.swout_4",
         FT_UINT8, BASE_HEX, NULL, 0x0,
-        "Ouput Subswitch of Port 4", HFILL }},
+        NULL, HFILL }},
 
     { &hf_artnet_address_subswitch,
       { "Subswitch",
         "artnet.address.subswitch",
         FT_UINT8, BASE_HEX, NULL, 0x0,
-        "Subswitch", HFILL }},
+        NULL, HFILL }},
 
     { &hf_artnet_address_swvideo,
       { "SwVideo",
         "artnet.address.swvideo",
         FT_UINT8, BASE_HEX, NULL, 0x0,
-        "SwVideo", HFILL }},
+        NULL, HFILL }},
 
     { &hf_artnet_address_command,
       { "Command",
         "artnet.address.command",
         FT_UINT8, BASE_HEX, VALS(artnet_address_command_vals), 0x0,
-        "Command", HFILL }},
+        NULL, HFILL }},
 
     /* ArtInput */
 
@@ -2230,37 +2224,37 @@ proto_register_artnet(void) {
       { "Number of Ports",
         "artnet.input.num_ports",
         FT_UINT16, BASE_DEC, NULL, 0x0,
-        "Number of Ports", HFILL }},
+        NULL, HFILL }},
 
     { &hf_artnet_input_input,
       { "Port Status",
         "artnet.input.input",
         FT_NONE, BASE_NONE, NULL, 0,
-        "Port Status", HFILL }},
+        NULL, HFILL }},
 
     { &hf_artnet_input_input_1,
       { "Status of Port 1",
         "artnet.input.input_1",
         FT_UINT8, BASE_HEX, NULL, 0x0,
-        "Status of Port 1", HFILL }},
+        NULL, HFILL }},
 
     { &hf_artnet_input_input_2,
       { "Status of Port 2",
         "artnet.input.input_2",
         FT_UINT8, BASE_HEX, NULL, 0x0,
-        "Status of Port 2", HFILL }},
+        NULL, HFILL }},
 
     { &hf_artnet_input_input_3,
       { "Status of Port 3",
         "artnet.input.input_3",
         FT_UINT8, BASE_HEX, NULL, 0x0,
-        "Status of Port 3", HFILL }},
+        NULL, HFILL }},
 
     { &hf_artnet_input_input_4,
       { "Status of Port 4",
         "artnet.input.input_4",
         FT_UINT8, BASE_HEX, NULL, 0x0,
-        "Status of Port 4", HFILL }},
+        NULL, HFILL }},
 
     /* ArtFirmwareMaster */
 
@@ -2280,19 +2274,19 @@ proto_register_artnet(void) {
       { "Block ID",
         "artnet.firmware_master.block_id",
         FT_UINT8, BASE_DEC, NULL, 0x0,
-        "Block ID", HFILL }},
+        NULL, HFILL }},
 
     { &hf_artnet_firmware_master_length,
       { "Length",
         "artnet.firmware_master.length",
         FT_UINT32, BASE_DEC, NULL, 0x0,
-        "Length", HFILL }},
+        NULL, HFILL }},
 
     { &hf_artnet_firmware_master_data,
       { "data",
         "artnet.firmware_master.data",
-        FT_BYTES, BASE_HEX, NULL, 0x0,
-        "data", HFILL }},
+        FT_BYTES, BASE_NONE, NULL, 0x0,
+        NULL, HFILL }},
 
     /* ArtFirmwareReply */
 
@@ -2320,36 +2314,36 @@ proto_register_artnet(void) {
       { "control",
         "artnet.video_setup.control",
         FT_UINT8, BASE_HEX, NULL, 0x0,
-        "control", HFILL }},
+        NULL, HFILL }},
 
     { &hf_artnet_video_setup_font_height,
       { "Font Height",
         "artnet.video_setup.font_height",
         FT_UINT8, BASE_DEC, NULL, 0x0,
-        "Font Height", HFILL }},
+        NULL, HFILL }},
 
     { &hf_artnet_video_setup_first_font,
       { "First Font",
         "artnet.video_setup.first_font",
         FT_UINT8, BASE_DEC, NULL, 0x0,
-        "First Font", HFILL }},
+        NULL, HFILL }},
 
     { &hf_artnet_video_setup_last_font,
       { "Last Font",
         "artnet.video_setup.last_font",
         FT_UINT8, BASE_DEC, NULL, 0x0,
-        "Last Font", HFILL }},
+        NULL, HFILL }},
 
     { &hf_artnet_video_setup_win_font_name,
       { "Windows Font Name",
         "artnet.video_setup.win_font_name",
-        FT_STRING, BASE_DEC, NULL, 0x0,
-        "Windows Font Name", HFILL }},
+        FT_STRING, BASE_NONE, NULL, 0x0,
+        NULL, HFILL }},
 
     { &hf_artnet_video_setup_font_data,
       { "Font data",
         "artnet.video_setup.font_data",
-        FT_BYTES, BASE_HEX, NULL, 0x0,
+        FT_BYTES, BASE_NONE, NULL, 0x0,
         "Font Date", HFILL }},
 
     /* ArtVideoPalette */
@@ -2363,20 +2357,20 @@ proto_register_artnet(void) {
     { &hf_artnet_video_palette_colour_red,
       { "Colour Red",
         "artnet.video_palette.colour_red",
-        FT_BYTES, BASE_HEX, NULL, 0x0,
-        "Colour Red", HFILL }},
+        FT_BYTES, BASE_NONE, NULL, 0x0,
+        NULL, HFILL }},
 
     { &hf_artnet_video_palette_colour_green,
       { "Colour Green",
         "artnet.video_palette.colour_green",
-        FT_BYTES, BASE_HEX, NULL, 0x0,
-        "Colour Green", HFILL }},
+        FT_BYTES, BASE_NONE, NULL, 0x0,
+        NULL, HFILL }},
 
     { &hf_artnet_video_palette_colour_blue,
       { "Colour Blue",
         "artnet.video_palette.colour_blue",
-        FT_BYTES, BASE_HEX, NULL, 0x0,
-        "Colour Blue", HFILL }},
+        FT_BYTES, BASE_NONE, NULL, 0x0,
+        NULL, HFILL }},
 
     /* ArtVideoData */
 
@@ -2390,31 +2384,31 @@ proto_register_artnet(void) {
       { "PosX",
         "artnet.video_data.pos_x",
         FT_UINT8, BASE_DEC, NULL, 0x0,
-        "PosX", HFILL }},
+        NULL, HFILL }},
 
     { &hf_artnet_video_data_pos_y,
       { "PosY",
         "artnet.video_data.pos_y",
         FT_UINT8, BASE_DEC, NULL, 0x0,
-        "PosY", HFILL }},
+        NULL, HFILL }},
 
     { &hf_artnet_video_data_len_x,
       { "LenX",
         "artnet.video_data.len_x",
         FT_UINT8, BASE_DEC, NULL, 0x0,
-        "LenX", HFILL }},
+        NULL, HFILL }},
 
     { &hf_artnet_video_data_len_y,
       { "LenY",
         "artnet.video_data.len_y",
         FT_UINT8, BASE_DEC, NULL, 0x0,
-        "LenY", HFILL }},
+        NULL, HFILL }},
 
     { &hf_artnet_video_data_data,
       { "Video Data",
         "artnet.video_data.data",
-        FT_BYTES, BASE_HEX, NULL, 0x0,
-        "Video Data", HFILL }},
+        FT_BYTES, BASE_NONE, NULL, 0x0,
+        NULL, HFILL }},
 
     /* ArtTodRequest */
     { &hf_artnet_tod_request,
@@ -2427,19 +2421,19 @@ proto_register_artnet(void) {
       { "Command",
         "artnet.tod_request.command",
         FT_UINT8, BASE_HEX, VALS(artnet_tod_request_command_vals), 0x0,
-        "Command", HFILL }},
+        NULL, HFILL }},
 
     { &hf_artnet_tod_request_ad_count,
       { "Address Count",
         "artnet.tod_request.ad_count",
         FT_UINT8, BASE_DEC, NULL, 0x0,
-        "Address Count", HFILL }},
+        NULL, HFILL }},
 
     { &hf_artnet_tod_request_address,
       { "Address",
         "artnet.tod_request.address",
-        FT_BYTES, BASE_HEX, NULL, 0x0,
-        "Address", HFILL }},
+        FT_BYTES, BASE_NONE, NULL, 0x0,
+        NULL, HFILL }},
 
     /* ArtTodData */
     { &hf_artnet_tod_data,
@@ -2452,43 +2446,43 @@ proto_register_artnet(void) {
       { "Port",
         "artnet.tod_data.port",
         FT_UINT8, BASE_DEC, NULL, 0x0,
-        "Port", HFILL }},
+        NULL, HFILL }},
 
     { &hf_artnet_tod_data_command_response,
       { "Command Response",
         "artnet.tod_data.command_response",
         FT_UINT8, BASE_HEX, VALS(artnet_tod_data_command_vals), 0x0,
-        "Command Response", HFILL }},
+        NULL, HFILL }},
 
     { &hf_artnet_tod_data_address,
       { "Address",
         "artnet.tod_data.address",
         FT_UINT8, BASE_HEX, NULL, 0x0,
-        "Address", HFILL }},
+        NULL, HFILL }},
 
     { &hf_artnet_tod_data_uid_total,
       { "UID Total",
         "artnet.tod_data.uid_total",
         FT_UINT16, BASE_DEC, NULL, 0x0,
-        "UID Total", HFILL }},
+        NULL, HFILL }},
 
     { &hf_artnet_tod_data_block_count,
       { "Block Count",
         "artnet.tod_data.block_count",
         FT_UINT8, BASE_DEC, NULL, 0x0,
-        "Block Count", HFILL }},
+        NULL, HFILL }},
 
     { &hf_artnet_tod_data_uid_count,
       { "UID Count",
         "artnet.tod_data.uid_count",
         FT_UINT8, BASE_DEC, NULL, 0x0,
-        "UID Count", HFILL }},
+        NULL, HFILL }},
 
     { &hf_artnet_tod_data_tod,
       { "TOD",
         "artnet.tod_data.tod",
-        FT_BYTES, BASE_HEX, NULL, 0x0,
-        "TOD", HFILL }},
+        FT_BYTES, BASE_NONE, NULL, 0x0,
+        NULL, HFILL }},
 
     /* ArtTodControl */
     { &hf_artnet_tod_control,
@@ -2501,13 +2495,13 @@ proto_register_artnet(void) {
       { "Command",
         "artnet.tod_control.command",
         FT_UINT8, BASE_HEX, VALS(artnet_tod_control_command_vals), 0x0,
-        "Command", HFILL }},
+        NULL, HFILL }},
 
     { &hf_artnet_tod_control_address,
       { "Address",
         "artnet.tod_request.address",
         FT_UINT8, BASE_HEX, NULL, 0x0,
-        "Address", HFILL }},
+        NULL, HFILL }},
 
     /* ArtRdm */
     { &hf_artnet_rdm,
@@ -2520,13 +2514,13 @@ proto_register_artnet(void) {
       { "Command",
         "artnet.rdm.command",
         FT_UINT8, BASE_HEX, VALS(artnet_rdm_command_vals), 0x0,
-        "Command", HFILL }},
+        NULL, HFILL }},
 
     { &hf_artnet_rdm_address,
       { "Address",
         "artnet.rdm.address",
         FT_UINT8, BASE_HEX, NULL, 0x0,
-        "Address", HFILL }},
+        NULL, HFILL }},
 
     /* ArtIpProg */
     { &hf_artnet_ip_prog,
@@ -2539,61 +2533,61 @@ proto_register_artnet(void) {
       { "Command",
         "artnet.ip_prog.command",
         FT_UINT8, BASE_HEX, NULL, 0x0,
-        "Command", HFILL }},
+        NULL, HFILL }},
 
     { &hf_artnet_ip_prog_command_prog_port,
       { "Program Port",
         "artnet.ip_prog.command_prog_port",
         FT_UINT8, BASE_HEX, NULL, 0x01,
-        "Program Port", HFILL }},
+        NULL, HFILL }},
 
     { &hf_artnet_ip_prog_command_prog_sm,
       { "Program Subnet Mask",
         "artnet.ip_prog.command_prog_sm",
         FT_UINT8, BASE_HEX, NULL, 0x02,
-        "Program Subnet Mask", HFILL }},
+        NULL, HFILL }},
 
     { &hf_artnet_ip_prog_command_prog_ip,
       { "Program IP",
         "artnet.ip_prog.command_prog_ip",
         FT_UINT8, BASE_HEX, NULL, 0x04,
-        "Program IP", HFILL }},
+        NULL, HFILL }},
 
     { &hf_artnet_ip_prog_command_reset,
       { "Reset parameters",
         "artnet.ip_prog.command_reset",
         FT_UINT8, BASE_HEX, NULL, 0x08,
-        "Reset parameters", HFILL }},
+        NULL, HFILL }},
 
     { &hf_artnet_ip_prog_command_unused,
       { "Unused",
         "artnet.ip_prog.command_unused",
         FT_UINT8, BASE_HEX, NULL, 0x70,
-        "Unused", HFILL }},
+        NULL, HFILL }},
 
     { &hf_artnet_ip_prog_command_prog_enable,
       { "Enable Programming",
         "artnet.ip_prog.command_prog_enable",
         FT_UINT8, BASE_HEX, NULL, 0x80,
-        "Enable Programming", HFILL }},
+        NULL, HFILL }},
 
     { &hf_artnet_ip_prog_ip,
       { "IP Address",
         "artnet.ip_prog.ip",
-        FT_IPv4, BASE_DEC, NULL, 0x0,
-        "IP Address", HFILL }},
+        FT_IPv4, BASE_NONE, NULL, 0x0,
+        NULL, HFILL }},
 
     { &hf_artnet_ip_prog_sm,
       { "Subnet mask",
         "artnet.ip_prog.sm",
-        FT_IPv4, BASE_DEC, NULL, 0x0,
+        FT_IPv4, BASE_NONE, NULL, 0x0,
         "IP Subnet mask", HFILL }},
 
     { &hf_artnet_ip_prog_port,
       { "Port",
         "artnet.ip_prog.port",
         FT_UINT16, BASE_DEC, NULL, 0x0,
-        "Port", HFILL }},
+        NULL, HFILL }},
 
     /* ArtIpProgReply */
     { &hf_artnet_ip_prog_reply,
@@ -2605,20 +2599,20 @@ proto_register_artnet(void) {
     { &hf_artnet_ip_prog_reply_ip,
       { "IP Address",
         "artnet.ip_prog_reply.ip",
-        FT_IPv4, BASE_DEC, NULL, 0x0,
-        "IP Address", HFILL }},
+        FT_IPv4, BASE_NONE, NULL, 0x0,
+        NULL, HFILL }},
 
     { &hf_artnet_ip_prog_reply_sm,
       { "Subnet mask",
         "artnet.ip_prog_reply.sm",
-        FT_IPv4, BASE_DEC, NULL, 0x0,
+        FT_IPv4, BASE_NONE, NULL, 0x0,
         "IP Subnet mask", HFILL }},
 
     { &hf_artnet_ip_prog_reply_port,
       { "Port",
         "artnet.ip_prog_reply.port",
         FT_UINT16, BASE_DEC, NULL, 0x0,
-        "Port", HFILL }},
+        NULL, HFILL }},
 
     /* ArtPollServerReply */
     { &hf_artnet_poll_server_reply,
