@@ -1,7 +1,7 @@
 /* packet-aruba-adp.c
  * Routines for Aruba ADP header disassembly
  *
- * $Id: packet-aruba-adp.c 26028 2008-08-14 23:51:52Z wmeier $
+ * $Id: packet-aruba-adp.c 29344 2009-08-09 07:36:13Z krj $
  *
  * Giles Scott < gscott <at> arubanetworks dot com>
  *
@@ -64,10 +64,8 @@ dissect_aruba_adp(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
   const guint8 *switchip;
 
 
-  if (check_col(pinfo->cinfo, COL_PROTOCOL))
-    col_set_str(pinfo->cinfo, COL_PROTOCOL, "ADP");
-  if (check_col(pinfo->cinfo, COL_INFO))
-    col_clear(pinfo->cinfo, COL_INFO);
+  col_set_str(pinfo->cinfo, COL_PROTOCOL, "ADP");
+  col_clear(pinfo->cinfo, COL_INFO);
 
 
   if (tree) {
@@ -131,7 +129,7 @@ proto_register_aruba_adp(void)
 
     { &hf_adp_mac,
     { "MAC address", "adp.mac", FT_ETHER, BASE_NONE, NULL, 0x0,
-    "MAC address", HFILL}},
+    NULL, HFILL}},
 
     { &hf_adp_switchip,
     { "Switch IP", "adp.switch", FT_IPv4, BASE_NONE, NULL, 0x0,
@@ -143,7 +141,7 @@ proto_register_aruba_adp(void)
     &ett_aruba_adp,
   };
 
-  proto_aruba_adp = proto_register_protocol("Aruba - Aruba Discovery Protocol",
+  proto_aruba_adp = proto_register_protocol("Aruba Discovery Protocol",
                     "ADP", "adp");
   proto_register_field_array(proto_aruba_adp, hf, array_length(hf));
   proto_register_subtree_array(ett, array_length(ett));
