@@ -1,7 +1,7 @@
 /* packet-bpdu.c
  * Routines for BPDU (Spanning Tree Protocol) disassembly
  *
- * $Id: packet-bpdu.c 29346 2009-08-09 08:14:59Z krj $
+ * $Id: packet-bpdu.c 30995 2009-11-17 18:35:27Z dimeg $
  *
  * Copyright 1999 Christophe Tronche <ch.tronche@computer.org>
  *
@@ -278,8 +278,6 @@ dissect_bpdu(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
        dstaddr[2] == 0xC2 && dstaddr[3] == 0x00 &&
        dstaddr[4] == 0x00 && ((dstaddr[5] & 0xF0) == 0x20)) {
 
-      protocol_identifier = tvb_get_ntohs(tvb, BPDU_IDENTIFIER);
-
       switch (dstaddr[5]) {
 
       case 0x20:
@@ -983,15 +981,15 @@ proto_register_bpdu(void)
   static hf_register_info hf[] = {
     { &hf_bpdu_proto_id,
       { "Protocol Identifier",		"stp.protocol",
-	FT_UINT16,	BASE_HEX,	VALS(&protocol_id_vals), 0x0,
+	FT_UINT16,	BASE_HEX,	VALS(protocol_id_vals), 0x0,
       	NULL, HFILL }},
     { &hf_bpdu_version_id,
       { "Protocol Version Identifier",	"stp.version",
-	FT_UINT8,	BASE_DEC,	VALS(&version_id_vals),	0x0,
+	FT_UINT8,	BASE_DEC,	VALS(version_id_vals),	0x0,
       	NULL, HFILL }},
     { &hf_bpdu_type,
       { "BPDU Type",			"stp.type",
-	FT_UINT8,	BASE_HEX,	VALS(&bpdu_type_vals),	0x0,
+	FT_UINT8,	BASE_HEX,	VALS(bpdu_type_vals),	0x0,
       	NULL, HFILL }},
     { &hf_bpdu_flags,
       { "BPDU flags",			"stp.flags",
