@@ -8,7 +8,7 @@
  * Refactored for wireshark checkin
  *   Ronnie Sahlberg 2006
  *
- * $Id: packet-bthci_acl.c 28412 2009-05-19 17:16:14Z stig $
+ * $Id: packet-bthci_acl.c 30830 2009-11-05 07:36:02Z krj $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -73,8 +73,9 @@ typedef struct _chandle_data_t {
 static emem_tree_t *chandle_tree=NULL;
 
 static const value_string pb_flag_vals[] = {
-	{1, "Continuing Fragment"},
-	{2, "Start Fragment"},
+    {0, "First Non-automatically Flushable Packet"},
+    {1, "Continuing Fragment"},
+    {2, "First Automatically Flushable Packet"},
 	{0, NULL }
 };
 
@@ -102,9 +103,7 @@ dissect_btacl(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 	chandle_data_t *chandle_data;
 	void* pd_save;
 
-	if(check_col(pinfo->cinfo, COL_PROTOCOL)){
-		col_set_str(pinfo->cinfo, COL_PROTOCOL, "HCI_ACL");
-	}
+	col_set_str(pinfo->cinfo, COL_PROTOCOL, "HCI_ACL");
 
 	if(tree){
 		ti=proto_tree_add_item(tree, proto_btacl, tvb, offset, -1, FALSE);
@@ -214,7 +213,7 @@ dissect_btacl(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 			}
 			if(mfp && mfp->last_frame==pinfo->fd->num){
 				next_tvb = tvb_new_child_real_data(tvb, (guint8*)mfp->reassembled, mfp->tot_len, mfp->tot_len);
-				add_new_data_source(pinfo, next_tvb, "Reassembled BTHCI ACL");
+				packet_add_new_data_source(pinfo, btacl_tree, next_tvb, "Reassembled BTHCI ACL");
 
 				/* call L2CAP dissector */
 				if(btl2cap_handle){
@@ -236,7 +235,7 @@ proto_register_btacl(void)
 		{ &hf_btacl_chandle,
 			{ "Connection Handle",           "btacl.chandle",
 				FT_UINT16, BASE_HEX, NULL, 0x0FFF,
-				"Connection Handle", HFILL }
+				NULL, HFILL }
 		},
 		{ &hf_btacl_pb_flag,
 			{ "PB Flag",           "btacl.pb_flag",
@@ -251,12 +250,12 @@ proto_register_btacl(void)
 		{ &hf_btacl_length,
 			{ "Data Total Length",           "btacl.length",
 				FT_UINT16, BASE_DEC, NULL, 0x0,
-				"Data Total Length", HFILL }
+				NULL, HFILL }
 		},
 		{ &hf_btacl_data,
 			{ "Data",           "btacl.data",
 				FT_NONE, BASE_NONE, NULL, 0x0,
-				"Data", HFILL }
+				NULL, HFILL }
 		},
 		{ &hf_btacl_continuation_to,
 			{ "This is a continuation to the PDU in frame",		"btacl.continuation_to", FT_FRAMENUM, BASE_NONE, NULL, 0x0,
