@@ -6,7 +6,7 @@
  * Refactored for wireshark checkin
  *   Ronnie Sahlberg 2006
  *
- * $Id: packet-btl2cap.c 29427 2009-08-15 06:38:10Z krj $
+ * $Id: packet-btl2cap.c 30605 2009-10-18 21:14:35Z stig $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -798,9 +798,7 @@ static void dissect_b_frame(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree,
 	tvbuff_t *next_tvb;
 	next_tvb = tvb_new_subset(tvb, offset, tvb_length_remaining(tvb, offset), length);
 
-	if(check_col(pinfo->cinfo, COL_INFO)){
-		col_append_str(pinfo->cinfo, COL_INFO, "Connection oriented channel");
-	}
+	col_append_str(pinfo->cinfo, COL_INFO, "Connection oriented channel");
 
 	if(psm){
 		proto_item *psm_item;
@@ -1020,7 +1018,6 @@ static void dissect_btl2cap(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 
 	col_set_str(pinfo->cinfo, COL_PROTOCOL, "L2CAP");
 	if(check_col(pinfo->cinfo, COL_INFO)){
-		col_clear(pinfo->cinfo, COL_INFO);
 		col_set_str(pinfo->cinfo, COL_INFO, pinfo->p2p_dir == P2P_DIR_SENT ? "Sent " : "Rcvd ");
 	}
 
@@ -1213,9 +1210,7 @@ static void dissect_btl2cap(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 			}
 		}
 	} else if (cid == BTL2CAP_FIXED_CID_CONNLESS) { /* Connectionless reception channel */
-		if(check_col(pinfo->cinfo, COL_INFO)){
-			col_append_str(pinfo->cinfo, COL_INFO, "Connectionless reception channel");
-		}
+		col_append_str(pinfo->cinfo, COL_INFO, "Connectionless reception channel");
 
 		psm = tvb_get_letohs(tvb, offset);
 		proto_tree_add_item(btl2cap_tree, hf_btl2cap_psm, tvb, offset, 2, TRUE);
@@ -1234,8 +1229,6 @@ static void dissect_btl2cap(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 	}
 	else if(cid < BTL2CAP_FIXED_CID_MAX) {
 		if (cid == BTL2CAP_FIXED_CID_AMP_MAN) {
-			guint16 control;
-
 			control = tvb_get_letohs(tvb, offset);
 			if(control & 0x1) {
 				dissect_s_frame(tvb, pinfo, tree, btl2cap_tree, 0 /* unused */, length, offset, NULL /* unused */);
