@@ -19,7 +19,7 @@
  * Refactored for wireshark checkin
  *   Ronnie Sahlberg 2006
  *
- * $Id: packet-btrfcomm.c 25682 2008-07-09 01:30:30Z wmeier $
+ * $Id: packet-btrfcomm.c 30937 2009-11-12 02:03:10Z gerald $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -51,6 +51,7 @@
 #include <epan/value_string.h>
 #include <etypes.h>
 #include <epan/emem.h>
+#include <epan/expert.h>
 #include "packet-btl2cap.h"
 
 static int hf_pf = -1;
@@ -284,14 +285,9 @@ dissect_ctrl_pn(packet_info *pinfo, proto_tree *t, tvbuff_t *tvb, int offset, in
 	if(!pinfo->fd->flags.visited){
 		dlci_state=se_tree_lookup32(dlci_table, dlci);
 		if(!dlci_state){
-			dlci_state=se_alloc(sizeof(dlci_state_t));
-			dlci_state->do_credit_fc=0;
-			dlci_state->direction[0].len=0;
+			dlci_state=se_alloc0(sizeof(dlci_state_t));
 			dlci_state->direction[0].current=-1;
-			dlci_state->direction[0].stream_buf=NULL;
-			dlci_state->direction[1].len=0;
 			dlci_state->direction[1].current=-1;
-			dlci_state->direction[1].stream_buf=NULL;
 			se_tree_insert32(dlci_table, dlci, dlci_state);
 		}
 
@@ -316,10 +312,10 @@ dissect_ctrl_pn(packet_info *pinfo, proto_tree *t, tvbuff_t *tvb, int offset, in
 /* to serve as inspiration when implementing ppp over rfcomm */
 static void *my_malloc(int size) {
 
-	void *p = calloc(size, 1);
+/*	void *p = calloc(size, 1); */
 
 	if (!p) {
-		perror("calloc()");
+/*		perror("calloc()"); */
 		/* exit(1); */
 	}
 	return p;
@@ -628,10 +624,8 @@ dissect_btrfcomm(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 	ti = proto_tree_add_item(tree, proto_btrfcomm, tvb, offset, -1, TRUE);
 	rfcomm_tree = proto_item_add_subtree(ti, ett_btrfcomm);
 
-	if (check_col(pinfo->cinfo, COL_PROTOCOL))
-		col_set_str(pinfo->cinfo, COL_PROTOCOL, "RFCOMM");
+	col_set_str(pinfo->cinfo, COL_PROTOCOL, "RFCOMM");
 	if (check_col(pinfo->cinfo, COL_INFO)) {
-		col_clear(pinfo->cinfo, COL_INFO);
 		col_set_str(pinfo->cinfo, COL_INFO, pinfo->p2p_dir == P2P_DIR_SENT ? "Sent " : "Rcvd ");
 	}
 
@@ -642,14 +636,9 @@ dissect_btrfcomm(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 
 	dlci_state=se_tree_lookup32(dlci_table, dlci);
 	if(!dlci_state){
-		dlci_state=se_alloc(sizeof(dlci_state_t));
-		dlci_state->do_credit_fc=0;
-		dlci_state->direction[0].len=0;
+		dlci_state=se_alloc0(sizeof(dlci_state_t));
 		dlci_state->direction[0].current=-1;
-		dlci_state->direction[0].stream_buf=NULL;
-		dlci_state->direction[1].len=0;
 		dlci_state->direction[1].current=-1;
-		dlci_state->direction[1].stream_buf=NULL;
 		se_tree_insert32(dlci_table, dlci, dlci_state);
 	}
 
@@ -703,17 +692,19 @@ dissect_btrfcomm(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 		/* len */
 		offset = get_le_multi_byte_value(tvb, offset, ctrl_tree, &length, hf_mcc_len);
 
+
+		if (length > (guint32) tvb_length_remaining(tvb, offset)) {
+			expert_add_info_format(pinfo, ctrl_tree, PI_MALFORMED, PI_ERROR, "Huge MCC length: %u", length);
+			return;
+		}
+
 		switch(mcc_type) {
 		case 0x20: /* Parameter Negotiation */
-			if ((check_col(pinfo->cinfo, COL_INFO))){
-				col_append_str(pinfo->cinfo, COL_INFO, "Parameter Negotiation ");
-			}
+			col_append_str(pinfo->cinfo, COL_INFO, "Parameter Negotiation ");
 			dissect_ctrl_pn(pinfo, ctrl_tree, tvb, offset, mcc_cr_flag);
 			break;
 		case 0x38: /* Model Status Command */
-			if ((check_col(pinfo->cinfo, COL_INFO))){
-				col_append_str(pinfo->cinfo, COL_INFO, "Model Status Command ");
-			}
+			col_append_str(pinfo->cinfo, COL_INFO, "Model Status Command ");
 			dissect_ctrl_msc(ctrl_tree, tvb, offset, length);
 			break;
 		}
@@ -770,9 +761,8 @@ dissect_btrfcomm(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 			rfcomm_ppp_frame *p;
 
 			for (p = rps->ppp_first; p; p = p->next) {
-				next_tvb = tvb_new_real_data((guint8 *) (p + 1), p->len, p->len);
-				tvb_set_child_real_data_tvbuff(tvb, next_tvb);
-				add_new_data_source(pinfo, next_tvb, "Reassembled PPP frame");
+				next_tvb = tvb_new_child_real_data(tvb, (guint8 *) (p + 1), p->len, p->len);
+				packet_add_new_data_source(pinfo, rfcomm_tree, next_tvb, "Reassembled PPP frame");
 				call_dissector(ppp_handle, next_tvb, pinfo, tree);
 			}
 		} else {
@@ -796,7 +786,7 @@ proto_register_btrfcomm(void)
 		{&hf_priority,
 			{"Priority", "btrfcomm.priority",
 			FT_UINT8, BASE_DEC, NULL, 0x3f,
-			"Priority", HFILL}
+			NULL, HFILL}
 		},
 		{&hf_max_frame_size,
 			{"Max Frame Size", "btrfcomm.max_frame_size",
@@ -811,7 +801,7 @@ proto_register_btrfcomm(void)
 		{&hf_error_recovery_mode,
 			{"Error Recovery Mode", "btrfcomm.error_recovery_mode",
 			FT_UINT8, BASE_DEC, NULL, 0x07,
-			"Error Recovery Mode", HFILL}
+			NULL, HFILL}
 		},
 		{&hf_ea,
 			{"EA Flag", "btrfcomm.ea",
@@ -902,7 +892,7 @@ proto_register_btrfcomm(void)
 		{&hf_msc_l,
 		         {"Length of break in units of 200ms", "btrfcomm.msc.bl",
 			 FT_UINT8, BASE_DEC, NULL, 0xf0,
-			  "Length of break in units of 200ms", HFILL}
+			  NULL, HFILL}
 		},
 		{&hf_fc_credits,
 		         {"Credits", "btrfcomm.credits",
