@@ -3,7 +3,7 @@
  * Copyright 2000, Scott Hovis scott.hovis@ums.msfc.nasa.gov
  * Enhanced 2008, Matt Dunkle Matthew.L.Dunkle@nasa.gov
  *
- * $Id: packet-ccsds.c 27794 2009-03-19 01:54:09Z wmeier $
+ * $Id: packet-ccsds.c 29342 2009-08-09 07:01:26Z krj $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -341,10 +341,8 @@ dissect_ccsds(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 	proto_tree *secondary_header_tree;
         const char* time_string;
 
-	if (check_col(pinfo->cinfo, COL_PROTOCOL)) 
-		col_set_str(pinfo->cinfo, COL_PROTOCOL, "CCSDS");
-	if (check_col(pinfo->cinfo, COL_INFO)) 
-		col_set_str(pinfo->cinfo, COL_INFO, "CCSDS Packet");
+	col_set_str(pinfo->cinfo, COL_PROTOCOL, "CCSDS");
+	col_set_str(pinfo->cinfo, COL_INFO, "CCSDS Packet");
 
 	if (tree) {
 		ccsds_packet = proto_tree_add_item(tree, proto_ccsds, tvb, 0, -1, FALSE);
