@@ -2,7 +2,7 @@
  * Routines for China Mobile Point to Point dissection
  * Copyright 2007, Andy Chu <chu.dev@gmail.com>
  *
- * $Id: packet-cmpp.c 29344 2009-08-09 07:36:13Z krj $
+ * $Id: packet-cmpp.c 30691 2009-10-25 11:43:30Z etxrab $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -34,8 +34,6 @@
 #include <epan/packet.h>
 #include <epan/dissectors/packet-tcp.h>
 
-#define CMPP_VERSIONBUF 6
-#define CMPP_TIMESTAMPBUFF 15
 #define CMPP_FIX_HEADER_LENGTH 12
 #define CMPP_DELIVER_REPORT_LEN 71
 
@@ -276,8 +274,7 @@ cmpp_version(proto_tree *tree, tvbuff_t *tvb, gint  field, gint offset)
 	version = tvb_get_guint8(tvb, offset);
 	minor = version & 0x0F;
 	major = (version & 0xF0) >> 4;
-	strval = ep_alloc(CMPP_VERSIONBUF);
-	g_snprintf(strval, CMPP_VERSIONBUF, "%02u.%02u", major, minor);
+	strval = ep_strdup_printf("%02u.%02u", major, minor);
 	/* TODO: the version should be added as a uint_format */
 	proto_tree_add_string(tree, field, tvb, offset, 1, strval);
 	return strval;
@@ -299,8 +296,7 @@ cmpp_timestamp(proto_tree *tree, tvbuff_t *tvb, gint  field, gint offset)
 	timevalue /= 100;
 	day = timevalue % 100;
 	month = timevalue / 100;
-	strval = ep_alloc(CMPP_TIMESTAMPBUFF);
-	g_snprintf(strval, CMPP_TIMESTAMPBUFF, "%02u/%02u %02u:%02u:%02u", month, day,
+	strval = ep_strdup_printf("%02u/%02u %02u:%02u:%02u", month, day,
 		hour, minute, second);
 	proto_tree_add_string(tree, field, tvb, offset, 4, strval);
 	return strval;
@@ -363,8 +359,7 @@ cmpp_msg_id(proto_tree *tree, tvbuff_t *tvb, gint  field, gint offset)
 	hour = (tvb_get_guint8(tvb, offset + 1) & 0x7C) >> 2;
 	minute = (tvb_get_ntohs(tvb, offset + 1) & 0x03F0) >> 4;
 	second = (tvb_get_ntohs(tvb, offset + 2) & 0x0FC0) >> 6;
-	strval = ep_alloc(CMPP_TIMESTAMPBUFF);
-	g_snprintf(strval, CMPP_TIMESTAMPBUFF, "%02u/%02u %02u:%02u:%02u", month, day,
+	strval = ep_strdup_printf("%02u/%02u %02u:%02u:%02u", month, day,
 		hour, minute, second);
 
 	ismg_code = (tvb_get_ntohl(tvb, offset + 3) & 0x3FFFFF00) >> 16;
