@@ -4,7 +4,7 @@
  * Copyright 2008 Bruno Premont <bonbons at linux-vserver.org>
  * Copyright 2009 Florian Forster <octo at verplant.org>
  *
- * $Id: packet-collectd.c 29894 2009-09-14 13:11:26Z morriss $
+ * $Id: packet-collectd.c 30603 2009-10-18 21:13:17Z stig $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -35,6 +35,7 @@
 #include <epan/packet.h>
 #include <epan/prefs.h>
 #include <epan/expert.h>
+#include <epan/stats_tree.h>
 
 #define TYPE_HOST            0x0000
 #define TYPE_TIME            0x0001
@@ -46,6 +47,8 @@
 #define TYPE_INTERVAL        0x0007
 #define TYPE_MESSAGE         0x0100
 #define TYPE_SEVERITY        0x0101
+#define TYPE_SIGN_SHA256     0x0200
+#define TYPE_ENCR_AES256     0x0210
 
 typedef struct value_data_s {
 	gchar *host;
@@ -84,6 +87,23 @@ typedef struct notify_data_s {
 	gint message_len;
 } notify_data_t;
 
+struct string_counter_s;
+typedef struct string_counter_s string_counter_t;
+struct string_counter_s
+{
+	gchar *string;
+	gint   count;
+	string_counter_t *next;
+};
+
+typedef struct tap_data_s {
+	gint values_num;
+
+	string_counter_t *hosts;
+	string_counter_t *plugins;
+	string_counter_t *types;
+} tap_data_t;
+
 static const value_string part_names[] = {
 	{ TYPE_VALUES,          "VALUES" },
 	{ TYPE_TIME,            "TIME" },
@@ -95,14 +115,20 @@ static const value_string part_names[] = {
 	{ TYPE_TYPE_INSTANCE,   "TYPE_INSTANCE" },
 	{ TYPE_MESSAGE,         "MESSAGE" },
 	{ TYPE_SEVERITY,        "SEVERITY" },
+	{ TYPE_SIGN_SHA256,     "SIGNATURE" },
+	{ TYPE_ENCR_AES256,     "ENCRYPTED_DATA" },
 	{ 0, NULL }
 };
 
 #define TYPE_VALUE_COUNTER  0x00
 #define TYPE_VALUE_GAUGE    0x01
+#define TYPE_VALUE_DERIVE   0x02
+#define TYPE_VALUE_ABSOLUTE 0x03
 static const value_string valuetypenames[] = {
 	{ TYPE_VALUE_COUNTER,   "COUNTER" },
 	{ TYPE_VALUE_GAUGE,     "GAUGE" },
+	{ TYPE_VALUE_DERIVE,    "DERIVE" },
+	{ TYPE_VALUE_ABSOLUTE,  "ABSOLUTE" },
 	{ 0, NULL }
 };
 
@@ -117,9 +143,10 @@ static const value_string severity_names[] = {
 };
 
 #define UDP_PORT_COLLECTD 25826
-static gint collectd_udp_port = UDP_PORT_COLLECTD;
+static guint collectd_udp_port = UDP_PORT_COLLECTD;
 
 static gint proto_collectd		= -1;
+static gint tap_collectd                = -1;
 
 static gint hf_collectd_type		= -1;
 static gint hf_collectd_length		= -1;
@@ -135,9 +162,16 @@ static gint hf_collectd_data_valcnt	= -1;
 static gint hf_collectd_val_type	= -1;
 static gint hf_collectd_val_counter	= -1;
 static gint hf_collectd_val_gauge	= -1;
+static gint hf_collectd_val_derive	= -1;
+static gint hf_collectd_val_absolute	= -1;
 static gint hf_collectd_val_unknown	= -1;
 static gint hf_collectd_data_severity	= -1;
 static gint hf_collectd_data_message	= -1;
+static gint hf_collectd_data_sighash    = -1;
+static gint hf_collectd_data_initvec    = -1;
+static gint hf_collectd_data_username_len = -1;
+static gint hf_collectd_data_username   = -1;
+static gint hf_collectd_data_encrypted  = -1;
 
 static gint ett_collectd		= -1;
 static gint ett_collectd_string		= -1;
@@ -145,13 +179,84 @@ static gint ett_collectd_integer	= -1;
 static gint ett_collectd_part_value	= -1;
 static gint ett_collectd_value		= -1;
 static gint ett_collectd_valinfo	= -1;
+static gint ett_collectd_signature	= -1;
+static gint ett_collectd_encryption	= -1;
 static gint ett_collectd_dispatch	= -1;
 static gint ett_collectd_invalid_length	= -1;
 static gint ett_collectd_unknown	= -1;
 
+static gint st_collectd_packets = -1;
+static gint st_collectd_values  = -1;
+static gint st_collectd_values_hosts   = -1;
+static gint st_collectd_values_plugins = -1;
+static gint st_collectd_values_types   = -1;
+
 /* Prototype for the handoff function */
 void proto_reg_handoff_collectd (void);
 
+static void
+collectd_stats_tree_init (stats_tree *st)
+{
+	st_collectd_packets = stats_tree_create_node (st, "Packets", 0, FALSE);
+	st_collectd_values = stats_tree_create_node (st, "Values", 0, TRUE);
+
+	st_collectd_values_hosts = stats_tree_create_pivot (st, "By host",
+							   st_collectd_values);
+	st_collectd_values_plugins = stats_tree_create_pivot (st, "By plugin",
+							      st_collectd_values);
+	st_collectd_values_types = stats_tree_create_pivot (st, "By type",
+							    st_collectd_values);
+} /* void collectd_stats_tree_init */
+
+static int
+collectd_stats_tree_packet (stats_tree *st, packet_info *pinfo _U_,
+			    epan_dissect_t *edt _U_, const void *user_data)
+{
+	const tap_data_t *td;
+	string_counter_t *sc;
+
+	td = user_data;
+	if (td == NULL)
+		return (-1);
+
+	tick_stat_node (st, "Packets", 0, FALSE);
+	increase_stat_node (st, "Values", 0, TRUE, td->values_num);
+
+	for (sc = td->hosts; sc != NULL; sc = sc->next)
+	{
+		gint i;
+		for (i = 0; i < sc->count; i++)
+			stats_tree_tick_pivot (st, st_collectd_values_hosts,
+					       sc->string);
+	}
+
+	for (sc = td->plugins; sc != NULL; sc = sc->next)
+	{
+		gint i;
+		for (i = 0; i < sc->count; i++)
+			stats_tree_tick_pivot (st, st_collectd_values_plugins,
+					       sc->string);
+	}
+
+	for (sc = td->types; sc != NULL; sc = sc->next)
+	{
+		gint i;
+		for (i = 0; i < sc->count; i++)
+			stats_tree_tick_pivot (st, st_collectd_values_types,
+					       sc->string);
+	}
+
+	return (1);
+} /* int collectd_stats_tree_packet */
+
+static void
+collectd_stats_tree_register (void)
+{
+	stats_tree_register ("collectd", "collectd", "Collectd", 0,
+			     collectd_stats_tree_packet,
+			     collectd_stats_tree_init, NULL);
+} /* void register_collectd_stat_trees */
+
 static int
 dissect_collectd_string (tvbuff_t *tvb, packet_info *pinfo, gint type_hf,
 			 gint offset, gint *ret_offset, gint *ret_length,
@@ -164,7 +269,7 @@ dissect_collectd_string (tvbuff_t *tvb, packet_info *pinfo, gint type_hf,
 	gint length;
 	gint size;
 
-	size = tvb_length_remaining (tvb, offset);
+	size = tvb_reported_length_remaining (tvb, offset);
 	if (size < 4)
 	{
 		/* This should never happen, because `dissect_collectd' checks
@@ -219,7 +324,7 @@ dissect_collectd_integer (tvbuff_t *tvb, packet_info *pinfo, gint type_hf,
 	gint length;
 	gint size;
 
-	size = tvb_length_remaining (tvb, offset);
+	size = tvb_reported_length_remaining (tvb, offset);
 	if (size < 4)
 	{
 		/* This should never happen, because `dissect_collectd' checks
@@ -300,7 +405,8 @@ dissect_collectd_values(tvbuff_t *tvb, gint msg_off, gint val_cnt,
 
 	values_tree = proto_item_add_subtree (pi, ett_collectd_value);
 
-	for (i = 0; i < val_cnt; i++) {
+	for (i = 0; i < val_cnt; i++)
+	{
 		gint value_offset;
 
 		gint value_type_offset;
@@ -354,6 +460,44 @@ dissect_collectd_values(tvbuff_t *tvb, gint msg_off, gint val_cnt,
 			break;
 		}
 
+		case TYPE_VALUE_DERIVE:
+		{
+			gint64 val64;
+
+			val64 = tvb_get_ntoh64 (tvb, value_offset);
+			pi = proto_tree_add_text (values_tree, tvb, msg_off + 6,
+						  val_cnt * 9,
+						  "Derive: %"G_GINT64_MODIFIER"i", val64);
+
+			value_tree = proto_item_add_subtree (pi,
+					ett_collectd_valinfo);
+			proto_tree_add_item (value_tree, hf_collectd_val_type,
+					     tvb, value_type_offset, 1, FALSE);
+			proto_tree_add_item (value_tree,
+					     hf_collectd_val_derive, tvb,
+					     value_offset, 8, FALSE);
+			break;
+		}
+
+		case TYPE_VALUE_ABSOLUTE:
+		{
+			guint64 val64;
+
+			val64 = tvb_get_ntoh64 (tvb, value_offset);
+			pi = proto_tree_add_text (values_tree, tvb, msg_off + 6,
+						  val_cnt * 9,
+						  "Absolute: %"G_GINT64_MODIFIER"u", val64);
+
+			value_tree = proto_item_add_subtree (pi,
+					ett_collectd_valinfo);
+			proto_tree_add_item (value_tree, hf_collectd_val_type,
+					     tvb, value_type_offset, 1, FALSE);
+			proto_tree_add_item (value_tree,
+					     hf_collectd_val_absolute, tvb,
+					     value_offset, 8, FALSE);
+			break;
+		}
+
 		default:
 		{
 			guint64 val64;
@@ -388,7 +532,7 @@ dissect_collectd_part_values (tvbuff_t *tvb, packet_info *pinfo, gint offset,
 	gint values_count;
 	gint corrected_values_count;
 
-	size = tvb_length_remaining (tvb, offset);
+	size = tvb_reported_length_remaining (tvb, offset);
 	if (size < 4)
 	{
 		/* This should never happen, because `dissect_collectd' checks
@@ -494,11 +638,211 @@ dissect_collectd_part_values (tvbuff_t *tvb, packet_info *pinfo, gint offset,
 			     "Interval: %"G_GINT64_MODIFIER"u",
 			     vdispatch->interval);
 	return (0);
-} /* int dissect_collectd_part_values */
+} /* void dissect_collectd_part_values */
+
+static int
+dissect_collectd_signature (tvbuff_t *tvb, packet_info *pinfo,
+			    gint offset, proto_tree *tree_root)
+{
+	proto_item *pi;
+	proto_tree *pt;
+	gint type;
+	gint length;
+	gint size;
+
+	size = tvb_reported_length_remaining (tvb, offset);
+	if (size < 4)
+	{
+		/* This should never happen, because `dissect_collectd' checks
+		 * for this condition already. */
+		return (-1);
+	}
+
+	type   = tvb_get_ntohs (tvb, offset);
+	length = tvb_get_ntohs (tvb, offset + 2);
+
+	if (size < 36) /* remaining packet size too small for signature */
+	{
+		pi = proto_tree_add_text (tree_root, tvb, offset, -1,
+					  "collectd %s segment: <BAD>",
+					  val_to_str (type, part_names, "UNKNOWN"));
+
+		pt = proto_item_add_subtree (pi, ett_collectd_signature);
+		proto_tree_add_uint (pt, hf_collectd_type, tvb, offset, 2, type);
+		proto_tree_add_uint (pt, hf_collectd_length, tvb, offset + 2, 2,
+				     length);
+		pi = proto_tree_add_text (pt, tvb, offset + 4, -1,
+					  "Garbage at end of packet: Length = %i <BAD>",
+					  size - 4);
+		expert_add_info_format (pinfo, pi, PI_MALFORMED, PI_ERROR,
+					"Garbage at end of packet");
+
+		return (-1);
+	}
+
+	if (length < 36)
+	{
+		pi = proto_tree_add_text (tree_root, tvb, offset, -1,
+					  "collectd %s segment: <BAD>",
+					  val_to_str (type, part_names, "UNKNOWN"));
+
+		pt = proto_item_add_subtree (pi, ett_collectd_signature);
+		proto_tree_add_uint (pt, hf_collectd_type, tvb, offset, 2, type);
+		pi = proto_tree_add_uint (pt, hf_collectd_length, tvb,
+					  offset + 2, 2, length);
+		expert_add_info_format (pinfo, pi, PI_MALFORMED, PI_ERROR,
+					"Invalid length field for a signature part.");
+
+		return (-1);
+	}
+
+	pi = proto_tree_add_text (tree_root, tvb, offset, length,
+				  "collectd %s segment: HMAC-SHA-256",
+				  val_to_str (type, part_names, "UNKNOWN"));
+
+	pt = proto_item_add_subtree (pi, ett_collectd_signature);
+	proto_tree_add_uint (pt, hf_collectd_type, tvb, offset, 2, type);
+	proto_tree_add_uint (pt, hf_collectd_length, tvb, offset + 2, 2,
+			     length);
+	proto_tree_add_item (pt, hf_collectd_data_sighash, tvb, offset + 4, 32, FALSE);
+	proto_tree_add_item (pt, hf_collectd_data_username, tvb, offset + 36, length - 36, FALSE);
+
+	return (0);
+} /* int dissect_collectd_signature */
+
+static int
+dissect_collectd_encrypted (tvbuff_t *tvb, packet_info *pinfo,
+			    gint offset, proto_tree *tree_root)
+{
+	proto_item *pi;
+	proto_tree *pt;
+	gint type;
+	gint length;
+	gint size;
+	gint username_length;
+
+	size = tvb_reported_length_remaining (tvb, offset);
+	if (size < 4)
+	{
+		/* This should never happen, because `dissect_collectd' checks
+		 * for this condition already. */
+		return (-1);
+	}
+
+	type   = tvb_get_ntohs (tvb, offset);
+	length = tvb_get_ntohs (tvb, offset + 2);
+
+	if (size < 42) /* remaining packet size too small for signature */
+	{
+		pi = proto_tree_add_text (tree_root, tvb, offset, -1,
+					  "collectd %s segment: <BAD>",
+					  val_to_str (type, part_names, "UNKNOWN"));
+
+		pt = proto_item_add_subtree (pi, ett_collectd_encryption);
+		proto_tree_add_uint (pt, hf_collectd_type, tvb, offset, 2, type);
+		proto_tree_add_uint (pt, hf_collectd_length, tvb, offset + 2, 2,
+				     length);
+		pi = proto_tree_add_text (pt, tvb, offset + 4, -1,
+					  "Garbage at end of packet: Length = %i <BAD>",
+					  size - 4);
+		expert_add_info_format (pinfo, pi, PI_MALFORMED, PI_ERROR,
+					"Garbage at end of packet");
+
+		return (-1);
+	}
+
+	if (length < 42)
+	{
+		pi = proto_tree_add_text (tree_root, tvb, offset, -1,
+					  "collectd %s segment: <BAD>",
+					  val_to_str (type, part_names, "UNKNOWN"));
+
+		pt = proto_item_add_subtree (pi, ett_collectd_encryption);
+		proto_tree_add_uint (pt, hf_collectd_type, tvb, offset, 2, type);
+		pi = proto_tree_add_uint (pt, hf_collectd_length, tvb,
+					  offset + 2, 2, length);
+		expert_add_info_format (pinfo, pi, PI_MALFORMED, PI_ERROR,
+					"Invalid length field for an encryption part.");
+
+		return (-1);
+	}
+
+	username_length = tvb_get_ntohs (tvb, offset + 4);
+	if (username_length > (length - 42))
+	{
+		pi = proto_tree_add_text (tree_root, tvb, offset, -1,
+					  "collectd %s segment: <BAD>",
+					  val_to_str (type, part_names, "UNKNOWN"));
+
+		pt = proto_item_add_subtree (pi, ett_collectd_encryption);
+		proto_tree_add_uint (pt, hf_collectd_type, tvb, offset, 2, type);
+		proto_tree_add_uint (pt, hf_collectd_length, tvb,
+				     offset + 2, 2, length);
+		pi = proto_tree_add_uint (pt, hf_collectd_data_username_len, tvb,
+					  offset + 4, 2, length);
+		expert_add_info_format (pinfo, pi, PI_MALFORMED, PI_ERROR,
+					"Invalid username length field for an encryption part.");
+
+		return (-1);
+	}
+
+	pi = proto_tree_add_text (tree_root, tvb, offset, length,
+				  "collectd %s segment: AES-256",
+				  val_to_str (type, part_names, "UNKNOWN"));
+
+	pt = proto_item_add_subtree (pi, ett_collectd_encryption);
+	proto_tree_add_uint (pt, hf_collectd_type, tvb, offset, 2, type);
+	proto_tree_add_uint (pt, hf_collectd_length, tvb, offset + 2, 2, length);
+	proto_tree_add_uint (pt, hf_collectd_data_username_len, tvb, offset + 4, 2, username_length);
+	proto_tree_add_item (pt, hf_collectd_data_username, tvb, offset + 6, username_length, FALSE);
+	proto_tree_add_item (pt, hf_collectd_data_initvec, tvb,
+			     offset + (6 + username_length), 16, FALSE);
+	proto_tree_add_item (pt, hf_collectd_data_encrypted, tvb,
+			     offset + (22 + username_length),
+			     length - (22 + username_length), FALSE);
+
+	return (0);
+} /* int dissect_collectd_encrypted */
+
+static int
+stats_account_string (string_counter_t **ret_list, const gchar *new_value)
+{
+	string_counter_t *entry;
+
+	if (ret_list == NULL)
+		return (-1);
+
+	if (new_value == NULL)
+		new_value = "(null)";
+
+	for (entry = *ret_list; entry != NULL; entry = entry->next)
+		if (strcmp (new_value, entry->string) == 0)
+		{
+			entry->count++;
+			return (0);
+		}
+
+	entry = ep_alloc (sizeof (*entry));
+	if (entry == NULL)
+		return (-1);
+	memset (entry, 0, sizeof (*entry));
+
+	entry->string = ep_strdup (new_value);
+	if (entry->string == NULL)
+		return (-1);
+	entry->count = 1;
+	entry->next = *ret_list;
+
+	*ret_list = entry;
+
+	return (0);
+}
 
 static void
 dissect_collectd (tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 {
+	static tap_data_t tap_data;
+
 	gint offset;
 	gint size;
 	gchar *pkt_host = NULL;
@@ -523,8 +867,11 @@ dissect_collectd (tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 	pi = proto_tree_add_item(tree, proto_collectd, tvb, 0, -1, FALSE);
 	collectd_tree = proto_item_add_subtree(pi, ett_collectd);
 
+	memset (&tap_data, 0, sizeof (tap_data));
+
 	status = 0;
-	while ((size > 0) && (status == 0)) {
+	while ((size > 0) && (status == 0))
+	{
 
 		gint part_type;
 		gint part_length;
@@ -534,7 +881,8 @@ dissect_collectd (tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 		 * plugins and notifications. The payload is not checked at
 		 * all, but the same checks are run on the part_length stuff -
 		 * it's important to keep an eye on that. */
-		if (!tree) {
+		if (!tree)
+		{
 			/* Check for garbage at end of packet. */
 			if (size < 4)
 			{
@@ -547,7 +895,8 @@ dissect_collectd (tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 			part_length  = tvb_get_ntohs (tvb, offset+2);
 
 			/* Check if part_length is in the valid range. */
-			if ((part_length < 4) || (part_length > size)) {
+			if ((part_length < 4) || (part_length > size))
+			{
 				pkt_errors++;
 				status = -1;
 				break;
@@ -555,25 +904,42 @@ dissect_collectd (tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 
 			switch (part_type) {
 			case TYPE_HOST:
+				vdispatch.host = tvb_get_ephemeral_string (tvb,
+						offset + 4, part_length - 4);
 				if (pkt_host == NULL)
-					pkt_host = tvb_get_ephemeral_string(tvb, offset+4, part_length-4);
+					pkt_host = vdispatch.host;
 				break;
 			case TYPE_TIME:
 				break;
 			case TYPE_PLUGIN:
+				vdispatch.plugin = tvb_get_ephemeral_string (tvb,
+						offset + 4, part_length - 4);
 				pkt_plugins++;
 				break;
 			case TYPE_PLUGIN_INSTANCE:
 				break;
 			case TYPE_TYPE:
+				vdispatch.type = tvb_get_ephemeral_string (tvb,
+						offset + 4, part_length - 4);
 				break;
 			case TYPE_TYPE_INSTANCE:
 				break;
 			case TYPE_INTERVAL:
 				break;
 			case TYPE_VALUES:
+			{
 				pkt_values++;
+
+				tap_data.values_num++;
+				stats_account_string (&tap_data.hosts,
+						      vdispatch.host);
+				stats_account_string (&tap_data.plugins,
+						      vdispatch.plugin);
+				stats_account_string (&tap_data.types,
+						      vdispatch.type);
+
 				break;
+			}
 			case TYPE_MESSAGE:
 				pkt_messages++;
 				break;
@@ -594,7 +960,8 @@ dissect_collectd (tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 		 * Four bytes are used to read the type and the length
 		 * of the next part. If there's less, there's some garbage
 		 * at the end of the packet. */
-		if (size < 4) {
+		if (size < 4)
+		{
 			pi = proto_tree_add_text (collectd_tree, tvb,
 						  offset, -1,
 						  "Garbage at end of packet: Length = %i <BAD>",
@@ -614,7 +981,8 @@ dissect_collectd (tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 		/* Check if the length of the part is in the valid range. Don't
 		 * confuse this with the above: Here we check the information
 		 * provided in the packet.. */
-		if ((part_length < 4) || (part_length > size)) {
+		if ((part_length < 4) || (part_length > size))
+		{
 			pi = proto_tree_add_text (collectd_tree, tvb,
 						  offset, part_length,
 						  "collectd %s segment: Length = %i <BAD>",
@@ -645,7 +1013,8 @@ dissect_collectd (tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 		/* The header information looks okay, let's tend to the actual
 		 * payload in this part. */
 		switch (part_type) {
-		case TYPE_HOST: {
+		case TYPE_HOST:
+		{
 			status = dissect_collectd_string (tvb, pinfo,
 					hf_collectd_data_host,
 					offset,
@@ -655,7 +1024,8 @@ dissect_collectd (tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 					collectd_tree, /* item = */ NULL);
 			if (status != 0)
 				pkt_errors++;
-			else {
+			else
+			{
 				if (pkt_host == NULL)
 					pkt_host = vdispatch.host;
 				ndispatch.host_off = vdispatch.host_off;
@@ -666,7 +1036,8 @@ dissect_collectd (tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 			break;
 		}
 
-		case TYPE_PLUGIN: {
+		case TYPE_PLUGIN:
+		{
 			status = dissect_collectd_string (tvb, pinfo,
 					hf_collectd_data_plugin,
 					offset,
@@ -682,7 +1053,8 @@ dissect_collectd (tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 			break;
 		}
 
-		case TYPE_PLUGIN_INSTANCE: {
+		case TYPE_PLUGIN_INSTANCE:
+		{
 			status = dissect_collectd_string (tvb, pinfo,
 					hf_collectd_data_plugin_inst,
 					offset,
@@ -696,7 +1068,8 @@ dissect_collectd (tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 			break;
 		}
 
-		case TYPE_TYPE: {
+		case TYPE_TYPE:
+		{
 			status = dissect_collectd_string (tvb, pinfo,
 					hf_collectd_data_type,
 					offset,
@@ -710,7 +1083,8 @@ dissect_collectd (tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 			break;
 		}
 
-		case TYPE_TYPE_INSTANCE: {
+		case TYPE_TYPE_INSTANCE:
+		{
 			status = dissect_collectd_string (tvb, pinfo,
 					hf_collectd_data_type_inst,
 					offset,
@@ -724,7 +1098,8 @@ dissect_collectd (tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 			break;
 		}
 
-		case TYPE_TIME: {
+		case TYPE_TIME:
+		{
 			ndispatch.time_str = NULL;
 			vdispatch.time_str = NULL;
 
@@ -737,7 +1112,8 @@ dissect_collectd (tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 					collectd_tree, &pi);
 			if (status != 0)
 				pkt_errors++;
-			else {
+			else
+			{
 				vdispatch.time_str = abs_time_secs_to_str ((time_t) vdispatch.time);
 
 				ndispatch.time = vdispatch.time;
@@ -750,7 +1126,8 @@ dissect_collectd (tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 			break;
 		}
 
-		case TYPE_INTERVAL: {
+		case TYPE_INTERVAL:
+		{
 			status = dissect_collectd_integer (tvb, pinfo,
 					hf_collectd_data_interval,
 					offset,
@@ -763,7 +1140,8 @@ dissect_collectd (tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 			break;
 		}
 
-		case TYPE_VALUES: {
+		case TYPE_VALUES:
+		{
 			status = dissect_collectd_part_values (tvb, pinfo,
 					offset,
 					&vdispatch,
@@ -773,10 +1151,19 @@ dissect_collectd (tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 			else
 				pkt_values++;
 
+			tap_data.values_num++;
+			stats_account_string (&tap_data.hosts,
+					      vdispatch.host);
+			stats_account_string (&tap_data.plugins,
+					      vdispatch.plugin);
+			stats_account_string (&tap_data.types,
+					      vdispatch.type);
+
 			break;
 		}
 
-		case TYPE_MESSAGE: {
+		case TYPE_MESSAGE:
+		{
 			pi = NULL;
 			status = dissect_collectd_string (tvb, pinfo,
 					hf_collectd_data_message,
@@ -815,7 +1202,8 @@ dissect_collectd (tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 			break;
 		}
 
-		case TYPE_SEVERITY: {
+		case TYPE_SEVERITY:
+		{
 			pi = NULL;
 			status = dissect_collectd_integer (tvb, pinfo,
 					hf_collectd_data_severity,
@@ -825,7 +1213,8 @@ dissect_collectd (tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 					collectd_tree, &pi);
 			if (status != 0)
 				pkt_errors++;
-			else {
+			else
+			{
 				proto_item_set_text (pi,
 						"collectd SEVERITY segment: "
 						"%s (%"G_GINT64_MODIFIER"u)",
@@ -836,7 +1225,29 @@ dissect_collectd (tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 			break;
 		}
 
-		default: {
+		case TYPE_SIGN_SHA256:
+		{
+			status = dissect_collectd_signature (tvb, pinfo,
+							     offset,
+							     collectd_tree);
+			if (status != 0)
+				pkt_errors++;
+
+			break;
+		}
+
+		case TYPE_ENCR_AES256:
+		{
+			status = dissect_collectd_encrypted (tvb, pinfo,
+					offset, collectd_tree);
+			if (status != 0)
+				pkt_errors++;
+
+			break;
+		}
+
+		default:
+		{
 			pkt_unknown++;
 			pi = proto_tree_add_text (collectd_tree, tvb,
 						  offset, part_length,
@@ -893,6 +1304,9 @@ dissect_collectd (tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 			      pkt_values, plurality (pkt_values, " ", "s"),
 			      pkt_plugins, plurality (pkt_plugins, ", ", "s,"),
 			      pkt_messages, plurality (pkt_messages, "", "s"));
+
+	/* Dispatch tap data. */
+	tap_queue_packet (tap_collectd, pinfo, &tap_data);
 } /* void dissect_collectd */
 
 void proto_register_collectd(void)
@@ -910,7 +1324,7 @@ void proto_register_collectd(void)
 				NULL, 0x0, NULL, HFILL }
 		},
 		{ &hf_collectd_data,
-			{ "Payload", "collectd.data", FT_BYTES, BASE_HEX,
+			{ "Payload", "collectd.data", FT_BYTES, BASE_NONE,
 				NULL, 0x0, NULL, HFILL }
 		},
 		{ &hf_collectd_data_host,
@@ -957,6 +1371,14 @@ void proto_register_collectd(void)
 			{ "Gauge value", "collectd.val.gauge", FT_DOUBLE, BASE_NONE,
 				NULL, 0x0, NULL, HFILL }
 		},
+		{ &hf_collectd_val_derive,
+			{ "Derive value", "collectd.val.derive", FT_INT64, BASE_DEC,
+				NULL, 0x0, NULL, HFILL }
+		},
+		{ &hf_collectd_val_absolute,
+			{ "Absolute value", "collectd.val.absolute", FT_UINT64, BASE_DEC,
+				NULL, 0x0, NULL, HFILL }
+		},
 		{ &hf_collectd_val_unknown,
 			{ "Value of unknown type", "collectd.val.unknown", FT_UINT64, BASE_HEX,
 				NULL, 0x0, NULL, HFILL }
@@ -969,6 +1391,26 @@ void proto_register_collectd(void)
 			{ "Message", "collectd.data.message", FT_STRING, BASE_NONE,
 				NULL, 0x0, NULL, HFILL }
 		},
+		{ &hf_collectd_data_sighash,
+			{ "Signature", "collectd.data.sighash", FT_BYTES, BASE_NONE,
+				NULL, 0x0, NULL, HFILL }
+		},
+		{ &hf_collectd_data_initvec,
+			{ "Init vector", "collectd.data.initvec", FT_BYTES, BASE_NONE,
+				NULL, 0x0, NULL, HFILL }
+		},
+		{ &hf_collectd_data_username_len,
+			{ "Username length", "collectd.data.username_length", FT_UINT16, BASE_DEC,
+				NULL, 0x0, NULL, HFILL }
+		},
+		{ &hf_collectd_data_username,
+			{ "Username", "collectd.data.username", FT_STRING, BASE_NONE,
+				NULL, 0x0, NULL, HFILL }
+		},
+		{ &hf_collectd_data_encrypted,
+			{ "Encrypted data", "collectd.data.encrypted", FT_BYTES, BASE_NONE,
+				NULL, 0x0, NULL, HFILL }
+		},
 	};
 
 	/* Setup protocol subtree array */
@@ -979,6 +1421,8 @@ void proto_register_collectd(void)
 		&ett_collectd_part_value,
 		&ett_collectd_value,
 		&ett_collectd_valinfo,
+		&ett_collectd_signature,
+		&ett_collectd_encryption,
 		&ett_collectd_dispatch,
 		&ett_collectd_invalid_length,
 		&ett_collectd_unknown,
@@ -992,6 +1436,8 @@ void proto_register_collectd(void)
 	proto_register_field_array(proto_collectd, hf, array_length(hf));
 	proto_register_subtree_array(ett, array_length(ett));
 
+	tap_collectd = register_tap ("collectd");
+
 	/*
 	 * Create an unsigned integer preference to allow the user to specify the
 	 * UDP port on which to capture DIS packets.
@@ -1024,5 +1470,8 @@ void proto_reg_handoff_collectd (void)
 	dissector_add ("udp.port", collectd_udp_port, collectd_handle);
 	registered_udp_port = collectd_udp_port;
 
+	if (first_run)
+		collectd_stats_tree_register ();
+
 	first_run = FALSE;
 } /* void proto_reg_handoff_collectd */
