@@ -2,7 +2,7 @@
  * Copyright 2001, Todd Sabin <tas@webspan.net>
  * Copyright 2003, Tim Potter <tpot@samba.org>
  *
- * $Id: packet-dcerpc.h 24289 2008-02-08 09:20:02Z sahlberg $
+ * $Id: packet-dcerpc.h 30272 2009-10-04 04:14:49Z sahlberg $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -28,6 +28,13 @@
 
 #include <epan/conversation.h>
 
+#ifdef PT_R4
+/* now glib always includes signal.h and on linux PPC 
+ * signal.h defines PT_R4
+*/
+#undef PT_R4
+#endif
+
 typedef struct _e_uuid_t {
     guint32 Data1;
     guint16 Data2;
@@ -176,8 +183,21 @@ int dissect_ndr_uuid_t (tvbuff_t *tvb, gint offset, packet_info *pinfo,
                         proto_tree *tree, guint8 *drep,
                         int hfindex, e_uuid_t *pdata);
 int dissect_ndr_ctx_hnd (tvbuff_t *tvb, gint offset, packet_info *pinfo,
-                         proto_tree *tree, guint8 *drep,
-                         int hfindex, e_ctx_hnd *pdata);
+                        proto_tree *tree, guint8 *drep,
+                        int hfindex, e_ctx_hnd *pdata);
+
+#define FT_UINT1632 FT_UINT32
+typedef guint32 guint1632;
+
+int dissect_ndr_uint1632 (tvbuff_t *tvb, gint offset, packet_info *pinfo,
+		        proto_tree *tree, guint8 *drep,
+		        int hfindex, guint1632 *pdata);
+
+typedef guint64 guint3264;
+
+int dissect_ndr_uint3264 (tvbuff_t *tvb, gint offset, packet_info *pinfo,
+		        proto_tree *tree, guint8 *drep,
+		        int hfindex, guint3264 *pdata);
 
 typedef int (dcerpc_dissect_fnct_t)(tvbuff_t *tvb, int offset, packet_info *pinfo, proto_tree *tree, guint8 *drep);
 
@@ -295,13 +315,15 @@ typedef struct _dcerpc_call_value {
                              */
     void *private_data;      /* XXX This will later be renamed as ep_data */
     e_ctx_hnd *pol;	     /* policy handle tracked between request/response*/
+#define DCERPC_IS_NDR64 0x00000001
+    guint32 flags;	     /* flags for this transaction */
 } dcerpc_call_value;
 
 typedef struct _dcerpc_info {
 	conversation_t *conv;	/* Which TCP stream we are in */
 	guint32 call_id;	/* Context id for this call */
 	guint16 smb_fid;	/* FID for DCERPC over SMB */
-    guint8 ptype;       /* packet type: PDU_REQ, PDU_RESP, ... */
+	guint8 ptype;       /* packet type: PDU_REQ, PDU_RESP, ... */
 	gboolean conformant_run;
 	gint32 conformant_eaten; /* how many bytes did the conformant run eat?*/
 	guint32 array_max_count;	/* max_count for conformant arrays */
@@ -454,6 +476,10 @@ init_ndr_pointer_list(packet_info *pinfo);
 #define PIDL_POLHND_TYPE_SAMR_GROUP	0x00040000
 #define PIDL_POLHND_TYPE_SAMR_ALIAS	0x00050000
 
+#define PIDL_POLHND_TYPE_LSA_POLICY	0x00060000
+#define PIDL_POLHND_TYPE_LSA_ACCOUNT	0x00070000
+#define PIDL_POLHND_TYPE_LSA_SECRET	0x00080000
+#define PIDL_POLHND_TYPE_LSA_DOMAIN	0x00090000
 
 /* a structure we store for all policy handles we track */
 typedef struct pol_value {
