@@ -1,7 +1,7 @@
 /* packet-diameter.c
  * Routines for Diameter packet disassembly
  *
- * $Id: packet-diameter.c 27062 2008-12-19 17:39:52Z gerald $
+ * $Id: packet-diameter.c 30395 2009-10-08 05:43:19Z jake $
  *
  * Copyright (c) 2001 by David Frascone <dave@frascone.com>
  * Copyright (c) 2007 by Luis E. Garcia Ontanon <luis@ontanon.org>
@@ -59,10 +59,10 @@
 #include <epan/expert.h>
 #include <epan/conversation.h>
 #include <epan/tap.h>
+#include <epan/diam_dict.h>
 #include "packet-tcp.h"
 #include "packet-ntp.h"
 #include "packet-diameter.h"
-#include "diam_dict.h"
 
 #define SCTP_PORT_DIAMETER	3868
 
@@ -190,11 +190,7 @@ static diam_dictionary_t dictionary = { NULL, NULL, NULL, NULL };
 static struct _build_dict build_dict;
 static const value_string* vnd_short_vs;
 static dissector_handle_t data_handle;
-
-static const true_false_string reserved_set = {
-	"Set",
-	"Unset"
-};
+static dissector_handle_t eap_handle;
 
 static const value_string diameter_avp_data_addrfamily_vals[]= {
 	{1,"IPv4"},
@@ -314,6 +310,19 @@ dissect_diameter_vedor_id(tvbuff_t *tvb _U_, packet_info *pinfo _U_, proto_tree
 
 }
 
+static int
+dissect_diameter_eap_payload(tvbuff_t *tvb _U_, packet_info *pinfo _U_, proto_tree *tree _U_) {
+	gboolean save_writable;
+
+	/* Ensure the packet is displayed as Diameter, not EAP */
+	save_writable = col_get_writable(pinfo->cinfo);
+	col_set_writable(pinfo->cinfo, FALSE);
+
+	call_dissector(eap_handle, tvb, pinfo, tree);
+
+	col_set_writable(pinfo->cinfo, save_writable);
+	return tvb_length(tvb);
+}
 
 /* Dissect an AVP at offset */
 static int
@@ -491,7 +500,7 @@ address_rfc_avp(diam_ctx_t* c, diam_avp_t* a, tvbuff_t* tvb)
 			break;
 	}
 
-	proto_item_fill_label(pi->finfo, label);
+	proto_item_fill_label(PITEM_FINFO(pi), label);
 	label = strstr(label,": ")+2;
 	return label;
 }
@@ -561,7 +570,7 @@ address_v16_avp(diam_ctx_t* c, diam_avp_t* a, tvbuff_t* tvb)
 			break;
 	}
 
-	proto_item_fill_label(pi->finfo, label);
+	proto_item_fill_label(PITEM_FINFO(pi), label);
 	label = strstr(label,": ")+2;
 	return label;
 }
@@ -571,7 +580,7 @@ simple_avp(diam_ctx_t* c, diam_avp_t* a, tvbuff_t* tvb)
 {
 	char* label = ep_alloc(ITEM_LABEL_LENGTH+1);
 	proto_item* pi = proto_tree_add_item(c->tree,a->hf_value,tvb,0,tvb_length(tvb),FALSE);
-	proto_item_fill_label(pi->finfo, label);
+	proto_item_fill_label(PITEM_FINFO(pi), label);
 	label = strstr(label,": ")+2;
 	return label;
 }
@@ -586,7 +595,7 @@ unsigned32_avp(diam_ctx_t* c, diam_avp_t* a, tvbuff_t* tvb)
 	gint length = tvb_length_remaining(tvb,0);
 	if (length == 4) {
 		pi= proto_tree_add_item(c->tree,a->hf_value,tvb,0,tvb_length_remaining(tvb,0),FALSE);
-		proto_item_fill_label(pi->finfo, label);
+		proto_item_fill_label(PITEM_FINFO(pi), label);
 		label = strstr(label,": ")+2;
 	}
 	else {
@@ -628,7 +637,6 @@ static const char* msgflags_str[] = {
 	"RP--", "RP-T", "RPE-", "RPET"
 };
 
-
 static void
 dissect_diameter_common(tvbuff_t* tvb, packet_info* pinfo, proto_tree* tree)
 {
@@ -651,8 +659,7 @@ dissect_diameter_common(tvbuff_t* tvb, packet_info* pinfo, proto_tree* tree)
 	proto_item *it;
 	nstime_t ns;
 
-	if (check_col(pinfo->cinfo, COL_PROTOCOL))
-		col_set_str(pinfo->cinfo, COL_PROTOCOL, "DIAMETER");
+	col_set_str(pinfo->cinfo, COL_PROTOCOL, "DIAMETER");
 
 	pi = proto_tree_add_item(tree,proto_diameter,tvb,0,-1,FALSE);
 	diam_tree = proto_item_add_subtree(pi,ett_diameter);
@@ -789,6 +796,7 @@ dissect_diameter_common(tvbuff_t* tvb, packet_info* pinfo, proto_tree* tree)
 			diameter_pair = se_alloc(sizeof(diameter_req_ans_pair_t));
 			diameter_pair->hop_by_hop_id = hop_by_hop_id;
 			diameter_pair->cmd_code = cmd;
+			diameter_pair->cmd_str = cmd_str;
 			diameter_pair->req_frame = pinfo->fd->num;
 			diameter_pair->ans_frame = 0;
 			diameter_pair->req_time = pinfo->fd->abs_ts;
@@ -925,7 +933,7 @@ reginfo(int* hf_ptr, const char* name, const char* abbr, const char* desc,
 				base,
 				VALS(vs),
 				mask,
-				desc ? g_strdup(desc) : "",
+				g_strdup(desc),
 				HFILL }};
 
 	g_array_append_vals(build_dict.hf,&hf,1);
@@ -1006,19 +1014,19 @@ RFC3588
 
 	reginfo(&(t->hf_address_type), ep_strdup_printf("%s Address Family",name),
 		alnumerize(ep_strdup_printf("diameter.%s.addr_family",name)),
-		"", FT_UINT16, BASE_DEC, diameter_avp_data_addrfamily_vals, 0);
+		NULL, FT_UINT16, BASE_DEC, diameter_avp_data_addrfamily_vals, 0);
 
 	reginfo(&(t->hf_ipv4), ep_strdup_printf("%s Address",name),
 		alnumerize(ep_strdup_printf("diameter.%s",name)),
-		"", FT_IPv4, BASE_NONE, NULL, 0);
+		NULL, FT_IPv4, BASE_NONE, NULL, 0);
 
 	reginfo(&(t->hf_ipv6), ep_strdup_printf("%s Address",name),
 		alnumerize(ep_strdup_printf("diameter.%s",name)),
-		"", FT_IPv6, BASE_NONE, NULL, 0);
+		NULL, FT_IPv6, BASE_NONE, NULL, 0);
 
 	reginfo(&(t->hf_other), ep_strdup_printf("%s Address",name),
 		alnumerize(ep_strdup_printf("diameter.%s",name)),
-		"", FT_BYTES, BASE_NONE, NULL, 0);
+		NULL, FT_BYTES, BASE_NONE, NULL, 0);
 
 	g_ptr_array_add(build_dict.ett,ettp);
 
@@ -1101,8 +1109,8 @@ static const avp_type_t basic_types[] = {
 	{"unsigned32"				, unsigned32_avp, unsigned32_avp, FT_UINT32			, BASE_DEC	, build_simple_avp  },
 	{"integer64"				, simple_avp	, simple_avp	, FT_INT64			, BASE_DEC	, build_simple_avp  },
 	{"unsigned64"				, simple_avp	, simple_avp	, FT_UINT64			, BASE_DEC	, build_simple_avp  },
-	{"float32"				, simple_avp	, simple_avp	, FT_FLOAT			, BASE_DEC	, build_simple_avp  },
-	{"float64"				, simple_avp	, simple_avp	, FT_DOUBLE			, BASE_DEC	, build_simple_avp  },
+	{"float32"				, simple_avp	, simple_avp	, FT_FLOAT			, BASE_NONE	, build_simple_avp  },
+	{"float64"				, simple_avp	, simple_avp	, FT_DOUBLE			, BASE_NONE	, build_simple_avp  },
 	{"ipaddress"				,  NULL		, NULL		, FT_NONE			, BASE_NONE	, build_address_avp },
 	{"diameteruri"				, simple_avp	, simple_avp	, FT_STRING			, BASE_NONE	, build_simple_avp  },
 	{"diameteridentity"			, simple_avp	, simple_avp	, FT_STRING			, BASE_NONE	, build_simple_avp  },
@@ -1362,10 +1370,18 @@ proto_reg_handoff_diameter(void)
 		diameter_tcp_handle = create_dissector_handle(dissect_diameter_tcp,
 							      proto_diameter);
 		data_handle = find_dissector("data");
+		eap_handle = find_dissector("eap");
 		/* Register special decoding for some AVP:s */
 		/* AVP Code: 266 Vendor-Id */
 		dissector_add("diameter.base", 266, 
 				new_create_dissector_handle(dissect_diameter_vedor_id, proto_diameter));
+		/* AVP Code: 462 EAP-Payload */
+		dissector_add("diameter.base", 462, 
+			new_create_dissector_handle(dissect_diameter_eap_payload, proto_diameter));
+		/* AVP Code: 463 EAP-Reissued-Payload */
+		dissector_add("diameter.base", 463, 
+			new_create_dissector_handle(dissect_diameter_eap_payload, proto_diameter));
+
 		Initialized=TRUE;
 	} else {
 		range_foreach(diameter_tcp_port_range, range_delete_callback);
@@ -1391,100 +1407,100 @@ proto_register_diameter(void)
 	hf_register_info hf_base[] = {
 	{ &hf_diameter_version,
 		  { "Version", "diameter.version", FT_UINT8, BASE_HEX, NULL, 0x00,
-			  "", HFILL }},
+			  NULL, HFILL }},
 	{ &hf_diameter_length,
 		  { "Length","diameter.length", FT_UINT24, BASE_DEC, NULL, 0x0,
-			  "", HFILL }},
+			  NULL, HFILL }},
 	{ &hf_diameter_flags,
 		  { "Flags", "diameter.flags", FT_UINT8, BASE_HEX, NULL, 0x0,
-			  "", HFILL }},
+			  NULL, HFILL }},
 	{ &hf_diameter_flags_request,
-		  { "Request", "diameter.flags.request", FT_BOOLEAN, 8, TFS(&flags_set_truth), DIAM_FLAGS_R,
-			  "", HFILL }},
+		  { "Request", "diameter.flags.request", FT_BOOLEAN, 8, TFS(&tfs_set_notset), DIAM_FLAGS_R,
+			  NULL, HFILL }},
 	{ &hf_diameter_flags_proxyable,
-		  { "Proxyable", "diameter.flags.proxyable", FT_BOOLEAN, 8, TFS(&flags_set_truth), DIAM_FLAGS_P,
-			  "", HFILL }},
+		  { "Proxyable", "diameter.flags.proxyable", FT_BOOLEAN, 8, TFS(&tfs_set_notset), DIAM_FLAGS_P,
+			  NULL, HFILL }},
 	{ &hf_diameter_flags_error,
-		  { "Error","diameter.flags.error", FT_BOOLEAN, 8, TFS(&flags_set_truth), DIAM_FLAGS_E,
-			  "", HFILL }},
+		  { "Error","diameter.flags.error", FT_BOOLEAN, 8, TFS(&tfs_set_notset), DIAM_FLAGS_E,
+			  NULL, HFILL }},
 	{ &hf_diameter_flags_T,
-		  { "T(Potentially re-transmitted message)","diameter.flags.T", FT_BOOLEAN, 8, TFS(&flags_set_truth),DIAM_FLAGS_T,
-			  "", HFILL }},
+		  { "T(Potentially re-transmitted message)","diameter.flags.T", FT_BOOLEAN, 8, TFS(&tfs_set_notset),DIAM_FLAGS_T,
+			  NULL, HFILL }},
 	{ &hf_diameter_flags_reserved4,
-		  { "Reserved","diameter.flags.reserved4", FT_BOOLEAN, 8, TFS(&reserved_set),
-			  DIAM_FLAGS_RESERVED4, "", HFILL }},
+		  { "Reserved","diameter.flags.reserved4", FT_BOOLEAN, 8, TFS(&tfs_set_notset),
+			  DIAM_FLAGS_RESERVED4, NULL, HFILL }},
 	{ &hf_diameter_flags_reserved5,
-		  { "Reserved","diameter.flags.reserved5", FT_BOOLEAN, 8, TFS(&reserved_set),
-			  DIAM_FLAGS_RESERVED5, "", HFILL }},
+		  { "Reserved","diameter.flags.reserved5", FT_BOOLEAN, 8, TFS(&tfs_set_notset),
+			  DIAM_FLAGS_RESERVED5, NULL, HFILL }},
 	{ &hf_diameter_flags_reserved6,
-		  { "Reserved","diameter.flags.reserved6", FT_BOOLEAN, 8, TFS(&reserved_set),
-			  DIAM_FLAGS_RESERVED6, "", HFILL }},
+		  { "Reserved","diameter.flags.reserved6", FT_BOOLEAN, 8, TFS(&tfs_set_notset),
+			  DIAM_FLAGS_RESERVED6, NULL, HFILL }},
 	{ &hf_diameter_flags_reserved7,
-		  { "Reserved","diameter.flags.reserved7", FT_BOOLEAN, 8, TFS(&reserved_set),
-			  DIAM_FLAGS_RESERVED7, "", HFILL }},
+		  { "Reserved","diameter.flags.reserved7", FT_BOOLEAN, 8, TFS(&tfs_set_notset),
+			  DIAM_FLAGS_RESERVED7, NULL, HFILL }},
 	{ &hf_diameter_vendor_id,
 		  { "VendorId",	"diameter.vendorId", FT_UINT32, BASE_DEC, VALS(sminmpec_values),
-			  0x0,"", HFILL }},
+			  0x0,NULL, HFILL }},
 	{ &hf_diameter_application_id,
 		  { "ApplicationId",	"diameter.applicationId", FT_UINT32, BASE_DEC, dictionary.applications,
-			  0x0,"", HFILL }},
+			  0x0,NULL, HFILL }},
 	{ &hf_diameter_hopbyhopid,
 		  { "Hop-by-Hop Identifier", "diameter.hopbyhopid", FT_UINT32,
-			  BASE_HEX, NULL, 0x0, "", HFILL }},
+			  BASE_HEX, NULL, 0x0, NULL, HFILL }},
 	{ &hf_diameter_endtoendid,
 		  { "End-to-End Identifier", "diameter.endtoendid", FT_UINT32,
-			  BASE_HEX, NULL, 0x0, "", HFILL }},
+			  BASE_HEX, NULL, 0x0, NULL, HFILL }},
 	{ &hf_diameter_avp,
-		  { "AVP","diameter.avp", FT_BYTES, BASE_HEX,
-			  NULL, 0x0, "", HFILL }},
+		  { "AVP","diameter.avp", FT_BYTES, BASE_NONE,
+			  NULL, 0x0, NULL, HFILL }},
 	{ &hf_diameter_avp_len,
 		  { "AVP Length","diameter.avp.len", FT_UINT24, BASE_DEC,
-			  NULL, 0x0, "", HFILL }},
+			  NULL, 0x0, NULL, HFILL }},
 	{ &hf_diameter_avp_flags,
 		  { "AVP Flags","diameter.avp.flags", FT_UINT8, BASE_HEX,
-			  NULL, 0x0, "", HFILL }},
+			  NULL, 0x0, NULL, HFILL }},
 	{ &hf_diameter_avp_flags_vendor_specific,
-		  { "Vendor-Specific", "diameter.flags.vendorspecific", FT_BOOLEAN, 8, TFS(&flags_set_truth), AVP_FLAGS_V,
-			  "", HFILL }},
+		  { "Vendor-Specific", "diameter.flags.vendorspecific", FT_BOOLEAN, 8, TFS(&tfs_set_notset), AVP_FLAGS_V,
+			  NULL, HFILL }},
 	{ &hf_diameter_avp_flags_mandatory,
-		  { "Mandatory", "diameter.flags.mandatory", FT_BOOLEAN, 8, TFS(&flags_set_truth), AVP_FLAGS_M,
-			  "", HFILL }},
+		  { "Mandatory", "diameter.flags.mandatory", FT_BOOLEAN, 8, TFS(&tfs_set_notset), AVP_FLAGS_M,
+			  NULL, HFILL }},
 	{ &hf_diameter_avp_flags_protected,
-		  { "Protected","diameter.avp.flags.protected", FT_BOOLEAN, 8, TFS(&flags_set_truth), AVP_FLAGS_P,
-			  "", HFILL }},
+		  { "Protected","diameter.avp.flags.protected", FT_BOOLEAN, 8, TFS(&tfs_set_notset), AVP_FLAGS_P,
+			  NULL, HFILL }},
 	{ &hf_diameter_avp_flags_reserved3,
-		  { "Reserved","diameter.avp.flags.reserved3", FT_BOOLEAN, 8, TFS(&reserved_set),
-			  AVP_FLAGS_RESERVED3,	"", HFILL }},
+		  { "Reserved","diameter.avp.flags.reserved3", FT_BOOLEAN, 8, TFS(&tfs_set_notset),
+			  AVP_FLAGS_RESERVED3,	NULL, HFILL }},
 	{ &hf_diameter_avp_flags_reserved4,
-		  { "Reserved","diameter.avp.flags.reserved4", FT_BOOLEAN, 8, TFS(&reserved_set),
-			  AVP_FLAGS_RESERVED4,	"", HFILL }},
+		  { "Reserved","diameter.avp.flags.reserved4", FT_BOOLEAN, 8, TFS(&tfs_set_notset),
+			  AVP_FLAGS_RESERVED4,	NULL, HFILL }},
 	{ &hf_diameter_avp_flags_reserved5,
-		  { "Reserved","diameter.avp.flags.reserved5", FT_BOOLEAN, 8, TFS(&reserved_set),
-			  AVP_FLAGS_RESERVED5,	"", HFILL }},
+		  { "Reserved","diameter.avp.flags.reserved5", FT_BOOLEAN, 8, TFS(&tfs_set_notset),
+			  AVP_FLAGS_RESERVED5,	NULL, HFILL }},
 	{ &hf_diameter_avp_flags_reserved6,
-		  { "Reserved","diameter.avp.flags.reserved6", FT_BOOLEAN, 8, TFS(&reserved_set),
-			  AVP_FLAGS_RESERVED6,	"", HFILL }},
+		  { "Reserved","diameter.avp.flags.reserved6", FT_BOOLEAN, 8, TFS(&tfs_set_notset),
+			  AVP_FLAGS_RESERVED6,	NULL, HFILL }},
 	{ &hf_diameter_avp_flags_reserved7,
-		  { "Reserved","diameter.avp.flags.reserved7", FT_BOOLEAN, 8, TFS(&reserved_set),
-			  AVP_FLAGS_RESERVED7,	"", HFILL }},
+		  { "Reserved","diameter.avp.flags.reserved7", FT_BOOLEAN, 8, TFS(&tfs_set_notset),
+			  AVP_FLAGS_RESERVED7,	NULL, HFILL }},
 	{ &hf_diameter_avp_vendor_id,
 		  { "AVP Vendor Id","diameter.avp.vendorId", FT_UINT32, BASE_DEC,
-			  VALS(sminmpec_values), 0x0, "", HFILL }},
+			  VALS(sminmpec_values), 0x0, NULL, HFILL }},
 	{ &(unknown_avp.hf_value),
 		  { "Value","diameter.avp.unknown", FT_BYTES, BASE_NONE,
-			  NULL, 0x0, "", HFILL }},
+			  NULL, 0x0, NULL, HFILL }},
 	{ &hf_diameter_avp_data_wrong_length,
 		  { "Data","diameter.avp.invalid-data", FT_BYTES, BASE_NONE,
-		    NULL, 0x0, "", HFILL }},
+		    NULL, 0x0, NULL, HFILL }},
 	{ &hf_diameter_code,
-		  { "Command Code", "diameter.cmd.code", FT_UINT32, BASE_DEC, NULL, 0, "", HFILL }},
+		  { "Command Code", "diameter.cmd.code", FT_UINT32, BASE_DEC, NULL, 0, NULL, HFILL }},
 	{ &hf_diameter_avp_code,
-		  { "AVP Code", "diameter.avp.code", FT_UINT32, BASE_DEC, NULL, 0, "", HFILL }},
+		  { "AVP Code", "diameter.avp.code", FT_UINT32, BASE_DEC, NULL, 0, NULL, HFILL }},
 	{ &hf_diameter_answer_in,
-		{ "Answer In", "diameter.answer_in", FT_FRAMENUM, BASE_DEC, NULL, 0x0,
+		{ "Answer In", "diameter.answer_in", FT_FRAMENUM, BASE_NONE, NULL, 0x0,
 		"The answer to this diameter request is in this frame", HFILL }},
 	{ &hf_diameter_answer_to,
-		{ "Request In", "diameter.answer_to", FT_FRAMENUM, BASE_DEC, NULL, 0x0,
+		{ "Request In", "diameter.answer_to", FT_FRAMENUM, BASE_NONE, NULL, 0x0,
 		"This is an answer to the diameter request in this frame", HFILL }},
 	{ &hf_diameter_answer_time,
 		{ "Response Time", "diameter.resp_time", FT_RELATIVE_TIME, BASE_NONE, NULL, 0x0,
