@@ -3,7 +3,7 @@
  * to many dissectors.
  * Copyright 2006, Anders Broman <anders.broman@ericsson.com>
  *
- * $Id: packet-e212.c 29149 2009-07-21 06:02:12Z etxrab $
+ * $Id: packet-e212.c 29917 2009-09-15 05:39:33Z etxrab $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -489,7 +489,7 @@ const value_string mcc_mnc_codes[] = {
 	{  250044, "Stuvtelesot" },
 	{  250092, "Printelefone" },
 	{  250093, "Telecom XXI" },
-	{  250099, "Bec Line GSM" },
+	{  250099, "Beeline, OJSC VimpelCom" },
 	{  255001, "Ukrainian Mobile Communication, UMC" },
 	{  255002, "Ukranian Radio Systems, URS" },
 	{  255003, "Kyivstar GSM" },
