@@ -6,7 +6,7 @@
  * Routines for EIGRP dissection
  * Copyright 2000, Paul Ionescu <paul@acorp.ro>
  *
- * $Id: packet-eigrp.c 29473 2009-08-19 11:34:40Z etxrab $
+ * $Id: packet-eigrp.c 30703 2009-10-26 07:00:15Z jake $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -352,7 +352,7 @@ static void dissect_eigrp_ip6_ext(tvbuff_t *tvb, proto_tree *tree, proto_item *t
 
 static void dissect_eigrp(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree) {
 
-	proto_tree *eigrp_tree, *tlv_tree, *eigrp_flags_tree;
+	proto_tree *eigrp_tree = NULL, *tlv_tree, *eigrp_flags_tree;
 	proto_item *ti;
 
 	guint opcode, opcode_tmp;
@@ -378,7 +378,6 @@ static void dissect_eigrp(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree) {
 		proto_tree_add_item(eigrp_tree, hf_eigrp_version, tvb, 0, 1, FALSE);
 		proto_tree_add_item(eigrp_tree, hf_eigrp_opcode, tvb, 1, 1, FALSE);
 		proto_tree_add_item(eigrp_tree, hf_eigrp_checksum, tvb, 2, 2, FALSE);
-
 /* Decode the EIGRP Flags Field */
 
 		ti = proto_tree_add_item(eigrp_tree, hf_eigrp_flags, tvb, 4, 4, FALSE);
@@ -392,12 +391,14 @@ static void dissect_eigrp(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree) {
 		proto_tree_add_item(eigrp_tree, hf_eigrp_sequence, tvb, 8, 4, FALSE);
 		proto_tree_add_item(eigrp_tree, hf_eigrp_acknowledge, tvb, 12, 4, FALSE);
 		proto_tree_add_item(eigrp_tree, hf_eigrp_as, tvb, 16, 4, FALSE);
+	}
 
-		if (opcode == EIGRP_SAP) {
-			call_dissector(ipxsap_handle, tvb_new_subset(tvb, EIGRP_HEADER_LENGTH, -1, -1), pinfo, eigrp_tree);
-			return;
-		}
+	if (opcode == EIGRP_SAP) {
+		call_dissector(ipxsap_handle, tvb_new_subset(tvb, EIGRP_HEADER_LENGTH, -1, -1), pinfo, eigrp_tree);
+		return;
+	}
 
+	if (tree) {
 		while (tvb_reported_length_remaining(tvb, offset) > 0) {
 
 			tlv = tvb_get_ntohs(tvb, offset);
@@ -908,6 +909,11 @@ static void dissect_eigrp_ip6_int(tvbuff_t *tvb, proto_tree *tree, proto_item *t
 		} else {
 			proto_tree_add_item(tree, hf_eigrp_ip6_int_prefixlen, tvb, offset, 1, FALSE);
 			offset += 1;
+
+			if ((length < 128) && (length % 8 == 0)) {
+				addr_len++;
+			}
+
 			proto_tree_add_text(tree, tvb, offset, addr_len, "Destination: %s", ip6_to_str(&addr));
 			proto_item_append_text(ti, "  %c   %s/%u%s", offset == 33 ? '=':',',
 				ip6_to_str(&addr), length, ((tvb_get_ntohl(tvb, 16) == 0xffffffff) ? " - Destination unreachable":""));
@@ -970,13 +976,18 @@ static void dissect_eigrp_ip6_ext(tvbuff_t *tvb, proto_tree *tree, proto_item *t
 		addr_len = ipv6_addr_and_mask(tvb, offset + 1, &addr, length);
 
 		if (addr_len < 0) {
-			prefixlenti = proto_tree_add_item(tree, hf_eigrp_ip6_int_prefixlen, tvb, offset, 1, FALSE);
+			prefixlenti = proto_tree_add_item(tree, hf_eigrp_ip6_ext_prefixlen, tvb, offset, 1, FALSE);
 			proto_item_append_text(prefixlenti, " (invalid, must be <= 128)");
 			proto_item_append_text(ti, "  [Invalid prefix length %u > 128]", length);
 			addr_len = 16; /* assure we can exit the loop */
 		} else {
-			proto_tree_add_item(tree, hf_eigrp_ip6_int_prefixlen, tvb, offset, 1, FALSE);
+			proto_tree_add_item(tree, hf_eigrp_ip6_ext_prefixlen, tvb, offset, 1, FALSE);
 			offset += 1;
+
+			if ((length < 128) && (length % 8 == 0)) {
+				addr_len++;
+			}
+
 			proto_tree_add_text(tree, tvb, offset, addr_len, "Destination: %s", ip6_to_str(&addr));
 			proto_item_append_text(eigrp_ip6_ext_ti, "  %c   %s/%u%s", offset == 53 ? '=':',',
 				ip6_to_str(&addr), length, ((tvb_get_ntohl(tvb, 36) == 0xffffffff) ? " - Destination unreachable":""));
