@@ -1,7 +1,7 @@
 /* packet-eth.c
  * Routines for ethernet packet disassembly
  *
- * $Id: packet-eth.c 27257 2009-01-18 12:08:56Z jake $
+ * $Id: packet-eth.c 29329 2009-08-07 21:53:40Z gerald $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -39,6 +39,8 @@
 #include <epan/crc32.h>
 #include <epan/tap.h>
 
+/* Assume all packets have an FCS */
+static gboolean eth_assume_fcs = FALSE;
 /* Interpret packets as FW1 monitor file packets if they look as if they are */
 static gboolean eth_interpret_as_fw1_monitor = FALSE;
 /* Preference settings defining conditions for which the CCSDS dissector is called */
@@ -177,7 +179,7 @@ capture_eth(const guchar *pd, int offset, int len, packet_counts *ld)
   }
 }
 
-static gboolean check_is_802_2(tvbuff_t *tvb);
+static gboolean check_is_802_2(tvbuff_t *tvb, int fcs_len);
 
 static void
 dissect_eth_common(tvbuff_t *tvb, packet_info *pinfo, proto_tree *parent_tree,
@@ -202,8 +204,7 @@ dissect_eth_common(tvbuff_t *tvb, packet_info *pinfo, proto_tree *parent_tree,
 
   tree=parent_tree;
 
-  if (check_col(pinfo->cinfo, COL_PROTOCOL))
-    col_set_str(pinfo->cinfo, COL_PROTOCOL, "Ethernet");
+  col_set_str(pinfo->cinfo, COL_PROTOCOL, "Ethernet");
 
   src_addr=tvb_get_ptr(tvb, 6, 6);
   SET_ADDRESS(&pinfo->dl_src,	AT_ETHER, 6, src_addr);
@@ -261,12 +262,10 @@ dissect_eth_common(tvbuff_t *tvb, packet_info *pinfo, proto_tree *parent_tree,
    */
   if (ehdr->type <= IEEE_802_3_MAX_LEN && ehdr->type != ETHERTYPE_UNK) {
 
-    is_802_2 = check_is_802_2(tvb);
+    is_802_2 = check_is_802_2(tvb, fcs_len);
 
-    if (check_col(pinfo->cinfo, COL_INFO)) {
-      col_add_fstr(pinfo->cinfo, COL_INFO, "IEEE 802.3 Ethernet %s",
+     col_add_fstr(pinfo->cinfo, COL_INFO, "IEEE 802.3 Ethernet %s",
 		(is_802_2 ? "" : "Raw "));
-    }
     if (tree) {
       ti = proto_tree_add_protocol_format(tree, proto_eth, tvb, 0, ETH_HEADER_SIZE,
 		"IEEE 802.3 Ethernet %s", (is_802_2 ? "" : "Raw "));
@@ -310,8 +309,7 @@ dissect_eth_common(tvbuff_t *tvb, packet_info *pinfo, proto_tree *parent_tree,
 	}
     }
 
-    if (check_col(pinfo->cinfo, COL_INFO)) 
-      col_set_str(pinfo->cinfo, COL_INFO, "Ethernet II");
+    col_set_str(pinfo->cinfo, COL_INFO, "Ethernet II");
     if (parent_tree) {
       if (PTREE_DATA(parent_tree)->visible) {
           ti = proto_tree_add_protocol_format(parent_tree, proto_eth, tvb, 0, ETH_HEADER_SIZE,
@@ -346,9 +344,11 @@ dissect_eth_common(tvbuff_t *tvb, packet_info *pinfo, proto_tree *parent_tree,
 }
 
 /* -------------- */
-static gboolean check_is_802_2(tvbuff_t *tvb)
+static gboolean check_is_802_2(tvbuff_t *tvb, int fcs_len)
 {
   volatile gboolean	is_802_2;
+  volatile int length;
+  gint captured_length, reported_length;
   
   is_802_2 = TRUE;
 
@@ -373,25 +373,39 @@ static gboolean check_is_802_2(tvbuff_t *tvb)
 	  /* See if the reported payload size matches the
 	     size contained in the CCSDS header. */
 	  if (ccsds_heuristic_length) {
-	    /* Get payload length */
-	    gint size = tvb_reported_length(tvb) - 14;
-	    /* Check if payload is large enough to contain CCSDS header with
-	       packet length info. */
-	    if (size >= 6) {
-	      /* Get CCSDS packet length contained in CCSDS header. */
-	      gint size2 = 7 + tvb_get_ntohs(tvb, 14 + 4);
-	      if (size != size2)
+	    /* The following technique to account for FCS
+	       is copied from packet-ieee8023.c dissect_802_3() */
+	    length = tvb_get_ntohs(tvb, 12);
+	    reported_length = tvb_reported_length_remaining(tvb, ETH_HEADER_SIZE);
+	    if (fcs_len > 0) {
+		  if (reported_length >= fcs_len)
+		    reported_length -= fcs_len;
+		}
+		/* Make sure the length in the 802.3 header doesn't go past the end of
+		   the payload. */
+		if (length > reported_length) {
+		  length = reported_length;
+		}
+		/* Only allow inspection of 'length' number of bytes. */
+		captured_length = tvb_length_remaining(tvb, ETH_HEADER_SIZE);
+		if (captured_length > length)
+		  captured_length = length;
+		  
+	    /* Check if payload is large enough to contain a CCSDS header */
+	    if (captured_length >= 6) {
+	      /* Compare length to packet length contained in CCSDS header. */
+	      if (length != 7 + tvb_get_ntohs(tvb, ETH_HEADER_SIZE + 4))
 	        CCSDS_len = FALSE;
 	    }
 	  }
 	  /* Check if CCSDS Version number (first 3 bits of payload) is zero */
-	  if ((ccsds_heuristic_version) && (tvb_get_bits8(tvb, 8*14, 3)!=0))
+	  if ((ccsds_heuristic_version) && (tvb_get_bits8(tvb, 8*ETH_HEADER_SIZE, 3)!=0))
 	    CCSDS_ver = FALSE;
 	  /* Check if Secondary Header Flag (4th bit of payload) is set to one. */
-	  if ((ccsds_heuristic_header) && (tvb_get_bits8(tvb, 8*14 + 4, 1)!=1))
+	  if ((ccsds_heuristic_header) && (tvb_get_bits8(tvb, 8*ETH_HEADER_SIZE + 4, 1)!=1))
 	    CCSDS_head = FALSE;
 	  /* Check if spare bit (1st bit of 7th word of payload) is zero. */
-	  if ((ccsds_heuristic_bit) && (tvb_get_bits8(tvb, 8*14 + 16*6, 1)!=0))
+	  if ((ccsds_heuristic_bit) && (tvb_get_bits8(tvb, 8*ETH_HEADER_SIZE + 16*6, 1)!=0))
 	    CCSDS_bit = FALSE;
 	  /* If all the conditions are true, don't interpret payload as an 802.2 (LLC).
 	   * Additional check in packet-802.3.c will distinguish between
@@ -500,11 +514,13 @@ add_ethernet_trailer(packet_info *pinfo, proto_tree *fh_tree, int trailer_id,
 }
 
 /* Called for the Ethernet Wiretap encapsulation type; pass the FCS length
-   reported to us. */
+   reported to us, or, if the "assume_fcs" preference is set, pass 4. */
 static void
 dissect_eth_maybefcs(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 {
-  dissect_eth_common(tvb, pinfo, tree, pinfo->pseudo_header->eth.fcs_len);
+  dissect_eth_common(tvb, pinfo, tree,
+                     eth_assume_fcs ? 4 :
+                     pinfo->pseudo_header->eth.fcs_len);
 }
 
 /* Called by other dissectors  This one's for encapsulated Ethernet
@@ -537,12 +553,12 @@ proto_register_eth(void)
 
 		{ &hf_eth_len,
 		{ "Length",		"eth.len", FT_UINT16, BASE_DEC, NULL, 0x0,
-			"", HFILL }},
+			NULL, HFILL }},
 
 		/* registered here but handled in packet-ethertype.c */
 		{ &hf_eth_type,
 		{ "Type",		"eth.type", FT_UINT16, BASE_HEX, VALS(etype_vals), 0x0,
-			"", HFILL }},
+			NULL, HFILL }},
 		{ &hf_eth_addr,
 		{ "Address", "eth.addr", FT_ETHER, BASE_NONE, NULL, 0x0,
 			"Source or Destination Hardware Address", HFILL }},
@@ -579,6 +595,14 @@ proto_register_eth(void)
 
 	/* Register configuration preferences */
 	eth_module = prefs_register_protocol(proto_eth, NULL);
+
+	prefs_register_bool_preference(eth_module, "assume_fcs",
+	    "Assume packets have FCS",
+	    "Some Ethernet adapters and drivers include the FCS at the end of a packet, others do not.  "
+	    "The Ethernet dissector attempts to guess whether a captured packet has an FCS, "
+	    "but it cannot always guess correctly.",
+	    &eth_assume_fcs);
+
 	prefs_register_bool_preference(eth_module, "interpret_as_fw1_monitor",
             "Attempt to interpret as FireWall-1 monitor file",
             "Whether packets should be interpreted as coming from CheckPoint FireWall-1 monitor file if they look as if they do",
