@@ -2,7 +2,7 @@
  * Routines for FC distributed Name Server (dNS)
  * Copyright 2001, Dinesh G Dutt <ddutt@andiamo.com>
  *
- * $Id: packet-fcdns.c 23406 2007-11-08 22:49:03Z etxrab $
+ * $Id: packet-fcdns.c 28770 2009-06-18 21:30:42Z stig $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -1444,15 +1444,15 @@ static void
 dissect_fcdns_gezn (tvbuff_t *tvb, proto_tree *req_tree, gboolean isreq)
 {
     int offset = 16;            /* past the fc_ct header */
-    int strlen;
+    int str_len;
 
     if (isreq) {
         if (req_tree) {
-            strlen = tvb_get_guint8 (tvb, offset);
+            str_len = tvb_get_guint8 (tvb, offset);
             proto_tree_add_text (req_tree, tvb, offset, 1, "Name Length: %d",
-                                 strlen);
+                                 str_len);
             proto_tree_add_string (req_tree, hf_fcdns_zonenm, tvb, offset+3,
-                                   strlen, tvb_get_ptr (tvb, offset+3, strlen));
+                                   str_len, tvb_get_ptr (tvb, offset+3, str_len));
         }
     }
     else {
@@ -1801,196 +1801,196 @@ proto_register_fcdns (void)
     static hf_register_info hf[] = {
         { &hf_fcdns_gssubtype,
           {"GS_Subtype", "fcdns.gssubtype", FT_UINT8, BASE_HEX,
-           VALS (fc_dns_subtype_val), 0x0, "", HFILL}},
+           VALS (fc_dns_subtype_val), 0x0, NULL, HFILL}},
         {&hf_fcdns_opcode,
          {"Opcode", "fcdns.opcode", FT_UINT16, BASE_HEX, VALS (fc_dns_opcode_val),
-          0x0, "", HFILL}},
+          0x0, NULL, HFILL}},
         { &hf_fcdns_req_portid,
-          {"Port Identifier", "fcdns.req.portid", FT_STRING, BASE_HEX, NULL, 0x0,
-           "", HFILL}},
+          {"Port Identifier", "fcdns.req.portid", FT_STRING, BASE_NONE, NULL, 0x0,
+           NULL, HFILL}},
         { &hf_fcdns_rply_pname,
-          {"Port Name", "fcdns.rply.pname", FT_STRING, BASE_HEX, NULL, 0x0, "",
+          {"Port Name", "fcdns.rply.pname", FT_STRING, BASE_NONE, NULL, 0x0, NULL,
            HFILL}},
         { &hf_fcdns_rply_nname,
-          {"Node Name", "fcdns.rply.nname", FT_STRING, BASE_HEX, NULL, 0x0, "",
+          {"Node Name", "fcdns.rply.nname", FT_STRING, BASE_NONE, NULL, 0x0, NULL,
            HFILL}},
         { &hf_fcdns_rply_snamelen,
           {"Symbolic Node Name Length", "fcdns.rply.snamelen", FT_UINT8, BASE_DEC,
-           NULL, 0x0, "", HFILL}},
+           NULL, 0x0, NULL, HFILL}},
         { &hf_fcdns_rply_sname,
-          {"Symbolic Node Name", "fcdns.rply.sname", FT_STRING, BASE_HEX, NULL,
-           0x0, "", HFILL}},
+          {"Symbolic Node Name", "fcdns.rply.sname", FT_STRING, BASE_NONE, NULL,
+           0x0, NULL, HFILL}},
         { &hf_fcdns_rply_ptype,
           {"Port Type", "fcdns.rply.porttype", FT_UINT8, BASE_HEX,
-           VALS (fc_dns_port_type_val), 0x0, "", HFILL}},
+           VALS (fc_dns_port_type_val), 0x0, NULL, HFILL}},
         { &hf_fcdns_rply_fpname,
-          {"Fabric Port Name", "fcdns.rply.fpname", FT_STRING, BASE_HEX, NULL,
-           0x0, "", HFILL}},
+          {"Fabric Port Name", "fcdns.rply.fpname", FT_STRING, BASE_NONE, NULL,
+           0x0, NULL, HFILL}},
         { &hf_fcdns_req_pname,
-          {"Port Name", "fcdns.req.portname", FT_STRING, BASE_HEX, NULL, 0x0,
-           "", HFILL}},
+          {"Port Name", "fcdns.req.portname", FT_STRING, BASE_NONE, NULL, 0x0,
+           NULL, HFILL}},
         { &hf_fcdns_rply_portid,
-          {"Port Identifier", "fcdns.rply.portid", FT_STRING, BASE_HEX, NULL,
-           0x0, "", HFILL}},
+          {"Port Identifier", "fcdns.rply.portid", FT_STRING, BASE_NONE, NULL,
+           0x0, NULL, HFILL}},
         { &hf_fcdns_req_nname,
-          {"Node Name", "fcdns.req.nname", FT_STRING, BASE_HEX, NULL, 0x0,
-           "", HFILL}},
+          {"Node Name", "fcdns.req.nname", FT_STRING, BASE_NONE, NULL, 0x0,
+           NULL, HFILL}},
         { &hf_fcdns_req_domainscope,
           {"Domain ID Scope", "fcdns.req.domainid", FT_UINT8, BASE_HEX, NULL,
-           0x0, "", HFILL}},
+           0x0, NULL, HFILL}},
         { &hf_fcdns_req_areascope,
           {"Area ID Scope", "fcdns.req.areaid", FT_UINT8, BASE_HEX, NULL,
-           0x0, "", HFILL}},
+           0x0, NULL, HFILL}},
         { &hf_fcdns_req_fc4type,
           {"FC-4 Type", "fcdns.req.fc4type", FT_UINT8, BASE_HEX,
-           VALS (fc_fc4_val), 0x0, "", HFILL}},
+           VALS (fc_fc4_val), 0x0, NULL, HFILL}},
         { &hf_fcdns_req_ptype,
           {"Port Type", "fcdns.req.porttype", FT_UINT8, BASE_HEX,
-           VALS (fc_dns_port_type_val), 0x0, "", HFILL}},
+           VALS (fc_dns_port_type_val), 0x0, NULL, HFILL}},
         { &hf_fcdns_req_ip,
-          {"IP Address", "fcdns.req.ip", FT_IPv6, BASE_DEC, NULL, 0x0,
-           "", HFILL}},
+          {"IP Address", "fcdns.req.ip", FT_IPv6, BASE_NONE, NULL, 0x0,
+           NULL, HFILL}},
         { &hf_fcdns_rply_fc4type,
           {"FC-4 Descriptor Type", "fcdns.rply.fc4type", FT_UINT8, BASE_HEX,
-           VALS (fc_fc4_val), 0x0, "", HFILL}},
+           VALS (fc_fc4_val), 0x0, NULL, HFILL}},
         { &hf_fcdns_req_snamelen,
           {"Symbolic Name Length", "fcdns.req.snamelen", FT_UINT8, BASE_DEC,
-           NULL, 0x0, "", HFILL}},
+           NULL, 0x0, NULL, HFILL}},
         { &hf_fcdns_req_sname,
-          {"Symbolic Port Name", "fcdns.req.sname", FT_STRING, BASE_HEX, NULL,
-           0x0, "", HFILL}},
+          {"Symbolic Port Name", "fcdns.req.sname", FT_STRING, BASE_NONE, NULL,
+           0x0, NULL, HFILL}},
         { &hf_fcdns_rply_spnamelen,
           {"Symbolic Port Name Length", "fcdns.rply.spnamelen", FT_UINT8,
-           BASE_DEC, NULL, 0x0, "", HFILL}},
+           BASE_DEC, NULL, 0x0, NULL, HFILL}},
         {&hf_fcdns_rply_spname,
-         {"Symbolic Port Name", "fcdns.rply.spname", FT_STRING, BASE_HEX, NULL,
-          0x0, "", HFILL}},
+         {"Symbolic Port Name", "fcdns.rply.spname", FT_STRING, BASE_NONE, NULL,
+          0x0, NULL, HFILL}},
         { &hf_fcdns_rply_ipa,
-          {"Initial Process Associator", "fcdns.rply.ipa", FT_BYTES, BASE_HEX,
-           NULL, 0x0, "", HFILL}},
+          {"Initial Process Associator", "fcdns.rply.ipa", FT_BYTES, BASE_NONE,
+           NULL, 0x0, NULL, HFILL}},
         { &hf_fcdns_rply_ipnode,
-          {"Node IP Address", "fcdns.rply.ipnode", FT_IPv6, BASE_DEC, NULL,
-           0x0, "", HFILL}},
+          {"Node IP Address", "fcdns.rply.ipnode", FT_IPv6, BASE_NONE, NULL,
+           0x0, NULL, HFILL}},
         { &hf_fcdns_rply_ipport,
-          {"Port IP Address", "fcdns.rply.ipport", FT_IPv6, BASE_DEC, NULL,
-           0x0, "", HFILL}},
+          {"Port IP Address", "fcdns.rply.ipport", FT_IPv6, BASE_NONE, NULL,
+           0x0, NULL, HFILL}},
         { &hf_fcdns_rply_fc4desclen,
           {"FC-4 Descriptor Length", "fcdns.rply.fc4desclen", FT_UINT8,
-           BASE_DEC, NULL, 0x0, "", HFILL}},
+           BASE_DEC, NULL, 0x0, NULL, HFILL}},
         { &hf_fcdns_rply_fc4desc,
-          {"FC-4 Descriptor", "fcdns.rply.fc4desc", FT_BYTES, BASE_HEX, NULL,
-           0x0, "", HFILL}},
+          {"FC-4 Descriptor", "fcdns.rply.fc4desc", FT_BYTES, BASE_NONE, NULL,
+           0x0, NULL, HFILL}},
         { &hf_fcdns_rply_hrdaddr,
-          {"Hard Address", "fcdns.rply.hrdaddr", FT_STRING, BASE_HEX, NULL,
-           0x0, "", HFILL}},
+          {"Hard Address", "fcdns.rply.hrdaddr", FT_STRING, BASE_NONE, NULL,
+           0x0, NULL, HFILL}},
         { &hf_fcdns_req_fdesclen,
           {"FC-4 Descriptor Length", "fcdns.req.fc4desclen", FT_UINT8, BASE_DEC,
-           NULL, 0x0, "", HFILL}},
+           NULL, 0x0, NULL, HFILL}},
         { &hf_fcdns_req_fdesc,
-          {"FC-4 Descriptor", "fcdns.req.fc4desc", FT_STRING, BASE_HEX, NULL,
-           0x0, "", HFILL}},
+          {"FC-4 Descriptor", "fcdns.req.fc4desc", FT_STRING, BASE_NONE, NULL,
+           0x0, NULL, HFILL}},
         { &hf_fcdns_req_spnamelen,
           {"Symbolic Port Name Length", "fcdns.req.spnamelen", FT_UINT8,
-           BASE_DEC, NULL, 0x0, "", HFILL}},
+           BASE_DEC, NULL, 0x0, NULL, HFILL}},
         { &hf_fcdns_req_spname,
-          {"Symbolic Port Name", "fcdns.req.spname", FT_STRING, BASE_HEX, NULL,
-           0x0, "", HFILL}},
+          {"Symbolic Port Name", "fcdns.req.spname", FT_STRING, BASE_NONE, NULL,
+           0x0, NULL, HFILL}},
         { &hf_fcdns_reason,
           {"Reason Code", "fcdns.rply.reason", FT_UINT8, BASE_HEX,
-           VALS (fc_ct_rjt_code_vals), 0x0, "", HFILL}},
+           VALS (fc_ct_rjt_code_vals), 0x0, NULL, HFILL}},
         { &hf_fcdns_rjtdetail,
           {"Reason Code Explanantion", "fcdns.rply.reasondet", FT_UINT8,
-           BASE_HEX, VALS (fc_dns_rjt_det_code_val), 0x0, "", HFILL}},
+           BASE_HEX, VALS (fc_dns_rjt_det_code_val), 0x0, NULL, HFILL}},
         { &hf_fcdns_vendor,
           {"Vendor Unique Reject Code", "fcdns.rply.vendor", FT_UINT8,
-           BASE_HEX, NULL, 0x0, "", HFILL}},
+           BASE_HEX, NULL, 0x0, NULL, HFILL}},
         { &hf_fcdns_zone_mbrtype,
           {"Zone Member Type", "fcdns.zone.mbrtype", FT_UINT8, BASE_HEX,
-           VALS (fc_swils_zonembr_type_val), 0x0, "", HFILL}},
+           VALS (fc_swils_zonembr_type_val), 0x0, NULL, HFILL}},
         { &hf_fcdns_zone_mbrid,
-          {"Member Identifier", "fcdns.zone.mbrid", FT_STRING, BASE_HEX, NULL,
-           0x0, "", HFILL}},
+          {"Member Identifier", "fcdns.zone.mbrid", FT_STRING, BASE_NONE, NULL,
+           0x0, NULL, HFILL}},
         { &hf_fcdns_zonenm,
-          {"Zone Name", "fcdns.zonename", FT_STRING, BASE_HEX, NULL, 0x0, "",
+          {"Zone Name", "fcdns.zonename", FT_STRING, BASE_NONE, NULL, 0x0, NULL,
            HFILL}},
         { &hf_fcdns_portip,
-          {"Port IP Address", "fcdns.portip", FT_IPv4, BASE_DEC, NULL, 0x0,
-           "", HFILL}},
+          {"Port IP Address", "fcdns.portip", FT_IPv4, BASE_NONE, NULL, 0x0,
+           NULL, HFILL}},
         { &hf_fcdns_sw2_objfmt,
           {"Name Entry Object Format", "fcdns.entry.objfmt", FT_UINT8, BASE_HEX,
-           NULL, 0x0, "", HFILL}},
+           NULL, 0x0, NULL, HFILL}},
         { &hf_fcdns_num_fc4desc,
           {"Number of FC4 Descriptors Registered", "fcdns.entry.numfc4desc",
-           FT_UINT8, BASE_DEC, NULL, 0x0, "", HFILL}},
+           FT_UINT8, BASE_DEC, NULL, 0x0, NULL, HFILL}},
         { &hf_fcdns_rply_ownerid,
-          {"Owner Id", "fcdns.rply.ownerid", FT_STRING, BASE_HEX, NULL, 0x0, "",
+          {"Owner Id", "fcdns.rply.ownerid", FT_STRING, BASE_NONE, NULL, 0x0, NULL,
            HFILL}},
         { &hf_fcdns_maxres_size,
           {"Maximum/Residual Size", "fcdns.maxres_size", FT_UINT16, BASE_DEC,
-           NULL, 0x0, "", HFILL}},
+           NULL, 0x0, NULL, HFILL}},
         { &hf_fcdns_reply_cos,
           {"Class of Service Supported", "fcdns.reply.cos", FT_UINT32, BASE_HEX,
-           NULL, 0x0, "", HFILL}},
+           NULL, 0x0, NULL, HFILL}},
         { &hf_fcdns_req_cos,
           {"Requested Class of Service", "fcdns.req.class", FT_UINT32, BASE_HEX,
-           NULL, 0x0, "", HFILL}},
+           NULL, 0x0, NULL, HFILL}},
         { &hf_fcdns_cos_f,
           {"F", "fcdns.cos.f", FT_BOOLEAN, 32,
-           TFS(&tfs_fcdns_cos_f), 0x01, "", HFILL}},
+           TFS(&tfs_fcdns_cos_f), 0x01, NULL, HFILL}},
         { &hf_fcdns_cos_1,
           {"1", "fcdns.cos.1", FT_BOOLEAN, 32,
-           TFS(&tfs_fcdns_cos_1), 0x02, "", HFILL}},
+           TFS(&tfs_fcdns_cos_1), 0x02, NULL, HFILL}},
         { &hf_fcdns_cos_2,
           {"2", "fcdns.cos.2", FT_BOOLEAN, 32,
-           TFS(&tfs_fcdns_cos_2), 0x04, "", HFILL}},
+           TFS(&tfs_fcdns_cos_2), 0x04, NULL, HFILL}},
         { &hf_fcdns_cos_3,
           {"3", "fcdns.cos.3", FT_BOOLEAN, 32,
-           TFS(&tfs_fcdns_cos_3), 0x08, "", HFILL}},
+           TFS(&tfs_fcdns_cos_3), 0x08, NULL, HFILL}},
         { &hf_fcdns_cos_4,
           {"4", "fcdns.cos.4", FT_BOOLEAN, 32,
-           TFS(&tfs_fcdns_cos_4), 0x10, "", HFILL}},
+           TFS(&tfs_fcdns_cos_4), 0x10, NULL, HFILL}},
         { &hf_fcdns_cos_6,
           {"6", "fcdns.cos.6", FT_BOOLEAN, 32,
-           TFS(&tfs_fcdns_cos_6), 0x40, "", HFILL}},
+           TFS(&tfs_fcdns_cos_6), 0x40, NULL, HFILL}},
         { &hf_fcdns_fc4type_llcsnap,
           {"LLC/SNAP", "fcdns.fc4types.llc_snap", FT_BOOLEAN, 32,
-           TFS(&tfs_fcdns_fc4type_llcsnap), 0x0010, "", HFILL}},
+           TFS(&tfs_fcdns_fc4type_llcsnap), 0x0010, NULL, HFILL}},
         { &hf_fcdns_fc4type_ip,
           {"IP", "fcdns.fc4types.ip", FT_BOOLEAN, 32,
-           TFS(&tfs_fcdns_fc4type_ip), 0x0020, "", HFILL}},
+           TFS(&tfs_fcdns_fc4type_ip), 0x0020, NULL, HFILL}},
         { &hf_fcdns_fc4type_fcp,
           {"FCP", "fcdns.fc4types.fcp", FT_BOOLEAN, 32,
-           TFS(&tfs_fcdns_fc4type_fcp), 0x0100, "", HFILL}},
+           TFS(&tfs_fcdns_fc4type_fcp), 0x0100, NULL, HFILL}},
         { &hf_fcdns_fc4type_swils,
           {"SW_ILS", "fcdns.fc4types.swils", FT_BOOLEAN, 32,
-           TFS(&tfs_fcdns_fc4type_swils), 0x0010, "", HFILL}},
+           TFS(&tfs_fcdns_fc4type_swils), 0x0010, NULL, HFILL}},
         { &hf_fcdns_fc4type_snmp,
           {"SNMP", "fcdns.fc4types.snmp", FT_BOOLEAN, 32,
-           TFS(&tfs_fcdns_fc4type_snmp), 0x0004, "", HFILL}},
+           TFS(&tfs_fcdns_fc4type_snmp), 0x0004, NULL, HFILL}},
         { &hf_fcdns_fc4type_gs3,
           {"GS3", "fcdns.fc4types.gs3", FT_BOOLEAN, 32,
-           TFS(&tfs_fcdns_fc4type_gs3), 0x0001, "", HFILL}},
+           TFS(&tfs_fcdns_fc4type_gs3), 0x0001, NULL, HFILL}},
         { &hf_fcdns_fc4type_vi,
           {"VI", "fcdns.fc4types.vi", FT_BOOLEAN, 32,
-           TFS(&tfs_fcdns_fc4type_vi), 0x0001, "", HFILL}},
+           TFS(&tfs_fcdns_fc4type_vi), 0x0001, NULL, HFILL}},
         { &hf_fcdns_rply_gft,
-          {"FC-4 Types Supported", "fcdns.rply.fc4type", FT_NONE, BASE_HEX,
-           NULL, 0x0, "", HFILL}},
+          {"FC-4 Types Supported", "fcdns.rply.fc4type", FT_NONE, BASE_NONE,
+           NULL, 0x0, NULL, HFILL}},
         { &hf_fcdns_req_fc4types,
-          {"FC-4 Types Supported", "fcdns.req.fc4types", FT_NONE, BASE_HEX,
-           NULL, 0x0, "", HFILL}},
+          {"FC-4 Types Supported", "fcdns.req.fc4types", FT_NONE, BASE_NONE,
+           NULL, 0x0, NULL, HFILL}},
         { &hf_fcdns_fc4type,
-          {"FC-4 Types", "fcdns.req.fc4type", FT_NONE, BASE_HEX,
-           NULL, 0x0, "", HFILL}},
+          {"FC-4 Types", "fcdns.req.fc4type", FT_NONE, BASE_NONE,
+           NULL, 0x0, NULL, HFILL}},
         { &hf_fcdns_fc4features,
           {"FC-4 Feature Bits", "fcdns.fc4features", FT_UINT8,
-           BASE_HEX, NULL, 0x0, "", HFILL}},
+           BASE_HEX, NULL, 0x0, NULL, HFILL}},
         { &hf_fcdns_fc4features_i,
           {"I", "fcdns.fc4features.i", FT_BOOLEAN, 8,
-           TFS(&tfs_fcdns_fc4features_i), 0x02, "", HFILL}},
+           TFS(&tfs_fcdns_fc4features_i), 0x02, NULL, HFILL}},
         { &hf_fcdns_fc4features_t,
           {"T", "fcdns.fc4features.t", FT_BOOLEAN, 8,
-           TFS(&tfs_fcdns_fc4features_t), 0x01, "", HFILL}},
+           TFS(&tfs_fcdns_fc4features_t), 0x01, NULL, HFILL}},
     };
 
     static gint *ett[] = {
