@@ -3,7 +3,7 @@
  * Routines for FIP dissection - FCoE Initialization Protocol
  * Copyright (c) 2008 Cisco Systems, Inc. (jeykholt@cisco.com)
  *
- * $Id: packet-fip.c 30577 2009-10-16 21:26:51Z jake $
+ * $Id: packet-fip.c 30995 2009-11-17 18:35:27Z dimeg $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -250,7 +250,6 @@ dissect_fip(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
     guint op;
     guint sub;
     guint rlen;
-    guint flags;
     proto_item *ti;
     proto_item *item;
     proto_tree *fip_tree;
@@ -299,7 +298,6 @@ dissect_fip(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
         col_set_str(pinfo->cinfo, COL_INFO, info);
 
     rlen = tvb_get_ntohs(tvb, 6);
-    flags = tvb_get_ntohs(tvb, 8);
 
     ti = proto_tree_add_protocol_format(tree, proto_fip, tvb, 0,
                                         FIP_HEADER_LEN + rlen * FIP_BPW,
@@ -475,19 +473,19 @@ proto_register_fip(void)
             NULL, 0xf0, NULL, HFILL}},
         { &hf_fip_op,
           {"Opcode", "fip.opcode", FT_UINT16, BASE_HEX,
-           VALS(&fip_opcodes), 0, NULL, HFILL}},
+           VALS(fip_opcodes), 0, NULL, HFILL}},
         { &hf_fip_disc_subcode,
           {"Discovery Subcode", "fip.disc_subcode", FT_UINT8, BASE_HEX,
-           VALS(&fip_disc_subcodes), 0, NULL, HFILL}},
+           VALS(fip_disc_subcodes), 0, NULL, HFILL}},
         { &hf_fip_ls_subcode,
           {"Link Service Subcode", "fip.ls.subcode", FT_UINT8, BASE_HEX,
-           VALS(&fip_ls_subcodes), 0, NULL, HFILL}},
+           VALS(fip_ls_subcodes), 0, NULL, HFILL}},
         { &hf_fip_ctrl_subcode,
           {"Control Subcode", "fip.ctrl_subcode", FT_UINT8, BASE_HEX,
-           VALS(&fip_ctrl_subcodes), 0, NULL, HFILL}},
+           VALS(fip_ctrl_subcodes), 0, NULL, HFILL}},
         { &hf_fip_vlan_subcode,
           {"VLAN Subcode", "fip.vlan_subcode", FT_UINT8, BASE_HEX,
-           VALS(&fip_vlan_subcodes), 0, NULL, HFILL}},
+           VALS(fip_vlan_subcodes), 0, NULL, HFILL}},
         { &hf_fip_hex_subcode,
           {"Unknown Subcode", "fip.subcode", FT_UINT8, BASE_HEX,
            NULL, 0, NULL, HFILL}},
@@ -514,7 +512,7 @@ proto_register_fip(void)
             NULL, FIP_FL_FPORT, NULL, HFILL}},
         { &hf_fip_desc_type,
           {"Descriptor Type", "fip.desc_type", FT_UINT8, BASE_HEX,
-            VALS(&fip_desc_types), 0, NULL, HFILL}},
+            VALS(fip_desc_types), 0, NULL, HFILL}},
         { &hf_fip_desc_len,
           {"Descriptor Length (words)", "fip.desc_len", FT_UINT8, BASE_DEC,
             NULL, 0, NULL, HFILL}},
