@@ -5,7 +5,7 @@
  *
  * 3GPP TS 49.031 version v7.4.0 (2009-09)
  *
- * $Id: packet-gsm_bssmap_le.c 29320 2009-08-06 23:51:45Z wmeier $
+ * $Id: packet-gsm_bssmap_le.c 30125 2009-09-24 20:00:21Z krj $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -873,10 +873,7 @@ dissect_bssmap_le(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 		sccp_msg = NULL;
 	}
 
-	if (check_col(pinfo->cinfo, COL_INFO))
-	{
-		col_append_str(pinfo->cinfo, COL_INFO, "(BSSMAP LE) ");
-	}
+	col_append_str(pinfo->cinfo, COL_INFO, "(BSSMAP LE) ");
 
 	/*
 	 * set tap record pointer
@@ -1068,8 +1065,8 @@ proto_register_gsm_bssmap_le(void)
 	};
 	/* Setup protocol subtree array */
 #define	NUM_INDIVIDUAL_ELEMS	1
-	static gint *ett[NUM_INDIVIDUAL_ELEMS + NUM_GSM_BSSMAP_LE_MSG +
-			NUM_GSM_BSSMAP_LE_ELEM];
+	gint *ett[NUM_INDIVIDUAL_ELEMS + NUM_GSM_BSSMAP_LE_MSG +
+		  NUM_GSM_BSSMAP_LE_ELEM];
 
 	ett[0] = &ett_bssmap_le_msg;
 
