@@ -14,7 +14,7 @@
  * Header field support for TPDU Parameters added by
  * Abhik Sarkar.
  *
- * $Id: packet-gsm_sms.c 29499 2009-08-21 20:25:24Z krj $
+ * $Id: packet-gsm_sms.c 30536 2009-10-12 14:29:48Z stig $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -2617,8 +2617,7 @@ dis_field_ud(tvbuff_t *tvb, proto_tree *tree, guint32 offset, guint32 length, gb
 		if (reassembled) 
 		{ 
 			/* Reassembled */
-			if (check_col (g_pinfo->cinfo, COL_INFO))
-				col_append_str (g_pinfo->cinfo, COL_INFO,
+			col_append_str (g_pinfo->cinfo, COL_INFO,
 						" (Short Message Reassembled)");
 		} 
 		else 
@@ -2886,10 +2885,10 @@ dis_msg_deliver_report(tvbuff_t *tvb, proto_tree *tree, guint32 offset)
     guint8	oct;
     guint8	pi;
     guint8	udl;
-    gboolean	seven_bit;
-    gboolean	eight_bit;
-    gboolean	ucs2;
-    gboolean	compressed;
+    gboolean	seven_bit = FALSE;
+    gboolean	eight_bit = FALSE;
+    gboolean	ucs2 = FALSE;
+    gboolean	compressed = FALSE;
     gboolean	udhi;
 
 
@@ -3074,10 +3073,10 @@ dis_msg_submit_report(tvbuff_t *tvb, proto_tree *tree, guint32 offset)
     guint8	oct;
     guint8	pi;
     guint8	udl;
-    gboolean	seven_bit;
-    gboolean	eight_bit;
-    gboolean	ucs2;
-    gboolean	compressed;
+    gboolean	seven_bit = FALSE;
+    gboolean	eight_bit = FALSE;
+    gboolean	ucs2 = FALSE;
+    gboolean	compressed = FALSE;
     gboolean	udhi;
 
 
@@ -3184,10 +3183,10 @@ dis_msg_status_report(tvbuff_t *tvb, proto_tree *tree, guint32 offset)
     guint8	oct;
     guint8	pi;
     guint8	udl;
-    gboolean	seven_bit;
-    gboolean	eight_bit;
-    gboolean	ucs2;
-    gboolean	compressed;
+    gboolean	seven_bit = FALSE;
+    gboolean	eight_bit = FALSE;
+    gboolean	ucs2 = FALSE;
+    gboolean	compressed = FALSE;
     gboolean	udhi; 
 
 
@@ -3660,7 +3659,7 @@ proto_register_gsm_sms(void)
 
     /* Setup protocol subtree array */
 #define	NUM_INDIVIDUAL_PARMS	12
-    static gint *ett[NUM_INDIVIDUAL_PARMS+NUM_MSGS+NUM_UDH_IEIS+2];
+    gint *ett[NUM_INDIVIDUAL_PARMS+NUM_MSGS+NUM_UDH_IEIS+2];
 
     ett[0] = &ett_gsm_sms;
     ett[1] = &ett_pid;
