@@ -4,7 +4,7 @@
  * Copyright 2002, Richard Sharpe <rsharpe@samba.org> Added a few 
  *		   bits and pieces ...
  *
- * $Id: packet-gssapi.c 26822 2008-11-22 15:55:01Z stig $
+ * $Id: packet-gssapi.c 31029 2009-11-19 22:41:01Z gerald $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -41,13 +41,13 @@
 #include <epan/dissectors/packet-dcerpc.h>
 #include <epan/dissectors/packet-gssapi.h>
 #include <epan/dissectors/packet-frame.h>
-#include "epan/conversation.h"
-#include "epan/emem.h"
-#include "epan/prefs.h"
-#include "epan/reassemble.h"
+#include <epan/conversation.h>
+#include <epan/emem.h>
+#include <epan/prefs.h>
+#include <epan/reassemble.h>
 #include <epan/asn1.h>
 #include "packet-ber.h"
-#include "to_str.h"
+#include <epan/to_str.h>
 
 static int proto_gssapi = -1;
 
@@ -112,6 +112,9 @@ gssapi_reassembly_init(void)
  */
 
 static dissector_handle_t ntlmssp_handle;
+static dissector_handle_t ntlmssp_payload_handle;
+static dissector_handle_t ntlmssp_verf_handle;
+static dissector_handle_t ntlmssp_data_only_handle;
 static dissector_handle_t spnego_krb5_wrap_handle;
 
 static GHashTable *gssapi_oids;
@@ -272,8 +275,7 @@ dissect_gssapi_work(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree,
 			gss_info->do_reassembly=FALSE;
 			fi->reassembled_in=pinfo->fd->num;
 
-			gss_tvb=tvb_new_real_data(fd_head->data, fd_head->datalen, fd_head->datalen);
-			tvb_set_child_real_data_tvbuff(tvb, gss_tvb);
+			gss_tvb=tvb_new_child_real_data(tvb, fd_head->data, fd_head->datalen, fd_head->datalen);
 			add_new_data_source(pinfo, gss_tvb, "Reassembled GSSAPI");
 		}
 		/* We have seen this packet before.
@@ -287,8 +289,7 @@ dissect_gssapi_work(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree,
 				if(fd_head && (fd_head->flags&FD_DEFRAGMENTED)){
 					if(pinfo->fd->num==fi->reassembled_in){
 					        proto_item *frag_tree_item;
-						gss_tvb=tvb_new_real_data(fd_head->data, fd_head->datalen, fd_head->datalen);
-						tvb_set_child_real_data_tvbuff(tvb, gss_tvb);
+						gss_tvb=tvb_new_child_real_data(tvb, fd_head->data, fd_head->datalen, fd_head->datalen);
 						add_new_data_source(pinfo, gss_tvb, "Reassembled GSSAPI");
 						show_fragment_tree(fd_head, &gssapi_frag_items, tree, pinfo, tvb, &frag_tree_item);
 					} else {
@@ -309,19 +310,43 @@ dissect_gssapi_work(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree,
 		if (!(class == BER_CLASS_APP && pc && tag == 0)) {
 		  /* It could be NTLMSSP, with no OID.  This can happen 
 		     for anything that microsoft calls 'Negotiate' or GSS-SPNEGO */
-		  if ((tvb_length_remaining(gss_tvb, start_offset)>7) && (tvb_strneql(gss_tvb, start_offset, "NTLMSSP", 7) == 0)) {
-		    return_offset = call_dissector(ntlmssp_handle,
-						   tvb_new_subset(gss_tvb, start_offset, -1, -1),
-						   pinfo, subtree);
-		    goto done;
-		  }
+			if ((tvb_length_remaining(gss_tvb, start_offset)>7) && (tvb_strneql(gss_tvb, start_offset, "NTLMSSP", 7) == 0)) {
+				return_offset = call_dissector(ntlmssp_handle,
+							tvb_new_subset_remaining(gss_tvb, start_offset),
+							pinfo, subtree);
+				goto done;
+			}
+			/* Maybe it's new NTLMSSP payload */
+			if ((tvb_length_remaining(gss_tvb, start_offset)>16) &&
+			   ((tvb_memeql(gss_tvb, start_offset, "\x01\x00\x00\x00", 4) == 0))) {
+				return_offset = call_dissector(ntlmssp_payload_handle,
+							tvb_new_subset(gss_tvb, start_offset, -1, -1),
+							pinfo, subtree);
+				pinfo->gssapi_data_encrypted = TRUE;
+				goto done;
+			}
+			if ((tvb_length_remaining(gss_tvb, start_offset)==16) &&
+			   ((tvb_memeql(gss_tvb, start_offset, "\x01\x00\x00\x00", 4) == 0))) {
+				if( is_verifier ) {
+					return_offset = call_dissector(ntlmssp_verf_handle, 
+									tvb_new_subset(gss_tvb, start_offset, -1, -1), 
+									pinfo, subtree);
+				}
+				else if( pinfo->gssapi_encrypted_tvb ) {
+					return_offset = call_dissector(ntlmssp_data_only_handle,
+									tvb_new_subset(pinfo->gssapi_encrypted_tvb, 0, -1, -1),
+									pinfo, subtree);
+					pinfo->gssapi_data_encrypted = TRUE;
+				}
+		   		goto done;
+		  	}
 
 		  /* Maybe it's new GSSKRB5 CFX Wrapping */
 		  if ((tvb_length_remaining(gss_tvb, start_offset)>2) &&
 		      ((tvb_memeql(gss_tvb, start_offset, "\04\x04", 2) == 0) ||
 		       (tvb_memeql(gss_tvb, start_offset, "\05\x04", 2) == 0))) {
 		    return_offset = call_dissector(spnego_krb5_wrap_handle,
-						   tvb_new_subset(gss_tvb, start_offset, -1, -1),
+						   tvb_new_subset_remaining(gss_tvb, start_offset),
 						   pinfo, subtree);
 		    goto done;
 		  }
@@ -364,7 +389,7 @@ dissect_gssapi_work(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree,
 		  } else {
 		    tvbuff_t *oid_tvb_local;
 
-		    oid_tvb_local = tvb_new_subset(gss_tvb, start_offset, -1, -1);
+		    oid_tvb_local = tvb_new_subset_remaining(gss_tvb, start_offset);
 		    if (is_verifier)
 			handle = oidvalue->wrap_handle;
 		    else
@@ -446,7 +471,7 @@ dissect_gssapi_work(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree,
 		if (is_verifier) {
 			handle = oidvalue->wrap_handle;
 			if (handle != NULL) {
-				oid_tvb = tvb_new_subset(gss_tvb, offset, -1, -1);
+				oid_tvb = tvb_new_subset_remaining(gss_tvb, offset);
 				len = call_dissector(handle, oid_tvb, pinfo,
 				    subtree);
 				if (len == 0)
@@ -461,7 +486,7 @@ dissect_gssapi_work(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree,
 		} else {
 			handle = oidvalue->handle;
 			if (handle != NULL) {
-				oid_tvb = tvb_new_subset(gss_tvb, offset, -1, -1);
+				oid_tvb = tvb_new_subset_remaining(gss_tvb, offset);
 				len = call_dissector(handle, oid_tvb, pinfo,
 				    subtree);
 				if (len == 0)
@@ -508,10 +533,10 @@ proto_register_gssapi(void)
 		  NULL, 0, "This is a GSS-API Object Identifier", HFILL }},
 	{ &hf_gssapi_segment,
 		{ "GSSAPI Segment", "gss-api.segment", FT_FRAMENUM, BASE_NONE, 
-		  NULL, 0x0, "GSSAPI Segment", HFILL }},
+		  NULL, 0x0, NULL, HFILL }},
 	{ &hf_gssapi_segments,
 		{ "GSSAPI Segments", "gss-api.segment.segments", FT_NONE, BASE_NONE, 
-		  NULL, 0x0, "GSSAPI Segments", HFILL }},
+		  NULL, 0x0, NULL, HFILL }},
 	{ &hf_gssapi_segment_overlap,
 		{ "Fragment overlap",	"gss-api.segment.overlap", FT_BOOLEAN, BASE_NONE, 
 		   NULL, 0x0, "Fragment overlaps with other fragments", HFILL }},
@@ -528,7 +553,7 @@ proto_register_gssapi(void)
 		{ "Defragmentation error", "gss-api.segment.error", FT_FRAMENUM, BASE_NONE, 
 		  NULL, 0x0, "Defragmentation error due to illegal fragments", HFILL }},
 	{ &hf_gssapi_reassembled_in,
-		{ "Reassembled In", "gss-api.reassembled_in", FT_FRAMENUM, BASE_DEC, 
+		{ "Reassembled In", "gss-api.reassembled_in", FT_FRAMENUM, BASE_NONE, 
 		  NULL, 0x0, "The frame where this pdu is reassembled", HFILL }},
 
 	};
@@ -565,7 +590,7 @@ static int wrap_dissect_gssapi(tvbuff_t *tvb, int offset,
 {
 	tvbuff_t *auth_tvb;
 
-	auth_tvb = tvb_new_subset(tvb, offset, -1, -1);
+	auth_tvb = tvb_new_subset_remaining(tvb, offset);
 
 	dissect_gssapi(auth_tvb, pinfo, tree);
 
@@ -578,7 +603,7 @@ int wrap_dissect_gssapi_verf(tvbuff_t *tvb, int offset,
 {
 	tvbuff_t *auth_tvb;
 
-	auth_tvb = tvb_new_subset(tvb, offset, -1, -1);
+	auth_tvb = tvb_new_subset_remaining(tvb, offset);
 
 	return dissect_gssapi_verf(auth_tvb, pinfo, tree);
 }
@@ -603,7 +628,7 @@ wrap_dissect_gssapi_payload(tvbuff_t *data_tvb,
 	pinfo->gssapi_wrap_tvb=NULL;
 	pinfo->gssapi_encrypted_tvb=data_tvb;
 	pinfo->gssapi_decrypted_tvb=NULL;
-	dissect_gssapi_verf(auth_tvb, pinfo, NULL);
+	dissect_gssapi(auth_tvb, pinfo, NULL);
 	result=pinfo->gssapi_decrypted_tvb;
 
 	pinfo->decrypt_gssapi_tvb=0;
@@ -630,6 +655,9 @@ proto_reg_handoff_gssapi(void)
 	dissector_handle_t gssapi_handle;
 
 	ntlmssp_handle = find_dissector("ntlmssp");
+	ntlmssp_payload_handle = find_dissector("ntlmssp_payload");
+	ntlmssp_verf_handle = find_dissector("ntlmssp_verf");
+	ntlmssp_data_only_handle = find_dissector("ntlmssp_data_only");
 	spnego_krb5_wrap_handle = find_dissector("spnego-krb5-wrap");
 
 	register_dcerpc_auth_subdissector(DCE_C_AUTHN_LEVEL_CONNECT,
