@@ -2,7 +2,7 @@
  * Routines for Sinec H1 packet disassembly
  * Gerrit Gehnen <G.Gehnen@atrie.de>
  *
- * $Id: packet-h1.c 23252 2007-10-23 05:50:00Z etxrab $
+ * $Id: packet-h1.c 29342 2009-08-09 07:01:26Z krj $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -122,10 +122,8 @@ static gboolean dissect_h1(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
       return FALSE;
     }
 
-  if (check_col (pinfo->cinfo, COL_PROTOCOL))
-    col_set_str (pinfo->cinfo, COL_PROTOCOL, "H1");
-  if (check_col (pinfo->cinfo, COL_INFO))
-    col_set_str (pinfo->cinfo, COL_INFO, "S5: ");
+  col_set_str (pinfo->cinfo, COL_PROTOCOL, "H1");
+  col_set_str(pinfo->cinfo, COL_INFO, "S5: ");
   if (tree)
     {
       ti = proto_tree_add_item (tree, proto_h1, tvb, offset, 16, FALSE);
@@ -217,7 +215,7 @@ static gboolean dissect_h1(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 	      {
 		col_append_fstr (pinfo->cinfo, COL_INFO, " %s",
 				 val_to_str (tvb_get_guint8(tvb,offset + position + 2),
-					     returncode_vals,"Unknown Returcode (0x%2.2x"));
+					     returncode_vals,"Unknown Returncode (0x%2.2x"));
 	      }
 	    break;
 	  case EMPTY_BLOCK:
@@ -238,7 +236,6 @@ static gboolean dissect_h1(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 	    /* This is not a valid telegram. So cancel dissection
                and try the next dissector */
             return FALSE;
-	    break;
 	}
 	if (tvb_get_guint8(tvb,offset + position + 1) < 1)
 	    THROW(ReportedBoundsError);
@@ -257,48 +254,48 @@ proto_register_h1 (void)
   static hf_register_info hf[] = {
     {&hf_h1_header,
      {"H1-Header", "h1.header", FT_UINT16, BASE_HEX, NULL, 0x0,
-      "", HFILL }},
+      NULL, HFILL }},
     {&hf_h1_len,
      {"Length indicator", "h1.len", FT_UINT16, BASE_DEC, NULL, 0x0,
-      "", HFILL }},
+      NULL, HFILL }},
     {&hf_h1_opfield,
      {"Operation identifier", "h1.opfield", FT_UINT8, BASE_HEX, NULL, 0x0,
-      "", HFILL }},
+      NULL, HFILL }},
     {&hf_h1_oplen,
-     {"Operation length", "h1.oplen", FT_UINT8, BASE_HEX, NULL, 0x0, "", HFILL }},
+     {"Operation length", "h1.oplen", FT_UINT8, BASE_HEX, NULL, 0x0, NULL, HFILL }},
     {&hf_h1_opcode,
      {"Opcode", "h1.opcode", FT_UINT8, BASE_HEX, VALS (opcode_vals), 0x0,
-      "", HFILL }},
+      NULL, HFILL }},
     {&hf_h1_requestblock,
      {"Request identifier", "h1.request", FT_UINT8, BASE_HEX, NULL, 0x0,
-      "", HFILL }},
+      NULL, HFILL }},
     {&hf_h1_requestlen,
      {"Request length", "h1.reqlen", FT_UINT8, BASE_HEX, NULL, 0x0,
-      "", HFILL }},
+      NULL, HFILL }},
     {&hf_h1_org,
      {"Memory type", "h1.org", FT_UINT8, BASE_HEX, VALS (org_vals), 0x0,
-      "", HFILL }},
+      NULL, HFILL }},
     {&hf_h1_dbnr,
-     {"Memory block number", "h1.dbnr", FT_UINT8, BASE_DEC, NULL, 0x0, "", HFILL }},
+     {"Memory block number", "h1.dbnr", FT_UINT8, BASE_DEC, NULL, 0x0, NULL, HFILL }},
     {&hf_h1_dwnr,
      {"Address within memory block", "h1.dwnr", FT_UINT16, BASE_DEC, NULL, 0x0,
-      "", HFILL }},
+      NULL, HFILL }},
     {&hf_h1_dlen,
-     {"Length in words", "h1.dlen", FT_INT16, BASE_DEC, NULL, 0x0, "", HFILL }},
+     {"Length in words", "h1.dlen", FT_INT16, BASE_DEC, NULL, 0x0, NULL, HFILL }},
     {&hf_h1_response,
-     {"Response identifier", "h1.response", FT_UINT8, BASE_HEX, NULL, 0x0, "", HFILL }},
+     {"Response identifier", "h1.response", FT_UINT8, BASE_HEX, NULL, 0x0, NULL, HFILL }},
     {&hf_h1_response_len,
      {"Response length", "h1.reslen", FT_UINT8, BASE_DEC, NULL, 0x0,
-      "", HFILL }},
+      NULL, HFILL }},
     {&hf_h1_response_value,
      {"Response value", "h1.resvalue", FT_UINT8, BASE_DEC,
-      VALS (returncode_vals), 0x0, "", HFILL }},
+      VALS (returncode_vals), 0x0, NULL, HFILL }},
     {&hf_h1_empty,
      {"Empty field", "h1.empty", FT_UINT8, BASE_HEX, NULL, 0x0,
-      "", HFILL }},
+      NULL, HFILL }},
     {&hf_h1_empty_len,
      {"Empty field length", "h1.empty_len", FT_UINT8, BASE_DEC, NULL, 0x0,
-      "", HFILL }}
+      NULL, HFILL }}
   };
 
   static gint *ett[] = {
