@@ -4,7 +4,7 @@
  * Copyright 2006, Sebastien Tandel <sebastien[AT]tandel.be>
  * Copyright 2009, Luca Ceresoli <luca[AT]lucaceresoli.net>
  *
- * $Id: packet-homeplug.c 29755 2009-09-07 01:19:26Z stig $
+ * $Id: packet-homeplug.c 30124 2009-09-24 19:50:43Z krj $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -727,10 +727,7 @@ static void dissect_homeplug_loader(ptvcursor_t * cursor, packet_info * pinfo)
 
 	switch(mid) {
 	case HOMEPLUG_MID_LGDFV:
-		if (check_col(pinfo->cinfo, COL_INFO)) {
-			col_clear(pinfo->cinfo, COL_INFO);
-			col_set_str(pinfo->cinfo, COL_INFO, "Loader Get Firmware Version");
-		}
+		col_set_str(pinfo->cinfo, COL_INFO, "Loader Get Firmware Version");
 		ptvcursor_add(cursor, hf_homeplug_loader_gdfv, 1, FALSE);
 		ptvcursor_add(cursor, hf_homeplug_loader_length, 2, FALSE);
 		if (length != 0) {
@@ -739,18 +736,12 @@ static void dissect_homeplug_loader(ptvcursor_t * cursor, packet_info * pinfo)
 		}
 		break;
 	case HOMEPLUG_MID_LSF:
-		if (check_col(pinfo->cinfo, COL_INFO)) {
-			col_clear(pinfo->cinfo, COL_INFO);
-			col_set_str(pinfo->cinfo, COL_INFO, "Loader Start Firmware");
-		}
+		col_set_str(pinfo->cinfo, COL_INFO, "Loader Start Firmware");
 		ptvcursor_add(cursor, hf_homeplug_loader_lsf, 1, FALSE);
 		ptvcursor_add(cursor, hf_homeplug_loader_length, 2, FALSE);
 		break;
 	case HOMEPLUG_MID_LWM:
-		if (check_col(pinfo->cinfo, COL_INFO)) {
-			col_clear(pinfo->cinfo, COL_INFO);
-			col_set_str(pinfo->cinfo, COL_INFO, "Loader Write Memory");
-		}
+		col_set_str(pinfo->cinfo, COL_INFO, "Loader Write Memory");
 		ptvcursor_add(cursor, hf_homeplug_loader_lwm, 1, FALSE);
 		ptvcursor_add(cursor, hf_homeplug_loader_length, 2, FALSE);
 		if (length == 7)
@@ -764,10 +755,7 @@ static void dissect_homeplug_loader(ptvcursor_t * cursor, packet_info * pinfo)
 			ptvcursor_add(cursor, hf_homeplug_loader_data, dlen, FALSE);
 		break;
 	case HOMEPLUG_MID_LRM:
-		if (check_col(pinfo->cinfo, COL_INFO)) {
-			col_clear(pinfo->cinfo, COL_INFO);
-			col_set_str(pinfo->cinfo, COL_INFO, "Loader Read Memory");
-		}
+		col_set_str(pinfo->cinfo, COL_INFO, "Loader Read Memory");
 		ptvcursor_add(cursor, hf_homeplug_loader_lrm, 1, FALSE);
 		ptvcursor_add(cursor, hf_homeplug_loader_length, 2, FALSE);
 		if (length != 6)
@@ -780,10 +768,7 @@ static void dissect_homeplug_loader(ptvcursor_t * cursor, packet_info * pinfo)
 			ptvcursor_add(cursor, hf_homeplug_loader_data, dlen, FALSE);
 		break;
 	case HOMEPLUG_MID_LRNVM:
-		if (check_col(pinfo->cinfo, COL_INFO)) {
-			col_clear(pinfo->cinfo, COL_INFO);
-			col_set_str(pinfo->cinfo, COL_INFO, "Loader Read NVM");
-		}
+		col_set_str(pinfo->cinfo, COL_INFO, "Loader Read NVM");
 		ptvcursor_add(cursor, hf_homeplug_loader_lrnvm, 1, FALSE);
 		ptvcursor_add(cursor, hf_homeplug_loader_length, 2, FALSE);
 		if (length != 7)
@@ -796,10 +781,7 @@ static void dissect_homeplug_loader(ptvcursor_t * cursor, packet_info * pinfo)
 			ptvcursor_add(cursor, hf_homeplug_loader_data, dlen, FALSE);
 		break;
 	case HOMEPLUG_MID_LWNVM:
-		if (check_col(pinfo->cinfo, COL_INFO)) {
-			col_clear(pinfo->cinfo, COL_INFO);
-			col_set_str(pinfo->cinfo, COL_INFO, "Loader Write NVM");
-		}
+		col_set_str(pinfo->cinfo, COL_INFO, "Loader Write NVM");
 		ptvcursor_add(cursor, hf_homeplug_loader_lwnvm, 1, FALSE);
 		ptvcursor_add(cursor, hf_homeplug_loader_length, 2, FALSE);
 		if (length == 7)
@@ -812,18 +794,12 @@ static void dissect_homeplug_loader(ptvcursor_t * cursor, packet_info * pinfo)
 			ptvcursor_add(cursor, hf_homeplug_loader_data, dlen, FALSE);
 		break;
 	case HOMEPLUG_MID_LRESET:
-		if (check_col(pinfo->cinfo, COL_INFO)) {
-			col_clear(pinfo->cinfo, COL_INFO);
-			col_set_str(pinfo->cinfo, COL_INFO, "Loader Reset");
-		}
+		col_set_str(pinfo->cinfo, COL_INFO, "Loader Reset");
 		ptvcursor_add(cursor, hf_homeplug_loader_lreset, 1, FALSE);
 		ptvcursor_add(cursor, hf_homeplug_loader_length, 2, FALSE);
 		break;
 	case HOMEPLUG_MID_GMD:
-		if (check_col(pinfo->cinfo, COL_INFO)) {
-			col_clear(pinfo->cinfo, COL_INFO);
-			col_set_str(pinfo->cinfo, COL_INFO, "Loader Get Module Data");
-		}
+		col_set_str(pinfo->cinfo, COL_INFO, "Loader Get Module Data");
 		ptvcursor_add(cursor, hf_homeplug_loader_gmd, 1, FALSE);
 		ptvcursor_add(cursor, hf_homeplug_loader_length, 2, FALSE);
 		if (length != 10)
@@ -838,10 +814,7 @@ static void dissect_homeplug_loader(ptvcursor_t * cursor, packet_info * pinfo)
 		}
 		break;
 	case HOMEPLUG_MID_SMD:
-		if (check_col(pinfo->cinfo, COL_INFO)) {
-			col_clear(pinfo->cinfo, COL_INFO);
-			col_set_str(pinfo->cinfo, COL_INFO, "Loader Set Module Data");
-		}
+		col_set_str(pinfo->cinfo, COL_INFO, "Loader Set Module Data");
 		ptvcursor_add(cursor, hf_homeplug_loader_smd, 1, FALSE);
 		ptvcursor_add(cursor, hf_homeplug_loader_length, 2, FALSE);
 		if (length == 13)
@@ -857,10 +830,7 @@ static void dissect_homeplug_loader(ptvcursor_t * cursor, packet_info * pinfo)
 			ptvcursor_add(cursor, hf_homeplug_loader_module_size, 4, FALSE);
 		break;
 	case HOMEPLUG_MID_CM:
-		if (check_col(pinfo->cinfo, COL_INFO)) {
-			col_clear(pinfo->cinfo, COL_INFO);
-			col_set_str(pinfo->cinfo, COL_INFO, "Loader Commit Module");
-		}
+		col_set_str(pinfo->cinfo, COL_INFO, "Loader Commit Module");
 		ptvcursor_add(cursor, hf_homeplug_loader_cm, 1, FALSE);
 		ptvcursor_add(cursor, hf_homeplug_loader_length, 2, FALSE);
 		if (length == 5)
@@ -868,10 +838,7 @@ static void dissect_homeplug_loader(ptvcursor_t * cursor, packet_info * pinfo)
 		ptvcursor_add(cursor, hf_homeplug_loader_module_id, 4, FALSE);
 		break;
 	case HOMEPLUG_MID_LEMD:
-		if (check_col(pinfo->cinfo, COL_INFO)) {
-			col_clear(pinfo->cinfo, COL_INFO);
-			col_set_str(pinfo->cinfo, COL_INFO, "Loader Erase Module Data");
-		}
+		col_set_str(pinfo->cinfo, COL_INFO, "Loader Erase Module Data");
 		ptvcursor_add(cursor, hf_homeplug_loader_lemd, 1, FALSE);
 		ptvcursor_add(cursor, hf_homeplug_loader_length, 2, FALSE);
 		if (length == 9)
@@ -879,10 +846,7 @@ static void dissect_homeplug_loader(ptvcursor_t * cursor, packet_info * pinfo)
 		ptvcursor_add(cursor, hf_homeplug_loader_module_id, 4, FALSE);
 		break;
 	case HOMEPLUG_MID_LENVMS:
-		if (check_col(pinfo->cinfo, COL_INFO)) {
-			col_clear(pinfo->cinfo, COL_INFO);
-			col_set_str(pinfo->cinfo, COL_INFO, "Loader Erase NVM Sectors");
-		}
+		col_set_str(pinfo->cinfo, COL_INFO, "Loader Erase NVM Sectors");
 		ptvcursor_add(cursor, hf_homeplug_loader_lenvms, 1, FALSE);
 		ptvcursor_add(cursor, hf_homeplug_loader_length, 2, FALSE);
 		if (length == 9)
@@ -891,10 +855,7 @@ static void dissect_homeplug_loader(ptvcursor_t * cursor, packet_info * pinfo)
 		ptvcursor_add(cursor, hf_homeplug_loader_module_size, 4, FALSE);
 		break;
 	case HOMEPLUG_MID_GNVMP:
-		if (check_col(pinfo->cinfo, COL_INFO)) {
-			col_clear(pinfo->cinfo, COL_INFO);
-			col_set_str(pinfo->cinfo, COL_INFO, "Loader Get NVM Parametes");
-		}
+		col_set_str(pinfo->cinfo, COL_INFO, "Loader Get NVM Parametes");
 		ptvcursor_add(cursor, hf_homeplug_loader_gnvmp, 1, FALSE);
 		ptvcursor_add(cursor, hf_homeplug_loader_length, 2, FALSE);
 		if (length == 17) {
@@ -906,10 +867,7 @@ static void dissect_homeplug_loader(ptvcursor_t * cursor, packet_info * pinfo)
 		}
 		break;
 	case HOMEPLUG_MID_SNVMP:
-		if (check_col(pinfo->cinfo, COL_INFO)) {
-			col_clear(pinfo->cinfo, COL_INFO);
-			col_set_str(pinfo->cinfo, COL_INFO, "Loader Set NVM Parametes");
-		}
+		col_set_str(pinfo->cinfo, COL_INFO, "Loader Set NVM Parametes");
 		ptvcursor_add(cursor, hf_homeplug_loader_snvmp, 1, FALSE);
 		ptvcursor_add(cursor, hf_homeplug_loader_length, 2, FALSE);
 		if (length == 17)
@@ -946,73 +904,43 @@ static void dissect_homeplug_hreq(ptvcursor_t * cursor, packet_info * pinfo)
 
   switch(mid) {
   case HOMEPLUG_MID_GDV:
-    if (check_col(pinfo->cinfo, COL_INFO)) {
-	col_clear(pinfo->cinfo, COL_INFO);
-	col_set_str(pinfo->cinfo, COL_INFO, "Host Request: Get Device Version");
-    }
+    col_set_str(pinfo->cinfo, COL_INFO, "Host Request: Get Device Version");
     ptvcursor_add(cursor, hf_homeplug_hreq_gdv, 1, FALSE);
     break;
   case HOMEPLUG_MID_GFV:
-    if (check_col(pinfo->cinfo, COL_INFO)) {
-	col_clear(pinfo->cinfo, COL_INFO);
-	col_set_str(pinfo->cinfo, COL_INFO, "Host Request: Get Firmware Version");
-    }
+    col_set_str(pinfo->cinfo, COL_INFO, "Host Request: Get Firmware Version");
     ptvcursor_add(cursor, hf_homeplug_hreq_gfv, 1, FALSE);
     break;
   case HOMEPLUG_MID_GNEK:
-    if (check_col(pinfo->cinfo, COL_INFO)) {
-	col_clear(pinfo->cinfo, COL_INFO);
-	col_set_str(pinfo->cinfo, COL_INFO, "Host Request: Get Network Encryption Key Request");
-    }
+    col_set_str(pinfo->cinfo, COL_INFO, "Host Request: Get Network Encryption Key Request");
     ptvcursor_add(cursor, hf_homeplug_hreq_gnek, 1, FALSE);
     break;
   case HOMEPLUG_MID_GCLBPL:
-    if (check_col(pinfo->cinfo, COL_INFO)) {
-	col_clear(pinfo->cinfo, COL_INFO);
-	col_set_str(pinfo->cinfo, COL_INFO, "Host Request: Get/ Clear Local Bridge Proxy List");
-    }
+    col_set_str(pinfo->cinfo, COL_INFO, "Host Request: Get/ Clear Local Bridge Proxy List");
     ptvcursor_add(cursor, hf_homeplug_hreq_gclbpl, 1, FALSE);
     break;
   case HOMEPLUG_MID_NVDS:
-    if (check_col(pinfo->cinfo, COL_INFO)) {
-	col_clear(pinfo->cinfo, COL_INFO);
-	col_set_str(pinfo->cinfo, COL_INFO, "Host Request: Non-volatile Database Status");
-    }
+    col_set_str(pinfo->cinfo, COL_INFO, "Host Request: Non-volatile Database Status");
     ptvcursor_add(cursor, hf_homeplug_hreq_nvds, 1, FALSE);
     break;
   case HOMEPLUG_MID_GRBT:
-    if (check_col(pinfo->cinfo, COL_INFO)) {
-	col_clear(pinfo->cinfo, COL_INFO);
-	col_set_str(pinfo->cinfo, COL_INFO, "Host Request: Get Remote Bridge Table");
-    }
+    col_set_str(pinfo->cinfo, COL_INFO, "Host Request: Get Remote Bridge Table");
     ptvcursor_add(cursor, hf_homeplug_hreq_grbt, 1, FALSE);
     break;
   case HOMEPLUG_MID_GSLNM:
-    if (check_col(pinfo->cinfo, COL_INFO)) {
-	col_clear(pinfo->cinfo, COL_INFO);
-	col_set_str(pinfo->cinfo, COL_INFO, "Host Request: Get/Set Logical Network Mappings");
-    }
+    col_set_str(pinfo->cinfo, COL_INFO, "Host Request: Get/Set Logical Network Mappings");
     ptvcursor_add(cursor, hf_homeplug_hreq_gslnm, 1, FALSE);
     break;
   case HOMEPLUG_MID_GSSS:
-    if (check_col(pinfo->cinfo, COL_INFO)) {
-	col_clear(pinfo->cinfo, COL_INFO);
-	col_set_str(pinfo->cinfo, COL_INFO, "Host Request: Get/Set Spectral Scaling");
-    }
+    col_set_str(pinfo->cinfo, COL_INFO, "Host Request: Get/Set Spectral Scaling");
     ptvcursor_add(cursor, hf_homeplug_hreq_gsss, 1, FALSE);
     break;
   case HOMEPLUG_MID_RSL:
-    if (check_col(pinfo->cinfo, COL_INFO)) {
-	col_clear(pinfo->cinfo, COL_INFO);
-	col_set_str(pinfo->cinfo, COL_INFO, "Host Request: MAC Reset to Secondary Loader");
-    }
+    col_set_str(pinfo->cinfo, COL_INFO, "Host Request: MAC Reset to Secondary Loader");
     ptvcursor_add(cursor, hf_homeplug_hreq_rsl, 1, FALSE);
     break;
   case HOMEPLUG_MID_RESET:
-    if (check_col(pinfo->cinfo, COL_INFO)) {
-	col_clear(pinfo->cinfo, COL_INFO);
-	col_set_str(pinfo->cinfo, COL_INFO, "Host Request: MAC Reset");
-    }
+    col_set_str(pinfo->cinfo, COL_INFO, "Host Request: MAC Reset");
     ptvcursor_add(cursor, hf_homeplug_hreq_reset, 1, FALSE);
     ptvcursor_add(cursor, hf_homeplug_hreq_reset_type, 1, FALSE);
     if (length == 4)
@@ -1042,35 +970,23 @@ static void dissect_homeplug_hrsp(ptvcursor_t * cursor, packet_info * pinfo)
       ptvcursor_current_offset(cursor));
   switch(mid) {
   case HOMEPLUG_MID_GDVR:
-    if (check_col(pinfo->cinfo, COL_INFO)) {
-	col_clear(pinfo->cinfo, COL_INFO);
-	col_set_str(pinfo->cinfo, COL_INFO, "Host Response: Get Device Version");
-    }
+    col_set_str(pinfo->cinfo, COL_INFO, "Host Response: Get Device Version");
     ptvcursor_add(cursor, hf_homeplug_hrsp_gdvr, 1, FALSE);
     ptvcursor_add(cursor, hf_homeplug_hrsp_version, -1, FALSE);
     break;
   case HOMEPLUG_MID_GFVR:
-    if (check_col(pinfo->cinfo, COL_INFO)) {
-	col_clear(pinfo->cinfo, COL_INFO);
-	col_set_str(pinfo->cinfo, COL_INFO, "Host Response: Get Firmware Version");
-    }
+    col_set_str(pinfo->cinfo, COL_INFO, "Host Response: Get Firmware Version");
     ptvcursor_add(cursor, hf_homeplug_hrsp_gfvr, 1, FALSE);
     ptvcursor_add(cursor, hf_homeplug_hrsp_version, -1, FALSE);
     break;
   case HOMEPLUG_MID_GNEKR:
-    if (check_col(pinfo->cinfo, COL_INFO)) {
-	col_clear(pinfo->cinfo, COL_INFO);
-	col_set_str(pinfo->cinfo, COL_INFO, "Get Network Encryption Key");
-    }
+    col_set_str(pinfo->cinfo, COL_INFO, "Get Network Encryption Key");
     ptvcursor_add(cursor, hf_homeplug_hrsp_gnekr, 1, FALSE);
     ptvcursor_add(cursor, hf_homeplug_hrsp_gnekr_select, 1, FALSE);
     ptvcursor_add(cursor, hf_homeplug_hrsp_gnekr_key, 8, FALSE);
     break;
   case HOMEPLUG_MID_INVALID:
-    if (check_col(pinfo->cinfo, COL_INFO)) {
-	col_clear(pinfo->cinfo, COL_INFO);
-	col_set_str(pinfo->cinfo, COL_INFO, "Host Response: Invalid MME");
-    }
+    col_set_str(pinfo->cinfo, COL_INFO, "Host Response: Invalid MME");
     ptvcursor_add(cursor, hf_homeplug_hrsp_invalid, 1, FALSE);
     break;
   default:
@@ -1306,38 +1222,23 @@ static void dissect_homeplug_mme(ptvcursor_t * cursor, packet_info * pinfo)
       dissect_homeplug_cer(cursor);
       break;
     case HOMEPLUG_MME_VS:
-      if (check_col(pinfo->cinfo, COL_INFO)) {
-	col_clear(pinfo->cinfo, COL_INFO);
-	col_set_str(pinfo->cinfo, COL_INFO, "Vendor Specific");
-      }
+      col_set_str(pinfo->cinfo, COL_INFO, "Vendor Specific");
       dissect_homeplug_vs(cursor);
       break;
     case HOMEPLUG_MME_RBA:
-      if (check_col(pinfo->cinfo, COL_INFO)) {
-	col_clear(pinfo->cinfo, COL_INFO);
-	col_set_str(pinfo->cinfo, COL_INFO, "Replace Bridge Address");
-      }
+      col_set_str(pinfo->cinfo, COL_INFO, "Replace Bridge Address");
       dissect_homeplug_rba(cursor);
       break;
     case HOMEPLUG_MME_SNK:
-      if (check_col(pinfo->cinfo, COL_INFO)) {
-	col_clear(pinfo->cinfo, COL_INFO);
-	col_set_str(pinfo->cinfo, COL_INFO, "Set Network Encryption Key");
-      }
+      col_set_str(pinfo->cinfo, COL_INFO, "Set Network Encryption Key");
       dissect_homeplug_snk(cursor);
       break;
     case HOMEPLUG_MME_MWR:
-      if (check_col(pinfo->cinfo, COL_INFO)) {
-	col_clear(pinfo->cinfo, COL_INFO);
-	col_set_str(pinfo->cinfo, COL_INFO, "Multicast With Response");
-      }
+      col_set_str(pinfo->cinfo, COL_INFO, "Multicast With Response");
       dissect_homeplug_mwr(cursor);
       break;
     case HOMEPLUG_MME_CNK:
-      if (check_col(pinfo->cinfo, COL_INFO)) {
-	col_clear(pinfo->cinfo, COL_INFO);
-	col_set_str(pinfo->cinfo, COL_INFO, "Confirm Network Encryption Key");
-      }
+      col_set_str(pinfo->cinfo, COL_INFO, "Confirm Network Encryption Key");
       dissect_homeplug_cnk(cursor);
       break;
     case HOMEPLUG_MME_RPS:
@@ -1350,31 +1251,19 @@ static void dissect_homeplug_mme(ptvcursor_t * cursor, packet_info * pinfo)
       dissect_homeplug_slp(cursor);
       break;
     case HOMEPLUG_MME_LOADER:
-      if (check_col(pinfo->cinfo, COL_INFO)) {
-	col_clear(pinfo->cinfo, COL_INFO);
-	col_set_str(pinfo->cinfo, COL_INFO, "Load Firmware");
-      }
+      col_set_str(pinfo->cinfo, COL_INFO, "Load Firmware");
       dissect_homeplug_loader(cursor, pinfo);
       break;
     case HOMEPLUG_MME_HREQ:
-      if (check_col(pinfo->cinfo, COL_INFO)) {
-	col_clear(pinfo->cinfo, COL_INFO);
-	col_set_str(pinfo->cinfo, COL_INFO, "Host Request");
-      }
+      col_set_str(pinfo->cinfo, COL_INFO, "Host Request");
       dissect_homeplug_hreq(cursor, pinfo);
       break;
     case HOMEPLUG_MME_HRSP:
-      if (check_col(pinfo->cinfo, COL_INFO)) {
-	col_clear(pinfo->cinfo, COL_INFO);
-	col_set_str(pinfo->cinfo, COL_INFO, "Host Response");
-      }
+      col_set_str(pinfo->cinfo, COL_INFO, "Host Response");
       dissect_homeplug_hrsp(cursor, pinfo);
       break;
     case HOMEPLUG_MME_HTAG:
-      if (check_col(pinfo->cinfo, COL_INFO)) {
-	col_clear(pinfo->cinfo, COL_INFO);
-	col_set_str(pinfo->cinfo, COL_INFO, "Host Tag");
-      }
+      col_set_str(pinfo->cinfo, COL_INFO, "Host Tag");
       dissect_homeplug_htag(cursor);
       break;
     case HOMEPLUG_MME_NS:
@@ -1416,10 +1305,7 @@ dissect_homeplug(tvbuff_t * tvb, packet_info * pinfo, proto_tree * tree)
 
   col_set_str(pinfo->cinfo, COL_PROTOCOL, "HomePlug");
   /* Clear out stuff in the info column */
-  if (check_col(pinfo->cinfo, COL_INFO)) {
-    col_clear(pinfo->cinfo, COL_INFO);
-    col_set_str(pinfo->cinfo, COL_INFO, "MAC Management");
-  }
+  col_set_str(pinfo->cinfo, COL_INFO, "MAC Management");
 
   homeplug_offset = 0;
 
