@@ -1,7 +1,7 @@
 /* packet-icq.c
  * Routines for ICQ packet disassembly
  *
- * $Id: packet-icq.c 25628 2008-06-28 21:09:57Z wmeier $
+ * $Id: packet-icq.c 30376 2009-10-06 19:15:58Z etxrab $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -451,12 +451,8 @@ dissect_icqv4(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
     proto_item *ti = NULL;
 
     /* Not really implemented yet */
-    if (check_col(pinfo->cinfo, COL_PROTOCOL)) {
-	col_set_str(pinfo->cinfo, COL_PROTOCOL, "ICQv4 (UDP)");
-    }
-    if (check_col(pinfo->cinfo, COL_INFO)) {
-	col_set_str(pinfo->cinfo, COL_INFO, "ICQ Version 4 protocol");
-    }
+    col_set_str(pinfo->cinfo, COL_PROTOCOL, "ICQv4 (UDP)");
+    col_set_str(pinfo->cinfo, COL_INFO, "ICQ Version 4 protocol");
     if (tree) {
         ti = proto_tree_add_protocol_format(tree, proto_icq, tvb, 0, -1,
 					    "ICQv4");
@@ -474,12 +470,8 @@ dissect_icqv3(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
     proto_item *ti = NULL;
 
     /* Not really implemented yet */
-    if (check_col(pinfo->cinfo, COL_PROTOCOL)) {
-	col_set_str(pinfo->cinfo, COL_PROTOCOL, "ICQv3 (UDP)");
-    }
-    if (check_col(pinfo->cinfo, COL_INFO)) {
-	col_set_str(pinfo->cinfo, COL_INFO, "ICQ Version 3 protocol");
-    }
+    col_set_str(pinfo->cinfo, COL_PROTOCOL, "ICQv3 (UDP)");
+    col_set_str(pinfo->cinfo, COL_INFO, "ICQ Version 3 protocol");
     if (tree) {
         ti = proto_tree_add_protocol_format(tree, proto_icq, tvb, 0, -1,
 					    "ICQv3");
@@ -497,12 +489,8 @@ dissect_icqv2(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
     proto_item *ti = NULL;
 
     /* Not really implemented yet */
-    if (check_col(pinfo->cinfo, COL_PROTOCOL)) {
-	col_set_str(pinfo->cinfo, COL_PROTOCOL, "ICQv2 (UDP)");
-    }
-    if (check_col(pinfo->cinfo, COL_INFO)) {
-	col_set_str(pinfo->cinfo, COL_INFO, "ICQ Version 2 protocol");
-    }
+    col_set_str(pinfo->cinfo, COL_PROTOCOL, "ICQv2 (UDP)");
+    col_set_str(pinfo->cinfo, COL_INFO, "ICQ Version 2 protocol");
     if (tree) {
         ti = proto_tree_add_protocol_format(tree, proto_icq, tvb, 0, -1,
 					    "ICQv2");
@@ -1278,7 +1266,7 @@ icqv5_srv_meta_user(proto_tree* tree, /* Tree to put the data in */
 	    /* Get the authorize setting */
 	    auth = tvb_get_guint8(tvb, offset);
 	    proto_tree_add_text(sstree, tvb, offset, 1,
-				"authorization: %s", (auth==0x01)?"Neccessary":"Who needs it");
+				"authorization: %s", (auth==0x01)?"Necessary":"Who needs it");
 	    offset++; left--;
 	    /* Get x2 */
 	    proto_tree_add_text(sstree, tvb, offset, sizeof(guint16),
@@ -1315,7 +1303,7 @@ icqv5_srv_meta_user(proto_tree* tree, /* Tree to put the data in */
 		"First name",
 		"Last name",
 		"Primary email",
-		"Secundary email",
+		"Secondary email",
 		"Old email",
 		"City",
 		"State",
@@ -1515,22 +1503,16 @@ dissect_icqv5Client(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
      * bytes in the buffer.
      */
     rounded_size = ((((capturedsize - ICQ5_CL_SESSIONID) + 3)/4)*4) + ICQ5_CL_SESSIONID;
-    decr_pd = g_malloc(rounded_size);
-    tvb_memcpy(tvb, decr_pd, 0, capturedsize);
+    decr_pd = tvb_memdup(tvb, 0, capturedsize);
     decrypt_v5(decr_pd, rounded_size, key);
 
     /* Allocate a new tvbuff, referring to the decrypted data. */
-    decr_tvb = tvb_new_real_data(decr_pd, capturedsize, pktsize);
+    decr_tvb = tvb_new_child_real_data(tvb, decr_pd, capturedsize, pktsize);
 
     /* Arrange that the allocated packet data copy be freed when the
        tvbuff is freed. */
     tvb_set_free_cb(decr_tvb, g_free);
 
-    /* Add the tvbuff to the list of tvbuffs to which the tvbuff we
-       were handed refers, so it'll get cleaned up when that tvbuff
-       is cleaned up. */
-    tvb_set_child_real_data_tvbuff(tvb, decr_tvb);
-
     /* Add the decrypted data to the data source list. */
     add_new_data_source(pinfo, decr_tvb, "Decrypted");
 
@@ -1724,10 +1706,8 @@ static void dissect_icqv5(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 {
   guint32 unknown;
 
-  if (check_col(pinfo->cinfo, COL_PROTOCOL))
-      col_set_str(pinfo->cinfo, COL_PROTOCOL, "ICQv5 (UDP)");
-  if (check_col(pinfo->cinfo, COL_INFO))
-      col_set_str(pinfo->cinfo, COL_INFO, "ICQv5 packet");
+  col_set_str(pinfo->cinfo, COL_PROTOCOL, "ICQv5 (UDP)");
+  col_set_str(pinfo->cinfo, COL_INFO, "ICQv5 packet");
 
   unknown = tvb_get_letohl(tvb, ICQ5_UNKNOWN);
 
@@ -1747,12 +1727,8 @@ dissect_icq(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
   if (version < 2 || version > 5)
     return 0;	/* This is not a (recognized) ICQ packet */
 
-  if (check_col(pinfo->cinfo, COL_PROTOCOL)) {
-    col_set_str(pinfo->cinfo, COL_PROTOCOL, "ICQ");
-  }
-  if (check_col(pinfo->cinfo, COL_INFO)) {
-    col_clear(pinfo->cinfo, COL_INFO);
-  }
+  col_set_str(pinfo->cinfo, COL_PROTOCOL, "ICQ");
+  col_clear(pinfo->cinfo, COL_INFO);
 
   version = tvb_get_letohs(tvb, ICQ_VERSION);
   switch (version) {
@@ -1783,19 +1759,19 @@ proto_register_icq(void)
 {
     static hf_register_info hf[] = {
 	{ &hf_icq_type,
-	  {"Type", "icq.type", FT_UINT16, BASE_DEC, NULL, 0x0, "", HFILL }},
+	  {"Type", "icq.type", FT_UINT16, BASE_DEC, NULL, 0x0, NULL, HFILL }},
 	{ &hf_icq_uin,
-	  {"UIN", "icq.uin", FT_UINT32, BASE_DEC, NULL, 0x0, "", HFILL }},
+	  {"UIN", "icq.uin", FT_UINT32, BASE_DEC, NULL, 0x0, NULL, HFILL }},
 	{ &hf_icq_sessionid,
-	  {"Session ID", "icq.sessionid", FT_UINT32, BASE_HEX, NULL, 0x0, "", HFILL }},
+	  {"Session ID", "icq.sessionid", FT_UINT32, BASE_HEX, NULL, 0x0, NULL, HFILL }},
 	{ &hf_icq_client_cmd,
-	  {"Client command", "icq.client_cmd", FT_UINT16, BASE_HEX, VALS(clientCmdCode), 0x0, "", HFILL }},
+	  {"Client command", "icq.client_cmd", FT_UINT16, BASE_HEX, VALS(clientCmdCode), 0x0, NULL, HFILL }},
 	{ &hf_icq_server_cmd,
-	  {"Server command", "icq.server_cmd", FT_UINT16, BASE_DEC, VALS(serverCmdCode), 0x0, "", HFILL }},
+	  {"Server command", "icq.server_cmd", FT_UINT16, BASE_DEC, VALS(serverCmdCode), 0x0, NULL, HFILL }},
 	{ &hf_icq_checkcode,
-	  {"Checkcode", "icq.checkcode", FT_UINT32, BASE_HEX, NULL, 0x0, "", HFILL }},
+	  {"Checkcode", "icq.checkcode", FT_UINT32, BASE_HEX, NULL, 0x0, NULL, HFILL }},
 	{ &hf_icq_decode,
-	  {"Decode", "icq.decode", FT_STRING, BASE_NONE, NULL, 0x0, "", HFILL }}
+	  {"Decode", "icq.decode", FT_STRING, BASE_NONE, NULL, 0x0, NULL, HFILL }}
     };
     static gint *ett[] = {
         &ett_icq,
