@@ -4,7 +4,7 @@
  * 2007 Thomas Morin
  * <See AUTHORS for emails>
  *
- * $Id: packet-igmp.c 25290 2008-05-14 01:47:41Z wmeier $
+ * $Id: packet-igmp.c 30995 2009-11-17 18:35:27Z dimeg $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -909,12 +909,8 @@ dissect_igmp(tvbuff_t *tvb, packet_info *pinfo, proto_tree *parent_tree)
 	tree = proto_item_add_subtree(item, ett_igmp);
 
 
-	if (check_col(pinfo->cinfo, COL_PROTOCOL)) {
-		col_set_str(pinfo->cinfo, COL_PROTOCOL, "IGMP");
-	}
-	if (check_col(pinfo->cinfo, COL_INFO)) {
-		col_clear(pinfo->cinfo, COL_INFO);
-	}
+	col_set_str(pinfo->cinfo, COL_PROTOCOL, "IGMP");
+	col_clear(pinfo->cinfo, COL_INFO);
 
 
 	type = tvb_get_guint8(tvb, offset);
@@ -1041,7 +1037,7 @@ proto_register_igmp(void)
 
 		{ &hf_version,
 			{ "IGMP Version", "igmp.version", FT_UINT8, BASE_DEC,
-			  NULL, 0, "IGMP Version", HFILL }},
+			  NULL, 0, NULL, HFILL }},
 
 		{ &hf_group_type,
 			{ "Type Of Group", "igmp.group_type", FT_UINT8, BASE_DEC,
@@ -1061,14 +1057,14 @@ proto_register_igmp(void)
 
 		{ &hf_checksum_bad,
 			{ "Bad Checksum", "igmp.checksum_bad", FT_BOOLEAN, BASE_NONE,
-			  NULL, 0, "Bad IGMP Checksum", HFILL }},
+			  NULL, 0x0, "Bad IGMP Checksum", HFILL }},
 
 		{ &hf_identifier,
 			{ "Identifier", "igmp.identifier", FT_UINT32, BASE_DEC,
 			  NULL, 0, "IGMP V0 Identifier", HFILL }},
 
 		{ &hf_access_key,
-			{ "Access Key", "igmp.access_key", FT_BYTES, BASE_HEX,
+			{ "Access Key", "igmp.access_key", FT_BYTES, BASE_NONE,
 			  NULL, 0, "IGMP V0 Access Key", HFILL }},
 
 		{ &hf_max_resp,
@@ -1093,7 +1089,7 @@ proto_register_igmp(void)
 
 		{ &hf_saddr,
 			{ "Source Address", "igmp.saddr", FT_IPv4, BASE_NONE,
-			  NULL, 0, "Source Address", HFILL }},
+			  NULL, 0, NULL, HFILL }},
 
 		{ &hf_num_grp_recs,
 			{ "Num Group Records", "igmp.num_grp_recs", FT_UINT16, BASE_DEC,
@@ -1101,7 +1097,7 @@ proto_register_igmp(void)
 
 		{ &hf_record_type,
 			{ "Record Type", "igmp.record_type", FT_UINT8, BASE_DEC,
-			VALS(vs_record_type), 0, "Record Type", HFILL }},
+			VALS(vs_record_type), 0, NULL, HFILL }},
 
 		{ &hf_aux_data_len,
 			{ "Aux Data Len", "igmp.aux_data_len", FT_UINT8, BASE_DEC,
@@ -1109,23 +1105,23 @@ proto_register_igmp(void)
 
 		{ &hf_maddr,
 			{ "Multicast Address", "igmp.maddr", FT_IPv4, BASE_NONE,
-			  NULL, 0, "Multicast Address", HFILL }},
+			  NULL, 0, NULL, HFILL }},
 
 		{ &hf_aux_data,
-			{ "Aux Data", "igmp.aux_data", FT_BYTES, BASE_HEX,
+			{ "Aux Data", "igmp.aux_data", FT_BYTES, BASE_NONE,
 			  NULL, 0, "IGMP V3 Auxiliary Data", HFILL }},
 
 		{ &hf_max_resp_exp,
 			{ "Exponent", "igmp.max_resp.exp", FT_UINT8, BASE_HEX,
-			NULL, IGMP_MAX_RESP_EXP, "Maxmimum Response Time, Exponent", HFILL }},
+			NULL, IGMP_MAX_RESP_EXP, "Maximum Response Time, Exponent", HFILL }},
 
 		{ &hf_max_resp_mant,
 			{ "Mantissa", "igmp.max_resp.mant", FT_UINT8, BASE_HEX,
-			NULL, IGMP_MAX_RESP_MANT, "Maxmimum Response Time, Mantissa", HFILL }},
+			NULL, IGMP_MAX_RESP_MANT, "Maximum Response Time, Mantissa", HFILL }},
 
 		{ &hf_mtrace_max_hops,
 			{ "# hops", "igmp.mtrace.max_hops", FT_UINT8, BASE_DEC,
-			NULL, 0, "Maxmimum Number of Hops to Trace", HFILL }},
+			NULL, 0, "Maximum Number of Hops to Trace", HFILL }},
 
 		{ &hf_mtrace_saddr,
 			{ "Source Address", "igmp.mtrace.saddr", FT_IPv4, BASE_NONE,
@@ -1177,7 +1173,7 @@ proto_register_igmp(void)
 
 		{ &hf_mtrace_q_rtg_proto,
 			{ "Rtg Protocol", "igmp.mtrace.q_rtg_proto", FT_UINT8, BASE_DEC,
-			VALS(&mtrace_rtg_vals), 0, "Routing protocol between this and previous hop rtr", HFILL }},
+			VALS(mtrace_rtg_vals), 0, "Routing protocol between this and previous hop rtr", HFILL }},
 
 		{ &hf_mtrace_q_fwd_ttl,
 			{ "FwdTTL", "igmp.mtrace.q_fwd_ttl", FT_UINT8, BASE_DEC,
@@ -1197,7 +1193,7 @@ proto_register_igmp(void)
 
 		{ &hf_mtrace_q_fwd_code,
 			{ "Forwarding Code", "igmp.mtrace.q_fwd_code", FT_UINT8, BASE_HEX,
-			VALS(&mtrace_fwd_code_vals), 0, "Forwarding information/error code", HFILL }},
+			VALS(mtrace_fwd_code_vals), 0, "Forwarding information/error code", HFILL }},
 
 	};
 	static gint *ett[] = {
