@@ -6,7 +6,7 @@
  * Portions Copyright (c) 2000-2002 by Gilbert Ramirez.
  * Portions Copyright (c) Novell, Inc. 2002-2003
  *
- * $Id: packet-ipx.c 35168 2010-12-10 12:13:53Z etxrab $
+ * $Id: packet-ipx.c 29747 2009-09-06 14:25:47Z krj $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -259,10 +259,8 @@ dissect_ipx(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 	ipxh=&ipxh_arr[ipx_current];
 
 
-	if (check_col(pinfo->cinfo, COL_PROTOCOL))
-		col_set_str(pinfo->cinfo, COL_PROTOCOL, "IPX");
-	if (check_col(pinfo->cinfo, COL_INFO))
-		col_clear(pinfo->cinfo, COL_INFO);
+	col_set_str(pinfo->cinfo, COL_PROTOCOL, "IPX");
+	col_clear(pinfo->cinfo, COL_INFO);
 
 	/* Calculate here for use in pinfo and in tree */
 	ipxh->ipx_dsocket = tvb_get_ntohs(tvb, 16);
@@ -355,7 +353,7 @@ dissect_ipx(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 	PROTO_ITEM_SET_HIDDEN(hidden_item);
 
 	/* Make the next tvbuff */
-	next_tvb = tvb_new_subset(tvb, IPX_HEADER_LEN, -1, -1);
+	next_tvb = tvb_new_subset_remaining(tvb, IPX_HEADER_LEN);
 
 	/*
 	 * Let the subdissector know what type of IPX packet this is.
@@ -596,10 +594,8 @@ dissect_spx(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 	spx_rexmit_info	*spx_rexmit_info;
 	spx_info	spx_info;
 
-	if (check_col(pinfo->cinfo, COL_PROTOCOL))
-		col_set_str(pinfo->cinfo, COL_PROTOCOL, "SPX");
-	if (check_col(pinfo->cinfo, COL_INFO))
-		col_set_str(pinfo->cinfo, COL_INFO, "SPX");
+	col_set_str(pinfo->cinfo, COL_PROTOCOL, "SPX");
+	col_set_str(pinfo->cinfo, COL_INFO, "SPX");
 
 	if (tree) {
 		ti = proto_tree_add_item(tree, proto_spx, tvb, 0, SPX_HEADER_LEN, FALSE);
@@ -819,7 +815,7 @@ dissect_spx(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 		pd_save = pinfo->private_data;
 		pinfo->private_data = &spx_info;
 
-		next_tvb = tvb_new_subset(tvb, SPX_HEADER_LEN, -1, -1);
+		next_tvb = tvb_new_subset_remaining(tvb, SPX_HEADER_LEN);
 		if (dissector_try_port(spx_socket_dissector_table, low_socket,
 		    next_tvb, pinfo, tree))
 		{
@@ -847,10 +843,8 @@ dissect_ipxmsg(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 	proto_item	*ti;
 	guint8		conn_number, sig_char;
 
-	if (check_col(pinfo->cinfo, COL_PROTOCOL))
-		col_set_str(pinfo->cinfo, COL_PROTOCOL, "IPX MSG");
-	if (check_col(pinfo->cinfo, COL_INFO))
-		col_clear(pinfo->cinfo, COL_INFO);
+	col_set_str(pinfo->cinfo, COL_PROTOCOL, "IPX MSG");
+	col_clear(pinfo->cinfo, COL_INFO);
 
 	conn_number = tvb_get_guint8(tvb, 0);
 	sig_char = tvb_get_guint8(tvb, 1);
@@ -886,10 +880,8 @@ dissect_ipxrip(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 
 	static const char	*rip_type[3] = { "Request", "Response", "Unknown" };
 
-	if (check_col(pinfo->cinfo, COL_PROTOCOL))
-		col_set_str(pinfo->cinfo, COL_PROTOCOL, "IPX RIP");
-	if (check_col(pinfo->cinfo, COL_INFO))
-		col_clear(pinfo->cinfo, COL_INFO);
+	col_set_str(pinfo->cinfo, COL_PROTOCOL, "IPX RIP");
+	col_clear(pinfo->cinfo, COL_INFO);
 
 	operation = tvb_get_ntohs(tvb, 0) - 1;
 
@@ -956,10 +948,8 @@ dissect_serialization(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 	proto_tree	*ser_tree = NULL;
 	proto_item	*ti;
 
-	if (check_col(pinfo->cinfo, COL_PROTOCOL))
-		col_set_str(pinfo->cinfo, COL_PROTOCOL, "NW_SERIAL");
-	if (check_col(pinfo->cinfo, COL_INFO))
-		col_clear(pinfo->cinfo, COL_INFO);
+	col_set_str(pinfo->cinfo, COL_PROTOCOL, "NW_SERIAL");
+	col_clear(pinfo->cinfo, COL_INFO);
 
 	if (tree) {
 		ti = proto_tree_add_item(tree, proto_serialization, tvb, 0, -1,
@@ -1229,10 +1219,8 @@ dissect_ipxsap(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 	static const char	*sap_type[4] = { "General Query", "General Response",
 		"Nearest Query", "Nearest Response" };
 
-	if (check_col(pinfo->cinfo, COL_PROTOCOL))
-		col_set_str(pinfo->cinfo, COL_PROTOCOL, "IPX SAP");
-	if (check_col(pinfo->cinfo, COL_INFO))
-		col_clear(pinfo->cinfo, COL_INFO);
+	col_set_str(pinfo->cinfo, COL_PROTOCOL, "IPX SAP");
+	col_clear(pinfo->cinfo, COL_INFO);
 
 	query.query_type = tvb_get_ntohs(tvb, 0);
 	query.server_type = tvb_get_ntohs(tvb, 2);
@@ -1311,132 +1299,132 @@ proto_register_ipx(void)
 	static hf_register_info hf_ipx[] = {
 		{ &hf_ipx_checksum,
 		{ "Checksum",		"ipx.checksum", FT_UINT16, BASE_HEX, NULL, 0x0,
-			"", HFILL }},
+			NULL, HFILL }},
 
 		{ &hf_ipx_src,
-		{ "Source Address",	"ipx.src", FT_STRING, BASE_DEC, NULL, 0x0,
+		{ "Source Address",	"ipx.src", FT_STRING, BASE_NONE, NULL, 0x0,
 		  "Source IPX Address  \"network.node\"", HFILL }},
 
 		{ &hf_ipx_dst,
-		{ "Destination Address",	"ipx.dst", FT_STRING, BASE_DEC, NULL, 0x0,
+		{ "Destination Address",	"ipx.dst", FT_STRING, BASE_NONE, NULL, 0x0,
 		  "Destination IPX Address  \"network.node\"", HFILL }},
 		{ &hf_ipx_addr,
-		{ "Src/Dst Address",	"ipx.addr", FT_STRING, BASE_DEC, NULL, 0x0,
+		{ "Src/Dst Address",	"ipx.addr", FT_STRING, BASE_NONE, NULL, 0x0,
 		  "Source or Destination IPX Address  \"network.node\"", HFILL }},
 
 		{ &hf_ipx_len,
 		{ "Length",		"ipx.len", FT_UINT16, BASE_DEC, NULL, 0x0,
-			"", HFILL }},
+			NULL, HFILL }},
 
 		{ &hf_ipx_hops,
 		{ "Transport Control (Hops)", "ipx.hops", FT_UINT8, BASE_DEC, NULL, 0x0,
-			"", HFILL }},
+			NULL, HFILL }},
 
 		{ &hf_ipx_packet_type,
 		{ "Packet Type",	"ipx.packet_type", FT_UINT8, BASE_HEX, VALS(ipx_packet_type_vals),
 			0x0,
-			"", HFILL }},
+			NULL, HFILL }},
 
 		{ &hf_ipx_dnet,
 		{ "Destination Network","ipx.dst.net", FT_IPXNET, BASE_NONE, NULL, 0x0,
-			"", HFILL }},
+			NULL, HFILL }},
 
 		{ &hf_ipx_dnode,
 		{ "Destination Node",	"ipx.dst.node", FT_ETHER, BASE_NONE, NULL, 0x0,
-			"", HFILL }},
+			NULL, HFILL }},
 
 		{ &hf_ipx_dsocket,
 		{ "Destination Socket",	"ipx.dst.socket", FT_UINT16, BASE_HEX,
 			VALS(ipx_socket_vals), 0x0,
-			"", HFILL }},
+			NULL, HFILL }},
 
 		{ &hf_ipx_snet,
 		{ "Source Network","ipx.src.net", FT_IPXNET, BASE_NONE, NULL, 0x0,
-			"", HFILL }},
+			NULL, HFILL }},
 
 		{ &hf_ipx_snode,
 		{ "Source Node",	"ipx.src.node", FT_ETHER, BASE_NONE, NULL, 0x0,
-			"", HFILL }},
+			NULL, HFILL }},
 
 		{ &hf_ipx_ssocket,
 		{ "Source Socket",	"ipx.src.socket", FT_UINT16, BASE_HEX,
 			VALS(ipx_socket_vals), 0x0,
-			"", HFILL }},
+			NULL, HFILL }},
 
 		{ &hf_ipx_net,
 		{ "Source or Destination Network","ipx.net", FT_IPXNET, BASE_NONE, NULL, 0x0,
-			"", HFILL }},
+			NULL, HFILL }},
 
 		{ &hf_ipx_node,
 		{ "Source or Destination Node", "ipx.node", FT_ETHER, BASE_NONE, NULL, 0x0,
-			"", HFILL }},
+			NULL, HFILL }},
 
 		{ &hf_ipx_socket,
 		{ "Source or Destination Socket", "ipx.socket", FT_UINT16, BASE_HEX,
 			VALS(ipx_socket_vals), 0x0,
-			"", HFILL }},
+			NULL, HFILL }},
 	};
 
 	static hf_register_info hf_spx[] = {
 		{ &hf_spx_connection_control,
 		{ "Connection Control",		"spx.ctl",
 		  FT_UINT8,	BASE_HEX,	NULL,	0x0,
-		  "", HFILL }},
+		  NULL, HFILL }},
 
 		{ &hf_spx_connection_control_sys,
 		{ "System Packet",		"spx.ctl.sys",
 		  FT_BOOLEAN,	8,	NULL,	SPX_SYS_PACKET,
-		  "", HFILL }},
+		  NULL, HFILL }},
 
 		{ &hf_spx_connection_control_send_ack,
 		{ "Send Ack",		"spx.ctl.send_ack",
 		  FT_BOOLEAN,	8,	NULL,	SPX_SEND_ACK,
-		  "", HFILL }},
+		  NULL, HFILL }},
 
 		{ &hf_spx_connection_control_attn,
 		{ "Attention",		"spx.ctl.attn",
 		  FT_BOOLEAN,	8,	NULL,	SPX_ATTN,
-		  "", HFILL }},
+		  NULL, HFILL }},
 
 		{ &hf_spx_connection_control_eom,
 		{ "End of Message",	"spx.ctl.eom",
 		  FT_BOOLEAN,	8,	NULL,	SPX_EOM,
-		  "", HFILL }},
+		  NULL, HFILL }},
 
 		{ &hf_spx_datastream_type,
 		{ "Datastream type",	       	"spx.type",
 		  FT_UINT8,	BASE_HEX,	NULL,	0x0,
-		  "", HFILL }},
+		  NULL, HFILL }},
 
 		{ &hf_spx_src_id,
 		{ "Source Connection ID",	"spx.src",
 		  FT_UINT16,	BASE_DEC,	NULL,	0x0,
-		  "", HFILL }},
+		  NULL, HFILL }},
 
 		{ &hf_spx_dst_id,
 		{ "Destination Connection ID",	"spx.dst",
 		  FT_UINT16,	BASE_DEC,	NULL,	0x0,
-		  "", HFILL }},
+		  NULL, HFILL }},
 
 		{ &hf_spx_seq_nr,
 		{ "Sequence Number",		"spx.seq",
 		  FT_UINT16,	BASE_DEC,	NULL,	0x0,
-		  "", HFILL }},
+		  NULL, HFILL }},
 
 		{ &hf_spx_ack_nr,
 		{ "Acknowledgment Number",	"spx.ack",
 		  FT_UINT16,	BASE_DEC,	NULL,	0x0,
-		  "", HFILL }},
+		  NULL, HFILL }},
 
 		{ &hf_spx_all_nr,
 		{ "Allocation Number",		"spx.alloc",
 		  FT_UINT16,	BASE_DEC,	NULL,	0x0,
-		  "", HFILL }},
+		  NULL, HFILL }},
 
 		{ &hf_spx_rexmt_frame,
 		{ "Retransmitted Frame Number",	"spx.rexmt_frame",
 		  FT_FRAMENUM,	BASE_NONE,	NULL,	0x0,
-		  "", HFILL }},
+		  NULL, HFILL }},
 	};
 
 	static hf_register_info hf_ipxrip[] = {
@@ -1467,12 +1455,12 @@ proto_register_ipx(void)
 		{ &hf_msg_conn,
 		{ "Connection Number",			"ipxmsg.conn",
 		  FT_UINT8,	BASE_DEC,	NULL,	0x0,
-		  "Connection Number", HFILL }},
+		  NULL, HFILL }},
 
 		{ &hf_msg_sigchar,
 		{ "Signature Char",			"ipxmsg.sigchar",
 		  FT_UINT8,	BASE_DEC,	VALS(ipxmsg_sigchar_vals),	0x0,
-		  "Signature Char", HFILL }}
+		  NULL, HFILL }}
 	};
 
 	static gint *ett[] = {
