@@ -1,13 +1,12 @@
 /* packet-l2tp.c
- * Routines for Layer Two Tunnelling Protocol (L2TP) (RFC 2661) packet
- * disassembly
+ * Routines for Layer Two Tunnelling Protocol (L2TP) packet disassembly
  * John Thomes <john@ensemblecom.com>
  *
  * Minor changes by: (2000-01-10)
  * Laurent Cazalet <laurent.cazalet@mailclub.net>
  * Thomas Parvais <thomas.parvais@advalvas.be>
  *
- * $Id: packet-l2tp.c 23405 2007-11-08 22:40:20Z etxrab $
+ * $Id: packet-l2tp.c 30857 2009-11-07 19:41:58Z jake $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -30,13 +29,29 @@
 
 /*
  * RFC 2661 for L2TPv2
- * I-D draft-ietf-l2tpext-l2tp-base for L2TPv3
+ * http://tools.ietf.org/html/rfc2661
  *
- * L2TPv3
- * http://www.ietf.org/rfc/rfc3931.txt
+ * RFC 3931 for L2TPv3
+ * http://tools.ietf.org/html/rfc3931
  *
  * Layer Two Tunneling Protocol "L2TP" number assignments:
  *	http://www.iana.org/assignments/l2tp-parameters
+ *
+ * Pseudowire types:
+ *
+ * RFC 4591 for Frame Relay
+ * http://tools.ietf.org/html/rfc4591
+ *
+ * RFC 4454 for ATM
+ * http://tools.ietf.org/html/rfc4454
+ *
+ * RFC 4719 for Ethernet
+ * http://tools.ietf.org/html/rfc4719
+ *
+ * RFC 4349 for HDLC
+ * http://tools.ietf.org/html/rfc4349
+ *
+ * XXX - what about LAPD?
  */
 
 static int proto_l2tp = -1;
@@ -64,7 +79,10 @@ static int hf_l2tp_ccid = -1;
 static int hf_l2tp_cookie = -1;
 static int hf_l2tp_l2_spec_def = -1;
 static int hf_l2tp_l2_spec_atm = -1;
+static int hf_l2tp_l2_spec_docsis_dmpt = -1;
+static int hf_l2tp_l2_spec_v = -1;
 static int hf_l2tp_l2_spec_s = -1;
+static int hf_l2tp_l2_spec_flow_id = -1;
 static int hf_l2tp_l2_spec_sequence = -1;
 static int hf_l2tp_l2_spec_t = -1;
 static int hf_l2tp_l2_spec_g = -1;
@@ -106,6 +124,9 @@ static int hf_l2tp_cisco_avp_type = -1;
 #define CIRCUIT_STATUS_BIT(msg_info) (msg_info & 0x0001)	/* Circuit Status */
 #define CIRCUIT_TYPE_BIT(msg_info) (msg_info & 0x0001)		/* Circuit Condition */
 
+/* DOCSIS DMPT Sub-Layer Header definitions */
+#define FLOW_ID_MASK  0x0E
+
 static gint ett_l2tp = -1;
 static gint ett_l2tp_ctrl = -1;
 static gint ett_l2tp_avp = -1;
@@ -127,7 +148,8 @@ static enum_val_t l2tpv3_cookies[] = {
 #define L2TPv3_PROTOCOL_IP      4
 #define L2TPv3_PROTOCOL_MPLS    5
 #define L2TPv3_PROTOCOL_AAL5    6
-#define L2TPv3_PROTOCOL_LAPD	7
+#define L2TPv3_PROTOCOL_LAPD    7
+#define L2TPv3_PROTOCOL_DOCSIS_DMPT 8
 
 static enum_val_t l2tpv3_protocols[] = {
     {"eth",     "Ethernet",     L2TPv3_PROTOCOL_ETH},
@@ -137,7 +159,8 @@ static enum_val_t l2tpv3_protocols[] = {
     {"ip",      "IP",           L2TPv3_PROTOCOL_IP},
     {"mpls",    "MPLS",         L2TPv3_PROTOCOL_MPLS},
     {"aal5",    "AAL5",         L2TPv3_PROTOCOL_AAL5},
-    {"lapd",	"LAPD",         L2TPv3_PROTOCOL_LAPD},
+    {"lapd",    "LAPD",         L2TPv3_PROTOCOL_LAPD},
+    {"docsis-dmpt", "DOCSIS-DMPT", L2TPv3_PROTOCOL_DOCSIS_DMPT},
     {NULL, NULL, 0}
 };
 
@@ -145,12 +168,14 @@ static enum_val_t l2tpv3_protocols[] = {
 #define L2TPv3_L2_SPECIFIC_DEFAULT      1
 #define L2TPv3_L2_SPECIFIC_ATM          2
 #define L2TPv3_L2_SPECIFIC_LAPD         3
+#define L2TPv3_L2_SPECIFIC_DOCSIS_DMPT  4
 
 static enum_val_t l2tpv3_l2_specifics[] = {
     {"none",    "None",                 L2TPv3_L2_SPECIFIC_NONE},
     {"default", "Default L2-Specific",  L2TPv3_L2_SPECIFIC_DEFAULT},
     {"atm",     "ATM-Specific",         L2TPv3_L2_SPECIFIC_ATM},
     {"lapd",    "LAPD-Specific",        L2TPv3_L2_SPECIFIC_LAPD},
+    {"dmpt",    "DOCSIS DMPT-Specific", L2TPv3_L2_SPECIFIC_DOCSIS_DMPT},
     {NULL, NULL, 0}
 };
 
@@ -556,8 +581,10 @@ static dissector_handle_t chdlc_handle;
 static dissector_handle_t fr_handle;
 static dissector_handle_t ip_handle;
 static dissector_handle_t mpls_handle;
+static dissector_handle_t atm_oam_handle;
 static dissector_handle_t llc_handle;
 static dissector_handle_t lapd_handle;
+static dissector_handle_t mp2t_handle;
 static dissector_handle_t data_handle;
 
 /*
@@ -585,7 +612,6 @@ static void process_control_avps(tvbuff_t *tvb,
 	guint32 	bits;
 	guint16 	firmware_rev;
 	
-	if (l2tp_tree) {
 		while (index < length) {    /* Process AVP's */
 			ver_len_hidden	= tvb_get_ntohs(tvb, index);
 			avp_len		= AVP_LENGTH(ver_len_hidden);
@@ -1329,8 +1355,6 @@ static void process_control_avps(tvbuff_t *tvb,
 			index += avp_len;
 		}
 
-	}
-	return;
 }
 
 /*
@@ -1343,7 +1367,8 @@ process_l2tpv3_data(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree,
 		    proto_tree *l2tp_tree, proto_item *l2tp_item, int *pIndex)
 {
 	int 		index = *pIndex;
-	int 		sid, oam_cell = 0;
+	int 		sid;
+	guint8		oam_cell = 0;
 	proto_tree	*l2_specific = NULL;
 	proto_item	*ti = NULL;
 	tvbuff_t	*next_tvb;
@@ -1365,100 +1390,120 @@ process_l2tpv3_data(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree,
 			return;
 		if (l2tpv3_cookie != 0)
 			proto_tree_add_item(l2tp_tree, hf_l2tp_cookie, tvb, index, l2tpv3_cookie, FALSE);
+	}
 
-                switch(l2tpv3_l2_specific){
+	switch(l2tpv3_l2_specific){
+	case L2TPv3_L2_SPECIFIC_DEFAULT:
+		if (tree) {
+			ti = proto_tree_add_item(tree, hf_l2tp_l2_spec_def,
+					tvb, index + l2tpv3_cookie, 4, FALSE);
+			l2_specific = proto_item_add_subtree(ti, ett_l2tp_l2_spec);
 
-                case L2TPv3_L2_SPECIFIC_DEFAULT:
-                        ti = proto_tree_add_item(tree, hf_l2tp_l2_spec_def,
-                                        tvb, index + l2tpv3_cookie, 4, FALSE);
-                        l2_specific = proto_item_add_subtree(ti, ett_l2tp_l2_spec);
+			proto_tree_add_item(l2_specific, hf_l2tp_l2_spec_s, tvb, index + l2tpv3_cookie,
+						1, FALSE);
+			proto_tree_add_item(l2_specific, hf_l2tp_l2_spec_sequence, tvb,
+						index + l2tpv3_cookie + 1, 3, FALSE);
+		}
+		next_tvb = tvb_new_subset_remaining(tvb, index + l2tpv3_cookie + 4);
+		break;
+	case L2TPv3_L2_SPECIFIC_DOCSIS_DMPT:
+		if (tree) {
+			ti = proto_tree_add_item(tree, hf_l2tp_l2_spec_docsis_dmpt,
+						tvb, index + l2tpv3_cookie, 4, FALSE);
+			l2_specific = proto_item_add_subtree(ti, ett_l2tp_l2_spec);
 
-                        proto_tree_add_item(l2_specific, hf_l2tp_l2_spec_s, tvb, index + l2tpv3_cookie,
-                                                1, FALSE);
-                        proto_tree_add_item(l2_specific, hf_l2tp_l2_spec_sequence, tvb,
-                                                index + l2tpv3_cookie + 1, 3, FALSE);
-                        break;
-                case L2TPv3_L2_SPECIFIC_ATM:
-                        ti = proto_tree_add_item(tree, hf_l2tp_l2_spec_atm,
-                                        tvb, index + l2tpv3_cookie, 4, FALSE);
-                        l2_specific = proto_item_add_subtree(ti, ett_l2tp_l2_spec);
+			proto_tree_add_item(l2_specific, hf_l2tp_l2_spec_v, tvb, 
+						index + l2tpv3_cookie,1, FALSE);
+		
+			proto_tree_add_item(l2_specific, hf_l2tp_l2_spec_s, tvb, 
+						index + l2tpv3_cookie,1, FALSE);
+		
+			proto_tree_add_item(l2_specific, hf_l2tp_l2_spec_flow_id, tvb, 
+						index + l2tpv3_cookie,1, FALSE);
+		
+			proto_tree_add_item(l2_specific, hf_l2tp_l2_spec_sequence, tvb, 
+						index + l2tpv3_cookie + 2,2, FALSE);
+		}
+		next_tvb = tvb_new_subset_remaining(tvb, index + l2tpv3_cookie + 4);
+		break;
+	case L2TPv3_L2_SPECIFIC_ATM:
+		if (tree) {
+			ti = proto_tree_add_item(tree, hf_l2tp_l2_spec_atm,
+					tvb, index + l2tpv3_cookie, 4, FALSE);
+			l2_specific = proto_item_add_subtree(ti, ett_l2tp_l2_spec);
 
-                        proto_tree_add_item(l2_specific, hf_l2tp_l2_spec_s, tvb, index + l2tpv3_cookie,
-                                                1, FALSE);
-                        proto_tree_add_item(l2_specific, hf_l2tp_l2_spec_t, tvb, index + l2tpv3_cookie,
-                                                1, FALSE);
-                        oam_cell = tvb_get_ntohl(tvb, 4 + l2tpv3_cookie) & 0x08000000;
-                        proto_tree_add_item(l2_specific, hf_l2tp_l2_spec_g, tvb, index + l2tpv3_cookie,
-                                                1, FALSE);
-                        proto_tree_add_item(l2_specific, hf_l2tp_l2_spec_c, tvb, index + l2tpv3_cookie,
-                                                1, FALSE);
-                        proto_tree_add_item(l2_specific, hf_l2tp_l2_spec_u, tvb, index + l2tpv3_cookie,
-                                                1, FALSE);
-                        proto_tree_add_item(l2_specific, hf_l2tp_l2_spec_sequence, tvb,
-                                                index + l2tpv3_cookie + 1, 3, FALSE);
-                        break;
-                case L2TPv3_L2_SPECIFIC_NONE:
-                default:
-                        break;
-                }
-          }
+			proto_tree_add_item(l2_specific, hf_l2tp_l2_spec_s, tvb, index + l2tpv3_cookie,
+						1, FALSE);
+			proto_tree_add_item(l2_specific, hf_l2tp_l2_spec_t, tvb, index + l2tpv3_cookie,
+						1, FALSE);
+			/*
+			 * As per RFC 4454, the T bit specifies whether
+			 * we're transporting an OAM cell or an AAL5 frame.
+			 */
+			oam_cell = tvb_get_guint8(tvb, index + l2tpv3_cookie) & 0x08;
+			proto_tree_add_item(l2_specific, hf_l2tp_l2_spec_g, tvb, index + l2tpv3_cookie,
+						1, FALSE);
+			proto_tree_add_item(l2_specific, hf_l2tp_l2_spec_c, tvb, index + l2tpv3_cookie,
+						1, FALSE);
+			proto_tree_add_item(l2_specific, hf_l2tp_l2_spec_u, tvb, index + l2tpv3_cookie,
+						1, FALSE);
+			proto_tree_add_item(l2_specific, hf_l2tp_l2_spec_sequence, tvb,
+						index + l2tpv3_cookie + 1, 3, FALSE);
+		}
+		next_tvb = tvb_new_subset_remaining(tvb, index + l2tpv3_cookie + 4);
+		break;
+	case L2TPv3_L2_SPECIFIC_LAPD:
+		if (tree)
+			proto_tree_add_text(tree, tvb, index + l2tpv3_cookie + 4, 3,"LAPD info");
+		next_tvb = tvb_new_subset_remaining(tvb, index + l2tpv3_cookie+4+3);
+		break;
+	case L2TPv3_L2_SPECIFIC_NONE:
+	default:
+		next_tvb = tvb_new_subset_remaining(tvb, index + l2tpv3_cookie);
+		break;
+	}
 
-          switch(l2tpv3_l2_specific){
-          case L2TPv3_L2_SPECIFIC_DEFAULT:
-          case L2TPv3_L2_SPECIFIC_ATM:
-                next_tvb = tvb_new_subset(tvb, index + l2tpv3_cookie + 4, -1, -1);
-                break;
-		case L2TPv3_L2_SPECIFIC_LAPD:
-				proto_tree_add_text(tree, tvb, index + l2tpv3_cookie + 4, 3,"LAPD info");
-				next_tvb = tvb_new_subset(tvb, index + l2tpv3_cookie+4+3, -1, -1);
-				break;
-          case L2TPv3_L2_SPECIFIC_NONE:
-          default:
-                next_tvb = tvb_new_subset(tvb, index + l2tpv3_cookie, -1, -1);
-                break;
-          }
-
-          switch(l2tpv3_protocol){
-          case L2TPv3_PROTOCOL_ETH:
-                call_dissector(eth_withoutfcs_handle, next_tvb, pinfo, tree);
-                break;
-          case L2TPv3_PROTOCOL_CHDLC:
-                call_dissector(chdlc_handle, next_tvb, pinfo, tree);
-                break;
-          case L2TPv3_PROTOCOL_FR:
-                call_dissector(fr_handle, next_tvb, pinfo, tree);
-                break;
-          case L2TPv3_PROTOCOL_PPP:
-                /*
-                 * PPP is transported without Address and Control
-                 * fields, ppp_hdlc_handle can handle that as if if
-                 * was ACFC (NULL Address and Control)
-                 */
-                call_dissector(ppp_hdlc_handle, next_tvb, pinfo, tree);
-                break;
-          case L2TPv3_PROTOCOL_IP:
-                call_dissector(ip_handle, next_tvb, pinfo, tree);
-                break;
-          case L2TPv3_PROTOCOL_MPLS:
-                call_dissector(mpls_handle, next_tvb, pinfo, tree);
-                break;
-          case L2TPv3_PROTOCOL_AAL5:
-                if (oam_cell) {
-                	/* XXX - the ATM dissector should offer an OAM cell dissector */
-                        call_dissector(data_handle, next_tvb, pinfo, tree);
-                } else {
-                        call_dissector(llc_handle, next_tvb, pinfo, tree);
-                }
-                break;
-		  case L2TPv3_PROTOCOL_LAPD:
-			  call_dissector(lapd_handle, next_tvb, pinfo, tree);
-			  break;
-          default:
-                call_dissector(data_handle, next_tvb, pinfo, tree);
-                break;
-          }
-
-	return;
+	switch(l2tpv3_protocol){
+	case L2TPv3_PROTOCOL_ETH:
+		call_dissector(eth_withoutfcs_handle, next_tvb, pinfo, tree);
+		break;
+	case L2TPv3_PROTOCOL_CHDLC:
+		call_dissector(chdlc_handle, next_tvb, pinfo, tree);
+		break;
+	case L2TPv3_PROTOCOL_FR:
+		call_dissector(fr_handle, next_tvb, pinfo, tree);
+		break;
+	case L2TPv3_PROTOCOL_PPP:
+		/*
+		 * PPP is transported without Address and Control
+		 * fields, ppp_hdlc_handle can handle that as if if
+		 * was ACFC (NULL Address and Control)
+		 */
+		call_dissector(ppp_hdlc_handle, next_tvb, pinfo, tree);
+		break;
+	case L2TPv3_PROTOCOL_IP:
+		call_dissector(ip_handle, next_tvb, pinfo, tree);
+		break;
+	case L2TPv3_PROTOCOL_MPLS:
+		call_dissector(mpls_handle, next_tvb, pinfo, tree);
+		break;
+	case L2TPv3_PROTOCOL_DOCSIS_DMPT:
+		call_dissector(mp2t_handle, next_tvb, pinfo, tree);
+		break;
+	case L2TPv3_PROTOCOL_AAL5:
+		if (oam_cell) {
+			call_dissector(atm_oam_handle, next_tvb, pinfo, tree);
+		} else {
+			call_dissector(llc_handle, next_tvb, pinfo, tree);
+		}
+		break;
+	case L2TPv3_PROTOCOL_LAPD:
+		call_dissector(lapd_handle, next_tvb, pinfo, tree);
+		break;
+	default:
+		call_dissector(data_handle, next_tvb, pinfo, tree);
+		break;
+	}
 }
 
 /*
@@ -1481,7 +1526,7 @@ process_l2tpv3_data_udp(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 	sid = tvb_get_ntohl(tvb, index);
 
 	if (tree) {
-        	l2tp_item = proto_tree_add_item(tree, proto_l2tp, tvb, 0, -1, FALSE);
+		l2tp_item = proto_tree_add_item(tree, proto_l2tp, tvb, 0, -1, FALSE);
 		l2tp_tree = proto_item_add_subtree(l2tp_item, ett_l2tp);
 		proto_item_append_text(l2tp_item, " version 3");
 
@@ -1500,8 +1545,6 @@ process_l2tpv3_data_udp(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 
 	/* Call process_l2tpv3_data from Session ID (offset in index of 4) */
 	process_l2tpv3_data(tvb, pinfo, tree, l2tp_tree, l2tp_item, &index);
-
-	return;
 }
 
 /*
@@ -1520,7 +1563,7 @@ process_l2tpv3_data_ip(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 	sid = tvb_get_ntohl(tvb, index);
 	
 	if (tree) {
-        	l2tp_item = proto_tree_add_item(tree, proto_l2tp, tvb, 0, -1, FALSE);
+		l2tp_item = proto_tree_add_item(tree, proto_l2tp, tvb, 0, -1, FALSE);
 		l2tp_tree = proto_item_add_subtree(l2tp_item, ett_l2tp);
 		proto_item_append_text(l2tp_item, " version 3");
 
@@ -1531,8 +1574,6 @@ process_l2tpv3_data_ip(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 
 	/* Call process_l2tpv3_data from Session ID (offset in index of 0) */
 	process_l2tpv3_data(tvb, pinfo, tree, l2tp_tree, l2tp_item, &index);
-
-	return;
 }
 
 /*
@@ -1618,7 +1659,7 @@ process_l2tpv3_control(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, int
 	}
 
 	if (tree) {
-        	l2tp_item = proto_tree_add_item(tree, proto_l2tp, tvb, 0, -1, FALSE);
+		l2tp_item = proto_tree_add_item(tree, proto_l2tp, tvb, 0, -1, FALSE);
 		l2tp_tree = proto_item_add_subtree(l2tp_item, ett_l2tp);
 		proto_item_append_text(l2tp_item, " version 3");
 
@@ -1668,8 +1709,6 @@ process_l2tpv3_control(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, int
 	}
 
 	process_control_avps(tvb, pinfo, l2tp_tree, index, length+baseIndex);
-
-	return;
 }
 
 /*
@@ -1714,8 +1753,7 @@ dissect_l2tp_udp(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 
 	if (check_col(pinfo->cinfo, COL_PROTOCOL))	/* build output for closed L2tp frame displayed  */
 		col_set_str(pinfo->cinfo, COL_PROTOCOL, "L2TP");
-	if (check_col(pinfo->cinfo, COL_INFO))
-		col_clear(pinfo->cinfo, COL_INFO);
+	col_clear(pinfo->cinfo, COL_INFO);
 
 	switch (L2TP_VERSION(control)) {
 
@@ -1723,8 +1761,7 @@ dissect_l2tp_udp(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 		break;
 
 	case 3:
-		if (check_col(pinfo->cinfo, COL_PROTOCOL))
-			col_set_str(pinfo->cinfo, COL_PROTOCOL, "L2TPv3");
+		col_set_str(pinfo->cinfo, COL_PROTOCOL, "L2TPv3");
 		if (CONTROL_BIT(control)) {
 			/* Call to process l2tp v3 control message */
 			process_l2tpv3_control(tvb, pinfo, tree, 0);
@@ -1876,7 +1913,7 @@ dissect_l2tp_udp(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 			proto_item_set_len(l2tp_item, index);
 		/* If we have data, signified by having a length bit, dissect it */
 		if (tvb_offset_exists(tvb, index)) {
-			next_tvb = tvb_new_subset(tvb, index, -1, -1);
+			next_tvb = tvb_new_subset_remaining(tvb, index);
 			call_dissector(ppp_hdlc_handle, next_tvb, pinfo, tree);
 		}
 		return tvb_length(tvb);
@@ -1904,8 +1941,7 @@ dissect_l2tp_ip(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 	if (check_col(pinfo->cinfo, COL_PROTOCOL))	/* Only L2TPv3 runs directly over IP */
 		col_set_str(pinfo->cinfo, COL_PROTOCOL, "L2TPv3");
 
-	if (check_col(pinfo->cinfo, COL_INFO))
-		col_clear(pinfo->cinfo, COL_INFO);
+	col_clear(pinfo->cinfo, COL_INFO);
 
 	sid = tvb_get_ntohl(tvb, index);
 	if (sid == 0) {
@@ -1940,7 +1976,7 @@ proto_register_l2tp(void)
 
 		{ &hf_l2tp_offset_bit,
 		{ "Offset bit", "l2tp.offset_bit", FT_BOOLEAN, 16, TFS(&l2tp_offset_bit_truth), 0x0200,
-			"Offset bit", HFILL }},
+			NULL, HFILL }},
 
 		{ &hf_l2tp_priority,
 		{ "Priority", "l2tp.priority", FT_BOOLEAN, 16, TFS(&l2tp_priority_truth), 0x0100,
@@ -1948,39 +1984,38 @@ proto_register_l2tp(void)
 
 		{ &hf_l2tp_version,
 		{ "Version", "l2tp.version", FT_UINT16, BASE_DEC, NULL, 0x000f,
-			"Version", HFILL }},
+			NULL, HFILL }},
 
 		{ &hf_l2tp_length,
 		{ "Length","l2tp.length", FT_UINT16, BASE_DEC, NULL, 0x0,
-			"", HFILL }},
+			NULL, HFILL }},
 
 		{ &hf_l2tp_tunnel,
 		{ "Tunnel ID","l2tp.tunnel", FT_UINT16, BASE_DEC, NULL, 0x0, /* Probably should be FT_BYTES */
-			"Tunnel ID", HFILL }},
+			NULL, HFILL }},
 
 		{ &hf_l2tp_session,
 		{ "Session ID","l2tp.session", FT_UINT16, BASE_DEC, NULL, 0x0, /* Probably should be FT_BYTES */
-			"Session ID", HFILL }},
+			NULL, HFILL }},
 
 		{ &hf_l2tp_Ns,
 		{ "Ns","l2tp.Ns", FT_UINT16, BASE_DEC, NULL, 0x0,
-			"", HFILL }},
+			NULL, HFILL }},
 
 		{ &hf_l2tp_Nr,
 		{ "Nr","l2tp.Nr", FT_UINT16, BASE_DEC, NULL, 0x0,
-			"", HFILL }},
+			NULL, HFILL }},
 
 		{ &hf_l2tp_offset,
 		{ "Offset","l2tp.offset", FT_UINT16, BASE_DEC, NULL, 0x0,
-			"Number of octest past the L2TP header at which the"
-				"payload data starts.", HFILL }},
+			"Number of octest past the L2TP header at which thepayload data starts.", HFILL }},
 
 		{ &hf_l2tp_avp_mandatory,
-		{ "Mandatory", "l2tp.avp.mandatory", FT_BOOLEAN, BASE_NONE, NULL, 0,
+		{ "Mandatory", "l2tp.avp.mandatory", FT_BOOLEAN, BASE_NONE, NULL, 0x0,
 			"Mandatory AVP", HFILL }},
 
 		{ &hf_l2tp_avp_hidden,
-		{ "Hidden", "l2tp.avp.hidden", FT_BOOLEAN, BASE_NONE, NULL, 0,
+		{ "Hidden", "l2tp.avp.hidden", FT_BOOLEAN, BASE_NONE, NULL, 0x0,
 			"Hidden AVP", HFILL }},
 
 		{ &hf_l2tp_avp_length,
@@ -1997,31 +2032,39 @@ proto_register_l2tp(void)
 
 		{ &hf_l2tp_tie_breaker,
 		{ "Tie Breaker", "l2tp.tie_breaker", FT_UINT64, BASE_HEX, NULL, 0,
-			"Tie Breaker", HFILL }},
+			NULL, HFILL }},
 
 		{ &hf_l2tp_sid,
 		{ "Session ID","l2tp.sid", FT_UINT32, BASE_DEC, NULL, 0x0,
-			"Session ID", HFILL }},
+			NULL, HFILL }},
 
 		{ &hf_l2tp_ccid,
 		{ "Control Connection ID","l2tp.ccid", FT_UINT32, BASE_DEC, NULL, 0x0,
-			"Control Connection ID", HFILL }},
+			NULL, HFILL }},
 
 		{ &hf_l2tp_res,
 		{ "Reserved","l2tp.res", FT_UINT16, BASE_HEX, NULL, 0x0,
-			"Reserved", HFILL }},
+			NULL, HFILL }},
 
 		{ &hf_l2tp_cookie,
-		{ "Cookie","lt2p.cookie", FT_BYTES, BASE_HEX, NULL, 0x0,
-			"Cookie", HFILL }},
+		{ "Cookie","lt2p.cookie", FT_BYTES, BASE_NONE, NULL, 0x0,
+			NULL, HFILL }},
 
 		{ &hf_l2tp_l2_spec_def,
 		{ "Default L2-Specific Sublayer","lt2p.l2_spec_def", FT_NONE, BASE_NONE, NULL, 0x0,
-			"Default L2-Specific Sublayer", HFILL }},
+			NULL, HFILL }},
 
 		{ &hf_l2tp_l2_spec_atm,
 		{ "ATM-Specific Sublayer","lt2p.l2_spec_atm", FT_NONE, BASE_NONE, NULL, 0x0,
-			"ATM-Specific Sublayer", HFILL }},
+			NULL, HFILL }},
+
+		{ &hf_l2tp_l2_spec_docsis_dmpt,
+		{ "DOCSIS DMPT - Specific Sublayer","lt2p.l2_spec_docsis_dmpt", FT_NONE, BASE_NONE, NULL, 0x0,
+			NULL, HFILL }},
+
+		{ &hf_l2tp_l2_spec_v,
+		{ "V-bit","lt2p.l2_spec_v", FT_BOOLEAN, 8, NULL, 0x80,
+			"VCCV Bit", HFILL }},
 
 		{ &hf_l2tp_l2_spec_s,
 		{ "S-bit","lt2p.l2_spec_s", FT_BOOLEAN, 8, NULL, 0x40,
@@ -2043,9 +2086,13 @@ proto_register_l2tp(void)
 		{ "U-bit","lt2p.l2_spec_u", FT_BOOLEAN, 8, NULL, 0x01,
 			"C/R Bit", HFILL }},
 
+		{ &hf_l2tp_l2_spec_flow_id,
+		{ "Flow ID","lt2p.l2_spec_flow_id", FT_UINT8, BASE_HEX, NULL, FLOW_ID_MASK,
+			NULL, HFILL }},
+
 		{ &hf_l2tp_l2_spec_sequence,
 		{ "Sequence Number","lt2p.l2_spec_sequence", FT_UINT24, BASE_DEC, NULL, 0x0,
-			"Sequence Number", HFILL }},
+			NULL, HFILL }},
 
 		{ &hf_l2tp_cisco_avp_type,
 		{ "Type", "l2tp.avp.ciscotype", FT_UINT16, BASE_DEC, VALS(cisco_avp_type_vals), 0,
@@ -2123,8 +2170,9 @@ proto_reg_handoff_l2tp(void)
 	fr_handle = find_dissector("fr");
 	ip_handle = find_dissector("ip");
 	mpls_handle = find_dissector("mpls");
+	atm_oam_handle = find_dissector("atm_oam_cell");
 	llc_handle = find_dissector("llc");
 	lapd_handle = find_dissector("lapd");
-
+	mp2t_handle = find_dissector("mp2t");
 	data_handle = find_dissector("data");
 }
