@@ -2,7 +2,7 @@
  * Routines for IEEE 802.2 LLC layer
  * Gilbert Ramirez <gram@alumni.rice.edu>
  *
- * $Id: packet-llc.c 28298 2009-05-08 06:53:43Z jake $
+ * $Id: packet-llc.c 30125 2009-09-24 20:00:21Z krj $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -88,6 +88,7 @@ static dissector_table_t dsap_subdissector_table;
 static dissector_table_t xid_subdissector_table;
 
 static dissector_table_t ethertype_subdissector_table;
+static dissector_table_t hpteam_subdissector_table;
 
 static dissector_handle_t bpdu_handle;
 static dissector_handle_t eth_withoutfcs_handle;
@@ -219,6 +220,7 @@ http://www.cisco.com/univercd/cc/td/doc/product/software/ios113ed/113ed_cr/ibm_r
 	{ OUI_SIEMENS,		"Siemens AG" },
 	{ OUI_APPLE_ATALK,	"Apple (AppleTalk)" },
 	{ OUI_HP,		"Hewlett-Packard" },
+	{ OUI_HP_2,		"Hewlett-Packard" },
 	{ 0,			NULL }
 };
 
@@ -305,7 +307,7 @@ capture_llc(const guchar *pd, int offset, int len, packet_counts *ld) {
 		return;
 	}
 	if (is_snap)
-		capture_snap(pd, offset+3, len, ld);
+		capture_snap(pd, offset+llc_header_len, len, ld);
 	else {
 		/* non-SNAP */
 		switch (pd[offset]) {
@@ -416,12 +418,8 @@ dissect_basicxid(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 	proto_item	*ti = NULL;
 	guint8		format, types, wsize;
 
-	if (check_col(pinfo->cinfo, COL_PROTOCOL)) {
-		col_set_str(pinfo->cinfo, COL_PROTOCOL, "XID");
-	}
-	if (check_col(pinfo->cinfo, COL_INFO)) {
-		col_clear(pinfo->cinfo, COL_INFO);
-	}
+	col_set_str(pinfo->cinfo, COL_PROTOCOL, "XID");
+	col_clear(pinfo->cinfo, COL_INFO);
 
 	format = tvb_get_guint8(tvb, 0);
 	if (tree) {
@@ -431,10 +429,8 @@ dissect_basicxid(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 			1, format);
 	} else
 		xid_tree = NULL;
-	if (check_col(pinfo->cinfo, COL_INFO)) {
-		col_append_str(pinfo->cinfo, COL_INFO,
+	col_append_str(pinfo->cinfo, COL_INFO,
 		    "Basic Format");
-	}
 
 	types = tvb_get_guint8(tvb, 1);
 	if (tree) {
@@ -468,12 +464,8 @@ dissect_llc(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 	guint8		dsap, ssap, format;
 	tvbuff_t	*next_tvb;
 
-	if (check_col(pinfo->cinfo, COL_PROTOCOL)) {
-		col_set_str(pinfo->cinfo, COL_PROTOCOL, "LLC");
-	}
-	if (check_col(pinfo->cinfo, COL_INFO)) {
-		col_clear(pinfo->cinfo, COL_INFO);
-	}
+	col_set_str(pinfo->cinfo, COL_PROTOCOL, "LLC");
+	col_clear(pinfo->cinfo, COL_INFO);
 
 	dsap = tvb_get_guint8(tvb, 0);
 	if (tree) {
@@ -516,7 +508,7 @@ dissect_llc(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 		proto_item_set_len(ti, llc_header_len);
 
 	if (is_snap) {
-		dissect_snap(tvb, 3, pinfo, tree, llc_tree, control,
+		dissect_snap(tvb, 2+XDLC_CONTROL_LEN(control, TRUE), pinfo, tree, llc_tree, control,
 		    hf_llc_oui, hf_llc_type, hf_llc_pid, 2);
 	}
 	else {
@@ -533,7 +525,7 @@ dissect_llc(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 		}
 
 		if (tvb_length_remaining(tvb, llc_header_len) > 0) {
-			next_tvb = tvb_new_subset(tvb, llc_header_len, -1, -1);
+			next_tvb = tvb_new_subset_remaining(tvb, llc_header_len);
 			if (XDLC_IS_INFORMATION(control)) {
 				/*
 				 * Non-SNAP I or UI frame.
@@ -607,6 +599,17 @@ dissect_snap(tvbuff_t *tvb, int offset, packet_info *pinfo, proto_tree *tree,
 
 	switch (oui) {
 
+	case OUI_HP_2:
+		oui_info = get_snap_oui_info(oui);
+		hf = *oui_info->field_info->p_id;
+		subdissector_table = oui_info->table;
+		proto_tree_add_uint(snap_tree, hf, tvb, offset+3, 2, etype);
+		next_tvb = tvb_new_subset_remaining(tvb, offset+5);
+
+		if(!dissector_try_port(hpteam_subdissector_table,etype, next_tvb, pinfo, tree))
+	 		call_dissector(data_handle, next_tvb, pinfo, tree);
+		break;
+
 	case OUI_ENCAP_ETHER:
 	case OUI_CISCO_90:
 	case OUI_APPLE_ATALK:
@@ -622,13 +625,13 @@ dissect_snap(tvbuff_t *tvb, int offset, packet_info *pinfo, proto_tree *tree,
 				proto_tree_add_uint(snap_tree, hf_type,
 				    tvb, offset+3, 2, etype);
 			}
-			next_tvb = tvb_new_subset(tvb, offset+5, -1, -1);
+			next_tvb = tvb_new_subset_remaining(tvb, offset+5);
 			if (!dissector_try_port(ethertype_subdissector_table,
 			    etype, next_tvb, pinfo, tree))
 				call_dissector(data_handle, next_tvb, pinfo,
 				    tree);
 		} else {
-			next_tvb = tvb_new_subset(tvb, offset+5, -1, -1);
+			next_tvb = tvb_new_subset_remaining(tvb, offset+5);
 			call_dissector(data_handle, next_tvb, pinfo, tree);
 		}
 		break;
@@ -652,15 +655,13 @@ dissect_snap(tvbuff_t *tvb, int offset, packet_info *pinfo, proto_tree *tree,
 		switch (etype) {
 
 		case BPID_ETH_WITH_FCS:
-			next_tvb = tvb_new_subset(tvb, offset+5+bridge_pad,
-			    -1, -1);
+			next_tvb = tvb_new_subset_remaining(tvb, offset+5+bridge_pad);
 			call_dissector(eth_withfcs_handle, next_tvb, pinfo,
 			    tree);
 			break;
 
 		case BPID_ETH_WITHOUT_FCS:
-			next_tvb = tvb_new_subset(tvb, offset+5+bridge_pad,
-			    -1, -1);
+			next_tvb = tvb_new_subset_remaining(tvb, offset+5+bridge_pad);
 			call_dissector(eth_withoutfcs_handle, next_tvb, pinfo, tree);
 			break;
 
@@ -672,25 +673,23 @@ dissect_snap(tvbuff_t *tvb, int offset, packet_info *pinfo, proto_tree *tree,
 			 * Ring dissector expects the first byte to
 			 * be.
 			 */
-			next_tvb = tvb_new_subset(tvb, offset+5+bridge_pad,
-			    -1, -1);
+			next_tvb = tvb_new_subset_remaining(tvb, offset+5+bridge_pad);
 			call_dissector(tr_handle, next_tvb, pinfo, tree);
 			break;
 
 		case BPID_FDDI_WITH_FCS:
 		case BPID_FDDI_WITHOUT_FCS:
-			next_tvb = tvb_new_subset(tvb, offset+5+1+bridge_pad,
-			    -1, -1);
+			next_tvb = tvb_new_subset_remaining(tvb, offset+5+1+bridge_pad);
 			call_dissector(fddi_handle, next_tvb, pinfo, tree);
 			break;
 
 		case BPID_BPDU:
-			next_tvb = tvb_new_subset(tvb, offset+5, -1, -1);
+			next_tvb = tvb_new_subset_remaining(tvb, offset+5);
 			call_dissector(bpdu_handle, next_tvb, pinfo, tree);
 			break;
 
 		default:
-			next_tvb = tvb_new_subset(tvb, offset+5, -1, -1);
+			next_tvb = tvb_new_subset_remaining(tvb, offset+5);
 			call_dissector(data_handle, next_tvb, pinfo, tree);
 			break;
 		}
@@ -701,12 +700,12 @@ dissect_snap(tvbuff_t *tvb, int offset, packet_info *pinfo, proto_tree *tree,
 			proto_tree_add_uint(snap_tree, hf_pid, tvb, offset+3, 2,
 			    etype);
 		}
-		next_tvb = tvb_new_subset(tvb, offset+5, -1, -1);
+		next_tvb = tvb_new_subset_remaining(tvb, offset+5);
 		call_dissector(bpdu_handle, next_tvb, pinfo, tree);
 		break;
 
 	case OUI_TURBOCELL:
-		next_tvb = tvb_new_subset(tvb, offset+3, -1, -1);
+		next_tvb = tvb_new_subset_remaining(tvb, offset+3);
 		call_dissector(turbo_handle, next_tvb, pinfo, tree);
 		break;
 
@@ -721,17 +720,16 @@ dissect_snap(tvbuff_t *tvb, int offset, packet_info *pinfo, proto_tree *tree,
 				proto_tree_add_uint(snap_tree, hf_type,
 				    tvb, offset+3, 2, etype);
 			}
-			next_tvb = tvb_new_subset(tvb, offset+5, -1, -1);
+			next_tvb = tvb_new_subset_remaining(tvb, offset+5);
 			mesh_header_len = call_dissector(mesh_handle,
 			    next_tvb, pinfo, tree);
-			next_tvb = tvb_new_subset(tvb, offset+5+mesh_header_len,
-			    -1, -1);
+			next_tvb = tvb_new_subset_remaining(tvb, offset+5+mesh_header_len);
 			if (!dissector_try_port(ethertype_subdissector_table,
 			    etype, next_tvb, pinfo, tree))
 				call_dissector(data_handle, next_tvb, pinfo,
 				    tree);
 		} else {
-			next_tvb = tvb_new_subset(tvb, offset+5, -1, -1);
+			next_tvb = tvb_new_subset_remaining(tvb, offset+5);
 			call_dissector(data_handle, next_tvb, pinfo, tree);
 		}
 		break;
@@ -759,7 +757,7 @@ dissect_snap(tvbuff_t *tvb, int offset, packet_info *pinfo, proto_tree *tree,
 			proto_tree_add_uint(snap_tree, hf, tvb, offset+3, 2,
 			    etype);
 		}
-		next_tvb = tvb_new_subset(tvb, offset+5, -1, -1);
+		next_tvb = tvb_new_subset_remaining(tvb, offset+5);
 		if (XDLC_IS_INFORMATION(control)) {
 			if (subdissector_table != NULL) {
 				/* do lookup with the subdissector table */
@@ -799,7 +797,7 @@ proto_register_llc(void)
 			VALS(sap_vals), 0x0, "DSAP - 7 Most Significant Bits only", HFILL }},
 
 		{ &hf_llc_dsap_ig,
-		{ "IG Bit",	"llc.dsap.ig", FT_BOOLEAN, 8,
+		{ "IG Bit",	"llc.dsap.ig", FT_BOOLEAN, BASE_NONE,
 			TFS(&ig_bit), 0x0, "Individual/Group - Least Significant Bit only", HFILL }},
 
 		{ &hf_llc_ssap,
@@ -807,7 +805,7 @@ proto_register_llc(void)
 			VALS(sap_vals), 0x0, "SSAP - 7 Most Significant Bits only", HFILL }},
 
 		{ &hf_llc_ssap_cr,
-		{ "CR Bit", "llc.ssap.cr", FT_BOOLEAN, 8,
+		{ "CR Bit", "llc.ssap.cr", FT_BOOLEAN, BASE_NONE,
 			TFS(&cr_bit), 0x0, "Command/Response - Least Significant Bit only", HFILL }},
 
 		{ &hf_llc_ctrl,
@@ -824,19 +822,19 @@ proto_register_llc(void)
 
 		{ &hf_llc_p,
 		{ "Poll", "llc.control.p", FT_BOOLEAN, 8,
-			TFS(&flags_set_truth), XDLC_P_F, NULL, HFILL }},
+			TFS(&tfs_set_notset), XDLC_P_F, NULL, HFILL }},
 
 		{ &hf_llc_p_ext,
 		{ "Poll", "llc.control.p", FT_BOOLEAN, 16,
-			TFS(&flags_set_truth), XDLC_P_F_EXT, NULL, HFILL }},
+			TFS(&tfs_set_notset), XDLC_P_F_EXT, NULL, HFILL }},
 
 		{ &hf_llc_f,
 		{ "Final", "llc.control.f", FT_BOOLEAN, 8,
-			TFS(&flags_set_truth), XDLC_P_F, NULL, HFILL }},
+			TFS(&tfs_set_notset), XDLC_P_F, NULL, HFILL }},
 
 		{ &hf_llc_f_ext,
 		{ "Final", "llc.control.f", FT_BOOLEAN, 16,
-			TFS(&flags_set_truth), XDLC_P_F_EXT, NULL, HFILL }},
+			TFS(&tfs_set_notset), XDLC_P_F_EXT, NULL, HFILL }},
 
 		{ &hf_llc_s_ftype,
 		{ "Supervisory frame type", "llc.control.s_ftype", FT_UINT16, BASE_HEX,
@@ -950,6 +948,7 @@ proto_reg_handoff_llc(void)
 	 * Get the Ethertype dissector table.
 	 */
 	ethertype_subdissector_table = find_dissector_table("ethertype");
+	hpteam_subdissector_table = find_dissector_table("llc.hpteam_pid");
 
 	llc_handle = find_dissector("llc");
 	dissector_add("wtap_encap", WTAP_ENCAP_ATM_RFC1483, llc_handle);
