@@ -1,8 +1,8 @@
 /* packet-llt.c
  * Routines for Veritas Low Latency Transport (LLT) dissection
- * Copyright 2006, Stephen Fisher <stephentfisher@yahoo.com>
+ * Copyright 2006, Stephen Fisher (see AUTHORS file)
  *
- * $Id: packet-llt.c 26128 2008-09-03 16:42:35Z wmeier $
+ * $Id: packet-llt.c 29340 2009-08-09 06:26:46Z krj $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -70,8 +70,7 @@ dissect_llt(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 	guint8 message_type;
 
 	/* Make entries in Protocol column and Info column on summary display */
-	if(check_col(pinfo->cinfo, COL_PROTOCOL))
-		col_set_str(pinfo->cinfo, COL_PROTOCOL, "LLT");
+	col_set_str(pinfo->cinfo, COL_PROTOCOL, "LLT");
 
 	message_type = tvb_get_guint8(tvb, 3);
 
@@ -138,7 +137,7 @@ proto_register_llt(void)
 	llt_module = prefs_register_protocol(proto_llt, proto_reg_handoff_llt);
 
 	/* Register our preferences */
-	prefs_register_uint_preference(llt_module, "alternate_ethertype", "Alternate ethertype value",
+	prefs_register_uint_preference(llt_module, "alternate_ethertype", "Alternate ethertype value (in hex)",
 				       "Dissect this ethertype as LLT traffic in addition to the default, 0xCAFE.",
 				       16, &preference_alternate_ethertype); /* A base-16 (hexadecimal) value */
 
@@ -150,7 +149,7 @@ proto_reg_handoff_llt(void)
 {
 	static gboolean initialized = FALSE;
 	static dissector_handle_t llt_handle;
-	static guint preference_alternate_ethertype_last = 0x0;
+	static guint preference_alternate_ethertype_last;
 
 	if (!initialized) {
 		llt_handle = create_dissector_handle(dissect_llt, proto_llt);
