@@ -5,7 +5,7 @@
  *
  *	http://stuff.mit.edu/people/jhawk/ctp.html
  *
- * $Id: packet-loop.c 23252 2007-10-23 05:50:00Z etxrab $
+ * $Id: packet-loop.c 29446 2009-08-16 12:36:22Z krj $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -65,10 +65,8 @@ dissect_loop(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
   gboolean    more_function;
   tvbuff_t    *next_tvb;
 
-  if (check_col(pinfo->cinfo, COL_PROTOCOL))
-    col_set_str(pinfo->cinfo, COL_PROTOCOL, "LOOP");
-  if (check_col(pinfo->cinfo, COL_INFO))
-    col_clear(pinfo->cinfo, COL_INFO);
+  col_set_str(pinfo->cinfo, COL_PROTOCOL, "LOOP");
+  col_clear(pinfo->cinfo, COL_INFO);
 
   if (tree) {
     ti = proto_tree_add_item(tree, proto_loop, tvb, offset, -1, FALSE);
@@ -123,7 +121,7 @@ dissect_loop(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 
   if (tvb_length_remaining(tvb, offset) > 0)
   {
-    next_tvb = tvb_new_subset(tvb, offset, -1, -1);
+    next_tvb = tvb_new_subset_remaining(tvb, offset);
     call_dissector(data_handle, next_tvb, pinfo, tree);
   }
 }
@@ -135,22 +133,22 @@ proto_register_loop(void)
     { &hf_loop_skipcount,
       { "skipCount",		"loop.skipcount",
 	FT_UINT16,	BASE_DEC,	NULL,	0x0,
-      	"", HFILL }},
+      	NULL, HFILL }},
 
     { &hf_loop_function,
       { "Function",		"loop.function",
 	FT_UINT16,	BASE_DEC,	VALS(function_vals),	0x0,
-      	"", HFILL }},
+      	NULL, HFILL }},
 
     { &hf_loop_receipt_number,
       { "Receipt number",	"loop.receipt_number",
 	FT_UINT16,	BASE_DEC,	NULL,	0x0,
-      	"", HFILL }},
+      	NULL, HFILL }},
 
     { &hf_loop_forwarding_address,
       { "Forwarding address",	"loop.forwarding_address",
 	FT_ETHER,	BASE_NONE,	NULL,	0x0,
-      	"", HFILL }},
+      	NULL, HFILL }},
   };
   static gint *ett[] = {
     &ett_loop,
