@@ -2,7 +2,7 @@
  * Routines for Pegasus LSC packet disassembly
  * Copyright 2006, Sean Sheedy <seansh@users.sourceforge.net>
  *
- * $Id: packet-lsc.c 26197 2008-09-15 16:36:06Z wmeier $
+ * $Id: packet-lsc.c 29344 2009-08-09 07:36:13Z krj $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -150,16 +150,13 @@ dissect_lsc_common(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
   guint expected_len;
 
   /* Protocol is LSC, packet summary is not yet known */
-  if (check_col(pinfo->cinfo, COL_PROTOCOL)) 
-    col_set_str(pinfo->cinfo, COL_PROTOCOL, "LSC");
-  if (check_col(pinfo->cinfo, COL_INFO))
-    col_clear(pinfo->cinfo, COL_INFO);
+  col_set_str(pinfo->cinfo, COL_PROTOCOL, "LSC");
+  col_clear(pinfo->cinfo, COL_INFO);
 
   /* Too little data? */
   if (tvb->length < LSC_MIN_LEN)
   {
-    if (check_col(pinfo->cinfo, COL_INFO))
-      col_set_str(pinfo->cinfo, COL_INFO, "[Too short]");
+    col_set_str(pinfo->cinfo, COL_INFO, "[Too short]");
     return;
   }
 
@@ -364,7 +361,7 @@ proto_register_lsc(void)
     { &hf_lsc_trans_id,
       { "Transaction ID", "lsc.trans_id",
         FT_UINT8, BASE_DEC, NULL, 0,          
-        "Transaction ID", HFILL }
+        NULL, HFILL }
     },
     { &hf_lsc_op_code,
       { "Op Code", "lsc.op_code",
@@ -374,7 +371,7 @@ proto_register_lsc(void)
     { &hf_lsc_status_code,
       { "Status Code", "lsc.status_code",
         FT_UINT8, BASE_HEX, VALS(status_code_vals), 0,          
-        "Status Code", HFILL }
+        NULL, HFILL }
     },
     { &hf_lsc_stream_handle,
       { "Stream Handle", "lsc.stream_handle",
@@ -399,12 +396,12 @@ proto_register_lsc(void)
     { &hf_lsc_scale_num,
       { "Scale Numerator", "lsc.scale_num",
         FT_INT16, BASE_DEC, NULL, 0,          
-        "Scale Numerator", HFILL }
+        NULL, HFILL }
     },
     { &hf_lsc_scale_denom,
       { "Scale Denominator", "lsc.scale_denum",
         FT_UINT16, BASE_DEC, NULL, 0,          
-        "Scale Denominator", HFILL }
+        NULL, HFILL }
     },
     { &hf_lsc_mode,
       { "Server Mode", "lsc.mode",
