@@ -2,7 +2,7 @@
  *
  * Routines for RFC 2250 MPEG2 (ISO/IEC 13818-1) Transport Stream dissection
  *
- * $Id: packet-mp2t.c 27486 2009-02-19 09:23:34Z guy $
+ * $Id: packet-mp2t.c 30857 2009-11-07 19:41:58Z jake $
  *
  * Copyright 2006, Erwin Rol <erwin@erwinrol.com>
  *
@@ -41,17 +41,22 @@
 #include <epan/emem.h>
 #include <epan/conversation.h>
 #include <epan/expert.h>
+#include <epan/reassemble.h>
 
 /* The MPEG2 TS packet size */
 #define MP2T_PACKET_SIZE 188
 #define MP2T_SYNC_BYTE 0x47
 
 static dissector_handle_t pes_handle;
+static dissector_handle_t docsis_handle;
+static dissector_handle_t data_handle;
 
 static int proto_mp2t = -1;
 static gint ett_mp2t = -1;
 static gint ett_mp2t_header = -1;
 static gint ett_mp2t_af = -1;
+static gint ett_mp2t_analysis = -1;
+static gint ett_dmpt = -1; 
 
 static int hf_mp2t_header = -1;
 static int hf_mp2t_sync_byte = -1;
@@ -64,6 +69,10 @@ static int hf_mp2t_afc = -1;
 static int hf_mp2t_cc = -1;
 static int hf_mp2t_cc_drop = -1;
 
+static int hf_mp2t_analysis_flags = -1;
+static int hf_mp2t_analysis_skips = -1;
+static int hf_mp2t_analysis_drops = -1;
+
 #define MP2T_SYNC_BYTE_MASK	0xFF000000
 #define MP2T_TEI_MASK		0x00800000
 #define MP2T_PUSI_MASK		0x00400000
@@ -149,12 +158,12 @@ static int hf_mp2t_af_e_m_3 = -1;
 static int hf_mp2t_payload = -1;
 static int hf_mp2t_malformed_payload = -1;
 
+
 static const value_string mp2t_sync_byte_vals[] = {
 	{ MP2T_SYNC_BYTE, "Correct" },
 	{ 0, NULL }
 };
 
-
 static const value_string mp2t_pid_vals[] = {
 	{ 0x0000, "Program Association Table" },
 	{ 0x0001, "Conditional Access Table" },
@@ -172,6 +181,7 @@ static const value_string mp2t_pid_vals[] = {
 	{ 0x000D, "Reserved" },
 	{ 0x000E, "Reserved" },
 	{ 0x000F, "Reserved" },
+	{ 0x1FFE, "DOCSIS Data-over-cable well-known PID" },
 	{ 0x1FFF, "Null packet" },
 	{ 0, NULL }
 };
@@ -192,27 +202,283 @@ static const value_string mp2t_afc_vals[] = {
 	{ 0, NULL }
 };
 
+static gint ett_depi_msg_fragment = -1;
+static gint ett_depi_msg_fragments = -1;
+static int hf_depi_msg_fragments = -1;
+static int hf_depi_msg_fragment = -1;
+static int hf_depi_msg_fragment_overlap = -1;
+static int hf_depi_msg_fragment_overlap_conflicts = -1;
+static int hf_depi_msg_fragment_multiple_tails = -1;
+static int hf_depi_msg_fragment_too_long_fragment = -1;
+static int hf_depi_msg_fragment_error = -1;
+static int hf_depi_msg_reassembled_in = -1;
+
+static const fragment_items depi_msg_frag_items = {
+    /* Fragment subtrees */
+    &ett_depi_msg_fragment,
+    &ett_depi_msg_fragments,
+    /* Fragment fields */
+    &hf_depi_msg_fragments,
+    &hf_depi_msg_fragment,
+    &hf_depi_msg_fragment_overlap,
+    &hf_depi_msg_fragment_overlap_conflicts,
+    &hf_depi_msg_fragment_multiple_tails,
+    &hf_depi_msg_fragment_too_long_fragment,
+    &hf_depi_msg_fragment_error,
+    /* Reassembled in field */
+    &hf_depi_msg_reassembled_in,
+    /* Tag */
+    "Message fragments"
+};
+
+/* Structures to handle DOCSIS-DEPI packets, spanned across
+ * multiple MPEG packets
+ */
+static GHashTable *mp2t_depi_fragment_table = NULL;
+static GHashTable *mp2t_depi_reassembled_table = NULL;
+
+/*****************   DOCSIS defragmentation support *******************/
+/* definitions of DOCSIS payload type - from plugins/docsis/packet-docsis.c  */
+#define DOCSIS_FC_TYPE_DATA         0x00
+#define DOCSIS_FC_TYPE_ATM          0x01
+#define DOCSIS_FC_TYPE_RESERVED     0x02
+#define DOCSIS_FC_TYPE_MAC          0x03
+
+static guint16
+get_docsis_packet_length(tvbuff_t * tvb, gint offset)
+{
+    guint16 len;
+    guint8  fc;
+    guint8  fctype;
+
+    /* Extract FC_TYPE and FC_PARM */
+    fc = tvb_get_guint8 (tvb, offset);  /* Frame Control Byte */
+    fctype = (fc >> 6) & 0x03;  /* Frame Control Type: 2 MSB Bits */
+
+    if((fctype == DOCSIS_FC_TYPE_ATM) ||
+       (fctype == DOCSIS_FC_TYPE_RESERVED)) {
+        /* add text - this FC type is not supported */
+        return 0;
+    }
+
+    /* The only case when this field is used for SID is for
+     * request frames, but they are in upstream direction.
+     */
+    len = tvb_get_ntohs(tvb, offset + 2)  +  6;
+
+    return (len);
+}
+
+static void
+mp2t_depi_docsis_fragmentation_handle(tvbuff_t *tvb, guint offset,
+					 packet_info *pinfo, proto_tree *tree,
+					 guint frag_offset, guint frag_len,
+					 gboolean fragment_last)
+{
+    fragment_data *frag_msg = NULL;
+    tvbuff_t *new_tvb = NULL;
+    tvbuff_t *next_tvb = NULL;
+    proto_item *ti;
+    proto_tree *dmpt_tree;
+
+    pinfo->fragmented = TRUE;
+
+    /* check length; send frame for reassembly */
+    frag_msg = fragment_add_check(tvb, offset, pinfo,
+                   0, mp2t_depi_fragment_table,
+                   mp2t_depi_reassembled_table,
+                   frag_offset,
+                   frag_len,
+                   !fragment_last);
+
+    new_tvb = process_reassembled_data(tvb, offset, pinfo,
+                  "Reassembled Message",
+                  frag_msg, &depi_msg_frag_items,
+                  NULL, tree);
+
+    if (frag_msg) { /* Reassembled */
+        col_append_str(pinfo->cinfo, COL_INFO, " (Message Reassembled)");
+    } else { /* Not last packet of reassembled Short Message */
+        col_append_fstr(pinfo->cinfo, COL_INFO," (Message fragment %u)", 0);
+    }
+
+    /* put DOCSIS handler here */
+    if (new_tvb) { /* take it all */
+        next_tvb = new_tvb;
+
+        ti = proto_tree_add_text(tree, tvb, offset, 0, "DOCSIS MAC Frame (reassembled)");
+        dmpt_tree = proto_item_add_subtree(ti, ett_dmpt);
+
+        if (docsis_handle)
+            call_dissector(docsis_handle, next_tvb, pinfo, dmpt_tree);
+        else
+            call_dissector(data_handle, next_tvb, pinfo, dmpt_tree);
+    } else { /* make a new subset */
+        next_tvb = tvb_new_subset(tvb, offset, -1, -1);
+    }
+
+    return;
+}
+
+/*  Decoding of DOCSIS MAC frames within MPEG packets. MAC frames may begin anywhere
+ *  within an MPEG packet or span multiple MPEG packets.
+ *  payload_unit_start_indicator bit in MPEG header, and pointer field are used to
+ *  decode fragmented DOCSIS frames within MPEG packet.
+ *-------------------------------------------------------------------------------
+ *MPEG Header | pointer_field | stuff_bytes | Start of MAC Frame #1              |
+ *(PUSI = 1)  | (= 0)         | (0 or more) |(up to 183 bytes)                   |
+ *-------------------------------------------------------------------------------
+ *-------------------------------------------------------------------------------
+ *MPEG Header |  Continuation of MAC Frame #1                                    |
+ *(PUSI = 0)  |  (up to 183 bytes)                                               |
+ *-------------------------------------------------------------------------------
+ *-------------------------------------------------------------------------------
+ *MPEG Header | pointer_field |Tail of MAC Frame| stuff_bytes |Start of MAC Frame|
+ *(PUSI = 1)  | (= M)         | #1  (M bytes)   | (0 or more) |# 2 (N bytes)     |
+ *-------------------------------------------------------------------------------
+ *  Source - Data-Over-Cable Service Interface Specifications
+ *  CM-SP-DRFI-I07-081209
+ */
+static void
+mp2t_depi_docsis_process_payload(tvbuff_t *tvb, gint offset, packet_info *pinfo,
+                                 proto_tree *tree, proto_tree *header_tree)
+{
+    guint32  pusi_flag;
+    tvbuff_t *next_tvb;
+    guint8   pointer;
+    proto_item *ti;
+    proto_tree *dmpt_tree;
+    static gboolean fragmentation = FALSE;
+    static guint32 mac_frame_len, cumulative_len;
+
+    pusi_flag = (tvb_get_ntohl(tvb, offset) & 0x00400000);
+
+    offset += 4;
+
+    if (pusi_flag) {
+        pointer = tvb_get_guint8(tvb, offset);
+        proto_tree_add_text(header_tree, tvb, offset, 1,
+            "Pointer: %u", tvb_get_guint8(tvb, offset));
+        offset += 1;
+    }
+
+    /* get tail of MAC frame */
+    if (pusi_flag && fragmentation) {
+        fragmentation = FALSE;
+
+        /* check length; send frame for reassembly */
+        mp2t_depi_docsis_fragmentation_handle(tvb, offset, pinfo,
+            tree,
+            cumulative_len,
+            pointer,
+            TRUE);
+        cumulative_len += pointer;
+
+        if (cumulative_len != mac_frame_len) {
+            proto_tree_add_text(tree, tvb, offset, mac_frame_len,
+                "Invalid cumulative length %u",
+                cumulative_len);
+            return;
+        }
+    }
+
+    /* Get start of MAC frame or get complete frame */
+    if (pusi_flag && !fragmentation) {
+        guint16 remaining_length;
+
+        remaining_length = 183 - pointer;
+        offset += pointer;
+
+        while (remaining_length > 0) {
+            while ((tvb_get_guint8(tvb, offset) == 0xFF)) {
+                remaining_length--;
+                if (remaining_length == 0)
+                    return;
+                offset += 1;
+            }
+
+            /* Here, we start DOCSIS frame */
+            mac_frame_len = get_docsis_packet_length(tvb, offset);
+            cumulative_len = 0;
+
+            if (!mac_frame_len) {
+                proto_tree_add_text(tree, tvb, offset, mac_frame_len,
+                    "Invalid DOCSIS length %u", mac_frame_len);
+                return;
+            }
+
+            if (mac_frame_len <= remaining_length) {
+                fragmentation = FALSE;
+                /* send for processing */
+                ti = proto_tree_add_text(tree, tvb, offset,
+                    mac_frame_len,
+                    "DOCSIS MAC Frame: %u bytes", mac_frame_len);
+                dmpt_tree = proto_item_add_subtree(ti, ett_dmpt);
+                next_tvb = tvb_new_subset(tvb, offset, -1, -1);
+                call_dissector(docsis_handle, next_tvb, pinfo, dmpt_tree);
+
+                offset += mac_frame_len;
+                remaining_length -= mac_frame_len;
+            } else {
+                fragmentation = TRUE;
+
+                mp2t_depi_docsis_fragmentation_handle(tvb, offset, pinfo,
+                    tree, 0, remaining_length, FALSE);
+                cumulative_len = remaining_length;
+                return;
+            }
+        }
+    }
+
+    /* if PUSI flag == 0 - check fragmentation flag */
+    if (!pusi_flag) {
+        gboolean last_fragment = FALSE;
+
+        if (fragmentation == FALSE) {
+            /* Error - fragmentation should be TRUE */
+            proto_tree_add_text(tree, tvb, offset, mac_frame_len,
+                "Error - PUSI is 0 in unfragmented DOCSIS packet");
+            return;
+        }
+
+        /* If packet length is consistent with MAC frame length -
+         * call function to handle all fragments
+         */
+        if ((cumulative_len + 184) == mac_frame_len) {
+            last_fragment = TRUE;
+            fragmentation = FALSE;
+        }
+
+        mp2t_depi_docsis_fragmentation_handle(tvb, offset, pinfo,
+            tree, cumulative_len, 184, last_fragment);
+        cumulative_len += 184;
+
+        return;
+    }
+}
+
+
 /* Data structure used for detecting CC drops
  *
  *  conversation
  *    |
  *    +-> mp2t_analysis_data
  *          |
- *          +-> pid_table (RB tree)
+ *          +-> pid_table (RB tree) (key: pid)
  *          |     |
  *          |     +-> pid_analysis_data (per pid)
  *          |     +-> pid_analysis_data
  *          |     +-> pid_analysis_data
  *          |
- *          +-> frame_table (RB tree)
+ *          +-> frame_table (RB tree) (key: pinfo->fd->num)
  *                |
  *                +-> frame_analysis_data (only created if drop detected)
  *                      |
  *                      +-> ts_table (RB tree)
  *                            |
- *                            +-> pid_analysis_data (per TS subframe)
- *                            +-> pid_analysis_data
- *                            +-> pid_analysis_data
+ *                            +-> ts_analysis_data (per TS subframe)
+ *                            +-> ts_analysis_data
+ *                            +-> ts_analysis_data
  */
 
 typedef struct mp2t_analysis_data {
@@ -232,15 +498,26 @@ typedef struct mp2t_analysis_data {
 	 */
 	emem_tree_t	*frame_table;
 
-	guint32 cc_drops;	/* Number of detected CC losses per conv */
+	/* Total counters per conversation / multicast stream */
+	guint32 total_skips;
+	guint32 total_discontinuity;
 
 } mp2t_analysis_data_t;
 
+/* Analysis TS frame info needed during sequential processing */
 typedef struct pid_analysis_data {
 	guint16 pid;
-	gint16  cc_prev;  	/* Previous CC number */
+	gint8   cc_prev;  	/* Previous CC number */
 } pid_analysis_data_t;
 
+/* Analysis info stored for a TS frame */
+typedef struct ts_analysis_data {
+	guint16 pid;
+	gint8   cc_prev;  	/* Previous CC number */
+	guint8  skips;          /* Skips between CCs max 14 */
+} ts_analysis_data_t;
+
+
 typedef struct frame_analysis_data {
 
 	/* As each frame has several pid's, thus need a pid data
@@ -250,7 +527,7 @@ typedef struct frame_analysis_data {
 
 } frame_analysis_data_t;
 
-conversation_t *
+static conversation_t *
 get_the_conversation(packet_info *pinfo)
 {
 	conversation_t *conv = NULL;
@@ -267,8 +544,8 @@ get_the_conversation(packet_info *pinfo)
 	return conv;
 }
 
-mp2t_analysis_data_t *
-init_mp2t_conversation_data()
+static mp2t_analysis_data_t *
+init_mp2t_conversation_data(void)
 {
 	mp2t_analysis_data_t *mp2t_data = NULL;
 
@@ -280,12 +557,14 @@ init_mp2t_conversation_data()
 	mp2t_data->frame_table =
 		se_tree_create_non_persistent(EMEM_TREE_TYPE_RED_BLACK,
 					      "mp2t_frame_table");
-	mp2t_data->cc_drops = 0;
+
+	mp2t_data->total_skips = 0;
+	mp2t_data->total_discontinuity = 0;
 
 	return mp2t_data;
 }
 
-mp2t_analysis_data_t *
+static mp2t_analysis_data_t *
 get_mp2t_conversation_data(conversation_t *conv)
 {
 	mp2t_analysis_data_t *mp2t_data = NULL;
@@ -299,7 +578,7 @@ get_mp2t_conversation_data(conversation_t *conv)
 	return mp2t_data;
 }
 
-frame_analysis_data_t *
+static frame_analysis_data_t *
 init_frame_analysis_data(mp2t_analysis_data_t *mp2t_data, packet_info *pinfo)
 {
 	frame_analysis_data_t *frame_data = NULL;
@@ -316,7 +595,7 @@ init_frame_analysis_data(mp2t_analysis_data_t *mp2t_data, packet_info *pinfo)
 }
 
 
-frame_analysis_data_t *
+static frame_analysis_data_t *
 get_frame_analysis_data(mp2t_analysis_data_t *mp2t_data, packet_info *pinfo)
 {
 	frame_analysis_data_t *frame_data = NULL;
@@ -324,7 +603,7 @@ get_frame_analysis_data(mp2t_analysis_data_t *mp2t_data, packet_info *pinfo)
 	return frame_data;
 }
 
-pid_analysis_data_t *
+static pid_analysis_data_t *
 get_pid_analysis(guint32 pid, conversation_t *conv)
 {
 
@@ -343,20 +622,47 @@ get_pid_analysis(guint32 pid, conversation_t *conv)
 	return pid_data;
 }
 
+/* Calc the number of skipped CC numbers. Note that this can easy
+ * overflow, and a value above 7 indicate several network packets
+ * could be lost.
+ */
+static guint32
+calc_skips(gint32 curr, gint32 prev)
+{
+	int res = 0;
+
+	/* Only count the missing TS frames in between prev and curr.
+	 * The "prev" frame CC number seen is confirmed received, its
+	 * the next frames CC counter which is the first known missing
+	 * TS frame
+	 */
+	prev += 1;
+
+	/* Calc missing TS frame 'skips' */
+	res = curr - prev;
+
+	/* Handle wrap around */
+	if (res < 0)
+		res += 16;
+
+	return res;
+}
+
 #define KEY(pid, cc) ((pid << 4)|cc)
 
-void
+static guint32
 detect_cc_drops(tvbuff_t *tvb, proto_tree *tree, packet_info *pinfo,
 		guint32 pid, gint32 cc_curr, conversation_t *conv)
 {
-	gint32 cc_prev;
+	gint32 cc_prev = -1;
 	pid_analysis_data_t   *pid_data   = NULL;
-	pid_analysis_data_t   *ts_data    = NULL;
+	ts_analysis_data_t    *ts_data    = NULL;
 	mp2t_analysis_data_t  *mp2t_data  = NULL;
 	frame_analysis_data_t *frame_data = NULL;
 	proto_item            *flags_item;
 
 	guint32 detected_drop = 0;
+	guint32 skips = 0;
 
 	mp2t_data = get_mp2t_conversation_data(conv);
 
@@ -371,20 +677,25 @@ detect_cc_drops(tvbuff_t *tvb, proto_tree *tree, packet_info *pinfo,
 
 		/* Null packet always have a CC value equal 0 */
 		if (pid == 0x1fff)
-			return;
+			return 0;
 
 		/* Its allowed that (cc_prev == cc_curr) if adaptation field */
 		if (cc_prev == cc_curr)
-			return;
+			return 0;
 
 		/* Have not seen this pid before */
 		if (cc_prev == -1)
-			return;
+			return 0;
 
 		/* Detect if CC is not increasing by one all the time */
 		if (cc_curr != ((cc_prev+1) & MP2T_CC_MASK)) {
 			detected_drop = 1;
-			mp2t_data->cc_drops++;
+
+			skips = calc_skips(cc_curr, cc_prev);
+
+			mp2t_data->total_skips += skips;
+			mp2t_data->total_discontinuity++;
+			/* TODO: if (skips > 7) signal_loss++; ??? */
 		}
 	}
 
@@ -399,9 +710,10 @@ detect_cc_drops(tvbuff_t *tvb, proto_tree *tree, packet_info *pinfo,
 		/* Create and store a new TS frame pid_data object.
 		   This indicate that we have a drop
 		 */
-		ts_data = se_alloc0(sizeof(struct pid_analysis_data));
+		ts_data = se_alloc0(sizeof(struct ts_analysis_data));
 		ts_data->cc_prev = cc_prev;
 		ts_data->pid = pid;
+		ts_data->skips = skips;
 		se_tree_insert32(frame_data->ts_table, KEY(pid, cc_curr),
 				 (void *)ts_data);
 	}
@@ -412,12 +724,18 @@ detect_cc_drops(tvbuff_t *tvb, proto_tree *tree, packet_info *pinfo,
 		/* Lookup frame data, contains TS pid data objects */
 		frame_data = get_frame_analysis_data(mp2t_data, pinfo);
 		if (!frame_data)
-			return; /* No stored frame data -> no drops*/
+			return 0; /* No stored frame data -> no drops*/
 		else {
 			ts_data = se_tree_lookup32(frame_data->ts_table,
 						   KEY(pid, cc_curr));
-			if (ts_data)
-				detected_drop = 1;
+
+			if (ts_data) {
+				if (ts_data->skips > 0) {
+					detected_drop = 1;
+					cc_prev = ts_data->cc_prev;
+					skips   = ts_data->skips;
+				}
+			}
 		}
 
 	}
@@ -428,16 +746,27 @@ detect_cc_drops(tvbuff_t *tvb, proto_tree *tree, packet_info *pinfo,
 		flags_item =
 			proto_tree_add_none_format(
 				tree, hf_mp2t_cc_drop, tvb, 0, 0,
-				"Detected missing CC frame before this"
-				" (accumulated CC loss count:%d)",
-				mp2t_data->cc_drops
+				"Detected %d missing TS frames before this"
+				" (last_cc:%d total skips:%d discontinuity:%d)",
+				skips, cc_prev,
+				mp2t_data->total_skips,
+				mp2t_data->total_discontinuity
 				);
 
 		PROTO_ITEM_SET_GENERATED(flags_item);
 		expert_add_info_format(pinfo, flags_item, PI_MALFORMED,
-				       PI_ERROR, "Detected CC loss");
+				       PI_ERROR, "Detected TS frame loss");
+
+		flags_item = proto_tree_add_uint(tree, hf_mp2t_analysis_skips,
+					       tvb, 0, 0, skips);
+		PROTO_ITEM_SET_GENERATED(flags_item);
+
+		flags_item = proto_tree_add_uint(tree, hf_mp2t_analysis_drops,
+					       tvb, 0, 0, 1);
+		PROTO_ITEM_SET_GENERATED(flags_item);
 
 	}
+	return skips;
 }
 
 
@@ -448,28 +777,29 @@ dissect_tsp(tvbuff_t *tvb, volatile gint offset, packet_info *pinfo,
 	guint32 header;
 	guint afc;
 	gint start_offset = offset;
-	gint payload_len;
+	volatile gint payload_len;
 
+	guint32 skips;
 	guint32 pid;
 	guint32 cc;
 
 	proto_item *ti = NULL;
 	proto_item *hi = NULL;
+	proto_item *item = NULL;
 	proto_tree *mp2t_tree = NULL;
 	proto_tree *mp2t_header_tree = NULL;
 	proto_tree *mp2t_af_tree = NULL;
+	proto_tree *mp2t_analysis_tree = NULL;
 
 	ti = proto_tree_add_item( tree, proto_mp2t, tvb, offset, MP2T_PACKET_SIZE, FALSE );
 	mp2t_tree = proto_item_add_subtree( ti, ett_mp2t );
-	
+
 	header = tvb_get_ntohl(tvb, offset);
 
 	pid = (header & MP2T_PID_MASK) >> MP2T_PID_SHIFT;
 	cc  = (header & MP2T_CC_MASK)  >> MP2T_CC_SHIFT;
 	proto_item_append_text(ti, " PID=0x%x CC=%d", pid, cc);
 
-	detect_cc_drops(tvb, tree, pinfo, pid, cc, conv);
-
 	hi = proto_tree_add_item( mp2t_tree, hf_mp2t_header, tvb, offset, 4, FALSE);
 	mp2t_header_tree = proto_item_add_subtree( hi, ett_mp2t_header );
 
@@ -481,8 +811,24 @@ dissect_tsp(tvbuff_t *tvb, volatile gint offset, packet_info *pinfo,
 	proto_tree_add_item( mp2t_header_tree, hf_mp2t_tsc, tvb, offset, 4, FALSE);
 	proto_tree_add_item( mp2t_header_tree, hf_mp2t_afc, tvb, offset, 4, FALSE);
 	proto_tree_add_item( mp2t_header_tree, hf_mp2t_cc, tvb, offset, 4, FALSE);
+
+	/* If this is a DOCSIS packet - reassemble MPEG frames and call DOCSIS dissector */
+	if (((header & MP2T_PID_MASK) >> MP2T_PID_SHIFT) == 0x1FFE) {
+		mp2t_depi_docsis_process_payload(tvb, offset, pinfo, tree, mp2t_tree);
+	}
+
 	offset += 4;
 
+	/* Create a subtree for analysis stuff */
+	item = proto_tree_add_text(mp2t_tree, tvb, 0, 0, "MPEG2 PCR Analysis");
+	PROTO_ITEM_SET_GENERATED(item);
+	mp2t_analysis_tree = proto_item_add_subtree(item, ett_mp2t_analysis);
+
+	skips = detect_cc_drops(tvb, mp2t_analysis_tree, pinfo, pid, cc, conv);
+	if (skips > 0)
+		proto_item_append_text(ti, " skips=%d", skips);
+
+
 	afc = (header & MP2T_AFC_MASK) >> MP2T_AFC_SHIFT;
 
 	if (afc == 2 || afc == 3) 
@@ -782,11 +1128,26 @@ proto_register_mp2t(void)
 		} } ,
 		{ &hf_mp2t_cc_drop, {
 			"Continuity Counter Drops", "mp2t.cc.drop",
-			FT_NONE, BASE_DEC, NULL, 0x0, NULL, HFILL
+			FT_NONE, BASE_NONE, NULL, 0x0, NULL, HFILL
+		} } ,
+		{ &hf_mp2t_analysis_flags, {
+			"MPEG2-TS Analysis Flags", "mp2t.analysis.flags",
+			FT_NONE, BASE_NONE, NULL, 0x0,
+			"This frame has some of the MPEG2 analysis flags set", HFILL
+		} } ,
+		{ &hf_mp2t_analysis_skips, {
+			"TS Continuity Counter Skips", "mp2t.analysis.skips",
+			FT_UINT8, BASE_DEC, NULL, 0x0,
+			"Missing TS frames accoding to CC counter values", HFILL
+		} } ,
+		{ &hf_mp2t_analysis_drops, {
+			"Some frames dropped", "mp2t.analysis.drops",
+			FT_UINT8, BASE_DEC, NULL, 0x0,
+			"Discontinuity: A number of TS frames were dropped", HFILL
 		} } ,
 		{ &hf_mp2t_af, {
 			"Adaption field", "mp2t.af",
-			FT_NONE, BASE_HEX, NULL, 0, NULL, HFILL
+			FT_NONE, BASE_NONE, NULL, 0, NULL, HFILL
 		} } ,
 		{ &hf_mp2t_af_length, {
 			"Adaptation Field Length", "mp2t.af.length",
@@ -826,11 +1187,11 @@ proto_register_mp2t(void)
 		} } ,
 		{ &hf_mp2t_af_pcr, {
 			"Program Clock Reference", "mp2t.af.pcr",
-			FT_NONE, BASE_DEC, NULL, 0, NULL, HFILL
+			FT_NONE, BASE_NONE, NULL, 0, NULL, HFILL
 		} } ,
 		{ &hf_mp2t_af_opcr, {
 			"Original Program Clock Reference", "mp2t.af.opcr",
-			FT_NONE, BASE_DEC, NULL, 0, NULL, HFILL
+			FT_NONE, BASE_NONE, NULL, 0, NULL, HFILL
 		} } ,
 		{ &hf_mp2t_af_sc, {
 			"Splice Countdown", "mp2t.af.sc",
@@ -842,7 +1203,7 @@ proto_register_mp2t(void)
 		} } ,
 		{ &hf_mp2t_af_tpd, {
 			"Transport Private Data", "mp2t.af.tpd",
-			FT_BYTES, BASE_DEC, NULL, 0, NULL, HFILL
+			FT_BYTES, BASE_NONE, NULL, 0, NULL, HFILL
 		} } ,
 		{ &hf_mp2t_af_e_length, {
 			"Adaptation Field Extension Length", "mp2t.af.e_length",
@@ -866,11 +1227,11 @@ proto_register_mp2t(void)
 		} } ,
 		{ &hf_mp2t_af_e_reserved_bytes, {
 			"Reserved", "mp2t.af.e.reserved_bytes",
-			FT_BYTES, BASE_DEC, NULL, 0x0, NULL, HFILL
+			FT_BYTES, BASE_NONE, NULL, 0x0, NULL, HFILL
 		} } ,
 		{ &hf_mp2t_af_stuffing_bytes, {
 			"Stuffing", "mp2t.af.stuffing_bytes",
-			FT_BYTES, BASE_DEC, NULL, 0x0, NULL, HFILL
+			FT_BYTES, BASE_NONE, NULL, 0x0, NULL, HFILL
 		} } ,
 		{ &hf_mp2t_af_e_ltwv_flag, {
 			"LTW Valid Flag", "mp2t.af.e.ltwv_flag",
@@ -918,24 +1279,66 @@ proto_register_mp2t(void)
 		} } ,
 		{ &hf_mp2t_payload, {
 			"Payload", "mp2t.payload",
-			FT_BYTES, BASE_DEC, NULL, 0x0, NULL, HFILL
+			FT_BYTES, BASE_NONE, NULL, 0x0, NULL, HFILL
 		} } ,
 		{ &hf_mp2t_malformed_payload, {
 			"Malformed Payload", "mp2t.malformed_payload",
-			FT_BYTES, BASE_DEC, NULL, 0x0, NULL, HFILL
+			FT_BYTES, BASE_NONE, NULL, 0x0, NULL, HFILL
+		} },
+		{  &hf_depi_msg_fragments, {
+			"Message fragments", "mp2t.depi_msg.fragments",
+			FT_NONE, BASE_NONE, NULL, 0x00, NULL, HFILL
+		} },
+		{  &hf_depi_msg_fragment, {
+			"Message fragment", "mp2t.depi_msg.fragment",
+			FT_FRAMENUM, BASE_NONE, NULL, 0x00, NULL, HFILL
+		} },
+		{  &hf_depi_msg_fragment_overlap, {
+			"Message fragment overlap", "mp2t.depi_msg.fragment.overlap",
+			FT_BOOLEAN, BASE_NONE, NULL, 0x00, NULL, HFILL
+		} },
+		{  &hf_depi_msg_fragment_overlap_conflicts, {
+			"Message fragment overlapping with conflicting data",
+			"mp2t.depi_msg.fragment.overlap.conflicts",
+			FT_BOOLEAN, BASE_NONE, NULL, 0x00, NULL, HFILL
+		} },
+		{  &hf_depi_msg_fragment_multiple_tails, {
+			"Message has multiple tail fragments",
+			"mp2t.depi_msg.fragment.multiple_tails",
+			FT_BOOLEAN, BASE_NONE, NULL, 0x00, NULL, HFILL
+		} },
+		{  &hf_depi_msg_fragment_too_long_fragment, {
+			"Message fragment too long", "mp2t.depi_msg.fragment.too_long_fragment",
+			FT_BOOLEAN, BASE_NONE, NULL, 0x00, NULL, HFILL
+		} },
+		{  &hf_depi_msg_fragment_error, {
+			"Message defragmentation error", "mp2t.depi_msg.fragment.error",
+			FT_FRAMENUM, BASE_NONE, NULL, 0x00, NULL, HFILL
+		} },
+		{  &hf_depi_msg_reassembled_in, {
+			"Reassembled in", "mp2t.depi_msg.reassembled.in",
+			FT_FRAMENUM, BASE_NONE, NULL, 0x00, NULL, HFILL
 		} }
 	};
-
+	
 	static gint *ett[] =
 	{
 		&ett_mp2t,
 		&ett_mp2t_header,
-		&ett_mp2t_af
+		&ett_mp2t_af,
+		&ett_mp2t_analysis,
+		&ett_dmpt,
+		&ett_depi_msg_fragment,
+		&ett_depi_msg_fragments
 	};
 
 	proto_mp2t = proto_register_protocol("ISO/IEC 13818-1", "MP2T", "mp2t");
+	register_dissector("mp2t", dissect_mp2t, proto_mp2t);
 	proto_register_field_array(proto_mp2t, hf, array_length(hf));
 	proto_register_subtree_array(ett, array_length(ett));
+	/* Register processing of fragmented DEPI packets */
+	fragment_table_init(&mp2t_depi_fragment_table);
+	reassembled_table_init(&mp2t_depi_reassembled_table);
 }
 
 
@@ -952,5 +1355,7 @@ proto_reg_handoff_mp2t(void)
 	dissector_add_handle("udp.port", mp2t_handle);  /* for decode-as */
 
 	pes_handle = find_dissector("mpeg-pes");
+	docsis_handle = find_dissector("docsis");
+	data_handle = find_dissector("data");
 }
 
