@@ -4,7 +4,7 @@
  *
  * Copyright 2001, Heikki Vatiainen <hessu@cs.tut.fi>
  *
- * $Id: packet-msdp.c 26091 2008-08-26 01:28:50Z wmeier $
+ * $Id: packet-msdp.c 30900 2009-11-09 15:16:12Z stig $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -182,8 +182,7 @@ dissect_msdp(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
         proto_tree *msdp_tree;
         int offset;
 
-        if (check_col(pinfo->cinfo, COL_PROTOCOL))
-                col_set_str(pinfo->cinfo, COL_PROTOCOL, "MSDP");
+        col_set_str(pinfo->cinfo, COL_PROTOCOL, "MSDP");
 
         if (check_col(pinfo->cinfo, COL_INFO))
                 col_add_str(pinfo->cinfo, COL_INFO, val_to_str(tvb_get_guint8(tvb, 0),
@@ -256,7 +255,6 @@ static void dissect_msdp_sa(tvbuff_t *tvb, packet_info *pinfo,
 
         if (length < 4) {
                	*offset += length;
-                length = 0;
                 return;
         }
         proto_tree_add_item(tree, hf_msdp_sa_rp_addr, tvb, *offset, 4, FALSE);
@@ -272,7 +270,6 @@ static void dissect_msdp_sa(tvbuff_t *tvb, packet_info *pinfo,
 
                 if (length < 12) {
                 	*offset += length;
-                        length = 0;
                         return;
                 }
                 ei = proto_tree_add_text(tree, tvb, *offset, 12, "(S,G) block: %s/%u -> %s",
@@ -444,7 +441,7 @@ static void dissect_msdp_notification(tvbuff_t *tvb, packet_info *pinfo, proto_t
                  * message with Error Code set to Notification to be
                  * sent back.
                  */
-                next_tvb = tvb_new_subset(tvb, *offset, -1, -1);
+                next_tvb = tvb_new_subset_remaining(tvb, *offset);
                 dissect_msdp(next_tvb, pinfo, tree);
                 break;
         case FSM_ERROR:
@@ -485,7 +482,7 @@ proto_register_msdp(void)
                 },
                 { &hf_msdp_sa_rp_addr,
                         { "RP Address",           "msdp.sa.rp_addr",
-                        FT_IPv4, 0, NULL, 0,
+                        FT_IPv4, BASE_NONE, NULL, 0,
                         "Active source's RP address", HFILL }
                 },
                 { &hf_msdp_sa_reserved,
@@ -500,12 +497,12 @@ proto_register_msdp(void)
                 },
                 { &hf_msdp_sa_group_addr,
                         { "Group Address",           "msdp.sa.group_addr",
-                        FT_IPv4, 0, NULL, 0,
+                        FT_IPv4, BASE_NONE, NULL, 0,
                         "The group address the active source has sent data to", HFILL }
                 },
                 { &hf_msdp_sa_src_addr,
                         { "Source Address",           "msdp.sa.src_addr",
-                        FT_IPv4, 0, NULL, 0,
+                        FT_IPv4, BASE_NONE, NULL, 0,
                         "The IP address of the active source", HFILL }
                 },
                 { &hf_msdp_sa_req_res,
@@ -515,7 +512,7 @@ proto_register_msdp(void)
                 },
                 { &hf_msdp_sa_req_group,
                         { "Group Address",           "msdp.sa_req.group_addr",
-                        FT_IPv4, 0, NULL, 0,
+                        FT_IPv4, BASE_NONE, NULL, 0,
                         "The group address the MSDP peer is requesting", HFILL }
                 },
                 { &hf_msdp_not_o,
@@ -535,7 +532,7 @@ proto_register_msdp(void)
                 },
                 { &hf_msdp_not_ipv4,
                         { "IPv4 address",           "msdp.not.ipv4",
-                        FT_IPv4, 0, NULL, 0,
+                        FT_IPv4, BASE_NONE, NULL, 0,
                         "Group/RP/Source address in Notification messages", HFILL }
                 },
                 { &hf_msdp_not_res,
