@@ -2,7 +2,7 @@
  * Routines for MSN Messenger Service packet dissection
  * Copyright 2003, Chris Waters <chris@waters.co.nz>
  *
- * $Id: packet-msn-messenger.c 23252 2007-10-23 05:50:00Z etxrab $
+ * $Id: packet-msn-messenger.c 29340 2009-08-09 06:26:46Z krj $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -62,8 +62,6 @@ static int proto_msnms = -1;
 
 static gint ett_msnms = -1;
 
-static dissector_handle_t data_handle;
-
 #define TCP_PORT_MSNMS			1863
 
 static void
@@ -78,8 +76,7 @@ dissect_msnms(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 	/* int		tokenlen; */
 	/* const guchar	*next_token; */
 
-	if (check_col(pinfo->cinfo, COL_PROTOCOL))
-		col_set_str(pinfo->cinfo, COL_PROTOCOL, "MSNMS");
+	col_set_str(pinfo->cinfo, COL_PROTOCOL, "MSNMS");
 
 	/*
 	 * Find the end of the first line.
@@ -145,7 +142,6 @@ proto_reg_handoff_msnms(void)
 
   msnms_handle = create_dissector_handle(dissect_msnms, proto_msnms);
   dissector_add("tcp.port", TCP_PORT_MSNMS, msnms_handle);
-  data_handle = find_dissector("data");
   /*
    * For MSN Messenger Protocol over HTTP
    */
