@@ -1,7 +1,7 @@
 /* packet-ositp.c
  * Routines for ISO/OSI transport protocol packet disassembly
  *
- * $Id: packet-ositp.c 27822 2009-03-22 20:55:31Z wmeier $
+ * $Id: packet-ositp.c 30127 2009-09-24 20:21:23Z krj $
  * Laurent Deniel <laurent.deniel@free.fr>
  * Ralf Schneider <Ralf.Schneider@t-online.de>
  *
@@ -282,7 +282,7 @@ const enum_val_t tsap_display_options[] = {
 static void cotp_frame_end(void)
 {
   if (!cotp_last_fragment) {
-    /* Last COTP in frame is not fragmentet.  
+    /* Last COTP in frame is not fragmented.  
      * No need for incrementing the dst_ref, so we decrement it here.
      */
     cotp_dst_ref--;
@@ -396,7 +396,6 @@ static gboolean ositp_decode_var_part(tvbuff_t *tvb, int offset,
 		"Residual error rate, TSDU size of interest: %u",
 		1<<tvb_get_guint8(tvb, offset));
       offset += 1;
-      length -= 1;
       vp_length -= 1;
 
       break;
@@ -435,7 +434,6 @@ static gboolean ositp_decode_var_part(tvbuff_t *tvb, int offset,
       proto_tree_add_text(tree, tvb, offset, 2,
 		"Transit delay, maximum acceptable, called-calling: %u ms", s4);
       offset += 2;
-      length -= 2;
       vp_length -= 2;
       break;
 
@@ -494,7 +492,6 @@ static gboolean ositp_decode_var_part(tvbuff_t *tvb, int offset,
 	proto_tree_add_text(tree, tvb, offset, 3,
 		"Average throughput, minimum acceptable, called-calling: %u o/s", t4);
 	offset += 3;
-	length -= 3;
 	vp_length -= 3;
       }
       break;
@@ -529,7 +526,6 @@ static gboolean ositp_decode_var_part(tvbuff_t *tvb, int offset,
       proto_tree_add_text(tree, tvb, offset, 2,
 		"Credit: 0x%04x", tvb_get_ntohs(tvb, offset));
       offset += 2;
-      length -= 2;
       vp_length -= 2;
 
       break;
@@ -757,7 +753,7 @@ static int ositp_decode_DR(tvbuff_t *tvb, int offset, guint8 li, guint8 tpdu,
 	  "Disconnect Request(DR): 0x%x -> 0x%x", src_ref, dst_ref);
 
   /* User data */
-  call_dissector(data_handle, tvb_new_subset(tvb, offset, -1, -1), pinfo, tree);
+  call_dissector(data_handle, tvb_new_subset_remaining(tvb, offset), pinfo, tree);
   offset += tvb_length_remaining(tvb, offset);
      /* we dissected all of the containing PDU */
 
@@ -915,7 +911,7 @@ static int ositp_decode_DT(tvbuff_t *tvb, int offset, guint8 li, guint8 tpdu,
     ositp_decode_var_part(tvb, offset, li, 4, cotp_tree);
   offset += li;
 
-  next_tvb = tvb_new_subset(tvb, offset, -1, -1);
+  next_tvb = tvb_new_subset_remaining(tvb, offset);
   fragment_length = tvb_length(next_tvb);
   if (check_col(pinfo->cinfo, COL_INFO)) {
       if(fragment) {
@@ -1093,7 +1089,7 @@ static int ositp_decode_ED(tvbuff_t *tvb, int offset, guint8 li, guint8 tpdu,
     ositp_decode_var_part(tvb, offset, li, 4, cotp_tree);
   offset += li;
 
-  next_tvb = tvb_new_subset(tvb, offset, -1, -1);
+  next_tvb = tvb_new_subset_remaining(tvb, offset);
   call_dissector(data_handle,next_tvb, pinfo, tree);
 
   offset += tvb_length_remaining(tvb, offset);
@@ -1236,7 +1232,7 @@ static int ositp_decode_CC(tvbuff_t *tvb, int offset, guint8 li, guint8 tpdu,
     ositp_decode_var_part(tvb, offset, li, class_option, cotp_tree);
   offset += li;
 
-  next_tvb = tvb_new_subset(tvb, offset, -1, -1);
+  next_tvb = tvb_new_subset_remaining(tvb, offset);
   if (!uses_inactive_subset){
     if (dissector_try_heuristic(cotp_heur_subdissector_list, next_tvb,
 				pinfo, tree)) {
@@ -1565,8 +1561,7 @@ static int ositp_decode_UD(tvbuff_t *tvb, int offset, guint8 li, guint8 tpdu,
   proto_tree *cltp_tree = NULL;
   tvbuff_t   *next_tvb;
 
-  if (check_col(pinfo->cinfo, COL_INFO))
-    col_append_str(pinfo->cinfo, COL_INFO, "UD TPDU");
+  col_append_str(pinfo->cinfo, COL_INFO, "UD TPDU");
 
   if (tree) {
     ti = proto_tree_add_item(tree, proto_cltp, tvb, offset, li + 1, FALSE);
@@ -1585,7 +1580,7 @@ static int ositp_decode_UD(tvbuff_t *tvb, int offset, guint8 li, guint8 tpdu,
     ositp_decode_var_part(tvb, offset, li, 0, cltp_tree);
   offset += li;
 
-  next_tvb = tvb_new_subset(tvb, offset, -1, -1);
+  next_tvb = tvb_new_subset_remaining(tvb, offset);
   call_dissector(data_handle,next_tvb, pinfo, tree);
   offset += tvb_length_remaining(tvb, offset);
      /* we dissected all of the containing PDU */
@@ -1626,15 +1621,13 @@ static gint dissect_ositp_internal(tvbuff_t *tvb, packet_info *pinfo,
 
   while (tvb_offset_exists(tvb, offset)) {
     if (!first_tpdu) {
-      if (check_col(pinfo->cinfo, COL_INFO))
-        col_append_str(pinfo->cinfo, COL_INFO, ", ");
+      col_append_str(pinfo->cinfo, COL_INFO, ", ");
 	  expert_add_info_format(pinfo, NULL, PI_SEQUENCE, PI_NOTE, "Multiple TPDUs in one packet");
     }
     if ((li = tvb_get_guint8(tvb, offset + P_LI)) == 0) {
-      if (check_col(pinfo->cinfo, COL_INFO))
-        col_append_str(pinfo->cinfo, COL_INFO, "Length indicator is zero");
+      col_append_str(pinfo->cinfo, COL_INFO, "Length indicator is zero");
       if (!first_tpdu)
-        call_dissector(data_handle, tvb_new_subset(tvb, offset, -1, -1),
+        call_dissector(data_handle, tvb_new_subset_remaining(tvb, offset),
                        pinfo, tree);
       return found_ositp;
     }
@@ -1688,7 +1681,7 @@ static gint dissect_ositp_internal(tvbuff_t *tvb, packet_info *pinfo,
 
     if (new_offset == -1) { /* incorrect TPDU */
       if (!first_tpdu)
-        call_dissector(data_handle, tvb_new_subset(tvb, offset, -1, -1),
+        call_dissector(data_handle, tvb_new_subset_remaining(tvb, offset),
                        pinfo, tree);
       break;
     }
@@ -1751,16 +1744,16 @@ void proto_register_cotp(void)
         "No explicit flow control in class 2", HFILL}},
     { &hf_cotp_tpdu_number,
       { "TPDU number", "cotp.tpdu-number", FT_UINT8, BASE_HEX, NULL, 0x7f,
-        "TPDU number", HFILL}},
+        NULL, HFILL}},
     { &hf_cotp_tpdu_number_extended,
       { "TPDU number", "cotp.tpdu-number", FT_UINT32, BASE_HEX, NULL, 0x0 /* XXX - 0x7fff? */,
-        "TPDU number", HFILL}},
+        NULL, HFILL}},
     { &hf_cotp_next_tpdu_number,
       { "Your TPDU number", "cotp.next-tpdu-number", FT_UINT8, BASE_HEX, NULL, 0x0,
-        "Your TPDU number", HFILL}},
+        NULL, HFILL}},
     { &hf_cotp_next_tpdu_number_extended,
       { "Your TPDU number", "cotp.next-tpdu-number", FT_UINT32, BASE_HEX, NULL, 0x0,
-        "Your TPDU number", HFILL}},
+        NULL, HFILL}},
     { &hf_cotp_eot,
       { "Last data unit", "cotp.eot", FT_BOOLEAN, 8, TFS(&fragment_descriptions),  0x80,
         "Is current TPDU the last data unit of a complete DT TPDU sequence (End of TSDU)?", HFILL}},
@@ -1784,10 +1777,10 @@ void proto_register_cotp(void)
 	"Reassembly error due to illegal segments", HFILL }},
     { &hf_cotp_segment,
       { "COTP Segment", "cotp.segment", FT_FRAMENUM, BASE_NONE, NULL, 0x0,
-	"COTP Segment", HFILL }},
+	NULL, HFILL }},
     { &hf_cotp_segments,
-      { "COTP Segments", "cotp.segments", FT_NONE, BASE_DEC, NULL, 0x0,
-	"COTP Segments", HFILL }},
+      { "COTP Segments", "cotp.segments", FT_NONE, BASE_NONE, NULL, 0x0,
+	NULL, HFILL }},
     { &hf_cotp_reassembled_in,
       { "Reassembled COTP in frame", "cotp.reassembled_in", FT_FRAMENUM, BASE_NONE, NULL, 0x0,
 	"This COTP packet is reassembled in this frame", HFILL }},
@@ -1857,7 +1850,7 @@ void proto_register_cltp(void)
         "Length Indicator, length of this header", HFILL}},
     { &hf_cltp_type,
       { "PDU Type", "cltp.type", FT_UINT8, BASE_HEX, VALS(cltp_tpdu_type_abbrev_vals), 0x0,
-        "PDU Type", HFILL}},
+        NULL, HFILL}},
   };
   static gint *ett[] = {
 	&ett_cltp,
