@@ -3,7 +3,7 @@
  * Original Author Mark C. Brown <mbrown@hp.com>
  * Copyright (C) 2004 Hewlett-Packard Development Company, L.P.
  *
- * $Id: packet-pagp.c 27065 2008-12-20 00:09:02Z wmeier $
+ * $Id: packet-pagp.c 29747 2009-09-06 14:25:47Z krj $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -148,11 +148,6 @@ static const value_string tlv_types[] = {
 	{ 0, NULL }
 };
 
-static const true_false_string yesno = {
-	"Yes",
-	"No"
-};
-
 static const true_false_string automode = {
 	"Yes",
 	"Desirable Mode"
@@ -204,9 +199,7 @@ dissect_pagp(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 	    col_set_str(pinfo->cinfo, COL_PROTOCOL, "PAGP"); /* PAGP Protocol */
       }
 
-      if (check_col(pinfo->cinfo, COL_INFO)) {
-	    col_clear(pinfo->cinfo, COL_INFO);
-      }
+      col_clear(pinfo->cinfo, COL_INFO);
 
       pinfo->current_proto = "PAGP";
 
@@ -217,7 +210,7 @@ dissect_pagp(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 	    pagp_tree = proto_item_add_subtree(pagp_item, ett_pagp);
 	    proto_tree_add_uint(pagp_tree, hf_pagp_version_number, tvb,
 				PAGP_VERSION_NUMBER, 1, raw_octet);
-      } 
+      }
       if (check_col(pinfo->cinfo, COL_INFO)) {
          col_append_str(pinfo->cinfo, COL_INFO,
   	       val_to_str(raw_octet, pdu_vers, "Unknown PDU version"));
@@ -228,7 +221,7 @@ dissect_pagp(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
          device_id.data = tvb_get_ptr(tvb, PAGP_FLUSH_LOCAL_DEVICE_ID, 6);
          if (check_col(pinfo->cinfo, COL_INFO)) {
             col_append_fstr(pinfo->cinfo, COL_INFO, "; Local DevID: %s",
-               address_to_str(&device_id));
+               ep_address_to_str(&device_id));
          }
          if (tree) {
 	       proto_tree_add_ether(pagp_tree, hf_pagp_flush_local_device_id, tvb,
@@ -238,7 +231,7 @@ dissect_pagp(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
          device_id.data = tvb_get_ptr(tvb, PAGP_FLUSH_PARTNER_DEVICE_ID, 6);
          if (check_col(pinfo->cinfo, COL_INFO)) {
             col_append_fstr(pinfo->cinfo, COL_INFO, ", Partner DevID: %s",
-               address_to_str(&device_id));
+               ep_address_to_str(&device_id));
          }
          if (tree) {
 	    proto_tree_add_ether(pagp_tree, hf_pagp_flush_partner_device_id, tvb,
@@ -294,7 +287,7 @@ dissect_pagp(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
       device_id.data = tvb_get_ptr(tvb, PAGP_LOCAL_DEVICE_ID, 6);
       if (check_col(pinfo->cinfo, COL_INFO)) {
          col_append_fstr(pinfo->cinfo, COL_INFO, "; Local DevID: %s",
-            address_to_str(&device_id));
+            ep_address_to_str(&device_id));
       }
       if (tree) {
 	    proto_tree_add_ether(pagp_tree, hf_pagp_local_device_id, tvb,
@@ -326,7 +319,7 @@ dissect_pagp(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
       device_id.data = tvb_get_ptr(tvb, PAGP_PARTNER_DEVICE_ID, 6);
       if (check_col(pinfo->cinfo, COL_INFO)) {
          col_append_fstr(pinfo->cinfo, COL_INFO, ", Partner DevID: %s",
-  	       address_to_str(&device_id));
+  	       ep_address_to_str(&device_id));
       }
       if (tree) {
 	    proto_tree_add_ether(pagp_tree, hf_pagp_partner_device_id, tvb,
@@ -376,7 +369,7 @@ dissect_pagp(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 
 		tlv_item = proto_tree_add_text (pagp_tree, tvb, offset, len,
 			   "TLV Entry #%d", i);
-                                                                                
+
 		tlv_tree = proto_item_add_subtree (tlv_item, ett_pagp_tlvs);
 		proto_tree_add_uint_format (tlv_tree, hf_pagp_tlv, tvb,
 			offset,2,tlv,"Type = %d (%s)", tlv,
@@ -388,7 +381,7 @@ dissect_pagp(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 			               "TLV length too large");
 		   return;
 		}
-                                                                                
+
 		switch (tlv) {
 		   case PAGP_TLV_DEVICE_NAME:
 			ch = tvb_get_ephemeral_string(tvb, offset+4, len-4);
@@ -437,7 +430,7 @@ proto_register_pagp(void)
 
     { &hf_pagp_flags_slow_hello,
       { "Slow Hello",		"pagp.flags.slowhello",
-	FT_BOOLEAN,	8,	TFS(&yesno),	PAGP_FLAGS_SLOW_HELLO,
+	FT_BOOLEAN,	8,	TFS(&tfs_yes_no), PAGP_FLAGS_SLOW_HELLO,
       	"1 = using Slow Hello, 0 = Slow Hello disabled", HFILL }},
 
     { &hf_pagp_flags_auto_mode,
