@@ -2,7 +2,7 @@
  * Routines for PIM disassembly
  * (c) Copyright Jun-ichiro itojun Hagino <itojun@itojun.org>
  *
- * $Id: packet-pim.c 28052 2009-04-14 18:31:02Z wmeier $
+ * $Id: packet-pim.c 31022 2009-11-19 20:19:12Z dimeg $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -50,6 +50,7 @@ static int hf_pim_version = -1;
 static int hf_pim_type = -1;
 static int hf_pim_code = -1;
 static int hf_pim_cksum = -1;
+static int hf_pim_res_bytes = -1;
 
 static gint ett_pim = -1;
 
@@ -114,19 +115,15 @@ dissect_pimv1(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree,
 	return offset+tvb_length_remaining(tvb, offset);
     }
 
-    if (check_col(pinfo->cinfo, COL_PROTOCOL))
-        col_set_str(pinfo->cinfo, COL_PROTOCOL, "PIMv1");
-    if (check_col(pinfo->cinfo, COL_INFO))
-	col_clear(pinfo->cinfo, COL_INFO);
+    col_set_str(pinfo->cinfo, COL_PROTOCOL, "PIMv1");
+    col_clear(pinfo->cinfo, COL_INFO);
 
-    if (tree) {
 	ti = proto_tree_add_item(tree, proto_pim, tvb, offset, -1, FALSE);
 	pim_tree = proto_item_add_subtree(ti, ett_pim);
 
 	/* Put IGMP type, 0x14, into the tree */
 	proto_tree_add_text(pim_tree, tvb, offset, 1,
 	    "Type: PIM (0x14)");
-    }
     offset += 1;
 
     pim_type = tvb_get_guint8(tvb, offset);
@@ -134,9 +131,7 @@ dissect_pimv1(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree,
 	col_add_str(pinfo->cinfo, COL_INFO,
 	    val_to_str(pim_type, type1vals, "Unknown (%u)"));
 
-    if (tree) {
 	proto_tree_add_uint(pim_tree, hf_pim_code, tvb, offset, 1, pim_type);
-    }
     offset += 1;
 
     pim_cksum = tvb_get_ntohs(tvb, offset);
@@ -145,13 +140,11 @@ dissect_pimv1(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree,
 	/*
 	 * Not PIMv1 - what gives?
 	 */
-    	if (tree) {
 	    proto_tree_add_uint(pim_tree, hf_pim_cksum, tvb,
 		    offset, 2, pim_cksum);
-	}
+
 	offset += 2;
-    	if (tree)
-	    proto_tree_add_uint(pim_tree, hf_pim_version, tvb, offset, 1, pim_ver);
+    proto_tree_add_item(pim_tree, hf_pim_version, tvb, offset, 1, FALSE);
 	return offset+tvb_length_remaining(tvb, offset);
     }
 
@@ -177,7 +170,6 @@ dissect_pimv1(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree,
 	pim_length = tvb_reported_length(tvb);
     }
 
-    if (tree) {
 	if (!pinfo->fragmented && length >= pim_length) {
 	    /*
 	     * The packet isn't part of a fragmented datagram and isn't
@@ -201,16 +193,13 @@ dissect_pimv1(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree,
 	    proto_tree_add_uint(pim_tree, hf_pim_cksum, tvb,
 		    offset, 2, pim_cksum);
         }
-    }
     offset += 2;
 
-    if (tree)
-	proto_tree_add_uint(pim_tree, hf_pim_version, tvb, offset, 1, pim_ver);
+	proto_tree_add_item(pim_tree, hf_pim_version, tvb, offset, 1, FALSE);
     offset += 1;
 
     offset += 3;	/* skip reserved stuff */
 
-    if (tree) {
 	if (tvb_reported_length_remaining(tvb, offset) > 0) {
 	    tiopt = proto_tree_add_text(pim_tree, tvb, offset, -1,
 		    "PIM parameters");
@@ -252,7 +241,7 @@ dissect_pimv1(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree,
 	    /*
 	     * The rest of the packet is a multicast data packet.
 	     */
-	    next_tvb = tvb_new_subset(tvb, offset, -1, -1);
+	    next_tvb = tvb_new_subset_remaining(tvb, offset);
 
 	    /*
 	     * It's an IP packet - determine whether it's IPv4 or IPv6.
@@ -471,7 +460,6 @@ dissect_pimv1(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree,
 	default:
 	    break;
 	}
-    }
 done:;
 
     return offset+tvb_length_remaining(tvb, offset);
@@ -610,10 +598,8 @@ dissect_pim(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree) {
     proto_tree *pimopt_tree = NULL;
     proto_item *tiopt;
 
-    if (check_col(pinfo->cinfo, COL_PROTOCOL))
-        col_set_str(pinfo->cinfo, COL_PROTOCOL, "PIM");
-    if (check_col(pinfo->cinfo, COL_INFO))
-	col_clear(pinfo->cinfo, COL_INFO);
+    col_set_str(pinfo->cinfo, COL_PROTOCOL, "PIM");
+    col_clear(pinfo->cinfo, COL_INFO);
 
     pim_typever = tvb_get_guint8(tvb, 0);
 
@@ -634,15 +620,12 @@ dissect_pim(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree) {
     if (check_col(pinfo->cinfo, COL_INFO))
 	col_add_str(pinfo->cinfo, COL_INFO, typestr);
 
-    if (tree) {
 	ti = proto_tree_add_item(tree, proto_pim, tvb, offset, -1, FALSE);
 	pim_tree = proto_item_add_subtree(ti, ett_pim);
 
-	proto_tree_add_uint(pim_tree, hf_pim_version, tvb, offset, 1,
-	    PIM_VER(pim_typever));
-	proto_tree_add_uint(pim_tree, hf_pim_type, tvb, offset, 1,
-	    PIM_TYPE(pim_typever));
-
+	proto_tree_add_item(pim_tree, hf_pim_version, tvb, offset, 1, FALSE);
+	proto_tree_add_item(pim_tree, hf_pim_type, tvb, offset, 1, FALSE);
+	proto_tree_add_item(pim_tree, hf_pim_res_bytes, tvb, offset + 1, 1, FALSE);
 	pim_cksum = tvb_get_ntohs(tvb, offset + 2);
 	length = tvb_length(tvb);
 	if (PIM_VER(pim_typever) == 2) {
@@ -860,7 +843,7 @@ dissect_pim(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree) {
 	    /*
 	     * The rest of the packet is a multicast data packet.
 	     */
-	    next_tvb = tvb_new_subset(tvb, offset, -1, -1);
+	    next_tvb = tvb_new_subset_remaining(tvb, offset);
 
 	    /*
 	     * It's an IP packet - determine whether it's IPv4 or IPv6.
@@ -951,15 +934,12 @@ dissect_pim(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree) {
 	    proto_tree *subtree = NULL;
 	    proto_item *tisub;
 
-	    if (PIM_TYPE(pim_typever) != 7) {
-		/* not graft-ack */
 		s = dissect_pim_addr(tvb, offset, pimv2_unicast, &advance);
 		if (s == NULL)
 		    break;
 		proto_tree_add_text(pimopt_tree, tvb, offset, advance,
 		    "Upstream-neighbor: %s", s);
 		offset += advance;
-	    }
 
 	    offset += 1;	/* skip reserved field */
 
@@ -968,13 +948,11 @@ dissect_pim(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree) {
 		"Groups: %u", ngroup);
 	    offset += 1;
 
-	    if (PIM_TYPE(pim_typever) != 7)	{
-		/* not graft-ack */
 		holdtime = tvb_get_ntohs(tvb, offset);
 		proto_tree_add_text(pimopt_tree, tvb, offset, 2,
 		    "Holdtime: %u%s", holdtime,
 		    holdtime == 0xffff ? " (infty)" : "");
-	    }
+
 	    offset += 2;
 
 	    for (i = 0; i < ngroup; i++) {
@@ -1223,26 +1201,39 @@ dissect_pim(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree) {
 	default:
 	    break;
 	}
-    }
 done:;
 }
 
 void
 proto_register_pim(void)
 {
-    static hf_register_info hf[] = {
-      { &hf_pim_version,
-	{ "Version",		"pim.version",
-				FT_UINT8, BASE_DEC, NULL, 0x0, "", HFILL }},
-      { &hf_pim_type,
-	{ "Type",		"pim.type",
-				FT_UINT8, BASE_DEC, VALS(type2vals), 0x0, "", HFILL }},
-      { &hf_pim_code,
-	{ "Code",		"pim.code",
-				FT_UINT8, BASE_DEC, VALS(type1vals), 0x0, "", HFILL }},
-      { &hf_pim_cksum,
-	{ "Checksum",		"pim.cksum",
-				FT_UINT16, BASE_HEX, NULL, 0x0, "", HFILL }},
+	static hf_register_info hf[] =
+	{
+	{ &hf_pim_version,
+		{ "Version", "pim.version",
+		FT_UINT8, BASE_DEC, NULL, 0xf0,
+		NULL, HFILL }
+	},
+	{ &hf_pim_type,
+		{ "Type", "pim.type",
+		FT_UINT8, BASE_DEC, VALS(type2vals), 0x0f,
+		NULL, HFILL }
+	},
+	{ &hf_pim_code,
+		{ "Code", "pim.code",
+		FT_UINT8, BASE_DEC, VALS(type1vals), 0x0,
+		NULL, HFILL }
+	},
+	{ &hf_pim_cksum,
+		{ "Checksum", "pim.cksum",
+		FT_UINT16, BASE_HEX, NULL, 0x0,
+		NULL, HFILL }
+	},
+	{ &hf_pim_res_bytes,
+		{ "Reserved byte(s)", "pim.res_bytes",
+		FT_BYTES, BASE_NONE, NULL, 0x0,
+		NULL, HFILL }
+	},
     };
     static gint *ett[] = {
         &ett_pim,
