@@ -4,7 +4,7 @@
  * Uwe Girlich <uwe@planetquake.com>
  *	http://www.idsoftware.com/q1source/q1source.zip
  *
- * $Id: packet-quake.c 26253 2008-09-23 01:10:45Z wmeier $
+ * $Id: packet-quake.c 29344 2009-08-09 07:36:13Z krj $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -441,10 +441,8 @@ dissect_quake(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 	guint		rest_length;
 	tvbuff_t	*next_tvb;
 
-	if (check_col(pinfo->cinfo, COL_PROTOCOL))
-		col_set_str(pinfo->cinfo, COL_PROTOCOL, "QUAKE");
-	if (check_col(pinfo->cinfo, COL_INFO))
-		col_clear(pinfo->cinfo, COL_INFO);
+	col_set_str(pinfo->cinfo, COL_PROTOCOL, "QUAKE");
+	col_clear(pinfo->cinfo, COL_INFO);
 
 	length = tvb_get_ntohl(tvb, 0);
 	flags = length & (~NETFLAG_LENGTH_MASK);
@@ -468,22 +466,22 @@ dissect_quake(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 		}
 
 		if (flags_tree) {
-			proto_tree_add_text(flags_tree, tvb, 0, 2,
+			proto_tree_add_text(flags_tree, tvb, 0, 2, "%s",
 				decode_boolean_bitfield(flags, NETFLAG_DATA, 32,
 				"Data","-"));
-			proto_tree_add_text(flags_tree, tvb, 0, 2,
+			proto_tree_add_text(flags_tree, tvb, 0, 2, "%s",
 				decode_boolean_bitfield(flags, NETFLAG_ACK, 32,
 				"Acknowledgment","-"));
-			proto_tree_add_text(flags_tree, tvb, 0, 2,
+			proto_tree_add_text(flags_tree, tvb, 0, 2, "%s",
 				decode_boolean_bitfield(flags, NETFLAG_NAK, 32,
 				"No Acknowledgment","-"));
-			proto_tree_add_text(flags_tree, tvb, 0, 2,
+			proto_tree_add_text(flags_tree, tvb, 0, 2, "%s",
 				decode_boolean_bitfield(flags, NETFLAG_EOM, 32,
 				"End Of Message","-"));
-			proto_tree_add_text(flags_tree, tvb, 0, 2,
+			proto_tree_add_text(flags_tree, tvb, 0, 2, "%s",
 				decode_boolean_bitfield(flags, NETFLAG_UNRELIABLE, 32,
 				"Unreliable","-"));
-			proto_tree_add_text(flags_tree, tvb, 0, 2,
+			proto_tree_add_text(flags_tree, tvb, 0, 2, "%s",
 				decode_boolean_bitfield(flags, NETFLAG_CTL, 32,
 				"Control","-"));
 		}
@@ -541,7 +539,7 @@ proto_register_quake(void)
     { &hf_quake_header_flags,
       { "Flags", "quake.header.flags",
 	FT_UINT16, BASE_HEX, NULL, 0x0,
-	"Flags", HFILL }},
+	NULL, HFILL }},
     { &hf_quake_header_length,
       { "Length", "quake.header.length",
 	FT_UINT16, BASE_DEC, NULL, 0x0,
@@ -573,7 +571,7 @@ proto_register_quake(void)
     { &hf_quake_CCREQ_PLAYER_INFO_player,
       { "Player", "quake.control.player_info.player",
 	FT_UINT8, BASE_DEC, NULL, 0x0,
-	"Player", HFILL }},
+	NULL, HFILL }},
     { &hf_quake_CCREQ_RULE_INFO_lastrule,
       { "Last Rule", "quake.control.rule_info.lastrule",
 	FT_STRINGZ, BASE_NONE, NULL, 0x0,
@@ -605,7 +603,7 @@ proto_register_quake(void)
     { &hf_quake_CCREP_SERVER_INFO_max_player,
       { "Maximal Number of Players", "quake.control.server_info.max_player",
 	FT_UINT8, BASE_DEC, NULL, 0x0,
-	"Maximal Number of Players", HFILL }},
+	NULL, HFILL }},
     { &hf_quake_CCREP_PLAYER_INFO_name,
       { "Name", "quake.control.player_info.name",
 	FT_STRINGZ, BASE_NONE, NULL, 0x0,
