@@ -1,6 +1,6 @@
 /* packet-redback.c
  *
- * $Id: packet-redback.c 29446 2009-08-16 12:36:22Z krj $
+ * $Id: packet-redback.c 30088 2009-09-23 14:43:23Z krj $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -65,7 +65,7 @@ dissect_redback(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 	tvbuff_t	*next_tvb;
 
 	if(check_col(pinfo->cinfo,COL_PROTOCOL))
-		col_add_str(pinfo->cinfo,COL_PROTOCOL,"RBN");
+		col_set_str(pinfo->cinfo, COL_PROTOCOL, "RBN");
 
 	dataoff = tvb_get_ntohs(tvb, 20);
 	l3off = tvb_get_ntohs(tvb, 22);
