@@ -2,7 +2,7 @@
  *
  * Martin Mathieson
  *
- * $Id: packet-rlc-lte.c 29862 2009-09-11 15:16:53Z martinm $
+ * $Id: packet-rlc-lte.c 31021 2009-11-19 18:23:53Z martinm $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -34,6 +34,7 @@
 #include <epan/prefs.h>
 
 #include "packet-rlc-lte.h"
+#include "packet-pdcp-lte.h"
 
 
 /* Described in:
@@ -49,6 +50,9 @@
 /* By default try to analyse the sequence of messages for UM channels */
 static gboolean global_rlc_lte_sequence_analysis = TRUE;
 
+/* By default don't call PDCP/RRC dissectors for SDU data */
+static gboolean global_rlc_lte_call_pdcp = FALSE;
+static gboolean global_rlc_lte_call_rrc = FALSE;
 
 
 /* Initialize the protocol and registered fields. */
@@ -230,6 +234,8 @@ static const value_string am_e2_vals[] =
 };
 
 
+extern int proto_pdcp_lte;
+
 
 /**********************************************************************************/
 /* These are for keeping track of UM/AM extension headers, and the lengths found  */
@@ -313,6 +319,7 @@ static int dissect_rlc_lte_extension_header(tvbuff_t *tvb, packet_info *pinfo,
 /* Show in the info column how many bytes are in the UM/AM PDU, and indicate
    whether or not the beginning and end are included in this packet */
 static void show_PDU_in_info(packet_info *pinfo,
+                             proto_item *top_ti,
                              guint16 length,
                              gboolean first_includes_start,
                              gboolean last_includes_end)
@@ -323,9 +330,63 @@ static void show_PDU_in_info(packet_info *pinfo,
                     length,
                     (length > 1) ? "s" : "",
                     (last_includes_end) ? "]" : "..");
+
+    proto_item_append_text(top_ti, "  %s%u-byte%s%s",
+                          (first_includes_start) ? "[" : "..",
+                          length,
+                          (length > 1) ? "s" : "",
+                          (last_includes_end) ? "]" : "..");
 }
 
 
+static void show_AM_PDU_in_tree(packet_info *pinfo, proto_tree *tree, tvbuff_t *tvb, gint offset, gint length,
+                                rlc_lte_info *rlc_info, gboolean whole_pdu)
+{
+    proto_item *data_ti = proto_tree_add_item(tree, hf_rlc_lte_am_data, tvb, offset, length, FALSE);
+
+    /* Decode signalling PDUs as PDCP */
+    if (global_rlc_lte_call_pdcp && whole_pdu) {
+        if (rlc_info->channelType == CHANNEL_TYPE_SRB) {
+            /* Attempt to decode payload using LTE PDCP dissector */
+            tvbuff_t *pdcp_tvb = tvb_new_subset(tvb, offset, length, length);
+            volatile dissector_handle_t protocol_handle;
+
+            struct pdcp_lte_info *p_pdcp_lte_info;
+
+            /* Reuse or allocate struct */
+            p_pdcp_lte_info = p_get_proto_data(pinfo->fd, proto_pdcp_lte);
+            if (p_pdcp_lte_info == NULL) {
+                p_pdcp_lte_info = se_alloc0(sizeof(struct pdcp_lte_info));
+            }
+            if (p_pdcp_lte_info == NULL) {
+                return;
+            }
+
+            p_pdcp_lte_info->channelType = Channel_DCCH;
+            p_pdcp_lte_info->direction = rlc_info->direction;
+            p_pdcp_lte_info->no_header_pdu = FALSE;
+            p_pdcp_lte_info->plane = SIGNALING_PLANE;
+
+            p_pdcp_lte_info->rohc_compression = FALSE;
+
+            /* Store info in packet */
+            p_add_proto_data(pinfo->fd, proto_pdcp_lte, p_pdcp_lte_info);
+
+            /* Get dissector handle */
+            protocol_handle = find_dissector("pdcp-lte");
+
+            TRY {
+                call_dissector_only(protocol_handle, pdcp_tvb, pinfo, tree);
+            }
+            CATCH_ALL {
+            }
+            ENDTRY
+
+            PROTO_ITEM_SET_HIDDEN(data_ti);
+        }
+    }
+}
+
 
 /*********************************************************************/
 /* UM/AM sequence analysis                                           */
@@ -596,6 +657,59 @@ static void checkChannelSequenceInfo(packet_info *pinfo, tvbuff_t *tvb,
 
 
 
+/***************************************************/
+/* Unacknowledged mode PDU                         */
+static void dissect_rlc_lte_tm(tvbuff_t *tvb, packet_info *pinfo,
+                               proto_tree *tree,
+                               int offset,
+                               rlc_lte_info *p_rlc_lte_info,
+                               proto_item *top_ti _U_)
+{
+    proto_item *raw_tm_ti;
+
+    /* Remaining bytes are all data */
+    raw_tm_ti = proto_tree_add_item(tree, hf_rlc_lte_tm_data, tvb, offset, -1, FALSE);
+    if (!global_rlc_lte_call_rrc) {
+        col_append_fstr(pinfo->cinfo, COL_INFO, "   [%u-bytes]",
+                        tvb_length_remaining(tvb, offset));
+    }
+
+    if (global_rlc_lte_call_rrc) {
+        tvbuff_t *rrc_tvb = tvb_new_subset(tvb, offset, -1, tvb_length_remaining(tvb, offset));
+        volatile dissector_handle_t protocol_handle = 0;
+
+        switch (p_rlc_lte_info->channelType) {
+            case CHANNEL_TYPE_CCCH:
+                if (p_rlc_lte_info->direction == DIRECTION_UPLINK) {
+                    protocol_handle = find_dissector("lte-rrc.ul.ccch");
+                }
+                else {
+                    protocol_handle = find_dissector("lte-rrc.dl.ccch");
+                }
+                break;
+
+            case CHANNEL_TYPE_BCCH:
+                /* TODO: Problem is don't know which transport channel... */
+                return;
+
+            case CHANNEL_TYPE_PCCH:
+                protocol_handle = find_dissector("lte-rrc.pcch");
+                break;
+        }
+
+        /* Hide raw view of bytes */
+        PROTO_ITEM_SET_HIDDEN(raw_tm_ti);
+
+        /* Call it (catch exceptions) */
+        TRY {
+            call_dissector_only(protocol_handle, rrc_tvb, pinfo, tree);
+        }
+        CATCH_ALL {
+        }
+        ENDTRY
+    }
+}
+
 
 
 /***************************************************/
@@ -603,7 +717,8 @@ static void checkChannelSequenceInfo(packet_info *pinfo, tvbuff_t *tvb,
 static void dissect_rlc_lte_um(tvbuff_t *tvb, packet_info *pinfo,
                                proto_tree *tree,
                                int offset,
-                               rlc_lte_info *p_rlc_lte_info)
+                               rlc_lte_info *p_rlc_lte_info,
+                               proto_item *top_ti)
 {
     guint64 framing_info;
     gboolean first_includes_start;
@@ -717,7 +832,7 @@ static void dissect_rlc_lte_um(tvbuff_t *tvb, packet_info *pinfo,
         int n;
         for (n=0; n < s_number_of_extensions; n++) {
             proto_tree_add_item(tree, hf_rlc_lte_um_data, tvb, offset, s_lengths[n], FALSE);
-            show_PDU_in_info(pinfo, s_lengths[n],
+            show_PDU_in_info(pinfo, top_ti, s_lengths[n],
                              (n==0) ? first_includes_start : TRUE,
                              TRUE);
             tvb_ensure_bytes_exist(tvb, offset, s_lengths[n]);
@@ -727,7 +842,7 @@ static void dissect_rlc_lte_um(tvbuff_t *tvb, packet_info *pinfo,
 
     /* Final data element */
     proto_tree_add_item(tree, hf_rlc_lte_um_data, tvb, offset, -1, FALSE);
-    show_PDU_in_info(pinfo, (guint16)tvb_length_remaining(tvb, offset),
+    show_PDU_in_info(pinfo, top_ti, (guint16)tvb_length_remaining(tvb, offset),
                      (s_number_of_extensions == 0) ? first_includes_start : TRUE,
                      last_includes_end);
 }
@@ -740,10 +855,12 @@ static void dissect_rlc_lte_am_status_pdu(tvbuff_t *tvb,
                                           packet_info *pinfo,
                                           proto_tree *tree,
                                           proto_item *status_ti,
-                                          int offset)
+                                          int offset,
+                                          proto_item *top_ti)
 {
     guint8     cpt;
     guint64    ack_sn, nack_sn;
+    guint      nack_count = 0;
     guint64    e1 = 0, e2 = 0;
     guint64    so_start, so_end;
     int        bit_offset = offset * 8;
@@ -774,6 +891,8 @@ static void dissect_rlc_lte_am_status_pdu(tvbuff_t *tvb,
                                 bit_offset, 10, &ack_sn, FALSE);
     bit_offset += 10;
     col_append_fstr(pinfo->cinfo, COL_INFO, "  ACK_SN=%u", (guint16)ack_sn);
+    proto_item_append_text(top_ti, "  ACK_SN=%u", (guint16)ack_sn);
+    proto_item_append_text(status_ti, "  ACK_SN=%u", (guint16)ack_sn);
 
     /* E1 */
     proto_tree_add_bits_ret_val(tree, hf_rlc_lte_am_e1, tvb,
@@ -793,8 +912,10 @@ static void dissect_rlc_lte_am_status_pdu(tvbuff_t *tvb,
             /* NACK_SN */
             nack_ti = proto_tree_add_bits_ret_val(tree, hf_rlc_lte_am_nack_sn, tvb,
                                                   bit_offset, 10, &nack_sn, FALSE);
+            nack_count++;
             bit_offset += 10;
             col_append_fstr(pinfo->cinfo, COL_INFO, "  NACK_SN=%u", (guint16)nack_sn);
+            proto_item_append_text(top_ti, "  NACK_SN=%u", (guint16)nack_sn);
             expert_add_info_format(pinfo, nack_ti, PI_SEQUENCE, PI_WARN,
                                    "Status PDU reports NACK for SN=%u", (guint16)nack_sn);
 
@@ -820,11 +941,14 @@ static void dissect_rlc_lte_am_status_pdu(tvbuff_t *tvb,
                                         bit_offset, 15, &so_end, FALSE);
             bit_offset += 15;
 
-            col_append_fstr(pinfo->cinfo, COL_INFO, "  (SOstart=%u SOend=%u)",
-                            (guint16)so_start, (guint16)so_end);
 
             if ((guint16)so_end == 0x7fff) {
-                col_append_str(pinfo->cinfo, COL_INFO, " (missing portion reaches end of AMD PDU)");
+                col_append_fstr(pinfo->cinfo, COL_INFO, "  (SOstart=%u SOend=<END-OF_PDU>)",
+                                (guint16)so_start);
+            }
+            else {
+                col_append_fstr(pinfo->cinfo, COL_INFO, "  (SOstart=%u SOend=%u)",
+                                (guint16)so_start, (guint16)so_end);
             }
 
             /* Reset this flag here */
@@ -832,6 +956,10 @@ static void dissect_rlc_lte_am_status_pdu(tvbuff_t *tvb,
         }
     } while (e1 || e2);
 
+    if (nack_count > 0) {
+        proto_item_append_text(status_ti, "  (%u NACKs)", nack_count);
+    }
+
     /* Check that we've reached the end of the PDU. If not, show malformed */
     offset = (bit_offset+7) / 8;
     if (tvb_length_remaining(tvb, offset) > 0) {
@@ -850,7 +978,7 @@ static void dissect_rlc_lte_am_status_pdu(tvbuff_t *tvb,
 static void dissect_rlc_lte_am(tvbuff_t *tvb, packet_info *pinfo,
                                proto_tree *tree,
                                int offset,
-                               rlc_lte_info *p_rlc_lte_info _U_,
+                               rlc_lte_info *p_rlc_lte_info,
                                proto_item *top_ti)
 {
     guint8 is_data;
@@ -883,10 +1011,10 @@ static void dissect_rlc_lte_am(tvbuff_t *tvb, packet_info *pinfo,
     /**************************************************/
     if (!is_data) {
         col_append_str(pinfo->cinfo, COL_INFO, " [CONTROL]");
-        proto_item_append_text(top_ti, "[CONTROL]");
+        proto_item_append_text(top_ti, " [CONTROL]");
 
         /* Control PDUs are a completely separate format  */
-        dissect_rlc_lte_am_status_pdu(tvb, pinfo, am_header_tree, am_header_ti, offset);
+        dissect_rlc_lte_am_status_pdu(tvb, pinfo, am_header_tree, am_header_ti, offset, top_ti);
         return;
     }
 
@@ -905,6 +1033,7 @@ static void dissect_rlc_lte_am(tvbuff_t *tvb, packet_info *pinfo,
     polling = (tvb_get_guint8(tvb, offset) & 0x20) >> 5;
     proto_tree_add_item(am_header_tree, hf_rlc_lte_am_p, tvb, offset, 1, FALSE);
     col_append_str(pinfo->cinfo, COL_INFO, (polling) ? " (P) " : "     ");
+    proto_item_append_text(top_ti,  (polling) ? " (P) " : "     ");
     if (polling) {
         proto_item_append_text(am_header_ti, " (P)");
     }
@@ -923,7 +1052,7 @@ static void dissect_rlc_lte_am(tvbuff_t *tvb, packet_info *pinfo,
     offset += 2;
 
     col_append_fstr(pinfo->cinfo, COL_INFO, "sn=%u", sn);
-
+    proto_item_append_text(top_ti, " (SN=%u)", sn);
 
     /* Show SN in AM header root */
     proto_item_append_text(am_header_ti, " (SN=%u)", sn);
@@ -941,6 +1070,7 @@ static void dissect_rlc_lte_am(tvbuff_t *tvb, packet_info *pinfo,
         segmentOffset = tvb_get_ntohs(tvb, offset) & 0x7fff;
         proto_tree_add_item(am_header_tree, hf_rlc_lte_am_segment_so, tvb, offset, 2, FALSE);
         col_append_fstr(pinfo->cinfo, COL_INFO, " SO=%u ", segmentOffset);
+        proto_item_append_text(top_ti, " SO=%u ", segmentOffset);
 
         offset += 2;
     }
@@ -973,8 +1103,9 @@ static void dissect_rlc_lte_am(tvbuff_t *tvb, packet_info *pinfo,
         /* Show each data segment separately */
         int n;
         for (n=0; n < s_number_of_extensions; n++) {
-            proto_tree_add_item(tree, hf_rlc_lte_am_data, tvb, offset, s_lengths[n], FALSE);
-            show_PDU_in_info(pinfo, s_lengths[n],
+            show_AM_PDU_in_tree(pinfo, tree, tvb, offset, s_lengths[n], p_rlc_lte_info,
+                                first_includes_start && last_includes_end);
+            show_PDU_in_info(pinfo, top_ti, s_lengths[n],
                              (n==0) ? first_includes_start : TRUE,
                              TRUE);
             tvb_ensure_bytes_exist(tvb, offset, s_lengths[n]);
@@ -984,13 +1115,14 @@ static void dissect_rlc_lte_am(tvbuff_t *tvb, packet_info *pinfo,
 
     /* Final data element */
     if (tvb_length_remaining(tvb, offset) > 0) {
-        proto_tree_add_item(tree, hf_rlc_lte_am_data, tvb, offset, -1, FALSE);
-        show_PDU_in_info(pinfo, (guint16)tvb_length_remaining(tvb, offset),
+        show_AM_PDU_in_tree(pinfo, tree, tvb, offset, -1, p_rlc_lte_info,
+                            first_includes_start && last_includes_end);
+        show_PDU_in_info(pinfo, top_ti, (guint16)tvb_length_remaining(tvb, offset),
                          (s_number_of_extensions == 0) ? first_includes_start : TRUE,
                          last_includes_end);
     }
     else {
-        expert_add_info_format(pinfo, am_header_ti, PI_MALFORMED, PI_WARN,
+        expert_add_info_format(pinfo, am_header_ti, PI_MALFORMED, PI_ERROR,
                                "AM data PDU doesn't contain any data");
 
     }
@@ -1033,7 +1165,6 @@ void dissect_rlc_lte(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 
     /*****************************************/
     /* Show context information              */
-    /* TODO: hide inside own tree?           */
 
     ti = proto_tree_add_uint(rlc_lte_tree, hf_rlc_lte_context_direction,
                              tvb, 0, 0, p_rlc_lte_info->direction);
@@ -1117,14 +1248,11 @@ void dissect_rlc_lte(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
     switch (p_rlc_lte_info->rlcMode) {
 
         case RLC_TM_MODE:
-            /* Remaining bytes are all data */
-            proto_tree_add_item(rlc_lte_tree, hf_rlc_lte_tm_data, tvb, offset, -1, FALSE);
-            col_append_fstr(pinfo->cinfo, COL_INFO, "   [%u-bytes]",
-                            tvb_length_remaining(tvb, offset));
+            dissect_rlc_lte_tm(tvb, pinfo, rlc_lte_tree, offset, p_rlc_lte_info, top_ti);
             break;
 
         case RLC_UM_MODE:
-            dissect_rlc_lte_um(tvb, pinfo, rlc_lte_tree, offset, p_rlc_lte_info);
+            dissect_rlc_lte_um(tvb, pinfo, rlc_lte_tree, offset, p_rlc_lte_info, top_ti);
             break;
 
         case RLC_AM_MODE:
@@ -1337,7 +1465,7 @@ void proto_register_rlc_lte(void)
         },
         { &hf_rlc_lte_am_fixed_sn,
             { "Sequence Number",
-              "rlc-lte.am.fixed.sn", FT_UINT16, BASE_HEX, 0, 0x03ff,
+              "rlc-lte.am.fixed.sn", FT_UINT16, BASE_DEC, 0, 0x03ff,
               "AM Fixed Sequence Number", HFILL
             }
         },
@@ -1464,6 +1592,18 @@ void proto_register_rlc_lte(void)
         "Attempt to keep track of PDUs for UM channels, and point out problems",
         &global_rlc_lte_sequence_analysis);
 
+    prefs_register_bool_preference(rlc_lte_module, "call_pdcp_for_srb",
+        "Call PDCP dissector for SRB PDUs",
+        "Call PDCP dissector for signalling PDUs.  Note that without reassembly, it can"
+        "only be called for complete PDus (i.e. not segmented over RLC)",
+        &global_rlc_lte_call_pdcp);
+
+    prefs_register_bool_preference(rlc_lte_module, "call_rrc_for_ccch",
+        "Call RRC dissector for CCCH PDUs",
+        "Call RRC dissector for CCCH PDUs",
+        &global_rlc_lte_call_rrc);
+
+
     register_init_routine(&rlc_lte_init_protocol);
 }
 
