@@ -6,7 +6,7 @@
  * Copyright 2000, Philips Electronics N.V.
  * Written by Andreas Sikkema <h323@ramdyne.nl>
  *
- * $Id: packet-rtp.c 29884 2009-09-13 23:03:38Z morriss $
+ * $Id: packet-rtp.c 30583 2009-10-16 22:05:49Z wmeier $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -105,7 +105,6 @@ typedef struct  _rtp_private_conv_info {
 } rtp_private_conv_info;
 
 static GHashTable *fragment_table = NULL;
-static GHashTable * fid_table = NULL;
 
 static int hf_rtp_fragments = -1;
 static int hf_rtp_fragment = -1;
@@ -430,7 +429,6 @@ static const value_string srtp_auth_alg_vals[] =
 static void rtp_fragment_init(void)
 {
 	fragment_table_init(&fragment_table);
-	fid_table = g_hash_table_new(g_direct_hash, g_direct_equal);
 }
 
 void
