@@ -4,7 +4,7 @@
  * Jason Lango <jal@netapp.com>
  * Liberally copied from packet-http.c, by Guy Harris <guy@alum.mit.edu>
  *
- * $Id: packet-rtsp.c 29568 2009-08-26 19:27:49Z wmeier $
+ * $Id: packet-rtsp.c 30691 2009-10-25 11:43:30Z etxrab $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -1129,9 +1129,7 @@ process_rtsp_request(tvbuff_t *tvb, int offset, const guchar *data,
 	while (url < lineend && !isspace(*url))
 		url++;
 	/* Create a URL-sized buffer and copy contents */
-	tmp_url = ep_alloc(url - url_start + 1);
-	memcpy(tmp_url, url_start, url - url_start);
-	tmp_url[url - url_start] = '\0';
+	tmp_url = ep_strndup(url_start, url - url_start);
 	
 	/* Add URL to tree */
 	proto_tree_add_string(sub_tree, hf_rtsp_url, tvb,
