@@ -4,7 +4,7 @@
  * Ronnie sahlberg 2006
  * Joe Breher 2006
  *
- * $Id: packet-scsi-osd.c 27065 2008-12-20 00:09:02Z wmeier $
+ * $Id: packet-scsi-osd.c 29321 2009-08-07 00:15:35Z gerald $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -873,12 +873,13 @@ static void
 dissect_osd_partition_id(packet_info *pinfo, tvbuff_t *tvb, int offset, proto_tree *tree, int hf_index, scsi_osd_lun_info_t *lun_info, gboolean is_created, gboolean is_removed)
 {
 	proto_item *item=NULL;
-	guint64 partition_id;
+	guint32 partition_id[2];
 
 	/* partition id */
 	item=proto_tree_add_item(tree, hf_index, tvb, offset, 8, 0);
-	partition_id=tvb_get_ntoh64(tvb, offset);
-	if(!partition_id){
+	partition_id[0]=tvb_get_ntohl(tvb, offset);
+	partition_id[1]=tvb_get_ntohl(tvb, offset+4);
+	if(!partition_id[0] && !partition_id[1]){
 		proto_item_append_text(item, " (ROOT partition)");
 	} else {
 		partition_info_t *part_info;
@@ -886,7 +887,7 @@ dissect_osd_partition_id(packet_info *pinfo, tvbuff_t *tvb, int offset, proto_tr
 		proto_tree *partition_tree=NULL;
 
 		pikey[0].length=2;
-		pikey[0].key=(guint32 *)&partition_id;
+		pikey[0].key=partition_id;
 		pikey[1].length=0;
 		part_info=se_tree_lookup32_array(lun_info->partitions, &pikey[0]);
 		if(!part_info){
@@ -895,7 +896,7 @@ dissect_osd_partition_id(packet_info *pinfo, tvbuff_t *tvb, int offset, proto_tr
 			part_info->removed_in=0;
 
 			pikey[0].length=2;
-			pikey[0].key=(guint32 *)&partition_id;
+			pikey[0].key=partition_id;
 			pikey[1].length=0;
 			se_tree_insert32_array(lun_info->partitions, &pikey[0], part_info);
 		}
@@ -2951,212 +2952,212 @@ proto_register_scsi_osd(void)
 	static hf_register_info hf[] = {
         { &hf_scsi_osd_opcode,
           {"OSD Opcode", "scsi.osd.opcode", FT_UINT8, BASE_HEX,
-           VALS (scsi_osd_vals), 0x0, "", HFILL}},
+           VALS (scsi_osd_vals), 0x0, NULL, HFILL}},
         { &hf_scsi_osd_add_cdblen,
           {"Additional CDB Length", "scsi.osd.addcdblen", FT_UINT8, BASE_DEC,
-           NULL, 0x0, "", HFILL}},
+           NULL, 0x0, NULL, HFILL}},
         { &hf_scsi_osd_svcaction,
           {"Service Action", "scsi.osd.svcaction", FT_UINT16, BASE_HEX,
-           VALS(scsi_osd_svcaction_vals), 0x0, "", HFILL}},
+           VALS(scsi_osd_svcaction_vals), 0x0, NULL, HFILL}},
         { &hf_scsi_osd_option,
           {"Options Byte", "scsi.osd.option", FT_UINT8, BASE_HEX,
-           NULL, 0x0, "", HFILL}},
+           NULL, 0x0, NULL, HFILL}},
         { &hf_scsi_osd_option_dpo,
           {"DPO", "scsi.osd.option.dpo", FT_BOOLEAN, 8,
-           TFS(&option_dpo_tfs), 0x10, "", HFILL}},
+           TFS(&option_dpo_tfs), 0x10, NULL, HFILL}},
         { &hf_scsi_osd_option_fua,
           {"FUA", "scsi.osd.option.fua", FT_BOOLEAN, 8,
-           TFS(&option_fua_tfs), 0x08, "", HFILL}},
+           TFS(&option_fua_tfs), 0x08, NULL, HFILL}},
         { &hf_scsi_osd_getsetattrib,
           {"GET/SET CDBFMT", "scsi.osd.getset", FT_UINT8, BASE_HEX,
-           VALS(scsi_osd_getsetattrib_vals), 0x30, "", HFILL}},
+           VALS(scsi_osd_getsetattrib_vals), 0x30, NULL, HFILL}},
         { &hf_scsi_osd_timestamps_control,
           {"Timestamps Control", "scsi.osd.timestamps_control", FT_UINT8, BASE_HEX,
-           VALS(scsi_osd_timestamps_control_vals), 0x0, "", HFILL}},
+           VALS(scsi_osd_timestamps_control_vals), 0x0, NULL, HFILL}},
         { &hf_scsi_osd_formatted_capacity,
           {"Formatted Capacity", "scsi.osd.formatted_capacity", FT_UINT64, BASE_DEC,
-           NULL, 0x0, "", HFILL}},
+           NULL, 0x0, NULL, HFILL}},
         { &hf_scsi_osd_get_attributes_page,
           {"Get Attributes Page", "scsi.osd.get_attributes_page", FT_UINT32, BASE_HEX,
-           NULL, 0x0, "", HFILL}},
+           NULL, 0x0, NULL, HFILL}},
         { &hf_scsi_osd_get_attributes_list_length,
           {"Get Attributes List Length", "scsi.osd.get_attributes_list_length", FT_UINT32, BASE_HEX,
-           NULL, 0x0, "", HFILL}},
+           NULL, 0x0, NULL, HFILL}},
         { &hf_scsi_osd_get_attributes_list_offset,
           {"Get Attributes List Offset", "scsi.osd.get_attributes_list_offset", FT_UINT32, BASE_HEX,
-           NULL, 0x0, "", HFILL}},
+           NULL, 0x0, NULL, HFILL}},
         { &hf_scsi_osd_set_attributes_list_length,
           {"Set Attributes List Length", "scsi.osd.set_attributes_list_length", FT_UINT32, BASE_HEX,
-           NULL, 0x0, "", HFILL}},
+           NULL, 0x0, NULL, HFILL}},
         { &hf_scsi_osd_set_attributes_list_offset,
           {"Set Attributes List Offset", "scsi.osd.set_attributes_list_offset", FT_UINT32, BASE_HEX,
-           NULL, 0x0, "", HFILL}},
+           NULL, 0x0, NULL, HFILL}},
         { &hf_scsi_osd_get_attributes_allocation_length,
           {"Get Attributes Allocation Length", "scsi.osd.get_attributes_allocation_length", FT_UINT32, BASE_HEX,
-           NULL, 0x0, "", HFILL}},
+           NULL, 0x0, NULL, HFILL}},
         { &hf_scsi_osd_retrieved_attributes_offset,
           {"Retrieved Attributes Offset", "scsi.osd.retrieved_attributes_offset", FT_UINT32, BASE_HEX,
-           NULL, 0x0, "", HFILL}},
+           NULL, 0x0, NULL, HFILL}},
         { &hf_scsi_osd_set_attributes_page,
           {"Set Attributes Page", "scsi.osd.set_attributes_page", FT_UINT32, BASE_HEX,
-           NULL, 0x0, "", HFILL}},
+           NULL, 0x0, NULL, HFILL}},
         { &hf_scsi_osd_set_attribute_length,
           {"Set Attribute Length", "scsi.osd.set_attribute_length", FT_UINT32, BASE_HEX,
-           NULL, 0x0, "", HFILL}},
+           NULL, 0x0, NULL, HFILL}},
         { &hf_scsi_osd_set_attribute_number,
           {"Set Attribute Number", "scsi.osd.set_attribute_number", FT_UINT32, BASE_HEX,
-           NULL, 0x0, "", HFILL}},
+           NULL, 0x0, NULL, HFILL}},
         { &hf_scsi_osd_set_attributes_offset,
           {"Set Attributes Offset", "scsi.osd.set_attributes_offset", FT_UINT32, BASE_HEX,
-           NULL, 0x0, "", HFILL}},
+           NULL, 0x0, NULL, HFILL}},
         { &hf_scsi_osd_capability_format,
           {"Capability Format", "scsi.osd.capability_format", FT_UINT8, BASE_HEX,
-           VALS(scsi_osd_capability_format_vals), 0x0f, "", HFILL}},
+           VALS(scsi_osd_capability_format_vals), 0x0f, NULL, HFILL}},
         { &hf_scsi_osd_key_version,
           {"Key Version", "scsi.osd.key_version", FT_UINT8, BASE_HEX,
-           NULL, 0xf0, "", HFILL}},
+           NULL, 0xf0, NULL, HFILL}},
         { &hf_scsi_osd_icva,
           {"Integrity Check Value Algorithm", "scsi.osd.icva", FT_UINT8, BASE_HEX,
-           NULL, 0x0f, "", HFILL}},
+           NULL, 0x0f, NULL, HFILL}},
         { &hf_scsi_osd_security_method,
           {"Security Method", "scsi.osd.security_method", FT_UINT8, BASE_HEX,
-           NULL, 0x0f, "", HFILL}},
+           NULL, 0x0f, NULL, HFILL}},
         { &hf_scsi_osd_capability_expiration_time,
-          {"Capability Expiration Time", "scsi.osd.capability_expiration_time", FT_BYTES, BASE_HEX,
-           NULL, 0, "", HFILL}},
+          {"Capability Expiration Time", "scsi.osd.capability_expiration_time", FT_BYTES, BASE_NONE,
+           NULL, 0, NULL, HFILL}},
         { &hf_scsi_osd_audit,
-          {"Audit", "scsi.osd.audit", FT_BYTES, BASE_HEX,
-           NULL, 0, "", HFILL}},
+          {"Audit", "scsi.osd.audit", FT_BYTES, BASE_NONE,
+           NULL, 0, NULL, HFILL}},
         { &hf_scsi_osd_capability_discriminator,
-          {"Capability Discriminator", "scsi.osd.capability_descriminator", FT_BYTES, BASE_HEX,
-           NULL, 0, "", HFILL}},
+          {"Capability Discriminator", "scsi.osd.capability_descriminator", FT_BYTES, BASE_NONE,
+           NULL, 0, NULL, HFILL}},
         { &hf_scsi_osd_object_created_time,
-          {"Object Created Time", "scsi.osd.object_created_time", FT_BYTES, BASE_HEX,
-           NULL, 0, "", HFILL}},
+          {"Object Created Time", "scsi.osd.object_created_time", FT_BYTES, BASE_NONE,
+           NULL, 0, NULL, HFILL}},
         { &hf_scsi_osd_object_type,
           {"Object Type", "scsi.osd.object_type", FT_UINT8, BASE_HEX,
-           VALS(scsi_osd_object_type_vals), 0, "", HFILL}},
+           VALS(scsi_osd_object_type_vals), 0, NULL, HFILL}},
         { &hf_scsi_osd_permissions,
           {"Permissions", "scsi.osd.permissions", FT_UINT16, BASE_HEX,
-           NULL, 0, "", HFILL}},
+           NULL, 0, NULL, HFILL}},
         { &hf_scsi_osd_permissions_read,
           {"READ", "scsi.osd.permissions.read", FT_BOOLEAN, 16,
-           TFS(&permissions_read_tfs), 0x8000, "", HFILL}},
+           TFS(&permissions_read_tfs), 0x8000, NULL, HFILL}},
         { &hf_scsi_osd_permissions_write,
           {"WRITE", "scsi.osd.permissions.write", FT_BOOLEAN, 16,
-           TFS(&permissions_write_tfs), 0x4000, "", HFILL}},
+           TFS(&permissions_write_tfs), 0x4000, NULL, HFILL}},
         { &hf_scsi_osd_permissions_get_attr,
           {"GET_ATTR", "scsi.osd.permissions.get_attr", FT_BOOLEAN, 16,
-           TFS(&permissions_get_attr_tfs), 0x2000, "", HFILL}},
+           TFS(&permissions_get_attr_tfs), 0x2000, NULL, HFILL}},
         { &hf_scsi_osd_permissions_set_attr,
           {"SET_ATTR", "scsi.osd.permissions.set_attr", FT_BOOLEAN, 16,
-           TFS(&permissions_set_attr_tfs), 0x1000, "", HFILL}},
+           TFS(&permissions_set_attr_tfs), 0x1000, NULL, HFILL}},
         { &hf_scsi_osd_permissions_create,
           {"CREATE", "scsi.osd.permissions.create", FT_BOOLEAN, 16,
-           TFS(&permissions_create_tfs), 0x0800, "", HFILL}},
+           TFS(&permissions_create_tfs), 0x0800, NULL, HFILL}},
         { &hf_scsi_osd_permissions_remove,
           {"REMOVE", "scsi.osd.permissions.remove", FT_BOOLEAN, 16,
-           TFS(&permissions_remove_tfs), 0x0400, "", HFILL}},
+           TFS(&permissions_remove_tfs), 0x0400, NULL, HFILL}},
         { &hf_scsi_osd_permissions_obj_mgmt,
           {"OBJ_MGMT", "scsi.osd.permissions.obj_mgmt", FT_BOOLEAN, 16,
-           TFS(&permissions_obj_mgmt_tfs), 0x0200, "", HFILL}},
+           TFS(&permissions_obj_mgmt_tfs), 0x0200, NULL, HFILL}},
         { &hf_scsi_osd_permissions_append,
           {"APPEND", "scsi.osd.permissions.append", FT_BOOLEAN, 16,
-           TFS(&permissions_append_tfs), 0x0100, "", HFILL}},
+           TFS(&permissions_append_tfs), 0x0100, NULL, HFILL}},
         { &hf_scsi_osd_permissions_dev_mgmt,
           {"DEV_MGMT", "scsi.osd.permissions.dev_mgmt", FT_BOOLEAN, 16,
-           TFS(&permissions_dev_mgmt_tfs), 0x0080, "", HFILL}},
+           TFS(&permissions_dev_mgmt_tfs), 0x0080, NULL, HFILL}},
         { &hf_scsi_osd_permissions_global,
           {"GLOBAL", "scsi.osd.permissions.global", FT_BOOLEAN, 16,
-           TFS(&permissions_global_tfs), 0x0040, "", HFILL}},
+           TFS(&permissions_global_tfs), 0x0040, NULL, HFILL}},
         { &hf_scsi_osd_permissions_pol_sec,
           {"POL/SEC", "scsi.osd.permissions.pol_sec", FT_BOOLEAN, 16,
-           TFS(&permissions_pol_sec_tfs), 0x0020, "", HFILL}},
+           TFS(&permissions_pol_sec_tfs), 0x0020, NULL, HFILL}},
 
         { &hf_scsi_osd_object_descriptor_type,
           {"Object Descriptor Type", "scsi.osd.object_descriptor_type", FT_UINT8, BASE_HEX,
-           VALS(scsi_osd_object_descriptor_type_vals), 0xf0, "", HFILL}},
+           VALS(scsi_osd_object_descriptor_type_vals), 0xf0, NULL, HFILL}},
         { &hf_scsi_osd_object_descriptor,
-          {"Object Descriptor", "scsi.osd.object_descriptor", FT_BYTES, BASE_HEX,
-           NULL, 0, "", HFILL}},
+          {"Object Descriptor", "scsi.osd.object_descriptor", FT_BYTES, BASE_NONE,
+           NULL, 0, NULL, HFILL}},
         { &hf_scsi_osd_ricv,
-          {"Request Integrity Check value", "scsi.osd.ricv", FT_BYTES, BASE_HEX,
-           NULL, 0, "", HFILL}},
+          {"Request Integrity Check value", "scsi.osd.ricv", FT_BYTES, BASE_NONE,
+           NULL, 0, NULL, HFILL}},
         { &hf_scsi_osd_request_nonce,
-          {"Request Nonce", "scsi.osd.request_nonce", FT_BYTES, BASE_HEX,
-           NULL, 0, "", HFILL}},
+          {"Request Nonce", "scsi.osd.request_nonce", FT_BYTES, BASE_NONE,
+           NULL, 0, NULL, HFILL}},
         { &hf_scsi_osd_diicvo,
           {"Data-In Integrity Check Value Offset", "scsi.osd.diicvo", FT_UINT32, BASE_DEC,
-           NULL, 0, "", HFILL}},
+           NULL, 0, NULL, HFILL}},
         { &hf_scsi_osd_doicvo,
           {"Data-Out Integrity Check Value Offset", "scsi.osd.doicvo", FT_UINT32, BASE_DEC,
-           NULL, 0, "", HFILL}},
+           NULL, 0, NULL, HFILL}},
         { &hf_scsi_osd_requested_partition_id,
           {"Requested Partition Id", "scsi.osd.requested_partition_id", FT_UINT64, BASE_HEX,
-           NULL, 0, "", HFILL}},
+           NULL, 0, NULL, HFILL}},
         { &hf_scsi_osd_sortorder,
           {"Sort Order", "scsi.osd.sort_order", FT_UINT8, BASE_DEC,
-           VALS(scsi_osd_sort_order_vals), 0x0f, "", HFILL}},
+           VALS(scsi_osd_sort_order_vals), 0x0f, NULL, HFILL}},
         { &hf_scsi_osd_partition_id,
           {"Partition Id", "scsi.osd.partition_id", FT_UINT64, BASE_HEX,
-           NULL, 0, "", HFILL}},
+           NULL, 0, NULL, HFILL}},
         { &hf_scsi_osd_list_identifier,
           {"List Identifier", "scsi.osd.list_identifier", FT_UINT32, BASE_DEC,
-           NULL, 0, "", HFILL}},
+           NULL, 0, NULL, HFILL}},
         { &hf_scsi_osd_allocation_length,
           {"Allocation Length", "scsi.osd.allocation_length", FT_UINT64, BASE_DEC,
-           NULL, 0, "", HFILL}},
+           NULL, 0, NULL, HFILL}},
         { &hf_scsi_osd_length,
           {"Length", "scsi.osd.length", FT_UINT64, BASE_DEC,
-           NULL, 0, "", HFILL}},
+           NULL, 0, NULL, HFILL}},
         { &hf_scsi_osd_starting_byte_address,
           {"Starting Byte Address", "scsi.osd.starting_byte_address", FT_UINT64, BASE_DEC,
-           NULL, 0, "", HFILL}},
+           NULL, 0, NULL, HFILL}},
         { &hf_scsi_osd_initial_object_id,
-          {"Initial Object Id", "scsi.osd.initial_object_id", FT_BYTES, BASE_HEX,
-           NULL, 0, "", HFILL}},
+          {"Initial Object Id", "scsi.osd.initial_object_id", FT_BYTES, BASE_NONE,
+           NULL, 0, NULL, HFILL}},
 	{ &hf_scsi_osd_additional_length,
           {"Additional Length", "scsi.osd.additional_length", FT_UINT64, BASE_DEC,
-           NULL, 0, "", HFILL}},
+           NULL, 0, NULL, HFILL}},
         { &hf_scsi_osd_continuation_object_id,
-          {"Continuation Object Id", "scsi.osd.continuation_object_id", FT_BYTES, BASE_HEX,
-           NULL, 0, "", HFILL}},
+          {"Continuation Object Id", "scsi.osd.continuation_object_id", FT_BYTES, BASE_NONE,
+           NULL, 0, NULL, HFILL}},
         { &hf_scsi_osd_user_object_id,
-          {"User Object Id", "scsi.osd.user_object_id", FT_BYTES, BASE_HEX,
-           NULL, 0, "", HFILL}},
+          {"User Object Id", "scsi.osd.user_object_id", FT_BYTES, BASE_NONE,
+           NULL, 0, NULL, HFILL}},
         { &hf_scsi_osd_list_flags_lstchg,
           {"LSTCHG", "scsi.osd.list.lstchg", FT_BOOLEAN, 8,
-           TFS(&list_lstchg_tfs), 0x02, "", HFILL}},
+           TFS(&list_lstchg_tfs), 0x02, NULL, HFILL}},
         { &hf_scsi_osd_list_flags_root,
           {"ROOT", "scsi.osd.list.root", FT_BOOLEAN, 8,
-           TFS(&list_root_tfs), 0x01, "", HFILL}},
+           TFS(&list_root_tfs), 0x01, NULL, HFILL}},
         { &hf_scsi_osd_requested_user_object_id,
-          {"Requested User Object Id", "scsi.osd.requested_user_object_id", FT_BYTES, BASE_HEX,
-           NULL, 0, "", HFILL}},
+          {"Requested User Object Id", "scsi.osd.requested_user_object_id", FT_BYTES, BASE_NONE,
+           NULL, 0, NULL, HFILL}},
 	{ &hf_scsi_osd_number_of_user_objects,
           {"Number Of User Objects", "scsi.osd.number_of_user_objects", FT_UINT16, BASE_DEC,
-           NULL, 0, "", HFILL}},
+           NULL, 0, NULL, HFILL}},
 	{ &hf_scsi_osd_key_to_set,
           {"Key to Set", "scsi.osd.key_to_set", FT_UINT8, BASE_DEC,
-           VALS(key_to_set_vals), 0x03, "", HFILL}},
+           VALS(key_to_set_vals), 0x03, NULL, HFILL}},
 	{ &hf_scsi_osd_set_key_version,
           {"Key Version", "scsi.osd.set_key_version", FT_UINT8, BASE_DEC,
-           NULL, 0x0f, "", HFILL}},
+           NULL, 0x0f, NULL, HFILL}},
 	{ &hf_scsi_osd_key_identifier,
-          {"Key Identifier", "scsi.osd.key_identifier", FT_BYTES, BASE_HEX,
-           NULL, 0, "", HFILL}},
+          {"Key Identifier", "scsi.osd.key_identifier", FT_BYTES, BASE_NONE,
+           NULL, 0, NULL, HFILL}},
 	{ &hf_scsi_osd_seed,
-          {"Seed", "scsi.osd.seed", FT_BYTES, BASE_HEX,
-           NULL, 0, "", HFILL}},
+          {"Seed", "scsi.osd.seed", FT_BYTES, BASE_NONE,
+           NULL, 0, NULL, HFILL}},
         { &hf_scsi_osd_collection_fcr,
           {"FCR", "scsi.osd.collection.fcr", FT_BOOLEAN, 8,
-           TFS(&collection_fcr_tfs), 0x01, "", HFILL}},
+           TFS(&collection_fcr_tfs), 0x01, NULL, HFILL}},
         { &hf_scsi_osd_collection_object_id,
-          {"Collection Object Id", "scsi.osd.collection_object_id", FT_BYTES, BASE_HEX,
-           NULL, 0, "", HFILL}},
+          {"Collection Object Id", "scsi.osd.collection_object_id", FT_BYTES, BASE_NONE,
+           NULL, 0, NULL, HFILL}},
         { &hf_scsi_osd_requested_collection_object_id,
-          {"Requested Collection Object Id", "scsi.osd.requested_collection_object_id", FT_BYTES, BASE_HEX,
-           NULL, 0, "", HFILL}},
+          {"Requested Collection Object Id", "scsi.osd.requested_collection_object_id", FT_BYTES, BASE_NONE,
+           NULL, 0, NULL, HFILL}},
         { &hf_scsi_osd_partition_created_in,
           { "Created In", "scsi.osd.partition.created_in", FT_FRAMENUM, BASE_NONE,
           NULL, 0x0, "The frame this partition was created", HFILL }},
@@ -3167,37 +3168,37 @@ proto_register_scsi_osd(void)
 
 	{ &hf_scsi_osd_flush_scope,
           {"Flush Scope", "scsi.osd.flush.scope", FT_UINT8, BASE_DEC,
-           VALS(flush_scope_vals), 0x03, "", HFILL}},
+           VALS(flush_scope_vals), 0x03, NULL, HFILL}},
 
 	{ &hf_scsi_osd_flush_collection_scope,
           {"Flush Collection Scope", "scsi.osd.flush_collection.scope", FT_UINT8, BASE_DEC,
-           VALS(flush_collection_scope_vals), 0x03, "", HFILL}},
+           VALS(flush_collection_scope_vals), 0x03, NULL, HFILL}},
 
 	{ &hf_scsi_osd_flush_partition_scope,
           {"Flush Partition Scope", "scsi.osd.flush_partition.scope", FT_UINT8, BASE_DEC,
-           VALS(flush_partition_scope_vals), 0x03, "", HFILL}},
+           VALS(flush_partition_scope_vals), 0x03, NULL, HFILL}},
 
 	{ &hf_scsi_osd_flush_osd_scope,
           {"Flush OSD Scope", "scsi.osd.flush_osd.scope", FT_UINT8, BASE_DEC,
-           VALS(flush_osd_scope_vals), 0x03, "", HFILL}},
+           VALS(flush_osd_scope_vals), 0x03, NULL, HFILL}},
 	{ &hf_scsi_osd_attributes_list_type,
           {"Attributes List Type", "scsi.osd.attributes_list.type", FT_UINT8, BASE_HEX,
-           VALS(attributes_list_type_vals), 0x0f, "", HFILL}},
+           VALS(attributes_list_type_vals), 0x0f, NULL, HFILL}},
 	{ &hf_scsi_osd_attributes_list_length,
           {"Attributes List Length", "scsi.osd.attributes_list.length", FT_UINT16, BASE_DEC,
-           NULL, 0, "", HFILL}},
+           NULL, 0, NULL, HFILL}},
 	{ &hf_scsi_osd_attributes_page,
 	  {"Attributes Page", "scsi.osd.attributes.page", FT_UINT32, BASE_HEX,
-	  VALS(attributes_page_vals), 0, "", HFILL}},
+	  VALS(attributes_page_vals), 0, NULL, HFILL}},
 	{ &hf_scsi_osd_attribute_number,
 	  {"Attribute Number", "scsi.osd.attribute.number", FT_UINT32, BASE_HEX,
-	  NULL, 0, "", HFILL}},
+	  NULL, 0, NULL, HFILL}},
 	{ &hf_scsi_osd_attribute_length,
 	  {"Attribute Length", "scsi.osd.attribute.length", FT_UINT16, BASE_DEC,
-	  NULL, 0, "", HFILL}},
+	  NULL, 0, NULL, HFILL}},
 	{ &hf_scsi_osd_user_object_logical_length,
 	 {"User Object Logical Length", "scsi.osd.user_object.logical_length", FT_UINT64, BASE_DEC,
-	  NULL, 0, "", HFILL}},
+	  NULL, 0, NULL, HFILL}},
 	};
 
 	/* Setup protocol subtree array */
