@@ -4,7 +4,7 @@
  * Jason Lango <jal@netapp.com>
  * Liberally copied from packet-http.c, by Guy Harris <guy@alum.mit.edu>
  *
- * $Id: packet-sdp.c 29568 2009-08-26 19:27:49Z wmeier $
+ * $Id: packet-sdp.c 31053 2009-11-23 18:47:52Z stig $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -32,7 +32,9 @@
 #include <string.h>
 #include <ctype.h>
 
+#ifdef HAVE_SYS_TYPES_H
 #include <sys/types.h>
+#endif
 #ifdef HAVE_SYS_SOCKET_H
 #include <sys/socket.h>
 #endif
@@ -282,6 +284,7 @@ dissect_sdp(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
   guint32     ipaddr[4];
   gint        n,i;
   sdp_packet_info *sdp_pi;
+  gchar       *unknown_encoding = ep_strdup("Unknown");
 
   /* Initialise packet info for passing to tap */
   sdp_pi = ep_alloc(sizeof(sdp_packet_info));
@@ -292,7 +295,7 @@ dissect_sdp(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
   transport_info.connection_type=NULL;
   transport_info.media_type=NULL;
   for (n=0; n < SDP_NO_OF_PT; n++){
-	  transport_info.encoding_name[n]=NULL;
+	  transport_info.encoding_name[n]=unknown_encoding;
   }
   for (n=0; n < SDP_MAX_RTP_CHANNELS; n++)
   {
@@ -318,8 +321,7 @@ dissect_sdp(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
    * what the protocol inside which the SDP stuff resides
    * put there.
    */
-  if (check_col(pinfo->cinfo, COL_PROTOCOL))
-    col_append_str(pinfo->cinfo, COL_PROTOCOL, "/SDP");
+  col_append_str(pinfo->cinfo, COL_PROTOCOL, "/SDP");
 
   if (check_col(pinfo->cinfo, COL_INFO)) {
     /* XXX: Needs description. */
@@ -1156,7 +1158,7 @@ dissect_sdp_media(tvbuff_t *tvb, proto_item *ti,
 static tvbuff_t *
 ascii_bytes_to_tvb(tvbuff_t *tvb, packet_info *pinfo, gint len, gchar *msg)
 {
-	guint8 *buf = ep_alloc(10240);
+	guint8 *buf = g_malloc(10240);
 
 	/* arbitrary maximum length */
 	if(len<20480){
@@ -1221,6 +1223,7 @@ ascii_bytes_to_tvb(tvbuff_t *tvb, packet_info *pinfo, gint len, gchar *msg)
 			return NULL;
 		}
 		bytes_tvb = tvb_new_child_real_data(tvb, buf,i,i);
+                tvb_set_free_cb(bytes_tvb, g_free);
 		add_new_data_source(pinfo, bytes_tvb, "ASCII bytes to tvb");
 		return bytes_tvb;
 	}
