@@ -2,7 +2,7 @@
 *
 * Routine to dissect ITU-T Rec. X.225 (1995 E)/ISO 8327-1 OSI Session Protocol packets
 *
-* $Id: packet-ses.c 23412 2007-11-09 06:01:18Z etxrab $
+* $Id: packet-ses.c 29446 2009-08-16 12:36:22Z krj $
 *
 * Yuriy Sidelnikov <YSidelnikov@hotmail.com>
 *
@@ -40,7 +40,7 @@
 #include "packet-ses.h"
 #include "packet-frame.h"
 
-#include <epan/prefs.h>
+/* #include <epan/prefs.h> */
 #include <epan/emem.h>
 #include <epan/strutil.h>
 
@@ -626,14 +626,25 @@ dissect_parameter(tvbuff_t *tvb, int offset, proto_tree *tree,
 		}
 		if (flags & END_SPDU) {
 			/*
-			 * In Data Transfer and Typed Data SPDUs,
+			 * In Data Transfer and Typed Data SPDUs, (X.225: 8.3.{11,13}.4)
 			 * "The User Information Field shall be present
 			 * if the Enclosure Item is not present, or has
 			 * bit 2 = 0", which presumably means it shall
 			 * *not* be present if the Enclosure item *is*
 			 * present and has bit 2 = 1.
 			 */
-			has_user_information = FALSE;
+
+		  if(!(flags & BEGINNING_SPDU)) {
+		    /* X.225 7.11.2 also states:
+		     * "All DATA TRANSFER SPDUs, except the last DATA TRANSFER SPDU in a sequence greater than one, must have user information"
+		     * So if BEGINNING_SPDU and END_SPDU are set in the enclosure item, then this is presumably a sequence of one and 
+		     * consequently there must be user information.
+		     *
+		     * So, there is only no user information if *only* END_SPDU is set.
+		     */
+
+		     has_user_information = FALSE;
+		  }
 		}
 		break;
 
@@ -811,7 +822,7 @@ dissect_parameter_group(tvbuff_t *tvb, int offset, proto_tree *tree,
 	while(pg_len != 0)
 	{
 		param_type = tvb_get_guint8(tvb, offset);
-		ti = proto_tree_add_text(pg_tree, tvb, offset, -1,
+		ti = proto_tree_add_text(pg_tree, tvb, offset, -1, "%s",
 		    val_to_str(param_type, param_vals,
 		      "Unknown parameter type (0x%02x)"));
 		param_tree = proto_item_add_subtree(ti, ett_ses_param);
@@ -890,7 +901,7 @@ dissect_parameters(tvbuff_t *tvb, int offset, guint16 len, proto_tree *tree,
 	while(len != 0)
 	{
 		param_type = tvb_get_guint8(tvb, offset);
-		ti = proto_tree_add_text(ses_tree, tvb, offset, -1,
+		ti = proto_tree_add_text(ses_tree, tvb, offset, -1, "%s",
 		    val_to_str(param_type, param_vals,
 		      "Unknown parameter type (0x%02x)"));
 		param_tree = proto_item_add_subtree(ti, ett_ses_param);
@@ -1056,7 +1067,7 @@ dissect_spdu(tvbuff_t *tvb, int offset, packet_info *pinfo, proto_tree *tree,
 	/* Dissect user information, if present */
 	if (has_user_information) {
 		if (tvb_reported_length_remaining(tvb, offset) > 0 || type == SES_MAJOR_SYNC_POINT) {
-			next_tvb = tvb_new_subset(tvb, offset, -1, -1);
+			next_tvb = tvb_new_subset_remaining(tvb, offset);
 
 			/* do we have OSI presentation packet dissector ? */
 			if(!pres_handle)
@@ -1097,10 +1108,8 @@ dissect_ses(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 	int offset = 0;
 	guint8 type;
 
-	if (check_col(pinfo->cinfo, COL_PROTOCOL))
-		col_set_str(pinfo->cinfo, COL_PROTOCOL, "SES");
-  	if (check_col(pinfo->cinfo, COL_INFO))
-  		col_clear(pinfo->cinfo, COL_INFO);
+	col_set_str(pinfo->cinfo, COL_PROTOCOL, "SES");
+  	col_clear(pinfo->cinfo, COL_INFO);
 
 	/*
 	 * Do we have a category 0 SPDU (GIVE_TOKENS/PLEASE_TOKENS) as
@@ -1132,7 +1141,7 @@ proto_register_ses(void)
 				BASE_DEC,
 				VALS(ses_vals),
 				0x0,
-				"", HFILL
+				NULL, HFILL
 			}
 		},
 		{
@@ -1144,7 +1153,7 @@ proto_register_ses(void)
 				BASE_DEC,
 				VALS(ses_category0_vals),
 				0x0,
-				"", HFILL
+				NULL, HFILL
 			}
 		},
 		{
@@ -1156,7 +1165,7 @@ proto_register_ses(void)
 				BASE_DEC,
 				NULL,
 				0x0,
-				"", HFILL
+				NULL, HFILL
 			}
 		},
 
@@ -1169,7 +1178,7 @@ proto_register_ses(void)
 				BASE_DEC,
 				NULL,
 				0x0,
-				"", HFILL
+				NULL, HFILL
 			}
 		},
 		{
@@ -1181,7 +1190,7 @@ proto_register_ses(void)
 				BASE_DEC,
 				NULL,
 				0x0,
-				"", HFILL
+				NULL, HFILL
 			}
 		},
 		{
@@ -1192,7 +1201,7 @@ proto_register_ses(void)
 				FT_BYTES, BASE_NONE,
 				NULL,
 				0x0,
-				"Called SS User Reference",
+				NULL,
 				HFILL
 			}
 		},
@@ -1204,7 +1213,7 @@ proto_register_ses(void)
 				FT_BYTES, BASE_NONE,
 				NULL,
 				0x0,
-				"Calling SS User Reference",
+				NULL,
 				HFILL
 			}
 		},
@@ -1216,7 +1225,7 @@ proto_register_ses(void)
 				FT_BYTES, BASE_NONE,
 				NULL,
 				0x0,
-				"Common Reference",
+				NULL,
 				HFILL
 			}
 		},
@@ -1228,7 +1237,7 @@ proto_register_ses(void)
 				FT_BYTES, BASE_NONE,
 				NULL,
 				0x0,
-				"Additional Reference Information",
+				NULL,
 				HFILL
 			}
 		},
@@ -1240,7 +1249,7 @@ proto_register_ses(void)
 				FT_BOOLEAN, 8,
 				NULL,
 				RELEASE_TOKEN,
-				"release token",
+				NULL,
 				HFILL
 			}
 		},
@@ -1252,7 +1261,7 @@ proto_register_ses(void)
 				FT_BOOLEAN, 8,
 				NULL,
 				MAJOR_ACTIVITY_TOKEN,
-				"major/activity token",
+				NULL,
 				HFILL
 			}
 		},
@@ -1264,7 +1273,7 @@ proto_register_ses(void)
 				FT_BOOLEAN, 8,
 				NULL,
 				SYNCHRONIZE_MINOR_TOKEN,
-				"synchronize minor token",
+				NULL,
 				HFILL
 			}
 		},
@@ -1288,7 +1297,7 @@ proto_register_ses(void)
 				FT_BOOLEAN, 8,
 				NULL,
 				SES_EXT_CONT,
-				"Able to receive extended concatenated SPDU",
+				NULL,
 				HFILL
 			}
 		},
@@ -1301,7 +1310,7 @@ proto_register_ses(void)
 				BASE_HEX,
 				NULL,
 				0x0,
-				"",
+				NULL,
 				HFILL
 			}
 		},
@@ -1313,7 +1322,7 @@ proto_register_ses(void)
 				FT_BOOLEAN, 16,
 				NULL,
 				SES_EXCEPTION_REPORT,
-				"Session exception report",
+				NULL,
 				HFILL
 			}
 		},
@@ -1325,7 +1334,7 @@ proto_register_ses(void)
 				FT_BOOLEAN, 16,
 				NULL,
 				DATA_SEPARATION_FUNCTION_UNIT,
-				"Data separation function unit",
+				NULL,
 				HFILL
 			}
 		},
@@ -1337,7 +1346,7 @@ proto_register_ses(void)
 				FT_BOOLEAN, 16,
 				NULL,
 				SYMMETRIC_SYNCHRONIZE_FUNCTION_UNIT,
-				"Symmetric synchronize function unit",
+				NULL,
 				HFILL
 			}
 		},
@@ -1349,7 +1358,7 @@ proto_register_ses(void)
 				FT_BOOLEAN, 16,
 				NULL,
 				TYPED_DATA_FUNCTION_UNIT,
-				"Typed data function unit",
+				NULL,
 				HFILL
 			}
 		},
@@ -1361,7 +1370,7 @@ proto_register_ses(void)
 				FT_BOOLEAN, 16,
 				NULL,
 				EXCEPTION_FUNCTION_UNIT,
-				"Exception function unit",
+				NULL,
 				HFILL
 			}
 		},
@@ -1373,7 +1382,7 @@ proto_register_ses(void)
 				FT_BOOLEAN, 16,
 				NULL,
 				CAPABILITY_DATA_FUNCTION_UNIT,
-				"Capability function unit",
+				NULL,
 				HFILL
 			}
 		},
@@ -1385,7 +1394,7 @@ proto_register_ses(void)
 				FT_BOOLEAN, 16,
 				NULL,
 				NEGOTIATED_RELEASE_FUNCTION_UNIT,
-				"Negotiated release function unit",
+				NULL,
 				HFILL
 			}
 		},
@@ -1397,7 +1406,7 @@ proto_register_ses(void)
 				FT_BOOLEAN, 16,
 				NULL,
 				ACTIVITY_MANAGEMENT_FUNCTION_UNIT,
-				"Activity management function unit",
+				NULL,
 				HFILL
 			}
 		},
@@ -1409,7 +1418,7 @@ proto_register_ses(void)
 				FT_BOOLEAN, 16,
 				NULL,
 				RESYNCHRONIZE_FUNCTION_UNIT,
-				"Resynchronize function unit",
+				NULL,
 				HFILL
 			}
 		},
@@ -1421,7 +1430,7 @@ proto_register_ses(void)
 				FT_BOOLEAN, 16,
 				NULL,
 				MAJOR_SYNCHRONIZE_FUNCTION_UNIT,
-				"Major resynchronize function unit",
+				NULL,
 				HFILL
 			}
 		},
@@ -1433,7 +1442,7 @@ proto_register_ses(void)
 				FT_BOOLEAN, 16,
 				NULL,
 				MINOR_SYNCHRONIZE_FUNCTION_UNIT,
-				"Minor resynchronize function unit",
+				NULL,
 				HFILL
 			}
 		},
@@ -1445,7 +1454,7 @@ proto_register_ses(void)
 				FT_BOOLEAN, 16,
 				NULL,
 				EXPEDITED_DATA_FUNCTION_UNIT,
-				"Expedited data function unit",
+				NULL,
 				HFILL
 			}
 		},
@@ -1457,7 +1466,7 @@ proto_register_ses(void)
 				FT_BOOLEAN, 16,
 				NULL,
 				DUPLEX_FUNCTION_UNIT,
-				"Duplex functional unit",
+				NULL,
 				HFILL
 			}
 		},
@@ -1469,7 +1478,7 @@ proto_register_ses(void)
 				FT_BOOLEAN, 16,
 				NULL,
 				HALF_DUPLEX_FUNCTION_UNIT,
-				"Half-duplex functional unit",
+				NULL,
 				HFILL
 			}
 		},
@@ -1482,7 +1491,7 @@ proto_register_ses(void)
 				BASE_DEC,
 				NULL,
 				0x0,
-				"Proposed TSDU Maximum Size, Initiator to Responder",
+				NULL,
 				HFILL
 			}
 		},
@@ -1495,7 +1504,7 @@ proto_register_ses(void)
 				BASE_DEC,
 				NULL,
 				0x0,
-				"Proposed TSDU Maximum Size, Responder to Initiator",
+				NULL,
 				HFILL
 			}
 		},
@@ -1507,7 +1516,7 @@ proto_register_ses(void)
 				FT_BOOLEAN, 8,
 				NULL,
 				PROTOCOL_VERSION_1,
-				"Protocol Version 1",
+				NULL,
 				HFILL
 			}
 		},
@@ -1519,7 +1528,7 @@ proto_register_ses(void)
 				FT_BOOLEAN, 8,
 				NULL,
 				PROTOCOL_VERSION_2,
-				"Protocol Version 2",
+				NULL,
 				HFILL
 			}
 		},
@@ -1531,7 +1540,7 @@ proto_register_ses(void)
 				FT_STRING, BASE_NONE,
 				NULL,
 				0x0,
-				"Initial Serial Number",
+				NULL,
 				HFILL
 			}
 		},
@@ -1543,7 +1552,7 @@ proto_register_ses(void)
 				FT_BOOLEAN, 8,
 				NULL,
 				BEGINNING_SPDU,
-				"beginning of SSDU",
+				NULL,
 				HFILL
 			}
 		},
@@ -1555,7 +1564,7 @@ proto_register_ses(void)
 				FT_BOOLEAN, 8,
 				NULL,
 				END_SPDU,
-				"end of SSDU",
+				NULL,
 				HFILL
 			}
 		},
@@ -1567,7 +1576,7 @@ proto_register_ses(void)
 				FT_UINT8, BASE_HEX,
 				VALS(token_setting_vals),
 				0xC0,
-				"release token setting",
+				NULL,
 				HFILL
 			}
 		},
@@ -1591,7 +1600,7 @@ proto_register_ses(void)
 				FT_UINT8, BASE_HEX,
 				VALS(token_setting_vals),
 				0x0C,
-				"synchronize-minor token setting",
+				NULL,
 				HFILL
 			}
 		},
@@ -1603,7 +1612,7 @@ proto_register_ses(void)
 				FT_UINT8, BASE_HEX,
 				VALS(token_setting_vals),
 				0x03,
-				"data token setting",
+				NULL,
 				HFILL
 			}
 		},
@@ -1615,7 +1624,7 @@ proto_register_ses(void)
 				FT_UINT32, BASE_DEC,
 				NULL,
 				0x0,
-				"Activity Identifier",
+				NULL,
 				HFILL
 			}
 		},
@@ -1627,7 +1636,7 @@ proto_register_ses(void)
 				FT_STRING, BASE_NONE,
 				NULL,
 				0x0,
-				"Serial Number",
+				NULL,
 				HFILL
 			}
 		},
@@ -1639,7 +1648,7 @@ proto_register_ses(void)
 				FT_BYTES, BASE_NONE,
 				NULL,
 				0x0,
-				"Calling Session Selector",
+				NULL,
 				HFILL
 			}
 		},
@@ -1651,7 +1660,7 @@ proto_register_ses(void)
 				FT_BYTES, BASE_NONE,
 				NULL,
 				0x0,
-				"Called Session Selector",
+				NULL,
 				HFILL
 			}
 		},
@@ -1663,7 +1672,7 @@ proto_register_ses(void)
 				FT_STRING, BASE_NONE,
 				NULL,
 				0x0,
-				"Second Serial Number",
+				NULL,
 				HFILL
 			}
 		},
@@ -1675,7 +1684,7 @@ proto_register_ses(void)
 				FT_STRING, BASE_NONE,
 				NULL,
 				0x0,
-				"Second Initial Serial Number",
+				NULL,
 				HFILL
 			}
 		},
@@ -1687,7 +1696,7 @@ proto_register_ses(void)
 				FT_STRING, BASE_NONE,
 				NULL,
 				0x0,
-				"Large Initial Serial Number",
+				NULL,
 				HFILL
 			}
 		},
@@ -1699,7 +1708,7 @@ proto_register_ses(void)
 				FT_STRING, BASE_NONE,
 				NULL,
 				0x0,
-				"Large Second Initial Serial Number",
+				NULL,
 				HFILL
 			}
 		},
@@ -1712,7 +1721,7 @@ proto_register_ses(void)
 				BASE_HEX,
 				NULL,
 				0x0,
-				"",
+				NULL,
 				HFILL
 			}
 		},
@@ -1726,7 +1735,7 @@ proto_register_ses(void)
 				BASE_HEX,
 				NULL,
 				0x0,
-				"",
+				NULL,
 				HFILL
 			}
 		},
@@ -1741,7 +1750,7 @@ proto_register_ses(void)
 				BASE_HEX,
 				NULL,
 				0x0,
-				"",
+				NULL,
 				HFILL
 			}
 		},
@@ -1756,7 +1765,7 @@ proto_register_ses(void)
 				BASE_HEX,
 				NULL,
 				0x0,
-				"",
+				NULL,
 				HFILL
 			}
 		},
@@ -1772,15 +1781,16 @@ proto_register_ses(void)
 		&ett_token_item_flags,
 		&ett_ses_req_options_flags,
 	};
-	module_t *ses_module;
+/* 	module_t *ses_module; */
 
 
 	proto_ses = proto_register_protocol(PROTO_STRING_SES, "SES", "ses");
 	proto_register_field_array(proto_ses, hf, array_length(hf));
 	proto_register_subtree_array(ett, array_length(ett));
 
-	ses_module = prefs_register_protocol(proto_ses, NULL);
 /*
+	ses_module = prefs_register_protocol(proto_ses, NULL);
+
 	prefs_register_bool_preference(ses_module, "desegment",
 	    "Reassemble session packets ",
 	    "Whether the session dissector should reassemble messages spanning multiple SES segments",
