@@ -3,7 +3,7 @@
  * Used to dissect XID compression parameters negotiated in GSM (TS44.065)
  * Copyright 2008, Vincent Helfre <vincent.helfre [AT] ericsson.com>
  *
- * $Id: packet-sndcp-xid.c 26277 2008-09-26 17:04:01Z wmeier $
+ * $Id: packet-sndcp-xid.c 30907 2009-11-09 15:51:30Z stig $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -481,19 +481,17 @@ dissect_sndcp_xid(tvbuff_t *tvb, packet_info *pinfo _U_, proto_tree *tree)
 	/* Set up structures needed to add the protocol subtree and manage it 
 	*/
 	proto_item *ti, *version_item, *dcomp_item, *pcomp_item;
-	proto_tree *sndcp_xid_tree = NULL, *version_tree = NULL, *dcomp_tree, *pcomp_tree = NULL;
+	proto_tree *sndcp_tree, *version_tree, *dcomp_tree, *pcomp_tree;
 	guint16 offset = 0, l3_param_len;
 	guint8 parameter_type, parameter_len;
 
 	/* create display subtree for the protocol 
 	*/
-	if (tree) {
-		ti         = proto_tree_add_item(tree, proto_sndcp_xid, tvb, 0, -1, FALSE);
-		sndcp_xid_tree = proto_item_add_subtree(ti, ett_sndcp_xid);
-	}
+	ti = proto_tree_add_item(tree, proto_sndcp_xid, tvb, 0, -1, FALSE);
+	sndcp_tree = proto_item_add_subtree(ti, ett_sndcp_xid);
 	l3_param_len = tvb_reported_length(tvb);
 
-	while (offset < l3_param_len)
+	while (offset < l3_param_len-1)
 	{
 		parameter_type = tvb_get_guint8(tvb, offset);
 		parameter_len = tvb_get_guint8(tvb, offset+1);
@@ -501,7 +499,7 @@ dissect_sndcp_xid(tvbuff_t *tvb, packet_info *pinfo _U_, proto_tree *tree)
 		if (parameter_type == SNDCP_VERSION_PAR_TYPE)
 		{
 			guint8 value = tvb_get_guint8(tvb, offset+2);
-			version_item = proto_tree_add_text(tree, tvb, offset, parameter_len+2,
+			version_item = proto_tree_add_text(sndcp_tree, tvb, offset, parameter_len+2,
 					"Version (SNDCP version number) - Value %d", value);
 		
 			version_tree = proto_item_add_subtree(version_item, ett_sndcp_xid_version_field);
@@ -518,7 +516,7 @@ dissect_sndcp_xid(tvbuff_t *tvb, packet_info *pinfo _U_, proto_tree *tree)
 		{
 			tvbuff_t * dcomp_tvb;
 
-			dcomp_item = proto_tree_add_text(tree, tvb, offset, parameter_len+2,
+			dcomp_item = proto_tree_add_text(sndcp_tree, tvb, offset, parameter_len+2,
 				"Data Compression");
 			dcomp_tree = proto_item_add_subtree(dcomp_item, ett_sndcp_comp_field);
 			proto_tree_add_uint(dcomp_tree, hf_sndcp_xid_type, tvb, offset,
@@ -537,7 +535,7 @@ dissect_sndcp_xid(tvbuff_t *tvb, packet_info *pinfo _U_, proto_tree *tree)
 		{
 			tvbuff_t * pcomp_tvb;
 
-			pcomp_item = proto_tree_add_text(tree, tvb, offset, parameter_len+2,
+			pcomp_item = proto_tree_add_text(sndcp_tree, tvb, offset, parameter_len+2,
 				"Protocol Control Information Compression");
 			pcomp_tree = proto_item_add_subtree(pcomp_item, ett_sndcp_comp_field);
 			proto_tree_add_uint(pcomp_tree, hf_sndcp_xid_type, tvb, offset,
@@ -723,11 +721,11 @@ static void parse_compression_parameters(tvbuff_t *tvb, proto_tree *tree, gboole
 
 void
 proto_register_sndcp_xid(void)
-{                 
+{
   /* Setup list of header fields
    */
-  static hf_register_info hf[] = {
-    		/* L3 XID Parameter Parsing Info */
+	static hf_register_info hf[] = {
+		/* L3 XID Parameter Parsing Info */
 		{&hf_sndcp_xid_type,
 				{ "Parameter type","llcgprs.l3xidpartype", FT_UINT8, BASE_DEC, NULL, 0xFF, "Data", HFILL}},
 		{&hf_sndcp_xid_len,
@@ -864,15 +862,14 @@ proto_register_sndcp_xid(void)
 				{ "P3r MSB","sndcpxid.V44_p3r_msb", FT_UINT8, BASE_HEX, NULL, 0xFF, "Data", HFILL}},
  		{&hf_sndcp_xid_V44_p3r_lsb,
 				{ "P3r LSB","sndcpxid.V44_p3r_lsb", FT_UINT8, BASE_HEX, NULL, 0xFF, "Data", HFILL}},
-				
- };
+	};
 
    /* Setup protocol subtree array */
   static gint *ett[] = {
     &ett_sndcp_xid,
     &ett_sndcp_xid_version_field,
-	&ett_sndcp_comp_field
-  };  
+    &ett_sndcp_comp_field
+  };
 
   /* Register the protocol name and description */
   proto_sndcp_xid = proto_register_protocol("Subnetwork Dependent Convergence Protocol XID",
