@@ -2,7 +2,7 @@
  * Routines for Subnetwork Dependent Convergence Protocol (SNDCP) dissection
  * Copyright 2000, Christian Falckenberg <christian.falckenberg@nortelnetworks.com>
  *
- * $Id: packet-sndcp.c 22846 2007-09-11 16:59:57Z etxrab $
+ * $Id: packet-sndcp.c 29446 2009-08-16 12:36:22Z krj $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -208,10 +208,8 @@ dissect_sndcp(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 
   /* Make entries in Protocol column and clear Info column on summary display 
    */
-  if (check_col(pinfo->cinfo, COL_PROTOCOL)) 
-    col_set_str(pinfo->cinfo, COL_PROTOCOL, "SNDCP");
-  if (check_col(pinfo->cinfo, COL_INFO)) 
-    col_clear(pinfo->cinfo, COL_INFO);
+  col_set_str(pinfo->cinfo, COL_PROTOCOL, "SNDCP");
+  col_clear(pinfo->cinfo, COL_INFO);
   
   /* create display subtree for the protocol 
    */
@@ -310,7 +308,7 @@ dissect_sndcp(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
   /* handle N-PDU data, reassemble if necessary 
    */
   if (first && !more_frags) {
-    next_tvb = tvb_new_subset (tvb, offset, -1, -1);
+    next_tvb = tvb_new_subset_remaining (tvb, offset);
     
     if (!dcomp && !pcomp) {
       call_dissector(ip_handle, next_tvb, pinfo, tree);
@@ -414,7 +412,7 @@ proto_register_sndcp(void)
       { "First segment indicator bit", 
 	"sndcp.f", 
 	FT_BOOLEAN,8, TFS(&f_bit), MASK_F, 
-	"First segment indicator bit", HFILL 
+	NULL, HFILL 
       }
     },
     { &hf_sndcp_t, 
@@ -428,7 +426,7 @@ proto_register_sndcp(void)
       { "More bit", 
 	"sndcp.m", 
 	FT_BOOLEAN,8, TFS(&m_bit), MASK_M, 
-	"More bit", HFILL 
+	NULL, HFILL 
       }
     },
     { &hf_sndcp_dcomp, 
@@ -449,7 +447,7 @@ proto_register_sndcp(void)
       { "NSAPI", 
 	"sndcp.nsapib", 
 	FT_UINT8, BASE_DEC , VALS(nsapi_t), 0xf, 
-	"Network Layer Service Access Point Identifier ",HFILL 
+	"Network Layer Service Access Point Identifier",HFILL 
       }
     },	
     { &hf_sndcp_segment, 
@@ -463,14 +461,14 @@ proto_register_sndcp(void)
       { "N-PDU", 
 	"sndcp.npdu", 
 	FT_UINT8, BASE_DEC, NULL, 0, 
-	"N-PDU", HFILL 
+	NULL, HFILL 
       }
     },
     { &hf_sndcp_npdu2, 
       { "N-PDU", 
 	"sndcp.npdu", 
 	FT_UINT16, BASE_DEC, NULL, 0x0FFF, 
-	"N-PDU", HFILL 
+	NULL, HFILL 
       }
     },
 
@@ -522,14 +520,14 @@ proto_register_sndcp(void)
       {	"N-PDU Fragment",
 	"npdu.fragment",
 	FT_FRAMENUM, BASE_NONE, NULL, 0x0,
-	"N-PDU Fragment", HFILL
+	NULL, HFILL
       }
     },
     { &hf_npdu_fragments,
       {	"N-PDU Fragments",
 	"npdu.fragments",
 	FT_NONE, BASE_NONE, NULL, 0x0,
-	"N-PDU Fragments", HFILL
+	NULL, HFILL
       }
     }
   };
