@@ -1,7 +1,7 @@
 /* packet-udp.c
  * Routines for UDP/UDPLite packet disassembly
  *
- * $Id: packet-udp.c 29170 2009-07-22 21:33:47Z etxrab $
+ * $Id: packet-udp.c 30851 2009-11-07 08:07:12Z krj $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -107,16 +107,16 @@ static gboolean try_heuristic_first = FALSE;
 static struct udp_analysis *
 init_udp_conversation_data(void)
 {
-  struct udp_analysis *udpd=NULL;
+  struct udp_analysis *udpd;
 
   /* Initialize the udp protocol data structure to add to the udp conversation */
   udpd = se_alloc0(sizeof(struct udp_analysis));
-  memset(&udpd->flow1, 0, sizeof(udp_flow_t));
-  memset(&udpd->flow2, 0, sizeof(udp_flow_t));
+  /*
   udpd->flow1.username = NULL;
   udpd->flow1.command = NULL;
   udpd->flow2.username = NULL;
   udpd->flow2.command = NULL;
+  */
 
   return udpd;
 }
@@ -546,7 +546,7 @@ dissect(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, guint32 ip_proto)
     udpd=get_udp_conversation_data(conv,pinfo);
   }
 
-  if (udpd && (udpd->fwd || udpd->rev) && (udpd->fwd->command || udpd->rev->command)) {
+  if (udpd && ((udpd->fwd && udpd->fwd->command) || (udpd->rev && udpd->rev->command))) {
     ti = proto_tree_add_text(udp_tree, tvb, offset, 0, "Process Information");
 	PROTO_ITEM_SET_GENERATED(ti);
     process_tree = proto_item_add_subtree(ti, ett_udp_process_info);
