@@ -1,6 +1,6 @@
 /* packet-usb-masstorage.c
  *
- * $Id: packet-usb-masstorage.c 19659 2006-10-22 11:49:23Z sahlberg $
+ * $Id: packet-usb-masstorage.c 29344 2009-08-09 07:36:13Z krj $
  *
  * usb mass storage dissector
  * Ronnie Sahlberg 2006
@@ -71,7 +71,7 @@ static const value_string status_vals[] = {
 
 
 static void
-dissect_usb_ms_reset(packet_info *pinfo, proto_tree *tree, tvbuff_t *tvb, int offset, gboolean is_request, usb_trans_info_t *usb_trans_info, usb_conv_info_t *usb_conv_info)
+dissect_usb_ms_reset(packet_info *pinfo _U_, proto_tree *tree, tvbuff_t *tvb, int offset, gboolean is_request, usb_trans_info_t *usb_trans_info _U_, usb_conv_info_t *usb_conv_info _U_)
 {
     if(is_request){
         proto_tree_add_item(tree, hf_usb_ms_value, tvb, offset, 2, FALSE);
@@ -88,7 +88,7 @@ dissect_usb_ms_reset(packet_info *pinfo, proto_tree *tree, tvbuff_t *tvb, int of
 }
 
 static void
-dissect_usb_ms_get_max_lun(packet_info *pinfo, proto_tree *tree, tvbuff_t *tvb, int offset, gboolean is_request, usb_trans_info_t *usb_trans_info, usb_conv_info_t *usb_conv_info)
+dissect_usb_ms_get_max_lun(packet_info *pinfo _U_, proto_tree *tree, tvbuff_t *tvb, int offset, gboolean is_request, usb_trans_info_t *usb_trans_info _U_, usb_conv_info_t *usb_conv_info _U_)
 {
     if(is_request){
         proto_tree_add_item(tree, hf_usb_ms_value, tvb, offset, 2, FALSE);
@@ -162,8 +162,7 @@ dissect_usb_ms_control(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
     }
 
 
-    if(check_col(pinfo->cinfo, COL_PROTOCOL))
-        col_set_str(pinfo->cinfo, COL_PROTOCOL, "USBMS");
+    col_set_str(pinfo->cinfo, COL_PROTOCOL, "USBMS");
 
     if (check_col(pinfo->cinfo, COL_INFO)) {
         col_clear(pinfo->cinfo, COL_INFO);
@@ -197,22 +196,20 @@ dissect_usb_ms_bulk(tvbuff_t *tvb, packet_info *pinfo, proto_tree *parent_tree)
 
     usb_conv_info=pinfo->usb_conv_info;
     /* verify that we do have a usb_ms_conv_info */
-    usb_ms_conv_info=usb_conv_info->masstorage;
+    usb_ms_conv_info=usb_conv_info->class_data;
     if(!usb_ms_conv_info){
         usb_ms_conv_info=se_alloc(sizeof(usb_ms_conv_info_t));
         usb_ms_conv_info->itl=se_tree_create_non_persistent(EMEM_TREE_TYPE_RED_BLACK, "USB ITL");
         usb_ms_conv_info->itlq=se_tree_create_non_persistent(EMEM_TREE_TYPE_RED_BLACK, "USB ITLQ");
-        usb_conv_info->masstorage=usb_ms_conv_info;
+        usb_conv_info->class_data=usb_ms_conv_info;
     }
 
 
     is_request=(pinfo->srcport==NO_ENDPOINT);
 
-    if(check_col(pinfo->cinfo, COL_PROTOCOL))
-        col_set_str(pinfo->cinfo, COL_PROTOCOL, "USBMS");
+    col_set_str(pinfo->cinfo, COL_PROTOCOL, "USBMS");
 
-    if(check_col(pinfo->cinfo, COL_INFO))
-        col_clear(pinfo->cinfo, COL_INFO);
+    col_clear(pinfo->cinfo, COL_INFO);
 
 
     if(parent_tree){
@@ -374,59 +371,59 @@ proto_register_usb_ms(void)
     static hf_register_info hf[] = {
         { &hf_usb_ms_dCBWSignature,
         { "Signature", "usbms.dCBWSignature", FT_UINT32, BASE_HEX, 
-          NULL, 0x0, "", HFILL }},
+          NULL, 0x0, NULL, HFILL }},
 
         { &hf_usb_ms_dCBWTag,
         { "Tag", "usbms.dCBWTag", FT_UINT32, BASE_HEX, 
-          NULL, 0x0, "", HFILL }},
+          NULL, 0x0, NULL, HFILL }},
 
         { &hf_usb_ms_dCBWDataTransferLength,
         { "DataTransferLength", "usbms.dCBWDataTransferLength", FT_UINT32, BASE_DEC, 
-          NULL, 0x0, "", HFILL }},
+          NULL, 0x0, NULL, HFILL }},
 
         { &hf_usb_ms_dCBWFlags,
         { "Flags", "usbms.dCBWFlags", FT_UINT8, BASE_HEX, 
-          NULL, 0x0, "", HFILL }},
+          NULL, 0x0, NULL, HFILL }},
 
         { &hf_usb_ms_dCBWLUN,
         { "LUN", "usbms.dCBWLUN", FT_UINT8, BASE_HEX, 
-          NULL, 0x0f, "", HFILL }},
+          NULL, 0x0f, NULL, HFILL }},
 
         { &hf_usb_ms_dCBWCBLength,
         { "CDB Length", "usbms.dCBWCBLength", FT_UINT8, BASE_HEX, 
-          NULL, 0x1f, "", HFILL }},
+          NULL, 0x1f, NULL, HFILL }},
 
         { &hf_usb_ms_dCSWSignature,
         { "Signature", "usbms.dCSWSignature", FT_UINT32, BASE_HEX, 
-          NULL, 0x0, "", HFILL }},
+          NULL, 0x0, NULL, HFILL }},
 
         { &hf_usb_ms_dCSWDataResidue,
         { "DataResidue", "usbms.dCSWDataResidue", FT_UINT32, BASE_DEC, 
-          NULL, 0x0, "", HFILL }},
+          NULL, 0x0, NULL, HFILL }},
 
         { &hf_usb_ms_dCSWStatus,
         { "Status", "usbms.dCSWStatus", FT_UINT8, BASE_HEX, 
-          VALS(status_vals), 0x0, "", HFILL }},
+          VALS(status_vals), 0x0, NULL, HFILL }},
 
         { &hf_usb_ms_request,
         { "bRequest", "usbms.setup.bRequest", FT_UINT8, BASE_HEX, VALS(setup_request_names_vals), 0x0,
-                "", HFILL }},
+                NULL, HFILL }},
 
         { &hf_usb_ms_value,
         { "wValue", "usbms.setup.wValue", FT_UINT16, BASE_HEX, NULL, 0x0,
-                "", HFILL }},
+                NULL, HFILL }},
 
         { &hf_usb_ms_index,
         { "wIndex", "usbms.setup.wIndex", FT_UINT16, BASE_DEC, NULL, 0x0,
-                "", HFILL }},
+                NULL, HFILL }},
 
         { &hf_usb_ms_length,
         { "wLength", "usbms.setup.wLength", FT_UINT16, BASE_DEC, NULL, 0x0,
-                "", HFILL }},
+                NULL, HFILL }},
                 
         { &hf_usb_ms_maxlun,
         { "Max LUN", "usbms.setup.maxlun", FT_UINT8, BASE_DEC, NULL, 0x0,
-                "", HFILL }},
+                NULL, HFILL }},
                 
     };
     
@@ -448,7 +445,7 @@ proto_reg_handoff_usb_ms(void)
     dissector_handle_t usb_ms_bulk_handle;
     dissector_handle_t usb_ms_control_handle;
 
-    usb_ms_bulk_handle = create_dissector_handle(dissect_usb_ms_bulk, proto_usb_ms);
+    usb_ms_bulk_handle = find_dissector("usbms");
     dissector_add("usb.bulk", IF_CLASS_MASSTORAGE, usb_ms_bulk_handle);
 
     usb_ms_control_handle = new_create_dissector_handle(dissect_usb_ms_control, proto_usb_ms);
