@@ -2,7 +2,7 @@
  * Routines for Web Cache Coordination Protocol dissection
  * Jerry Talkington <jtalkington@users.sourceforge.net>
  *
- * $Id: packet-wccp.c 29346 2009-08-09 08:14:59Z krj $
+ * $Id: packet-wccp.c 30691 2009-10-25 11:43:30Z etxrab $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -389,13 +389,12 @@ wccp_bucket_info(guint8 bucket_info, proto_tree *bucket_tree, guint32 start,
 static gchar *
 bucket_name(guint8 bucket)
 {
-	gchar *cur=NULL;
+	gchar *cur;
 
 	if (bucket == 0xff) {
 		cur="Unassigned";
 	} else {
-		cur=ep_alloc(10+1);
-		g_snprintf(cur, 10+1, "%u", bucket);
+		cur=ep_strdup_printf("%u", bucket);
 	}
 	return cur;
 }
@@ -979,13 +978,12 @@ dissect_wccp2_router_assignment_element(tvbuff_t *tvb, int offset,
 static gchar *
 assignment_bucket_name(guint8 bucket)
 {
-	gchar *cur=NULL;
+	gchar *cur;
 
 	if (bucket == 0xff) {
 		cur="Unassigned";
 	} else {
-		cur=ep_alloc(10+1);
-		g_snprintf(cur, 10+1, "%u%s", bucket >> 1,
+		cur=ep_strdup_printf("%u%s", bucket >> 1,
 		    (bucket & 0x01) ? " (Alt)" : "");
 	}
 	return cur;
