@@ -2,7 +2,7 @@
  * Routines for XDMCP message dissection
  * Copyright 2002, Pasi Eronen <pasi.eronen@nixu.com>
  *
- * $Id: packet-xdmcp.c 23252 2007-10-23 05:50:00Z etxrab $
+ * $Id: packet-xdmcp.c 29344 2009-08-09 07:36:13Z krj $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -77,6 +77,7 @@ static const value_string family_vals[] = {
   { 0, "Internet" },
   { 1, "DECnet" },
   { 2, "Chaos" },
+  { 6, "InternetV6" },
   { 0, NULL }
 };
 
@@ -198,10 +199,8 @@ static void dissect_xdmcp(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
     return;
   }
 
-  if (check_col(pinfo->cinfo, COL_PROTOCOL))
-    col_set_str(pinfo->cinfo, COL_PROTOCOL, "XDMCP");
-  if (check_col(pinfo->cinfo, COL_INFO))
-    col_clear(pinfo->cinfo, COL_INFO);
+  col_set_str(pinfo->cinfo, COL_PROTOCOL, "XDMCP");
+  col_clear(pinfo->cinfo, COL_INFO);
 
   if (tree) {
     ti = proto_tree_add_item(tree, proto_xdmcp, tvb, offset, -1, FALSE);
@@ -242,6 +241,11 @@ static void dissect_xdmcp(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 			      "Client address: %s",
 			      ip_to_str(tvb_get_ptr(tvb, offset+2, 4)));
 	  offset += 6;
+	} else if (alen == 16) {
+	  proto_tree_add_text(xdmcp_tree, tvb, offset, alen+2,
+			      "Client address: %s",
+			      ip6_to_str((const struct e_in6_addr *)tvb_get_ptr(tvb, offset+2, 16)));
+	  offset += 18;
 	} else {
 	  offset += xdmcp_add_bytes(xdmcp_tree, "Client address", tvb, offset);
 	}
@@ -324,6 +328,8 @@ static void dissect_xdmcp(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 
 	  if ((ctype == 0) && (alen == 4)) {
 	    ip_string = ip_to_str(tvb_get_ptr(tvb, caddrs_offset, 4));
+	  } else if ((ctype == 6) && (alen == 16)) {
+	    ip_string = ip6_to_str((const struct e_in6_addr *)tvb_get_ptr(tvb, caddrs_offset, 16));
 	  } else {
 	    ip_string = NULL;
 	  }
@@ -339,7 +345,7 @@ static void dissect_xdmcp(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 			      "Type: %s",
 			      val_to_str(ctype, family_vals,
 					 "Unknown (0x%04x)"));
-	  if ((ctype == 0) && (alen == 4)) {
+	  if (ip_string) {
 	    proto_tree_add_text(connection_tree, tvb, caddrs_offset-2, alen+2,
 				"Address: %s", ip_string);
 	  } else {
@@ -454,7 +460,7 @@ void proto_register_xdmcp(void)
     { &hf_xdmcp_opcode,
       { "Opcode",              "xdmcp.opcode",
       FT_UINT16, BASE_HEX, VALS(opcode_vals), 0,
-      "Opcode", HFILL }
+      NULL, HFILL }
     },
     { &hf_xdmcp_length,
       { "Message length",     "xdmcp.length",
@@ -463,23 +469,23 @@ void proto_register_xdmcp(void)
     },
     { &hf_xdmcp_authentication_name,
       { "Authentication name",     "xdmcp.authentication_name",
-      FT_STRING, BASE_DEC, NULL, 0,
-      "Authentication name", HFILL }
+      FT_STRING, BASE_NONE, NULL, 0,
+      NULL, HFILL }
     },
     { &hf_xdmcp_authorization_name,
       { "Authorization name",     "xdmcp.authorization_name",
-      FT_STRING, BASE_DEC, NULL, 0,
-      "Authorization name", HFILL }
+      FT_STRING, BASE_NONE, NULL, 0,
+      NULL, HFILL }
     },
     { &hf_xdmcp_hostname,
       { "Hostname",     "xdmcp.hostname",
-      FT_STRING, BASE_DEC, NULL, 0,
-      "Hostname", HFILL }
+      FT_STRING, BASE_NONE, NULL, 0,
+      NULL, HFILL }
     },
     { &hf_xdmcp_status,
       { "Status",     "xdmcp.status",
-      FT_STRING, BASE_DEC, NULL, 0,
-      "Status", HFILL }
+      FT_STRING, BASE_NONE, NULL, 0,
+      NULL, HFILL }
     },
     { &hf_xdmcp_session_id,
       { "Session ID",     "xdmcp.session_id",
@@ -489,7 +495,7 @@ void proto_register_xdmcp(void)
     { &hf_xdmcp_display_number,
       { "Display number",     "xdmcp.display_number",
       FT_UINT16, BASE_DEC, NULL, 0,
-      "Display number", HFILL }
+      NULL, HFILL }
     },
   };
 
