@@ -1,7 +1,7 @@
 /* filesystem.h
  * Filesystem utility definitions
  *
- * $Id: filesystem.h 28529 2009-05-29 21:10:40Z standel $
+ * $Id: filesystem.h 30675 2009-10-23 17:52:18Z stig $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -78,6 +78,11 @@ extern const char *get_datafile_dir(void);
  */
 extern char *get_datafile_path(const char *filename);
 
+/* 
+ * Get the personal plugin dir.
+ */
+extern char *get_plugins_pers_dir(void);
+
 /*
  * Get the directory in which files that, at least on UNIX, are
  * system files (such as "/etc/ethers") are stored; on Windows,
