@@ -1,7 +1,7 @@
 /* frame_data.h
  * Definitions for frame_data structures and routines
  *
- * $Id: frame_data.h 33715 2010-08-05 16:37:41Z etxrab $
+ * $Id: frame_data.h 30838 2009-11-05 21:54:06Z etxrab $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -25,14 +25,14 @@
 #ifndef __FRAME_DATA_H__
 #define __FRAME_DATA_H__
 
-#include "column_info.h"
-#include "tvbuff.h"
+#include <epan/column_info.h>
+#include <epan/tvbuff.h>
 #include <epan/nstime.h>
 
-
 /* XXX - some of this stuff is used only while a packet is being dissected;
    should we keep that stuff in the "packet_info" structure, instead, to
    save memory? */
+
 /* The frame number is the ordinal number of the frame in the capture, so
    it's 1-origin.  In various contexts, 0 as a frame number means "frame
    number unknown". */
@@ -44,21 +44,28 @@ typedef struct _frame_data {
   guint32      pkt_len;     /* Packet length */
   guint32      cap_len;     /* Amount actually captured */
   guint32      cum_bytes;   /* Cumulative bytes into the capture */
+  guint16      subnum;      /* subframe number, for protocols that require this */
+  gint64       file_off;    /* File offset */
+  gint8        lnk_t;       /* Per-packet encapsulation/data-link type */
+  struct {
+    unsigned int passed_dfilter : 1; /* 1 = display, 0 = no display */
+    unsigned int encoding       : 2; /* Character encoding (ASCII, EBCDIC...) */
+    unsigned int visited        : 1; /* Has this packet been visited yet? 1=Yes,0=No*/
+    unsigned int marked         : 1; /* 1 = marked by user, 0 = normal */
+    unsigned int ref_time       : 1; /* 1 = marked as a reference time frame, 0 = normal */
+  } flags;
+
+  const void *color_filter; /* Per-packet matching color_filter_t object */
+
   nstime_t     abs_ts;      /* Absolute timestamp */
   nstime_t     rel_ts;      /* Relative timestamp (yes, it can be negative) */
   nstime_t     del_dis_ts;  /* Delta timestamp to previous displayed frame (yes, it can be negative) */
   nstime_t     del_cap_ts;  /* Delta timestamp to previous captured frame (yes, it can be negative) */
-  gint64       file_off;    /* File offset */
-  int          lnk_t;       /* Per-packet encapsulation/data-link type */
-  struct {
-	unsigned int passed_dfilter	: 1; /* 1 = display, 0 = no display */
-  	unsigned int encoding		: 2; /* Character encoding (ASCII, EBCDIC...) */
-	unsigned int visited		: 1; /* Has this packet been visited yet? 1=Yes,0=No*/
-	unsigned int marked             : 1; /* 1 = marked by user, 0 = normal */
-	unsigned int ref_time		: 1; /* 1 = marked as a reference time frame, 0 = normal */
-  } flags;
-  void *color_filter;       /* Per-packet matching color_filter_t object */
-  col_expr_t   col_expr;   /* Column expressions & values */
+
+#ifdef NEW_PACKET_LIST
+  gchar        **col_text;    /* The column text for some columns, see colum_utils */
+  guint        *col_text_len; /* The length of the column text strings in 'col_text' */
+#endif
 } frame_data;
 
 /*
@@ -77,4 +84,24 @@ extern void p_add_proto_data(frame_data *fd, int proto, void *proto_data);
 extern void *p_get_proto_data(frame_data *fd, int proto);
 extern void p_remove_proto_data(frame_data *fd, int proto);
 
+/* compare two frame_datas */
+extern gint frame_data_compare(const frame_data *fdata1, const frame_data *fdata2, int field);
+
+extern void frame_data_cleanup(frame_data *fdata);
+
+extern void frame_data_init(frame_data *fdata, guint32 num,
+                const struct wtap_pkthdr *phdr, gint64 offset,
+                guint32 cum_bytes);
+
+extern void frame_data_set_before_dissect(frame_data *fdata,
+                nstime_t *elapsed_time,
+                nstime_t *first_ts,
+                nstime_t *prev_dis_ts,
+                nstime_t *prev_cap_ts);
+
+extern void frame_data_set_after_dissect(frame_data *fdata,
+                guint32 *cum_bytes,
+                nstime_t *prev_dis_ts);
+
 #endif  /* __FRAME_DATA__ */
+
