@@ -1,7 +1,7 @@
 /* ftypes.h
  * Definitions for field types
  *
- * $Id: ftypes.h 31605 2010-01-21 17:30:45Z gerald $
+ * $Id: ftypes.h 29846 2009-09-10 18:22:33Z krj $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -71,6 +71,13 @@ enum ftenum {
 #define IS_FT_TIME(ft)   ((ft)==FT_ABSOLUTE_TIME||(ft)==FT_RELATIVE_TIME)
 #define IS_FT_STRING(ft) ((ft)==FT_STRING||(ft)==FT_STRINGZ)
 
+/* field types lengths */
+#define FT_ETHER_LEN        6
+#define FT_GUID_LEN         16
+#define FT_IPv4_LEN         4
+#define FT_IPv6_LEN         16
+#define FT_IPXNET_LEN       4
+
 typedef enum ftenum ftenum_t;
 typedef struct _ftype_t ftype_t;
 
@@ -149,7 +156,6 @@ typedef struct _fvalue_t {
 	ftype_t	*ftype;
 	union {
 		/* Put a few basic types in here */
-		gpointer	pointer;
 		guint32		uinteger;
 		gint32		sinteger;
 		guint64		integer64;
@@ -157,15 +163,12 @@ typedef struct _fvalue_t {
 		gchar		*string;
 		guchar		*ustring;
 		GByteArray	*bytes;
-		GString		*gstring;
 		ipv4_addr	ipv4;
 		e_guid_t	guid;
 		nstime_t	time;
 		tvbuff_t	*tvb;
 #ifdef HAVE_LIBPCRE
 		pcre_tuple_t	*re;
-#elif GLIB_CHECK_VERSION(2,14,0) /* Try falling back to GRegex. */
-		GRegex	        *re;
 #endif /* HAVE_LIBPCRE */
 	} value;
 
@@ -252,7 +255,7 @@ fvalue_init(fvalue_t *fv, ftenum_t ftype);
 /* Define type needed for the fvalue_t free list. */
 SLAB_ITEM_TYPE_DEFINE(fvalue_t)
 
-/* Free all memory used by an fvalue_t. With MSVC and a 
+/* Free all memory used by an fvalue_t. With MSVC and a
  * libwireshark.dll, we need a special declaration.
  */
 WS_VAR_IMPORT SLAB_FREE_LIST_DECLARE(fvalue_t)
@@ -296,7 +299,7 @@ fvalue_string_repr_len(fvalue_t *fv, ftrepr_t rtype);
  * The pointer to the beginning of the string representation is
  * returned. If 'buf' was NULL, this points to the newly-allocated
  * memory. if 'buf' was non-NULL, then the return value will be
- * 'buf'. 
+ * 'buf'.
  *
  * Returns NULL if the string cannot be represented in the given rtype.*/
 extern char *
