@@ -1,7 +1,7 @@
 /* reassemble.c
  * Routines for {fragment,segment} reassembly
  *
- * $Id: reassemble.c 29754 2009-09-06 18:25:23Z krj $
+ * $Id: reassemble.c 30639 2009-10-20 15:43:40Z gerald $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -53,6 +53,7 @@ typedef struct _dcerpc_fragment_key {
 #else
 static GMemChunk *fragment_key_chunk = NULL;
 static GMemChunk *fragment_data_chunk = NULL;
+static GMemChunk *dcerpc_fragment_key_chunk = NULL;
 static int fragment_init_count = 200;
 #endif
 
@@ -89,7 +90,12 @@ static void *fragment_key_copy(const void *k)
 static void *dcerpc_fragment_key_copy(const void *k)
 {
 	const dcerpc_fragment_key* key = (const dcerpc_fragment_key*) k;
-	dcerpc_fragment_key *new_key = se_alloc(sizeof(dcerpc_fragment_key));
+
+#if GLIB_CHECK_VERSION(2,10,0)
+	dcerpc_fragment_key *new_key = g_slice_new(dcerpc_fragment_key);
+#else
+	dcerpc_fragment_key *new_key = g_mem_chunk_alloc(dcerpc_fragment_key_chunk);
+#endif
 
 	COPY_ADDRESS(&new_key->src, &key->src);
 	COPY_ADDRESS(&new_key->dst, &key->dst);
@@ -363,10 +369,13 @@ reassemble_cleanup(void)
 #else
 	if (fragment_key_chunk != NULL)
 		g_mem_chunk_destroy(fragment_key_chunk);
+	if (dcerpc_fragment_key_chunk != NULL)
+		g_mem_chunk_destroy(dcerpc_fragment_key_chunk);
 	if (fragment_data_chunk != NULL)
 		g_mem_chunk_destroy(fragment_data_chunk);
 
 	fragment_key_chunk = NULL;
+	dcerpc_fragment_key_chunk = NULL;
 	fragment_data_chunk = NULL;
 #endif
 }
@@ -380,6 +389,10 @@ reassemble_init(void)
 		sizeof(fragment_key),
 		fragment_init_count * sizeof(fragment_key),
 		G_ALLOC_AND_FREE);
+	dcerpc_fragment_key_chunk = g_mem_chunk_new("dcerpc_fragment_key_chunk",
+		sizeof(dcerpc_fragment_key),
+		fragment_init_count * sizeof(dcerpc_fragment_key),
+		G_ALLOC_AND_FREE);
 	fragment_data_chunk = g_mem_chunk_new("fragment_data_chunk",
 		sizeof(fragment_data),
 		fragment_init_count * sizeof(fragment_data),
