@@ -1,7 +1,7 @@
 /* to_str.c
  * Routines for utilities to convert various other types to strings.
  *
- * $Id: to_str.c 26302 2008-09-30 02:56:11Z gerald $
+ * $Id: to_str.c 30691 2009-10-25 11:43:30Z etxrab $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -123,223 +123,6 @@ bytestring_to_str(const guint8 *ad, guint32 len, char punct) {
   return p;
 }
 
-/* Wrapper for the most common case of asking
- * for a string using a colon as the hex-digit separator.
- */
-/* XXX FIXME
-remove this one later when every call has been converted to address_to_str()
-*/
-gchar *
-ether_to_str(const guint8 *ad)
-{
-	return bytestring_to_str(ad, 6, ':');
-}
-
-/*
- This function is very fast and this function is called a lot.
- XXX update the address_to_str stuff to use this function.
-*/
-const gchar *
-ip_to_str(const guint8 *ad) {
-  gchar *buf;
-
-  buf=ep_alloc(MAX_IP_STR_LEN);
-  ip_to_str_buf(ad, buf, MAX_IP_STR_LEN);
-  return buf;
-}
-
-/*
- This function is very fast and this function is called a lot.
- XXX update the address_to_str stuff to use this function.
-*/
-static const char * const fast_strings[] = {
-"0", "1", "2", "3", "4", "5", "6", "7",
-"8", "9", "10", "11", "12", "13", "14", "15",
-"16", "17", "18", "19", "20", "21", "22", "23",
-"24", "25", "26", "27", "28", "29", "30", "31",
-"32", "33", "34", "35", "36", "37", "38", "39",
-"40", "41", "42", "43", "44", "45", "46", "47",
-"48", "49", "50", "51", "52", "53", "54", "55",
-"56", "57", "58", "59", "60", "61", "62", "63",
-"64", "65", "66", "67", "68", "69", "70", "71",
-"72", "73", "74", "75", "76", "77", "78", "79",
-"80", "81", "82", "83", "84", "85", "86", "87",
-"88", "89", "90", "91", "92", "93", "94", "95",
-"96", "97", "98", "99", "100", "101", "102", "103",
-"104", "105", "106", "107", "108", "109", "110", "111",
-"112", "113", "114", "115", "116", "117", "118", "119",
-"120", "121", "122", "123", "124", "125", "126", "127",
-"128", "129", "130", "131", "132", "133", "134", "135",
-"136", "137", "138", "139", "140", "141", "142", "143",
-"144", "145", "146", "147", "148", "149", "150", "151",
-"152", "153", "154", "155", "156", "157", "158", "159",
-"160", "161", "162", "163", "164", "165", "166", "167",
-"168", "169", "170", "171", "172", "173", "174", "175",
-"176", "177", "178", "179", "180", "181", "182", "183",
-"184", "185", "186", "187", "188", "189", "190", "191",
-"192", "193", "194", "195", "196", "197", "198", "199",
-"200", "201", "202", "203", "204", "205", "206", "207",
-"208", "209", "210", "211", "212", "213", "214", "215",
-"216", "217", "218", "219", "220", "221", "222", "223",
-"224", "225", "226", "227", "228", "229", "230", "231",
-"232", "233", "234", "235", "236", "237", "238", "239",
-"240", "241", "242", "243", "244", "245", "246", "247",
-"248", "249", "250", "251", "252", "253", "254", "255"
-};
-void
-ip_to_str_buf(const guint8 *ad, gchar *buf, int buf_len)
-{
-	register gchar const *p;
-	register gchar *b=buf;
-
-	if (buf_len < MAX_IP_STR_LEN) {
-		g_snprintf ( buf, buf_len, BUF_TOO_SMALL_ERR );                 /* Let the unexpected value alert user */
-		return;
-	}
-
-	p=fast_strings[*ad++];
-	do {
-		*b++=*p;
-		p++;
-	} while(*p);
-	*b++='.';
-
-	p=fast_strings[*ad++];
-	do {
-		*b++=*p;
-		p++;
-	} while(*p);
-	*b++='.';
-
-	p=fast_strings[*ad++];
-	do {
-		*b++=*p;
-		p++;
-	} while(*p);
-	*b++='.';
-
-	p=fast_strings[*ad];
-	do {
-		*b++=*p;
-		p++;
-	} while(*p);
-	*b=0;
-}
-
-
-/* XXX FIXME
-remove this one later when every call has been converted to address_to_str()
-*/
-gchar *
-ip6_to_str(const struct e_in6_addr *ad) {
-#ifndef INET6_ADDRSTRLEN
-#define INET6_ADDRSTRLEN 46
-#endif
-  static gchar *str;
-
-  str=ep_alloc(INET6_ADDRSTRLEN+1);
-
-  ip6_to_str_buf(ad, str);
-  return str;
-}
-
-void
-ip6_to_str_buf(const struct e_in6_addr *ad, gchar *buf)
-{
-  inet_ntop(AF_INET6, (const guchar*)ad, buf, INET6_ADDRSTRLEN);
-}
-
-gchar*
-ipx_addr_to_str(guint32 net, const guint8 *ad)
-{
-	gchar	*buf;
-	char	*name;
-
-	buf=ep_alloc(8+1+MAXNAMELEN+1); /* 8 digits, 1 period, NAME, 1 null */
-	name = get_ether_name_if_known(ad);
-
-	if (name) {
-		g_snprintf(buf, 8+1+MAXNAMELEN+1, "%s.%s", get_ipxnet_name(net), name);
-	}
-	else {
-		g_snprintf(buf, 8+1+MAXNAMELEN+1, "%s.%s", get_ipxnet_name(net),
-		    bytestring_to_str(ad, 6, '\0'));
-	}
-	return buf;
-}
-
-gchar*
-ipxnet_to_string(const guint8 *ad)
-{
-	guint32	addr = pntohl(ad);
-	return ipxnet_to_str_punct(addr, ' ');
-}
-
-gchar *
-ipxnet_to_str_punct(const guint32 ad, char punct)
-{
-  gchar        *buf;
-  gchar        *p;
-  int          i;
-  guint32      octet;
-  /* At least one version of Apple's C compiler/linker is buggy, causing
-     a complaint from the linker about the "literal C string section"
-     not ending with '\0' if we initialize a 16-element "char" array with
-     a 16-character string, the fact that initializing such an array with
-     such a string is perfectly legitimate ANSI C nonwithstanding, the 17th
-     '\0' byte in the string nonwithstanding. */
-  static const gchar hex_digits[16] =
-      { '0', '1', '2', '3', '4', '5', '6', '7',
-        '8', '9', 'A', 'B', 'C', 'D', 'E', 'F' };
-  static const guint32  octet_mask[4] =
-	  { 0xff000000 , 0x00ff0000, 0x0000ff00, 0x000000ff };
-
-  buf=ep_alloc(12);
-  p = &buf[12];
-  *--p = '\0';
-  i = 3;
-  for (;;) {
-    octet = (ad & octet_mask[i]) >> ((3 - i) * 8);
-    *--p = hex_digits[octet&0xF];
-    octet >>= 4;
-    *--p = hex_digits[octet&0xF];
-    if (i == 0)
-      break;
-    if (punct)
-      *--p = punct;
-    i--;
-  }
-  return p;
-}
-
-gchar *
-vines_addr_to_str(const guint8 *addrp)
-{
-  gchar	*buf;
-
-  buf=ep_alloc(214);
-
-  vines_addr_to_str_buf(addrp, buf, 214);
-  return buf;
-}
-
-void
-vines_addr_to_str_buf(const guint8 *addrp, gchar *buf, int buf_len)
-{
-  g_snprintf(buf, buf_len, "%08x.%04x", pntohl(&addrp[0]), pntohs(&addrp[4]));
-}
-
-
-void
-usb_addr_to_str_buf(const guint8 *addrp, gchar *buf, int buf_len)
-{
-  if(pletohl(&addrp[0])==0xffffffff){
-    g_snprintf(buf, buf_len, "host");
-  } else {
-    g_snprintf(buf, buf_len, "%d.%d", pletohl(&addrp[0]), pletohl(&addrp[4]));
-  }
-}
-
 #define	PLURALIZE(n)	(((n) > 1) ? "s" : "")
 #define	COMMA(do_it)	((do_it) ? ", " : "")
 
@@ -361,15 +144,14 @@ usb_addr_to_str_buf(const guint8 *addrp, gchar *buf, int buf_len)
  */
 static void
 time_secs_to_str_buf(gint32 time, guint32 frac, gboolean is_nsecs,
-			   gchar *buf, int buf_len)
+			   emem_strbuf_t *buf)
 {
-  static gchar *p;
   int hours, mins, secs;
   const gchar *msign = "";
   gboolean do_comma = FALSE;
 
   if(time == G_MININT32) {	/* That Which Shall Not Be Negated */
-    g_snprintf(buf, buf_len, "Unable to cope with time value %d", time);
+    ep_strbuf_append_printf(buf, "Unable to cope with time value %d", time);
     return;
   }
 
@@ -385,61 +167,113 @@ time_secs_to_str_buf(gint32 time, guint32 frac, gboolean is_nsecs,
   hours = time % 24;
   time /= 24;
 
-  /* This would probably be cleaner if we used GStrings instead. */
-  p = buf;
   if (time != 0) {
-    p += g_snprintf(p, buf_len, "%s%u day%s", msign, time, PLURALIZE(time));
+    ep_strbuf_append_printf(buf, "%s%u day%s", msign, time, PLURALIZE(time));
     do_comma = TRUE;
     msign="";
   }
   if (hours != 0) {
-    p += g_snprintf(p, buf_len-(p-buf), "%s%s%u hour%s", COMMA(do_comma), msign, hours, PLURALIZE(hours));
+    ep_strbuf_append_printf(buf, "%s%s%u hour%s", COMMA(do_comma), msign, hours, PLURALIZE(hours));
     do_comma = TRUE;
     msign="";
   }
   if (mins != 0) {
-    p += g_snprintf(p, buf_len-(p-buf), "%s%s%u minute%s", COMMA(do_comma), msign, mins, PLURALIZE(mins));
+    ep_strbuf_append_printf(buf, "%s%s%u minute%s", COMMA(do_comma), msign, mins, PLURALIZE(mins));
     do_comma = TRUE;
     msign="";
   }
   if (secs != 0 || frac != 0) {
     if (frac != 0) {
       if (is_nsecs)
-        p += g_snprintf(p, buf_len-(p-buf), "%s%s%u.%09u seconds", COMMA(do_comma), msign, secs, frac);
+        ep_strbuf_append_printf(buf, "%s%s%u.%09u seconds", COMMA(do_comma), msign, secs, frac);
       else
-        p += g_snprintf(p, buf_len-(p-buf), "%s%s%u.%03u seconds", COMMA(do_comma), msign, secs, frac);
+        ep_strbuf_append_printf(buf, "%s%s%u.%03u seconds", COMMA(do_comma), msign, secs, frac);
     } else
-      p += g_snprintf(p, buf_len-(p-buf), "%s%s%u second%s", COMMA(do_comma), msign, secs, PLURALIZE(secs));
+      ep_strbuf_append_printf(buf, "%s%s%u second%s", COMMA(do_comma), msign, secs, PLURALIZE(secs));
   }
 }
 
 gchar *
 time_secs_to_str(gint32 time)
 {
-  gchar *buf;
+  emem_strbuf_t *buf;
 
-  buf=ep_alloc(TIME_SECS_LEN+1);
+  buf=ep_strbuf_sized_new(TIME_SECS_LEN+1, TIME_SECS_LEN+1);
 
   if (time == 0) {
-    g_snprintf(buf, TIME_SECS_LEN+1, "0 time");
-    return buf;
+    ep_strbuf_append(buf, "0 time");
+    return buf->str;
   }
 
-  time_secs_to_str_buf(time, 0, FALSE, buf, TIME_SECS_LEN+1);
-  return buf;
+  time_secs_to_str_buf(time, 0, FALSE, buf);
+  return buf->str;
 }
 
+static void
+time_secs_to_str_buf_unsigned(guint32 time, guint32 frac, gboolean is_nsecs,
+			 emem_strbuf_t *buf)
+{
+  int hours, mins, secs;
+  gboolean do_comma = FALSE;
+
+  secs = time % 60;
+  time /= 60;
+  mins = time % 60;
+  time /= 60;
+  hours = time % 24;
+  time /= 24;
+
+  if (time != 0) {
+    ep_strbuf_append_printf(buf, "%u day%s", time, PLURALIZE(time));
+    do_comma = TRUE;
+  }
+  if (hours != 0) {
+    ep_strbuf_append_printf(buf, "%s%u hour%s", COMMA(do_comma), hours, PLURALIZE(hours));
+    do_comma = TRUE;
+  }
+  if (mins != 0) {
+    ep_strbuf_append_printf(buf, "%s%u minute%s", COMMA(do_comma), mins, PLURALIZE(mins));
+    do_comma = TRUE;
+  }
+  if (secs != 0 || frac != 0) {
+    if (frac != 0) {
+      if (is_nsecs)
+        ep_strbuf_append_printf(buf, "%s%u.%09u seconds", COMMA(do_comma), secs, frac);
+      else
+        ep_strbuf_append_printf(buf, "%s%u.%03u seconds", COMMA(do_comma), secs, frac);
+    } else
+      ep_strbuf_append_printf(buf, "%s%u second%s", COMMA(do_comma), secs, PLURALIZE(secs));
+  }
+}
+
+gchar *
+time_secs_to_str_unsigned(guint32 time)
+{
+  emem_strbuf_t *buf;
+
+  buf=ep_strbuf_sized_new(TIME_SECS_LEN+1, TIME_SECS_LEN+1);
+
+  if (time == 0) {
+    ep_strbuf_append(buf, "0 time");
+    return buf->str;
+  }
+
+  time_secs_to_str_buf_unsigned(time, 0, FALSE, buf);
+  return buf->str;
+}
+
+
 gchar *
 time_msecs_to_str(gint32 time)
 {
-  gchar *buf;
+  emem_strbuf_t *buf;
   int msecs;
 
-  buf=ep_alloc(TIME_SECS_LEN+1+3+1);
+  buf=ep_strbuf_sized_new(TIME_SECS_LEN+1+3+1, TIME_SECS_LEN+1+3+1);
 
   if (time == 0) {
-    g_snprintf(buf, TIME_SECS_LEN+1+3+1, "0 time");
-    return buf;
+    ep_strbuf_append(buf, "0 time");
+    return buf->str;
   }
 
   if(time<0){
@@ -453,8 +287,8 @@ time_msecs_to_str(gint32 time)
     time /= 1000;
   }
 
-  time_secs_to_str_buf(time, msecs, FALSE, buf, TIME_SECS_LEN+1+3+1);
-  return buf;
+  time_secs_to_str_buf(time, msecs, FALSE, buf);
+  return buf->str;
 }
 
 static const char *mon_names[12] = {
@@ -478,9 +312,6 @@ abs_time_to_str(nstime_t *abs_time)
         struct tm *tmp;
         gchar *buf;
 
-        buf=ep_alloc(3+1+2+2+4+1+2+1+2+1+2+1+9+1);
-
-
 #ifdef _MSC_VER
         /* calling localtime() on MSVC 2005 with huge values causes it to crash */
         /* XXX - find the exact value that still does work */
@@ -491,8 +322,7 @@ abs_time_to_str(nstime_t *abs_time)
 #endif
         tmp = localtime(&abs_time->secs);
         if (tmp) {
-		g_snprintf(buf, 3+1+2+2+4+1+2+1+2+1+2+1+9+1,
-		    "%s %2d, %d %02d:%02d:%02d.%09ld",
+		buf = ep_strdup_printf("%s %2d, %d %02d:%02d:%02d.%09ld",
 		    mon_names[tmp->tm_mon],
 		    tmp->tm_mday,
 		    tmp->tm_year + 1900,
@@ -501,7 +331,7 @@ abs_time_to_str(nstime_t *abs_time)
 		    tmp->tm_sec,
 		    (long)abs_time->nsecs);
         } else
-		strncpy(buf, "Not representable", 3+1+2+2+4+1+2+1+2+1+2+1+9+1);
+		buf = ep_strdup("Not representable");
         return buf;
 }
 
@@ -511,12 +341,9 @@ abs_time_secs_to_str(time_t abs_time)
         struct tm *tmp;
         gchar *buf;
 
-	buf=ep_alloc(3+1+2+2+4+1+2+1+2+1+2+1);
-
         tmp = localtime(&abs_time);
         if (tmp) {
-		g_snprintf(buf, 3+1+2+2+4+1+2+1+2+1+2+1,
-		    "%s %2d, %d %02d:%02d:%02d",
+		buf = ep_strdup_printf("%s %2d, %d %02d:%02d:%02d",
 		    mon_names[tmp->tm_mon],
 		    tmp->tm_mday,
 		    tmp->tm_year + 1900,
@@ -524,7 +351,7 @@ abs_time_secs_to_str(time_t abs_time)
 		    tmp->tm_min,
 		    tmp->tm_sec);
         } else
-		strncpy(buf, "Not representable", 3+1+2+2+4+1+2+1+2+1+2+1);
+		buf = ep_strdup("Not representable");
         return buf;
 }
 
@@ -532,42 +359,45 @@ void
 display_signed_time(gchar *buf, int buflen, gint32 sec, gint32 frac,
     time_res_t units)
 {
-	const char *sign;
-
 	/* If the fractional part of the time stamp is negative,
 	   print its absolute value and, if the seconds part isn't
 	   (the seconds part should be zero in that case), stick
 	   a "-" in front of the entire time stamp. */
-	sign = "";
 	if (frac < 0) {
 		frac = -frac;
-		if (sec >= 0)
-			sign = "-";
+		if (sec >= 0) {
+			if (buflen < 1) {
+			  return;
+			}
+			buf[0] = '-';
+			buf++;
+			buflen--;
+		}
 	}
 	switch (units) {
 
 	case SECS:
-		g_snprintf(buf, buflen, "%s%d", sign, sec);
+		g_snprintf(buf, buflen, "%d", sec);
 		break;
 
 	case DSECS:
-		g_snprintf(buf, buflen, "%s%d.%01d", sign, sec, frac);
+		g_snprintf(buf, buflen, "%d.%01d", sec, frac);
 		break;
 
 	case CSECS:
-		g_snprintf(buf, buflen, "%s%d.%02d", sign, sec, frac);
+		g_snprintf(buf, buflen, "%d.%02d", sec, frac);
 		break;
 
 	case MSECS:
-		g_snprintf(buf, buflen, "%s%d.%03d", sign, sec, frac);
+		g_snprintf(buf, buflen, "%d.%03d", sec, frac);
 		break;
 
 	case USECS:
-		g_snprintf(buf, buflen, "%s%d.%06d", sign, sec, frac);
+		g_snprintf(buf, buflen, "%d.%06d", sec, frac);
 		break;
 
 	case NSECS:
-		g_snprintf(buf, buflen, "%s%d.%09d", sign, sec, frac);
+		g_snprintf(buf, buflen, "%d.%09d", sec, frac);
 		break;
 	}
 }
@@ -577,7 +407,6 @@ void
 display_epoch_time(gchar *buf, int buflen, time_t sec, gint32 frac,
     time_res_t units)
 {
-	const char *sign;
 	double elapsed_secs;
 
 	elapsed_secs = difftime(sec,(time_t)0);
@@ -588,36 +417,41 @@ display_epoch_time(gchar *buf, int buflen, time_t sec, gint32 frac,
 	   print its absolute value and, if the seconds part isn't
 	   (the seconds part should be zero in that case), stick
 	   a "-" in front of the entire time stamp. */
-	sign = "";
 	if (frac < 0) {
 		frac = -frac;
-		if (elapsed_secs >= 0)
-			sign = "-";
+		if (elapsed_secs >= 0) {
+			if (buflen < 1) {
+			  return;
+			}
+			buf[0] = '-';
+			buf++;
+			buflen--;
+		}
 	}
 	switch (units) {
 
 	case SECS:
-		g_snprintf(buf, buflen, "%s%0.0f", sign, elapsed_secs);
+		g_snprintf(buf, buflen, "%0.0f", elapsed_secs);
 		break;
 
 	case DSECS:
-		g_snprintf(buf, buflen, "%s%0.0f.%01d", sign, elapsed_secs, frac);
+		g_snprintf(buf, buflen, "%0.0f.%01d", elapsed_secs, frac);
 		break;
 
 	case CSECS:
-		g_snprintf(buf, buflen, "%s%0.0f.%02d", sign, elapsed_secs, frac);
+		g_snprintf(buf, buflen, "%0.0f.%02d", elapsed_secs, frac);
 		break;
 
 	case MSECS:
-		g_snprintf(buf, buflen, "%s%0.0f.%03d", sign, elapsed_secs, frac);
+		g_snprintf(buf, buflen, "%0.0f.%03d", elapsed_secs, frac);
 		break;
 
 	case USECS:
-		g_snprintf(buf, buflen, "%s%0.0f.%06d", sign, elapsed_secs, frac);
+		g_snprintf(buf, buflen, "%0.0f.%06d", elapsed_secs, frac);
 		break;
 
 	case NSECS:
-		g_snprintf(buf, buflen, "%s%0.0f.%09d", sign, elapsed_secs, frac);
+		g_snprintf(buf, buflen, "%0.0f.%09d", elapsed_secs, frac);
 		break;
 	}
 }
@@ -628,14 +462,12 @@ display_epoch_time(gchar *buf, int buflen, time_t sec, gint32 frac,
 gchar *
 rel_time_to_str(nstime_t *rel_time)
 {
-	gchar *buf;
-	char *p;
+	emem_strbuf_t *buf;
 	const char *sign;
 	gint32 time;
 	gint32 nsec;
 
-	buf=ep_alloc(1+TIME_SECS_LEN+1+6+1);
-	p = buf;
+	buf=ep_strbuf_sized_new(1+TIME_SECS_LEN+1+6+1, 1+TIME_SECS_LEN+1+6+1);
 
 	/* If the nanoseconds part of the time stamp is negative,
 	   print its absolute value and, if the seconds part isn't
@@ -645,12 +477,12 @@ rel_time_to_str(nstime_t *rel_time)
 	time = (gint) rel_time->secs;
 	nsec = rel_time->nsecs;
 	if (time == 0 && nsec == 0) {
-		g_snprintf(buf, 1+TIME_SECS_LEN+1+6+1, "0.000000000 seconds");
-		return buf;
+		ep_strbuf_append(buf, "0.000000000 seconds");
+		return buf->str;
 	}
 	if (nsec < 0) {
 		nsec = -nsec;
-		*p++ = '-';
+		ep_strbuf_append_c(buf, '-');
 
 		/*
 		 * We assume here that "rel_time->secs" is negative
@@ -660,8 +492,8 @@ rel_time_to_str(nstime_t *rel_time)
 		time = (gint) -rel_time->secs;
 	}
 
-	time_secs_to_str_buf(time, nsec, TRUE, p, 1+TIME_SECS_LEN+1+6+1);
-	return buf;
+	time_secs_to_str_buf(time, nsec, TRUE, buf);
+	return buf->str;
 }
 
 #define REL_TIME_SECS_LEN	(1+10+1+9+1)
@@ -681,70 +513,58 @@ rel_time_to_secs_str(nstime_t *rel_time)
         return buf;
 }
 
+/*
+ * Generates a string representing the bits in a bitfield at "bit_offset" from an 8 bit boundary
+ * with the length in bits of no_of_bits based on value.
+ * Ex: ..xx x...
+ */
 
-/* XXX FIXME
-remove this one later when every call has been converted to address_to_str()
-*/
-gchar *
-fc_to_str(const guint8 *ad)
+char *
+decode_bits_in_field(gint bit_offset, gint no_of_bits, guint64 value)
 {
-    return bytestring_to_str (ad, 3, '.');
-}
+	guint64 mask = 0,tmp;
+	char *str;
+	int bit;
+	int i;
 
-/* FC Network Header Network Address Authority Identifiers */
+	mask = 1;
+	mask = mask << (no_of_bits-1);
 
-#define FC_NH_NAA_IEEE		1	/* IEEE 802.1a */
-#define FC_NH_NAA_IEEE_E	2	/* IEEE Exteneded */
-#define FC_NH_NAA_LOCAL		3
-#define FC_NH_NAA_IP		4	/* 32-bit IP address */
-#define FC_NH_NAA_IEEE_R	5	/* IEEE Registered */
-#define FC_NH_NAA_IEEE_R_E	6	/* IEEE Registered Exteneded */
-/* according to FC-PH 3 draft these are now reclaimed and reserved */
-#define FC_NH_NAA_CCITT_INDV	12	/* CCITT 60 bit individual address */
-#define FC_NH_NAA_CCITT_GRP	14	/* CCITT 60 bit group address */
+	/* prepare the string */
+	str=ep_alloc(256);
+	str[0]='\0';
+	for(bit=0;bit<((int)(bit_offset&0x07));bit++){
+		if(bit&&(!(bit%4))){
+			strcat(str, " ");
+		}
+		strcat(str,".");
+	}
 
-gchar *
-fcwwn_to_str (const guint8 *ad)
-{
-    int fmt;
-    guint8 oui[6];
-    gchar *ethstr;
+	/* read the bits for the int */
+	for(i=0;i<no_of_bits;i++){
+		if(bit&&(!(bit%4))){
+			strcat(str, " ");
+		}
+		if(bit&&(!(bit%8))){
+			strcat(str, " ");
+		}
+		bit++;
+		tmp = value & mask;
+		if(tmp != 0){
+			strcat(str, "1");
+		} else {
+			strcat(str, "0");
+		}
+		mask = mask>>1;
+	}
 
-    if (ad == NULL) return NULL;
-
-    ethstr=ep_alloc(512);
-
-    fmt = (ad[0] & 0xF0) >> 4;
-
-    switch (fmt) {
-
-    case FC_NH_NAA_IEEE:
-    case FC_NH_NAA_IEEE_E:
-        memcpy (oui, &ad[2], 6);
-        g_snprintf (ethstr, 512, "%02x:%02x:%02x:%02x:%02x:%02x:%02x:%02x (%s)", ad[0],
-                 ad[1], ad[2], ad[3], ad[4], ad[5], ad[6], ad[7],
-                 get_manuf_name (oui));
-        break;
-
-    case FC_NH_NAA_IEEE_R:
-        oui[0] = ((ad[0] & 0x0F) << 4) | ((ad[1] & 0xF0) >> 4);
-        oui[1] = ((ad[1] & 0x0F) << 4) | ((ad[2] & 0xF0) >> 4);
-        oui[2] = ((ad[2] & 0x0F) << 4) | ((ad[3] & 0xF0) >> 4);
-        oui[3] = ((ad[3] & 0x0F) << 4) | ((ad[4] & 0xF0) >> 4);
-        oui[4] = ((ad[4] & 0x0F) << 4) | ((ad[5] & 0xF0) >> 4);
-        oui[5] = ((ad[5] & 0x0F) << 4) | ((ad[6] & 0xF0) >> 4);
-
-        g_snprintf (ethstr, 512, "%02x:%02x:%02x:%02x:%02x:%02x:%02x:%02x (%s)", ad[0],
-                 ad[1], ad[2], ad[3], ad[4], ad[5], ad[6], ad[7],
-                 get_manuf_name (oui));
-        break;
-
-    default:
-        g_snprintf (ethstr, 512, "%02x:%02x:%02x:%02x:%02x:%02x:%02x:%02x", ad[0],
-                 ad[1], ad[2], ad[3], ad[4], ad[5], ad[6], ad[7]);
-        break;
-    }
-    return (ethstr);
+	for(;bit%8;bit++){
+		if(bit&&(!(bit%4))){
+			strcat(str, " ");
+		}
+		strcat(str,".");
+	}
+	return str;
 }
 
 /* Generate, into "buf", a string showing the bits of a bitfield.
@@ -828,10 +648,313 @@ decode_numeric_bitfield(guint32 val, guint32 mask, int width,
     shift++;
 
   p = decode_bitfield_value(buf, val, mask, width);
-  g_snprintf(p, 1025-(p-buf), fmt, (val & mask) >> shift);
+  g_snprintf(p, (gulong) (1025-(p-buf)), fmt, (val & mask) >> shift);
   return buf;
 }
 
+/* Wrapper for the most common case of asking
+ * for a string using a colon as the hex-digit separator.
+ */
+/* XXX FIXME
+remove this one later when every call has been converted to ep_address_to_str()
+*/
+gchar *
+ether_to_str(const guint8 *ad)
+{
+	return bytestring_to_str(ad, 6, ':');
+}
+
+/*
+ This function is very fast and this function is called a lot.
+ XXX update the ep_address_to_str stuff to use this function.
+*/
+const gchar *
+ip_to_str(const guint8 *ad) {
+  gchar *buf;
+
+  buf=ep_alloc(MAX_IP_STR_LEN);
+  ip_to_str_buf(ad, buf, MAX_IP_STR_LEN);
+  return buf;
+}
+
+/*
+ This function is very fast and this function is called a lot.
+ XXX update the ep_address_to_str stuff to use this function.
+*/
+static const char * const fast_strings[] = {
+"0", "1", "2", "3", "4", "5", "6", "7",
+"8", "9", "10", "11", "12", "13", "14", "15",
+"16", "17", "18", "19", "20", "21", "22", "23",
+"24", "25", "26", "27", "28", "29", "30", "31",
+"32", "33", "34", "35", "36", "37", "38", "39",
+"40", "41", "42", "43", "44", "45", "46", "47",
+"48", "49", "50", "51", "52", "53", "54", "55",
+"56", "57", "58", "59", "60", "61", "62", "63",
+"64", "65", "66", "67", "68", "69", "70", "71",
+"72", "73", "74", "75", "76", "77", "78", "79",
+"80", "81", "82", "83", "84", "85", "86", "87",
+"88", "89", "90", "91", "92", "93", "94", "95",
+"96", "97", "98", "99", "100", "101", "102", "103",
+"104", "105", "106", "107", "108", "109", "110", "111",
+"112", "113", "114", "115", "116", "117", "118", "119",
+"120", "121", "122", "123", "124", "125", "126", "127",
+"128", "129", "130", "131", "132", "133", "134", "135",
+"136", "137", "138", "139", "140", "141", "142", "143",
+"144", "145", "146", "147", "148", "149", "150", "151",
+"152", "153", "154", "155", "156", "157", "158", "159",
+"160", "161", "162", "163", "164", "165", "166", "167",
+"168", "169", "170", "171", "172", "173", "174", "175",
+"176", "177", "178", "179", "180", "181", "182", "183",
+"184", "185", "186", "187", "188", "189", "190", "191",
+"192", "193", "194", "195", "196", "197", "198", "199",
+"200", "201", "202", "203", "204", "205", "206", "207",
+"208", "209", "210", "211", "212", "213", "214", "215",
+"216", "217", "218", "219", "220", "221", "222", "223",
+"224", "225", "226", "227", "228", "229", "230", "231",
+"232", "233", "234", "235", "236", "237", "238", "239",
+"240", "241", "242", "243", "244", "245", "246", "247",
+"248", "249", "250", "251", "252", "253", "254", "255"
+};
+void
+ip_to_str_buf(const guint8 *ad, gchar *buf, int buf_len)
+{
+	register gchar const *p;
+	register gchar *b=buf;
+
+	if (buf_len < MAX_IP_STR_LEN) {
+		g_snprintf ( buf, buf_len, BUF_TOO_SMALL_ERR );                 /* Let the unexpected value alert user */
+		return;
+	}
+
+	p=fast_strings[*ad++];
+	do {
+		*b++=*p;
+		p++;
+	} while(*p);
+	*b++='.';
+
+	p=fast_strings[*ad++];
+	do {
+		*b++=*p;
+		p++;
+	} while(*p);
+	*b++='.';
+
+	p=fast_strings[*ad++];
+	do {
+		*b++=*p;
+		p++;
+	} while(*p);
+	*b++='.';
+
+	p=fast_strings[*ad];
+	do {
+		*b++=*p;
+		p++;
+	} while(*p);
+	*b=0;
+}
+
+
+/* XXX FIXME
+remove this one later when every call has been converted to ep_address_to_str()
+*/
+gchar *
+ip6_to_str(const struct e_in6_addr *ad) {
+#ifndef INET6_ADDRSTRLEN
+#define INET6_ADDRSTRLEN 46
+#endif
+  static gchar *str;
+
+  str=ep_alloc(INET6_ADDRSTRLEN+1);
+
+  ip6_to_str_buf(ad, str);
+  return str;
+}
+
+void
+ip6_to_str_buf(const struct e_in6_addr *ad, gchar *buf)
+{
+  inet_ntop(AF_INET6, (const guchar*)ad, buf, INET6_ADDRSTRLEN);
+}
+
+gchar*
+ipx_addr_to_str(guint32 net, const guint8 *ad)
+{
+	gchar	*buf;
+	char	*name;
+
+	name = get_ether_name_if_known(ad);
+
+	if (name) {
+		buf = ep_strdup_printf("%s.%s", get_ipxnet_name(net), name);
+	}
+	else {
+		buf = ep_strdup_printf("%s.%s", get_ipxnet_name(net),
+		    bytestring_to_str(ad, 6, '\0'));
+	}
+	return buf;
+}
+
+gchar*
+ipxnet_to_string(const guint8 *ad)
+{
+	guint32	addr = pntohl(ad);
+	return ipxnet_to_str_punct(addr, ' ');
+}
+
+gchar *
+ipxnet_to_str_punct(const guint32 ad, char punct)
+{
+  gchar        *buf;
+  gchar        *p;
+  int          i;
+  guint32      octet;
+  /* At least one version of Apple's C compiler/linker is buggy, causing
+     a complaint from the linker about the "literal C string section"
+     not ending with '\0' if we initialize a 16-element "char" array with
+     a 16-character string, the fact that initializing such an array with
+     such a string is perfectly legitimate ANSI C nonwithstanding, the 17th
+     '\0' byte in the string nonwithstanding. */
+  static const gchar hex_digits[16] =
+      { '0', '1', '2', '3', '4', '5', '6', '7',
+        '8', '9', 'A', 'B', 'C', 'D', 'E', 'F' };
+  static const guint32  octet_mask[4] =
+	  { 0xff000000 , 0x00ff0000, 0x0000ff00, 0x000000ff };
+
+  buf=ep_alloc(12);
+  p = &buf[12];
+  *--p = '\0';
+  i = 3;
+  for (;;) {
+    octet = (ad & octet_mask[i]) >> ((3 - i) * 8);
+    *--p = hex_digits[octet&0xF];
+    octet >>= 4;
+    *--p = hex_digits[octet&0xF];
+    if (i == 0)
+      break;
+    if (punct)
+      *--p = punct;
+    i--;
+  }
+  return p;
+}
+
+gchar *
+vines_addr_to_str(const guint8 *addrp)
+{
+  gchar	*buf;
+
+  buf=ep_alloc(214);
+
+  vines_addr_to_str_buf(addrp, buf, 214);
+  return buf;
+}
+
+void
+vines_addr_to_str_buf(const guint8 *addrp, gchar *buf, int buf_len)
+{
+  g_snprintf(buf, buf_len, "%08x.%04x", pntohl(&addrp[0]), pntohs(&addrp[4]));
+}
+
+
+void
+usb_addr_to_str_buf(const guint8 *addrp, gchar *buf, int buf_len)
+{
+  if(pletohl(&addrp[0])==0xffffffff){
+    g_snprintf(buf, buf_len, "host");
+  } else {
+    g_snprintf(buf, buf_len, "%d.%d", pletohl(&addrp[0]), pletohl(&addrp[4]));
+  }
+}
+
+void
+tipc_addr_to_str_buf( const guint8 *data, gchar *buf, int buf_len){
+	guint8 zone;
+	guint16 subnetwork;
+	guint16 processor;
+	guint32 tipc_address;
+
+	tipc_address = data[0];
+	tipc_address = (tipc_address << 8) ^ data[1];
+	tipc_address = (tipc_address << 8) ^ data[2];
+	tipc_address = (tipc_address << 8) ^ data[3];
+
+	processor = tipc_address & 0x0fff;
+
+	tipc_address = tipc_address >> 12;
+	subnetwork = tipc_address & 0x0fff;
+
+	tipc_address = tipc_address >> 12;
+	zone = tipc_address & 0xff;
+
+	g_snprintf(buf,buf_len,"%u.%u.%u",zone,subnetwork,processor);
+}
+
+/* XXX FIXME
+remove this one later when every call has been converted to ep_address_to_str()
+*/
+gchar *
+fc_to_str(const guint8 *ad)
+{
+    return bytestring_to_str (ad, 3, '.');
+}
+
+/* FC Network Header Network Address Authority Identifiers */
+
+#define FC_NH_NAA_IEEE		1	/* IEEE 802.1a */
+#define FC_NH_NAA_IEEE_E	2	/* IEEE Exteneded */
+#define FC_NH_NAA_LOCAL		3
+#define FC_NH_NAA_IP		4	/* 32-bit IP address */
+#define FC_NH_NAA_IEEE_R	5	/* IEEE Registered */
+#define FC_NH_NAA_IEEE_R_E	6	/* IEEE Registered Exteneded */
+/* according to FC-PH 3 draft these are now reclaimed and reserved */
+#define FC_NH_NAA_CCITT_INDV	12	/* CCITT 60 bit individual address */
+#define FC_NH_NAA_CCITT_GRP	14	/* CCITT 60 bit group address */
+
+gchar *
+fcwwn_to_str (const guint8 *ad)
+{
+    int fmt;
+    guint8 oui[6];
+    gchar *ethstr;
+
+    if (ad == NULL) return NULL;
+
+    ethstr=ep_alloc(512);
+
+    fmt = (ad[0] & 0xF0) >> 4;
+
+    switch (fmt) {
+
+    case FC_NH_NAA_IEEE:
+    case FC_NH_NAA_IEEE_E:
+        memcpy (oui, &ad[2], 6);
+        g_snprintf (ethstr, 512, "%02x:%02x:%02x:%02x:%02x:%02x:%02x:%02x (%s)", ad[0],
+                 ad[1], ad[2], ad[3], ad[4], ad[5], ad[6], ad[7],
+                 get_manuf_name (oui));
+        break;
+
+    case FC_NH_NAA_IEEE_R:
+        oui[0] = ((ad[0] & 0x0F) << 4) | ((ad[1] & 0xF0) >> 4);
+        oui[1] = ((ad[1] & 0x0F) << 4) | ((ad[2] & 0xF0) >> 4);
+        oui[2] = ((ad[2] & 0x0F) << 4) | ((ad[3] & 0xF0) >> 4);
+        oui[3] = ((ad[3] & 0x0F) << 4) | ((ad[4] & 0xF0) >> 4);
+        oui[4] = ((ad[4] & 0x0F) << 4) | ((ad[5] & 0xF0) >> 4);
+        oui[5] = ((ad[5] & 0x0F) << 4) | ((ad[6] & 0xF0) >> 4);
+
+        g_snprintf (ethstr, 512, "%02x:%02x:%02x:%02x:%02x:%02x:%02x:%02x (%s)", ad[0],
+                 ad[1], ad[2], ad[3], ad[4], ad[5], ad[6], ad[7],
+                 get_manuf_name (oui));
+        break;
+
+    default:
+        g_snprintf (ethstr, 512, "%02x:%02x:%02x:%02x:%02x:%02x:%02x:%02x", ad[0],
+                 ad[1], ad[2], ad[3], ad[4], ad[5], ad[6], ad[7]);
+        break;
+    }
+    return (ethstr);
+}
 
 /*XXX FIXME the code below may be called very very frequently in the future.
   optimize it for speed and get rid of the slow sprintfs */
@@ -845,8 +968,9 @@ decode_numeric_bitfield(guint32 val, guint32 mask, int width,
    that "col_set_addr()" need know nothing whatsoever about particular
    address types */
 /* convert an address struct into a printable string */
+
 gchar*
-address_to_str(const address *addr)
+ep_address_to_str(const address *addr)
 {
   gchar *str;
 
@@ -855,6 +979,17 @@ address_to_str(const address *addr)
   return str;
 }
 
+/* The called routines use se_alloc'ed memory */
+gchar*
+se_address_to_str(const address *addr)
+{
+  gchar *str;
+
+  str=se_alloc(MAX_ADDR_STR_LEN);
+  address_to_str_buf(addr, str, MAX_ADDR_STR_LEN);
+  return str;
+}
+
 void
 address_to_str_buf(const address *addr, gchar *buf, int buf_len)
 {
@@ -949,28 +1084,3 @@ gchar* guid_to_str_buf(const e_guid_t *guid, gchar *buf, int buf_len) {
   return buf;
 }
 
-void
-tipc_addr_to_str_buf( const guint8 *data, gchar *buf, int buf_len){
-	guint8 zone;
-	guint16 subnetwork;
-	guint16 processor;
-	guint32 tipc_address;
-
-	tipc_address = data[0];
-	tipc_address = (tipc_address << 8) ^ data[1];
-	tipc_address = (tipc_address << 8) ^ data[2];
-	tipc_address = (tipc_address << 8) ^ data[3];
-
-	processor = tipc_address & 0x0fff;
-
-	tipc_address = tipc_address >> 12;
-	subnetwork = tipc_address & 0x0fff;
-
-	tipc_address = tipc_address >> 12;
-	zone = tipc_address & 0xff;
-
-	g_snprintf(buf,buf_len,"%u.%u.%u",zone,subnetwork,processor);
-
-
-}
-
