@@ -3,13 +3,13 @@
  * Testy, Virtual(-izable) Buffer of guint8*'s
  *
  * "Testy" -- the buffer gets mad when an attempt to access data
- * 		beyond the bounds of the buffer. An exception is thrown.
+ *		beyond the bounds of the buffer. An exception is thrown.
  *
  * "Virtual" -- the buffer can have its own data, can use a subset of
- * 		the data of a backing tvbuff, or can be a composite of
- * 		other tvbuffs.
+ *		the data of a backing tvbuff, or can be a composite of
+ *		other tvbuffs.
  *
- * $Id: tvbuff.c 35158 2010-12-08 20:14:57Z etxrab $
+ * $Id: tvbuff.c 31059 2009-11-23 22:02:12Z jake $
  *
  * Copyright (c) 2000 by Gilbert Ramirez <gram@alumni.rice.edu>
  *
@@ -328,7 +328,7 @@ tvb_new_child_real_data(tvbuff_t *parent, const guint8* data, guint length, gint
 	if (tvb) {
 		tvb_set_child_real_data_tvbuff (parent, tvb);
 	}
-	
+
 	return tvb;
 }
 
@@ -410,7 +410,7 @@ compute_offset_length(guint tvb_length, guint tvb_reported_length, gint offset,
 
 
 static gboolean
-check_offset_length_no_exception(guint tvb_length, guint tvb_reported_length, gint offset, gint length, 
+check_offset_length_no_exception(guint tvb_length, guint tvb_reported_length, gint offset, gint length,
 		guint *offset_ptr, guint *length_ptr, int *exception)
 {
 	guint	end_offset;
@@ -517,6 +517,8 @@ tvb_new_subset(tvbuff_t *backing, gint backing_offset, gint backing_length, gint
 	guint		subset_tvb_offset;
 	guint		subset_tvb_length;
 
+	DISSECTOR_ASSERT(backing && backing->initialized);
+
 	THROW_ON(reported_length < -1, ReportedBoundsError);
 
 	check_offset_length(backing->length, backing->reported_length, backing_offset, backing_length,
@@ -827,7 +829,7 @@ offset_from_real_beginning(tvbuff_t *tvb, guint counter)
 guint
 tvb_offset_from_real_beginning(tvbuff_t *tvb)
 {
-    return offset_from_real_beginning(tvb, 0);
+	return offset_from_real_beginning(tvb, 0);
 }
 
 static const guint8*
@@ -881,7 +883,7 @@ ensure_contiguous_no_exception(tvbuff_t *tvb, gint offset, gint length,
 	guint	abs_offset, abs_length;
 
 	if (!check_offset_length_no_exception(tvb->length, tvb->reported_length, offset, length,
-	    &abs_offset, &abs_length, exception)) {
+		&abs_offset, &abs_length, exception)) {
 		return NULL;
 	}
 
@@ -934,7 +936,7 @@ fast_ensure_contiguous(tvbuff_t *tvb, gint offset, guint length)
 	DISSECTOR_ASSERT(length <= 8);
 
 	if (offset < 0 || !tvb->real_data) {
-	    return ensure_contiguous(tvb, offset, length);
+		return ensure_contiguous(tvb, offset, length);
 	}
 
 	u_offset = offset;
@@ -968,7 +970,7 @@ guint8_find(const guint8* haystack, size_t haystacklen, guint8 needle)
 }
 
 static const guint8*
-guint8_pbrk(const guint8* haystack, size_t haystacklen, const guint8 *needles, guchar *found_needle)
+guint8_pbrk(const guint8* haystack, size_t haystacklen, const guint8 *needles)
 {
 	const guint8	*b;
 	int		i;
@@ -979,11 +981,8 @@ guint8_pbrk(const guint8* haystack, size_t haystacklen, const guint8 *needles, g
 		item = *b;
 		needlep = needles;
 		while ((needle = *needlep) != '\0') {
-			if (item == needle){
-				if(found_needle)
-					*found_needle = needle;
+			if (item == needle)
 				return b;
-			}
 			needlep++;
 		}
 	}
@@ -1279,7 +1278,7 @@ get_ieee_float(guint32 w)
 #endif
 
 	exponent = ((exponent >> IEEE_SP_MANTISSA_WIDTH) - IEEE_SP_BIAS) -
-	    IEEE_SP_MANTISSA_WIDTH;
+		IEEE_SP_MANTISSA_WIDTH;
 	mantissa |= IEEE_SP_IMPLIED_BIT;
 
 	if (sign)
@@ -1340,7 +1339,7 @@ get_ieee_double(guint64 w)
 #endif
 
 	exponent = ((exponent >> IEEE_DP_MANTISSA_WIDTH) - IEEE_DP_BIAS) -
-	    IEEE_DP_MANTISSA_WIDTH;
+		IEEE_DP_MANTISSA_WIDTH;
 	mantissa |= IEEE_DP_IMPLIED_BIT;
 
 	if (sign)
@@ -1556,26 +1555,26 @@ tvb_get_guid(tvbuff_t *tvb, gint offset, e_guid_t *guid, gboolean little_endian)
 }
 
 static const guint8 bit_mask8[] = {
-    0xff,
-    0x7f,
-    0x3f,
-    0x1f,
-    0x0f,
-    0x07,
-    0x03,
-    0x01
+	0xff,
+	0x7f,
+	0x3f,
+	0x1f,
+	0x0f,
+	0x07,
+	0x03,
+	0x01
 };
 
 /* Bit offset mask for number of bits = 8 - 16 */
 static const guint16 bit_mask16[] = {
-    0xffff,
-    0x7fff,
-    0x3fff,
-    0x1fff,
-    0x0fff,
-    0x07ff,
-    0x03ff,
-    0x01ff
+	0xffff,
+	0x7fff,
+	0x3fff,
+	0x1fff,
+	0x0fff,
+	0x07ff,
+	0x03ff,
+	0x01ff
 };
 
 /* Get 1 - 8 bits */
@@ -1614,14 +1613,14 @@ tvb_get_bits8(tvbuff_t *tvb, gint bit_offset, gint no_of_bits)
 /* Get 9 - 16 bits */
 /* Bit offset mask for number of bits = 16 - 32 */
 static const guint32 bit_mask32[] = {
-    0xffffffff,
-    0x7fffffff,
-    0x3fffffff,
-    0x1fffffff,
-    0x0fffffff,
-    0x07ffffff,
-    0x03ffffff,
-    0x01ffffff
+	0xffffffff,
+	0x7fffffff,
+	0x3fffffff,
+	0x1fffffff,
+	0x0fffffff,
+	0x07ffffff,
+	0x03ffffff,
+	0x01ffffff
 };
 
 guint16
@@ -1668,14 +1667,14 @@ tvb_get_bits16(tvbuff_t *tvb, gint bit_offset, gint no_of_bits,gboolean little_e
 
 /* Bit offset mask for number of bits = 32 - 64 */
 static const guint64 bit_mask64[] = {
-    G_GINT64_CONSTANT(0xffffffffffffffffU),
-    G_GINT64_CONSTANT(0x7fffffffffffffffU),
-    G_GINT64_CONSTANT(0x3fffffffffffffffU),
-    G_GINT64_CONSTANT(0x1fffffffffffffffU),
-    G_GINT64_CONSTANT(0x0fffffffffffffffU),
-    G_GINT64_CONSTANT(0x07ffffffffffffffU),
-    G_GINT64_CONSTANT(0x03ffffffffffffffU),
-    G_GINT64_CONSTANT(0x01ffffffffffffffU)
+	G_GINT64_CONSTANT(0xffffffffffffffffU),
+	G_GINT64_CONSTANT(0x7fffffffffffffffU),
+	G_GINT64_CONSTANT(0x3fffffffffffffffU),
+	G_GINT64_CONSTANT(0x1fffffffffffffffU),
+	G_GINT64_CONSTANT(0x0fffffffffffffffU),
+	G_GINT64_CONSTANT(0x07ffffffffffffffU),
+	G_GINT64_CONSTANT(0x03ffffffffffffffU),
+	G_GINT64_CONSTANT(0x01ffffffffffffffU)
 };
 
 guint32
@@ -1857,7 +1856,7 @@ tvb_find_guint8(tvbuff_t *tvb, gint offset, gint maxlength, guint8 needle)
  * in that case, -1 will be returned if the boundary is reached before
  * finding needle. */
 gint
-tvb_pbrk_guint8(tvbuff_t *tvb, gint offset, gint maxlength, const guint8 *needles, guchar *found_needle)
+tvb_pbrk_guint8(tvbuff_t *tvb, gint offset, gint maxlength, const guint8 *needles)
 {
 	const guint8	*result;
 	guint		abs_offset, junk_length;
@@ -1887,7 +1886,7 @@ tvb_pbrk_guint8(tvbuff_t *tvb, gint offset, gint maxlength, const guint8 *needle
 
 	/* If we have real data, perform our search now. */
 	if (tvb->real_data) {
-		result = guint8_pbrk(tvb->real_data + abs_offset, limit, needles, found_needle);
+		result = guint8_pbrk(tvb->real_data + abs_offset, limit, needles);
 		if (result == NULL) {
 			return -1;
 		}
@@ -1903,7 +1902,7 @@ tvb_pbrk_guint8(tvbuff_t *tvb, gint offset, gint maxlength, const guint8 *needle
 		case TVBUFF_SUBSET:
 			return tvb_pbrk_guint8(tvb->tvbuffs.subset.tvb,
 					abs_offset - tvb->tvbuffs.subset.offset,
-					limit, needles, found_needle);
+					limit, needles);
 
 		case TVBUFF_COMPOSITE:
 			DISSECTOR_ASSERT_NOT_REACHED();
@@ -1935,7 +1934,7 @@ tvb_strsize(tvbuff_t *tvb, gint offset)
 		 * an exception.
 		 *
 		 * Did we hit the end of the captured data, or the end
-		 * of the actual data?  If there's less captured data
+		 * of the actual data?	If there's less captured data
 		 * than actual data, we presumably hit the end of the
 		 * captured data, otherwise we hit the end of the actual
 		 * data.
@@ -2058,7 +2057,7 @@ tvb_memeql(tvbuff_t *tvb, gint offset, const guint8 *str, size_t size)
 	}
 }
 
-/* Convert a string from Unicode to ASCII.  At the moment we fake it by
+/* Convert a string from Unicode to ASCII.	At the moment we fake it by
  * replacing all non-ASCII characters with a '.' )-:  The caller must
  * free the result returned.  The len parameter is the number of guint16's
  * to convert from Unicode. */
@@ -2089,7 +2088,7 @@ tvb_fake_unicode(tvbuff_t *tvb, int offset, int len, gboolean little_endian)
 	return buffer;
 }
 
-/* Convert a string from Unicode to ASCII.  At the moment we fake it by
+/* Convert a string from Unicode to ASCII.	At the moment we fake it by
  * replacing all non-ASCII characters with a '.' )-:   The len parameter is
  * the number of guint16's to convert from Unicode.
  *
@@ -2135,14 +2134,11 @@ tvb_format_text(tvbuff_t *tvb, gint offset, gint size)
   gint len = size;
 
   if ((ptr = ensure_contiguous(tvb, offset, size)) == NULL) {
-
     len = tvb_length_remaining(tvb, offset);
     ptr = ensure_contiguous(tvb, offset, len);
-
   }
 
   return format_text(ptr, len);
-
 }
 
 /*
@@ -2157,8 +2153,8 @@ tvb_format_text_wsp(tvbuff_t *tvb, gint offset, gint size)
 
   if ((ptr = ensure_contiguous(tvb, offset, size)) == NULL) {
 
-    len = tvb_length_remaining(tvb, offset);
-    ptr = ensure_contiguous(tvb, offset, len);
+	len = tvb_length_remaining(tvb, offset);
+	ptr = ensure_contiguous(tvb, offset, len);
 
   }
 
@@ -2179,13 +2175,13 @@ tvb_format_stringzpad(tvbuff_t *tvb, gint offset, gint size)
 
   if ((ptr = ensure_contiguous(tvb, offset, size)) == NULL) {
 
-    len = tvb_length_remaining(tvb, offset);
-    ptr = ensure_contiguous(tvb, offset, len);
+	len = tvb_length_remaining(tvb, offset);
+	ptr = ensure_contiguous(tvb, offset, len);
 
   }
 
   for (p = ptr, stringlen = 0; stringlen < len && *p != '\0'; p++, stringlen++)
-    ;
+	;
   return format_text(ptr, stringlen);
 
 }
@@ -2203,13 +2199,13 @@ tvb_format_stringzpad_wsp(tvbuff_t *tvb, gint offset, gint size)
 
   if ((ptr = ensure_contiguous(tvb, offset, size)) == NULL) {
 
-    len = tvb_length_remaining(tvb, offset);
-    ptr = ensure_contiguous(tvb, offset, len);
+	len = tvb_length_remaining(tvb, offset);
+	ptr = ensure_contiguous(tvb, offset, len);
 
   }
 
   for (p = ptr, stringlen = 0; stringlen < len && *p != '\0'; p++, stringlen++)
-    ;
+	;
   return format_text_wsp(ptr, stringlen);
 
 }
@@ -2303,7 +2299,7 @@ tvb_get_seasonal_string(tvbuff_t *tvb, gint offset, gint length)
  * a null-terminated string, find the length of that string (and throw
  * an exception if the tvbuff ends before we find the null), allocate
  * a buffer big enough to hold the string, copy the string into it,
- * and return a pointer to the string.  Also return the length of the
+ * and return a pointer to the string.	Also return the length of the
  * string (including the terminating null) through a pointer.
  */
 guint8 *
@@ -2315,7 +2311,8 @@ tvb_get_stringz(tvbuff_t *tvb, gint offset, gint *lengthp)
 	size = tvb_strsize(tvb, offset);
 	strptr = g_malloc(size);
 	tvb_memcpy(tvb, strptr, offset, size);
-	*lengthp = size;
+	if (lengthp)
+		*lengthp = size;
 	return strptr;
 }
 /*
@@ -2323,7 +2320,7 @@ tvb_get_stringz(tvbuff_t *tvb, gint offset, gint *lengthp)
  * a null-terminated string, find the length of that string (and throw
  * an exception if the tvbuff ends before we find the null), allocate
  * a buffer big enough to hold the string, copy the string into it,
- * and return a pointer to the string.  Also return the length of the
+ * and return a pointer to the string.	Also return the length of the
  * string (including the terminating null) through a pointer.
  *
  * This function allocates memory from a buffer with packet lifetime.
@@ -2341,7 +2338,8 @@ tvb_get_ephemeral_stringz(tvbuff_t *tvb, gint offset, gint *lengthp)
 	size = tvb_strsize(tvb, offset);
 	strptr = ep_alloc(size);
 	tvb_memcpy(tvb, strptr, offset, size);
-	*lengthp = size;
+	if (lengthp)
+		*lengthp = size;
 	return strptr;
 }
 
@@ -2350,7 +2348,7 @@ tvb_get_ephemeral_stringz(tvbuff_t *tvb, gint offset, gint *lengthp)
  * a null-terminated string, find the length of that string (and throw
  * an exception if the tvbuff ends before we find the null), allocate
  * a buffer big enough to hold the string, copy the string into it,
- * and return a pointer to the string.  Also return the length of the
+ * and return a pointer to the string.	Also return the length of the
  * string (including the terminating null) through a pointer.
  *
  * This function allocates memory from a buffer with capture session lifetime.
@@ -2366,7 +2364,8 @@ tvb_get_seasonal_stringz(tvbuff_t *tvb, gint offset, gint *lengthp)
 	size = tvb_strsize(tvb, offset);
 	strptr = se_alloc(size);
 	tvb_memcpy(tvb, strptr, offset, size);
-	*lengthp = size;
+	if (lengthp)
+		*lengthp = size;
 	return strptr;
 }
 
@@ -2521,16 +2520,15 @@ tvb_get_nstringz0(tvbuff_t *tvb, gint offset, guint bufsize, guint8* buffer)
  *
  * Set "*next_offset" to the offset of the character past the line
  * terminator, or past the end of the buffer if we don't find a line
- * terminator.  (It's not set if we return -1.)
+ * terminator.	(It's not set if we return -1.)
  */
 gint
 tvb_find_line_end(tvbuff_t *tvb, gint offset, int len, gint *next_offset,
-    gboolean desegment)
+	gboolean desegment)
 {
 	gint eob_offset;
 	gint eol_offset;
 	int linelen;
-	guchar found_needle = 0;
 
 	if (len == -1)
 		len = tvb_length_remaining(tvb, offset);
@@ -2543,7 +2541,7 @@ tvb_find_line_end(tvbuff_t *tvb, gint offset, int len, gint *next_offset,
 	/*
 	 * Look either for a CR or an LF.
 	 */
-	eol_offset = tvb_pbrk_guint8(tvb, offset, len, (const guint8 *)"\r\n", &found_needle);
+	eol_offset = tvb_pbrk_guint8(tvb, offset, len, (const guint8 *)"\r\n");
 	if (eol_offset == -1) {
 		/*
 		 * No CR or LF - line is presumably continued in next packet.
@@ -2560,7 +2558,8 @@ tvb_find_line_end(tvbuff_t *tvb, gint offset, int len, gint *next_offset,
 			 * Pretend the line runs to the end of the tvbuff.
 			 */
 			linelen = eob_offset - offset;
-			*next_offset = eob_offset;
+			if (next_offset)
+				*next_offset = eob_offset;
 		}
 	} else {
 		/*
@@ -2571,8 +2570,8 @@ tvb_find_line_end(tvbuff_t *tvb, gint offset, int len, gint *next_offset,
 
 		/*
 		 * Is it a CR?
-		 */		
-		if (found_needle == '\r') {
+		 */
+		if (tvb_get_guint8(tvb, eol_offset) == '\r') {
 			/*
 			 * Yes - is it followed by an LF?
 			 */
@@ -2614,7 +2613,8 @@ tvb_find_line_end(tvbuff_t *tvb, gint offset, int len, gint *next_offset,
 		 * character in the line, skipping over the last character
 		 * in the line terminator.
 		 */
-		*next_offset = eol_offset + 1;
+		if (next_offset)
+			*next_offset = eol_offset + 1;
 	}
 	return linelen;
 }
@@ -2639,11 +2639,11 @@ tvb_find_line_end(tvbuff_t *tvb, gint offset, int len, gint *next_offset,
  */
 gint
 tvb_find_line_end_unquoted(tvbuff_t *tvb, gint offset, int len,
-    gint *next_offset)
+	gint *next_offset)
 {
 	gint cur_offset, char_offset;
 	gboolean is_quoted;
-	guchar c = 0;
+	guchar c;
 	gint eob_offset;
 	int linelen;
 
@@ -2658,7 +2658,7 @@ tvb_find_line_end_unquoted(tvbuff_t *tvb, gint offset, int len,
 	cur_offset = offset;
 	is_quoted = FALSE;
 	for (;;) {
-	    	/*
+			/*
 		 * Is this part of the string quoted?
 		 */
 		if (is_quoted) {
@@ -2666,13 +2666,13 @@ tvb_find_line_end_unquoted(tvbuff_t *tvb, gint offset, int len,
 			 * Yes - look only for the terminating quote.
 			 */
 			char_offset = tvb_find_guint8(tvb, cur_offset, len,
-			    '"');
+				'"');
 		} else {
 			/*
 			 * Look either for a CR, an LF, or a '"'.
 			 */
 			char_offset = tvb_pbrk_guint8(tvb, cur_offset, len,
-			    (const guint8 *)"\r\n\"", &c);
+				(const guint8 *)"\r\n\"");
 		}
 		if (char_offset == -1) {
 			/*
@@ -2681,7 +2681,8 @@ tvb_find_line_end_unquoted(tvbuff_t *tvb, gint offset, int len,
 			 * We pretend the line runs to the end of the tvbuff.
 			 */
 			linelen = eob_offset - offset;
-			*next_offset = eob_offset;
+			if (next_offset)
+				*next_offset = eob_offset;
 			break;
 		}
 
@@ -2697,6 +2698,7 @@ tvb_find_line_end_unquoted(tvbuff_t *tvb, gint offset, int len,
 			/*
 			 * OK, what is it?
 			 */
+			c = tvb_get_guint8(tvb, char_offset);
 			if (c == '"') {
 				/*
 				 * Un-quoted "; it begins a quoted
@@ -2721,8 +2723,8 @@ tvb_find_line_end_unquoted(tvbuff_t *tvb, gint offset, int len,
 					 * Yes; is it followed by an LF?
 					 */
 					if (char_offset + 1 < eob_offset &&
-					    tvb_get_guint8(tvb, char_offset + 1)
-					      == '\n') {
+						tvb_get_guint8(tvb, char_offset + 1)
+						  == '\n') {
 						/*
 						 * Yes; skip over the CR.
 						 */
@@ -2736,7 +2738,8 @@ tvb_find_line_end_unquoted(tvbuff_t *tvb, gint offset, int len,
 				 * over the last character in the line
 				 * terminator, and quit.
 				 */
-				*next_offset = char_offset + 1;
+				if (next_offset)
+					*next_offset = char_offset + 1;
 				break;
 			}
 		}
@@ -2753,7 +2756,8 @@ tvb_find_line_end_unquoted(tvbuff_t *tvb, gint offset, int len,
 			 * We pretend the line runs to the end of the tvbuff.
 			 */
 			linelen = eob_offset - offset;
-			*next_offset = eob_offset;
+			if (next_offset)
+				*next_offset = eob_offset;
 			break;
 		}
 	}
@@ -2763,8 +2767,8 @@ tvb_find_line_end_unquoted(tvbuff_t *tvb, gint offset, int len,
 /*
  * Copied from the mgcp dissector. (This function should be moved to /epan )
  * tvb_skip_wsp - Returns the position in tvb of the first non-whitespace
- *                character following offset or offset + maxlength -1 whichever
- *                is smaller.
+ *				  character following offset or offset + maxlength -1 whichever
+ *				  is smaller.
  *
  * Parameters:
  * tvb - The tvbuff in which we are skipping whitespace.
@@ -2773,8 +2777,8 @@ tvb_find_line_end_unquoted(tvbuff_t *tvb, gint offset, int len,
  * whitespace.
  *
  * Returns: The position in tvb of the first non-whitespace
- *          character following offset or offset + maxlength -1 whichever
- *          is smaller.
+ *			character following offset or offset + maxlength -1 whichever
+ *			is smaller.
  */
 gint tvb_skip_wsp(tvbuff_t* tvb, gint offset, gint maxlength)
 {
@@ -2792,10 +2796,10 @@ gint tvb_skip_wsp(tvbuff_t* tvb, gint offset, gint maxlength)
 
 	/* Skip past spaces, tabs, CRs and LFs until run out or meet something else */
 	for (counter = offset;
-	     counter < end &&
-	      ((tempchar = tvb_get_guint8(tvb,counter)) == ' ' ||
-	      tempchar == '\t' || tempchar == '\r' || tempchar == '\n');
-	     counter++);
+		 counter < end &&
+		  ((tempchar = tvb_get_guint8(tvb,counter)) == ' ' ||
+		  tempchar == '\t' || tempchar == '\r' || tempchar == '\n');
+		 counter++);
 
 	return (counter);
 }
@@ -2882,8 +2886,6 @@ tvb_find_tvb(tvbuff_t *haystack_tvb, tvbuff_t *needle_tvb, gint haystack_offset)
 tvbuff_t *
 tvb_uncompress(tvbuff_t *tvb, int offset, int comprlen)
 {
-
-
 	gint err = Z_OK;
 	guint bytes_out = 0;
 	guint8 *compr = NULL;
@@ -2904,26 +2906,17 @@ tvb_uncompress(tvbuff_t *tvb, int offset, int comprlen)
 		return NULL;
 	}
 
-	strm = g_malloc0(sizeof(z_stream));
-
 	compr = tvb_memdup(tvb, offset, comprlen);
 
-	if (!compr) {
-		g_free(strm);
+	if (!compr)
 		return NULL;
-	}
 
 	/*
 	 * Assume that the uncompressed data is at least twice as big as
 	 * the compressed size.
 	 */
 	bufsiz = tvb_length_remaining(tvb, offset) * 2;
-
-	if (bufsiz < TVB_Z_MIN_BUFSIZ) {
-		bufsiz = TVB_Z_MIN_BUFSIZ;
-	} else if (bufsiz > TVB_Z_MAX_BUFSIZ) {
-		bufsiz = TVB_Z_MIN_BUFSIZ;
-	}
+	bufsiz = CLAMP(bufsiz, TVB_Z_MIN_BUFSIZ, TVB_Z_MAX_BUFSIZ);
 
 #ifdef TVB_Z_DEBUG
 	printf("bufsiz: %u bytes\n", bufsiz);
@@ -2931,10 +2924,10 @@ tvb_uncompress(tvbuff_t *tvb, int offset, int comprlen)
 
 	next = compr;
 
+	strm = g_new0(z_stream, 1);
 	strm->next_in = next;
 	strm->avail_in = comprlen;
 
-
 	strmbuf = g_malloc0(bufsiz);
 	strm->next_out = strmbuf;
 	strm->avail_out = bufsiz;
@@ -2970,7 +2963,7 @@ tvb_uncompress(tvbuff_t *tvb, int offset, int comprlen)
 
 				g_memmove(new_data, uncompr, bytes_out);
 				g_memmove((new_data + bytes_out), strmbuf,
-				    bytes_pass);
+					bytes_pass);
 
 				g_free(uncompr);
 				uncompr = new_data;
@@ -3002,8 +2995,8 @@ tvb_uncompress(tvbuff_t *tvb, int offset, int comprlen)
 			}
 
 		} else if (err == Z_DATA_ERROR && inits_done == 1
-		    && uncompr == NULL && (*compr  == 0x1f) &&
-		    (*(compr + 1) == 0x8b)) {
+			&& uncompr == NULL && (*compr  == 0x1f) &&
+			(*(compr + 1) == 0x8b)) {
 			/*
 			 * inflate() is supposed to handle both gzip and deflate
 			 * streams automatically, but in reality it doesn't
@@ -3039,7 +3032,7 @@ tvb_uncompress(tvbuff_t *tvb, int offset, int comprlen)
 			if (flags & (1 << 2)) {
 				/* An Extra field is present. */
 				gint xsize = (gint)(*c |
-				    (*(c + 1) << 8));
+					(*(c + 1) << 8));
 
 				c += xsize;
 			}
@@ -3081,7 +3074,7 @@ tvb_uncompress(tvbuff_t *tvb, int offset, int comprlen)
 			err = inflateInit2(strm, wbits);
 			inits_done++;
 		} else if (err == Z_DATA_ERROR && uncompr == NULL &&
-		    inits_done <= 3) {
+			inits_done <= 3) {
 
 			/*
 			 * Re-init the stream with a negative
@@ -3135,7 +3128,7 @@ tvb_uncompress(tvbuff_t *tvb, int offset, int comprlen)
 
 	if (uncompr != NULL) {
 		uncompr_tvb =  tvb_new_real_data((guint8*) uncompr, bytes_out,
-		    bytes_out);
+			bytes_out);
 		tvb_set_free_cb(uncompr_tvb, g_free);
 	}
 	g_free(compr);
