@@ -3,7 +3,7 @@
 --
 -- (c) 2006 Luis E. Garcia Ontanon <luis@ontanon.org>
 --
--- $Id: console.lua 25937 2008-08-05 21:03:46Z lego $
+-- $Id: console.lua 28700 2009-06-11 13:08:06Z stig $
 -- 
 -- Wireshark - Network traffic analyzer
 -- By Gerald Combs <gerald@wireshark.org>
@@ -105,7 +105,7 @@ if (gui_enabled()) then
 		browser_open_url("http://wiki.wireshark.org/Lua")
 	end
 
-	register_menu("Lua/Evaluate", evaluate_lua, MENU_TOOLS)
-	register_menu("Lua/Console", run_console, MENU_TOOLS)
-	register_menu("Lua/Wiki", wiki_page, MENU_TOOLS)
+	register_menu("Lua/Evaluate", evaluate_lua, MENU_TOOLS_UNSORTED)
+	register_menu("Lua/Console", run_console, MENU_TOOLS_UNSORTED)
+	register_menu("Lua/Wiki", wiki_page, MENU_TOOLS_UNSORTED)
 end
