@@ -7,7 +7,7 @@
  * (c) 2007, Tamas Regos <tamas.regos@ericsson.com>
  * (c) 2008, Balint Reczey <balint.reczey@ericsson.com>
  *
- * $Id: wslua.h 26216 2008-09-16 14:37:00Z rbalint $
+ * $Id: wslua.h 31050 2009-11-22 22:13:11Z stig $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -38,6 +38,7 @@
 #include <glib.h>
 #include <errno.h>
 #include <string.h>
+#include <ctype.h>
 #include <lua.h>
 #include <lualib.h>
 #include <lauxlib.h>
@@ -76,6 +77,11 @@ struct _wslua_tvbrange {
     int len;
 };
 
+struct _wslua_tw {
+    funnel_text_window_t* ws_tw;
+    gboolean expired;
+};
+
 typedef struct _wslua_field_t {
     int hfid;
     int ett;
@@ -219,7 +225,7 @@ typedef guint64* UInt64;
 typedef header_field_info** Field;
 typedef field_info* FieldInfo;
 typedef struct _wslua_tap* Listener;
-typedef funnel_text_window_t* TextWindow;
+typedef struct _wslua_tw* TextWindow;
 typedef struct _wslua_progdlg* ProgDlg;
 typedef wtap_dumper* Dumper;
 typedef struct lua_pseudo_header* PseudoHeader;
@@ -230,7 +236,6 @@ typedef tvbparse_action_t* Shortcut;
 typedef struct _wslua_main* WireShark;
 typedef struct _wslua_dir* Dir;
 
-
 /*
  * toXxx(L,idx) gets a Xxx from an index (Lua Error if fails)
  * checkXxx(L,idx) gets a Xxx from an index after calling check_code (No Lua Error if it fails)
@@ -254,7 +259,9 @@ C check##C(lua_State* L, int index) { \
     return p ? *p : NULL; \
 } \
 C* push##C(lua_State* L, C v) { \
-    C* p = lua_newuserdata(L,sizeof(C)); *p = v; \
+    C* p; \
+    luaL_checkstack(L,2,"Unable to grow stack\n"); \
+    p = lua_newuserdata(L,sizeof(C)); *p = v; \
     luaL_getmetatable(L, #C); lua_setmetatable(L, -2); \
 	push_code; \
     return p; \
@@ -292,10 +299,14 @@ typedef int dummy##C
 	lua_pushliteral(L, "__metatable"); \
 	lua_pushvalue(L, -3); \
 	lua_rawset(L, -3); \
-	lua_pop(L, 1); \
+       lua_pop(L, 2); \
 }
 
-#define WSLUA_REGISTER_META(C) luaL_newmetatable (L, #C);   luaL_register (L, NULL, C ## _meta); 
+#define WSLUA_REGISTER_META(C) { \
+       luaL_newmetatable (L, #C); \
+       luaL_register (L, NULL, C ## _meta); \
+       lua_pop(L,1); \
+}
 
 #define WSLUA_INIT(L) \
 	luaL_openlibs(L); \
@@ -324,8 +335,8 @@ typedef int dummy##C
 #define WSLUA_OPTARG_ERROR(name,attr,error) { luaL_argerror(L,WSLUA_OPTARG_##name##_ ##attr, #name  ": " error); return 0; }
 
 #define WSLUA_REG_GLOBAL_BOOL(L,n,v) { lua_pushstring(L,n); lua_pushboolean(L,v); lua_settable(L, LUA_GLOBALSINDEX); }
-#define WSLUA_REG_GLOBAL_STRING(n,v) { lua_pushstring(L,n); lua_pushstring(L,v); lua_settable(L, LUA_GLOBALSINDEX); }
-#define WSLUA_REG_GLOBAL_NUMBER(n,v) { lua_pushstring(L,n); lua_pushnumber(L,v); lua_settable(L, LUA_GLOBALSINDEX); }
+#define WSLUA_REG_GLOBAL_STRING(L,n,v) { lua_pushstring(L,n); lua_pushstring(L,v); lua_settable(L, LUA_GLOBALSINDEX); }
+#define WSLUA_REG_GLOBAL_NUMBER(L,n,v) { lua_pushstring(L,n); lua_pushnumber(L,v); lua_settable(L, LUA_GLOBALSINDEX); }
 
 #define WSLUA_RETURN(i) return (i);
 
@@ -398,4 +409,6 @@ extern int wslua_init(lua_State* L);
 extern tap_extractor_t wslua_get_tap_extractor(const gchar* name);
 extern int wslua_set_tap_enums(lua_State* L);
 
+extern int luaopen_bit(lua_State *L);
+
 #endif
