@@ -5,8 +5,9 @@
  *
  * (c) 2006, Luis E. Garcia Ontanon <luis@ontanon.org>
  * (c) 2008, Balint Reczey <balint.reczey@ericsson.com>
+ * (c) 2009, Stig Bjorlykke <stig@bjorlykke.org>
  *
- * $Id: wslua_tvb.c 28327 2009-05-10 16:02:57Z stig $
+ * $Id: wslua_tvb.c 30517 2009-10-11 16:27:37Z stig $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -95,8 +96,8 @@ WSLUA_METAMETHOD ByteArray__concat(lua_State* L) {
     ByteArray ba = checkByteArray(L,WSLUA_ARG_ByteArray__cat_FIRST);
     ByteArray ba2 = checkByteArray(L,WSLUA_ARG_ByteArray__cat_SECOND);
 
-	if (! (ba  && ba2) )
-		WSLUA_ERROR(ByteArray__cat,"Both arguments must be ByteArrays");
+    if (! (ba  && ba2) )
+        WSLUA_ERROR(ByteArray__cat,"Both arguments must be ByteArrays");
 
     g_byte_array_append(ba,ba2->data,ba2->len);
 
@@ -110,8 +111,8 @@ WSLUA_METHOD ByteArray_prepend(lua_State* L) {
     ByteArray ba = checkByteArray(L,1);
     ByteArray ba2 = checkByteArray(L,WSLUA_ARG_ByteArray_prepend_PREPENDED);
 
-	if (! (ba  && ba2) )
-		WSLUA_ERROR(ByteArray_prepend,"Both arguments must be ByteArrays");
+    if (! (ba  && ba2) )
+        WSLUA_ERROR(ByteArray_prepend,"Both arguments must be ByteArrays");
 
     g_byte_array_prepend(ba,ba2->data,ba2->len);
 
@@ -125,8 +126,8 @@ WSLUA_METHOD ByteArray_append(lua_State* L) {
     ByteArray ba = checkByteArray(L,1);
     ByteArray ba2 = checkByteArray(L,WSLUA_ARG_ByteArray_append_APPENDED);
 
-	if (! (ba  && ba2) )
-		WSLUA_ERROR(ByteArray_append,"Both arguments must be ByteArrays");
+    if (! (ba  && ba2) )
+        WSLUA_ERROR(ByteArray_append,"Both arguments must be ByteArrays");
 
     g_byte_array_append(ba,ba2->data,ba2->len);
 
@@ -190,10 +191,10 @@ WSLUA_METHOD ByteArray_set_index(lua_State* L) {
 
 
 WSLUA_METHOD ByteArray_get_index(lua_State* L) {
-	/* Set the value of a byte in a ByteArray */
-#define WSLUA_ARG_ByteArray_set_index_INDEX 2 /* The position of the byte to be set */
+	/* Get the value of a byte in a ByteArray */
+#define WSLUA_ARG_ByteArray_get_index_INDEX 2 /* The position of the byte to get */
     ByteArray ba = checkByteArray(L,1);
-    int idx = luaL_checkint(L,WSLUA_ARG_ByteArray_set_index_INDEX);
+    int idx = luaL_checkint(L,WSLUA_ARG_ByteArray_get_index_INDEX);
 
     if (!ba) return 0;
 
@@ -308,7 +309,7 @@ static const luaL_reg ByteArray_meta[] = {
 };
 
 int ByteArray_register(lua_State* L) {
-	WSLUA_REGISTER_CLASS(ByteArray);
+    WSLUA_REGISTER_CLASS(ByteArray);
     return 1;
 }
 
@@ -492,7 +493,7 @@ WSLUA_CLASS_DEFINE(TvbRange,FAIL_ON_NULL("expired tvbrange"),NOP);
   TvbRanges are created by calling a tvb (e.g. tvb(offset,length)). If the TvbRange span is outside the Tvb's range the creation will cause a runtime error.
  */
 
-TvbRange new_TvbRange(lua_State* L, tvbuff_t* ws_tvb, int offset, int len) {
+static TvbRange new_TvbRange(lua_State* L, tvbuff_t* ws_tvb, int offset, int len) {
     TvbRange tvbr;
 
 
@@ -541,7 +542,7 @@ WSLUA_METHOD Tvb_range(lua_State* L) {
 
     if ((tvbr = new_TvbRange(L,tvb->ws_tvb,offset,len))) {
         PUSH_TVBRANGE(L,tvbr);
-	WSLUA_RETURN(1); /* The TvbRange */
+        WSLUA_RETURN(1); /* The TvbRange */
     }
 
     return 0;
@@ -554,8 +555,6 @@ static const luaL_reg Tvb_methods[] = {
     { NULL, NULL }
 };
 
-static int Tvb_range(lua_State* L);
-
 static const luaL_reg Tvb_meta[] = {
     {"__call", Tvb_range},
     {"__tostring", Tvb__tostring},
@@ -564,7 +563,7 @@ static const luaL_reg Tvb_meta[] = {
 };
 
 int Tvb_register(lua_State* L) {
-	WSLUA_REGISTER_CLASS(Tvb);
+    WSLUA_REGISTER_CLASS(Tvb);
     return 1;
 }
 
@@ -593,7 +592,7 @@ WSLUA_METHOD TvbRange_uint(lua_State* L) {
             return 1;
         case 4:
             lua_pushnumber(L,tvb_get_ntohl(tvbr->tvb->ws_tvb,tvbr->offset));
-	    WSLUA_RETURN(1); /* The unsigned integer value */
+            WSLUA_RETURN(1); /* The unsigned integer value */
             /*
              * XXX:
              *    lua uses double so we have 52 bits to play with
@@ -632,7 +631,7 @@ WSLUA_METHOD TvbRange_le_uint(lua_State* L) {
             return 1;
         case 4:
             lua_pushnumber(L,tvb_get_letohl(tvbr->tvb->ws_tvb,tvbr->offset));
-	    WSLUA_RETURN(1); /* The unsigned integer value */
+            WSLUA_RETURN(1); /* The unsigned integer value */
         default:
             luaL_error(L,"TvbRange:get_le_uint() does not handle %d byte integers",tvbr->len);
             return 0;
@@ -660,9 +659,9 @@ WSLUA_METHOD TvbRange_uint64(lua_State* L) {
         case 6:
         case 7:
         case 8: {
-	    UInt64 num = g_malloc(sizeof(guint64));
-	    *num = tvb_get_ntoh64(tvbr->tvb->ws_tvb,tvbr->offset);
-	    pushUInt64(L,num);
+            UInt64 num = g_malloc(sizeof(guint64));
+            *num = tvb_get_ntoh64(tvbr->tvb->ws_tvb,tvbr->offset);
+            pushUInt64(L,num);
             WSLUA_RETURN(1);
         }
         default:
@@ -692,9 +691,9 @@ WSLUA_METHOD TvbRange_le_uint64(lua_State* L) {
         case 6:
         case 7:
         case 8: {
-	    UInt64 num = g_malloc(sizeof(guint64));
-	    *num = tvb_get_ntoh64(tvbr->tvb->ws_tvb,tvbr->offset);
-	    pushUInt64(L,num);
+            UInt64 num = g_malloc(sizeof(guint64));
+            *num = tvb_get_ntoh64(tvbr->tvb->ws_tvb,tvbr->offset);
+            pushUInt64(L,num);
             WSLUA_RETURN(1);
         }
         default:
@@ -721,7 +720,7 @@ WSLUA_METHOD TvbRange_float(lua_State* L) {
             return 1;
         case 8:
             lua_pushnumber(L,tvb_get_ntohieee_double(tvbr->tvb->ws_tvb,tvbr->offset));
-			WSLUA_RETURN(1); /* The flaoting point value */
+            WSLUA_RETURN(1); /* The flaoting point value */
         default:
             luaL_error(L,"TvbRange:get_float() does not handle %d byte floating numbers",tvbr->len);
             return 0;
@@ -742,7 +741,7 @@ WSLUA_METHOD TvbRange_le_float(lua_State* L) {
             return 1;
         case 8:
             lua_pushnumber(L,tvb_get_letohieee_double(tvbr->tvb->ws_tvb,tvbr->offset));
-			WSLUA_RETURN(1); /* The flaoting point value */
+            WSLUA_RETURN(1); /* The flaoting point value */
         default:
             luaL_error(L,"TvbRange:get_float() does not handle %d byte floating numbers",tvbr->len);
             return 0;
@@ -751,7 +750,6 @@ WSLUA_METHOD TvbRange_le_float(lua_State* L) {
 
 WSLUA_METHOD TvbRange_ipv4(lua_State* L) {
 	/* Get an IPv4 Address from a TvbRange. */
-
     TvbRange tvbr = checkTvbRange(L,1);
     Address addr;
     guint32* ip_addr;
@@ -762,8 +760,8 @@ WSLUA_METHOD TvbRange_ipv4(lua_State* L) {
         return 0;
     }
 
-	if (tvbr->len != 4)
-		WSLUA_ERROR(TvbRange_ipv4,"The range must be 4 octets long");
+    if (tvbr->len != 4)
+        WSLUA_ERROR(TvbRange_ipv4,"The range must be 4 octets long");
 
     addr = g_malloc(sizeof(address));
 
@@ -773,12 +771,11 @@ WSLUA_METHOD TvbRange_ipv4(lua_State* L) {
     SET_ADDRESS(addr, AT_IPv4, 4, ip_addr);
     pushAddress(L,addr);
 
-	WSLUA_RETURN(1); /* The IPv4 Address */
+    WSLUA_RETURN(1); /* The IPv4 Address */
 }
 
 WSLUA_METHOD TvbRange_le_ipv4(lua_State* L) {
 	/* Get an Little Endian IPv4 Address from a TvbRange. */
-
     TvbRange tvbr = checkTvbRange(L,1);
     Address addr;
     guint32* ip_addr;
@@ -789,8 +786,8 @@ WSLUA_METHOD TvbRange_le_ipv4(lua_State* L) {
         return 0;
     }
 
-	if (tvbr->len != 4)
-		WSLUA_ERROR(TvbRange_ipv4,"The range must be 4 octets long");
+    if (tvbr->len != 4)
+        WSLUA_ERROR(TvbRange_ipv4,"The range must be 4 octets long");
 
     addr = g_malloc(sizeof(address));
 
@@ -801,7 +798,7 @@ WSLUA_METHOD TvbRange_le_ipv4(lua_State* L) {
     SET_ADDRESS(addr, AT_IPv4, 4, ip_addr);
     pushAddress(L,addr);
 
-	WSLUA_RETURN(1); /* The IPv4 Address */
+    WSLUA_RETURN(1); /* The IPv4 Address */
 }
 
 WSLUA_METHOD TvbRange_ether(lua_State* L) {
@@ -818,15 +815,15 @@ WSLUA_METHOD TvbRange_ether(lua_State* L) {
 
     addr = g_malloc(sizeof(address));
 
-	if (tvbr->len != 6)
-		WSLUA_ERROR(TvbRange_ether,"The range must be 6 bytes long");
+    if (tvbr->len != 6)
+        WSLUA_ERROR(TvbRange_ether,"The range must be 6 bytes long");
 
     buff = tvb_memdup(tvbr->tvb->ws_tvb,tvbr->offset,tvbr->len);
 
     SET_ADDRESS(addr, AT_ETHER, 6, buff);
     pushAddress(L,addr);
 
-	WSLUA_RETURN(1); /* The Ethernet Address */
+    WSLUA_RETURN(1); /* The Ethernet Address */
 }
 
 
@@ -842,7 +839,7 @@ WSLUA_METHOD TvbRange_string(lua_State* L) {
 
     lua_pushstring(L, (gchar*)tvb_get_ephemeral_string(tvbr->tvb->ws_tvb,tvbr->offset,tvbr->len) );
 
-	WSLUA_RETURN(1); /* The string */
+    WSLUA_RETURN(1); /* The string */
 }
 
 WSLUA_METHOD TvbRange_bytes(lua_State* L) {
@@ -861,7 +858,75 @@ WSLUA_METHOD TvbRange_bytes(lua_State* L) {
 
     pushByteArray(L,ba);
 
-	WSLUA_RETURN(1); /* The ByteArray */
+    WSLUA_RETURN(1); /* The ByteArray */
+}
+
+WSLUA_METHOD TvbRange_bitfield(lua_State* L) {
+	/* Get a bitfield from a TvbRange. */
+#define WSLUA_OPTARG_TvbRange_bitfield_POSITION 2 /* The bit offset from the begining of the TvbRange. Defaults to 0. */
+#define WSLUA_OPTARG_TvbRange_bitfield_LENGTH 3 /* The length (in bits) of the field. Defaults to 1. */
+
+    TvbRange tvbr = checkTvbRange(L,1);
+    int pos = luaL_optint(L,WSLUA_OPTARG_TvbRange_bitfield_POSITION,0);
+    int len = luaL_optint(L,WSLUA_OPTARG_TvbRange_bitfield_LENGTH,1);
+
+    if (!(tvbr && tvbr->tvb)) return 0;
+    if (tvbr->tvb->expired) {
+        luaL_error(L,"expired tvb");
+        return 0;
+    }
+
+    if ((pos+len) > (tvbr->len<<3)) {
+        luaL_error(L, "Requested bitfield out of range");
+        return 0;
+    }
+
+    if (len <= 8) {
+        lua_pushnumber(L,(lua_Number)tvb_get_bits8(tvbr->tvb->ws_tvb,tvbr->offset*8 + pos, len));
+        return 1;
+    } else if (len <= 16) {
+        lua_pushnumber(L,tvb_get_bits16(tvbr->tvb->ws_tvb,tvbr->offset*8 + pos, len, FALSE));
+        return 1;
+    } else if (len <= 32) {
+        lua_pushnumber(L,tvb_get_bits32(tvbr->tvb->ws_tvb,tvbr->offset*8 + pos, len, FALSE));
+        return 1;
+    } else if (len <= 64) {
+        UInt64 num = g_malloc(sizeof(guint64));
+        *num = tvb_get_bits64(tvbr->tvb->ws_tvb,tvbr->offset*8 + pos, len, FALSE);
+        pushUInt64(L,num);
+        WSLUA_RETURN(1); /* The bitfield value */
+    } else {
+        luaL_error(L,"TvbRange:bitfield() does not handle %d bits",len);
+        return 0;
+    }
+}
+
+WSLUA_METHOD TvbRange_range(lua_State* L) {
+	/* Creates a sub-TvbRange from this TvbRange. This is used also as the TvbRange:__call() metamethod. */
+#define WSLUA_OPTARG_TvbRange_range_OFFSET 2 /* The offset (in octets) from the begining of the TvbRange. Defaults to 0. */
+#define WSLUA_OPTARG_TvbRange_range_LENGTH 3 /* The length (in octets) of the range. Defaults to until the end of the TvbRange. */
+ 
+    TvbRange tvbr = checkTvbRange(L,1);
+    int offset = luaL_optint(L,WSLUA_OPTARG_TvbRange_range_OFFSET,0);
+    int len = luaL_optint(L,WSLUA_OPTARG_TvbRange_range_LENGTH,tvbr->len-offset);
+
+    if (!(tvbr && tvbr->tvb)) return 0;
+    if (tvbr->tvb->expired) {
+        luaL_error(L,"expired tvb");
+        return 0;
+    }
+
+    if (offset >= tvbr->len || (len + offset) > tvbr->len) {
+        luaL_error(L,"Range is out of bounds");
+        return 0;
+    }
+
+    if ((tvbr = new_TvbRange(L,tvbr->tvb->ws_tvb,tvbr->offset+offset,len))) {
+        PUSH_TVBRANGE(L,tvbr);
+        WSLUA_RETURN(1); /* The TvbRange */
+    }
+
+    return 0;
 }
 
 WSLUA_METHOD TvbRange_len(lua_State* L) {
@@ -916,9 +981,11 @@ static const luaL_reg TvbRange_methods[] = {
     {"le_float", TvbRange_le_float},
     {"ether", TvbRange_ether},
     {"ipv4", TvbRange_ipv4},
-	{"le_ipv4", TvbRange_le_ipv4},
+    {"le_ipv4", TvbRange_le_ipv4},
     {"string", TvbRange_string},
     {"bytes", TvbRange_bytes},
+    {"bitfield", TvbRange_bitfield},
+    {"range", TvbRange_range},
     {"len", TvbRange_len},
     {"offset", TvbRange_offset},
     {"tvb", Tvb_tvb},
@@ -927,6 +994,7 @@ static const luaL_reg TvbRange_methods[] = {
 
 static const luaL_reg TvbRange_meta[] = {
     {"__tostring", TvbRange__tostring},
+    {"__call", TvbRange_range},
     { NULL, NULL }
 };
 
@@ -937,7 +1005,7 @@ int TvbRange_register(lua_State* L) {
     return 1;
 }
 
-WSLUA_CLASS_DEFINE(Int64,NOP,NOP);
+WSLUA_CLASS_DEFINE(Int64,FAIL_ON_NULL("null int64"),NOP);
 /*
   Int64 represents a 64 bit integer.
   Lua uses one single number representation which can be chosen at compile time and since
@@ -949,16 +1017,27 @@ WSLUA_CLASS_DEFINE(Int64,NOP,NOP);
 WSLUA_METAMETHOD Int64__tostring(lua_State* L) {
 	/* Converts the Int64 into a string */
     Int64 num = checkInt64(L,1);
-    lua_pushstring(L,g_strdup_printf("%ld",(long int)*(num)));
+    lua_pushstring(L,ep_strdup_printf("%" G_GINT64_MODIFIER "d",(gint64)*(num)));
     return 1;
 }
 
+static int Int64__gc(lua_State* L) {
+    Int64 num = checkInt64(L,1);
+
+    if (!num) return 0;
+
+    g_free(num);
+
+    return 0;
+}
+
 static const luaL_reg Int64_methods[] = {
     { NULL, NULL }
 };
 
 static const luaL_reg Int64_meta[] = {
-   {"__tostring", Int64__tostring},
+    {"__tostring", Int64__tostring},
+    {"__gc", Int64__gc},
     { NULL, NULL }
 };
 
@@ -967,22 +1046,33 @@ int Int64_register(lua_State* L) {
     return 1;
 }
 
-WSLUA_CLASS_DEFINE(UInt64,NOP,NOP);
-	/* Int64 represents a 64 bit integer. */
+WSLUA_CLASS_DEFINE(UInt64,FAIL_ON_NULL("null uint64"),NOP);
+	/* UInt64 represents a 64 bit unsigned integer. */
 
 WSLUA_METAMETHOD UInt64__tostring(lua_State* L) {
 	/* Converts the UInt64 into a string */
     UInt64 num = checkUInt64(L,1);
-    lua_pushstring(L,g_strdup_printf("%ld",(unsigned long int)*(num)));
+    lua_pushstring(L,ep_strdup_printf("%" G_GINT64_MODIFIER "u",(guint64)*(num)));
     return 1;
 }
 
+static int UInt64__gc(lua_State* L) {
+    UInt64 num = checkUInt64(L,1);
+
+    if (!num) return 0;
+
+    g_free(num);
+
+    return 0;
+}
+
 static const luaL_reg UInt64_methods[] = {
     { NULL, NULL }
 };
 
 static const luaL_reg UInt64_meta[] = {
     {"__tostring", UInt64__tostring},
+    {"__gc", UInt64__gc},
     { NULL, NULL }
 };
 
