@@ -1,12 +1,12 @@
 /* about_dlg.c
  *
- * $Id: about_dlg.c 29575 2009-08-26 23:24:22Z wmeier $
+ * $Id: about_dlg.c 30675 2009-10-23 17:52:18Z stig $
  *
  * Ulf Lamping <ulf.lamping@web.de>
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
- * Copyright 2000 Gerald Combs
+ * Copyright 1998 Gerald Combs
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -267,16 +267,16 @@ splash_update(register_action_e action, const char *message, gpointer client_dat
 
 }
 
-guint
+gboolean
 splash_destroy(GtkWidget *win)
 {
-    if (win == NULL) return FALSE;
+    if (win == NULL)
+        return FALSE;
 
     gtk_widget_destroy(win);
     return FALSE;
 }
 
-
 static GtkWidget *
 about_wireshark_page_new(void)
 {
@@ -361,7 +361,6 @@ about_folders_row(GtkWidget *table, const char *label, const char *dir, const ch
   simple_list_append(table, 0, label, 1, dir, 2, tip, -1);
 }
 
-
 static GtkWidget *
 about_folders_page_new(void)
 {
@@ -396,13 +395,13 @@ about_folders_page_new(void)
   path = get_tempfile_path("");
   about_folders_row(table, "Temp", path,
       "untitled capture files");
-  g_free((void *) path);
+  g_free(path);
 
   /* pers conf */
   path = get_persconffile_path("", FALSE, FALSE);
   about_folders_row(table, "Personal configuration", path,
       "\"dfilters\", \"preferences\", \"ethers\", ...");
-  g_free((void *) path);
+  g_free(path);
 
   /* global conf */
   constpath = get_datafile_dir();
@@ -421,12 +420,12 @@ about_folders_page_new(void)
   about_folders_row(table, "Program", constpath,
       "program files");
 
-#ifdef HAVE_PLUGINS
+#if defined(HAVE_PLUGINS) || defined(HAVE_LUA_5_1)
   /* pers plugins */
   path = get_plugins_pers_dir();
   about_folders_row(table, "Personal Plugins", path,
       "dissector plugins");
-  g_free((void *) path);
+  g_free(path);
 
   /* global plugins */
   about_folders_row(table, "Global Plugins", get_plugin_dir(),
@@ -443,34 +442,26 @@ about_folders_page_new(void)
   /* GeoIP */
   path = geoip_db_get_paths();
 
-#ifdef _WIN32
-  resultArray = g_strsplit(path, ";", 10);
-#else
-  resultArray = g_strsplit(path, ":", 10);
-#endif
+  resultArray = g_strsplit(path, G_SEARCHPATH_SEPARATOR_S, 10);
 
   for(i = 0; resultArray[i]; i++)
     about_folders_row(table, "GeoIP path", g_strstrip(resultArray[i]),
 		      "GeoIP database search path");
   g_strfreev(resultArray);
-  g_free((void *) path);
+  g_free(path);
 #endif
 
 #ifdef HAVE_LIBSMI
   /* SMI MIBs/PIBs */
   path = oid_get_default_mib_path();
 
-#ifdef _WIN32
-  resultArray = g_strsplit(path, ";", 10);
-#else
-  resultArray = g_strsplit(path, ":", 10);
-#endif
+  resultArray = g_strsplit(path, G_SEARCHPATH_SEPARATOR_S, 10);
 
   for(i = 0; resultArray[i]; i++)
     about_folders_row(table, "MIB/PIB path", g_strstrip(resultArray[i]),
 		      "SMI MIB/PIB search path");
   g_strfreev(resultArray);
-  g_free((void *) path);
+  g_free(path);
 #endif
 
   gtk_container_add(GTK_CONTAINER(scrolledwindow), table);
@@ -496,7 +487,7 @@ about_wireshark_cb( GtkWidget *w _U_, gpointer data _U_ )
   GtkWidget   *main_vb, *main_nb, *bbox, *ok_btn;
   GtkWidget   *page_lb, *about_page, *folders_page;
 
-#ifdef HAVE_PLUGINS
+#if defined(HAVE_PLUGINS) || defined(HAVE_LUA_5_1)
   GtkWidget   *plugins_page;
 #endif
 
@@ -540,7 +531,7 @@ about_wireshark_cb( GtkWidget *w _U_, gpointer data _U_ )
   page_lb = gtk_label_new("Folders");
   gtk_notebook_append_page(GTK_NOTEBOOK(main_nb), folders_page, page_lb);
 
-#ifdef HAVE_PLUGINS
+#if defined(HAVE_PLUGINS) || defined(HAVE_LUA_5_1)
   plugins_page = about_plugins_page_new();
   page_lb = gtk_label_new("Plugins");
   gtk_notebook_append_page(GTK_NOTEBOOK(main_nb), plugins_page, page_lb);
@@ -575,4 +566,3 @@ about_wireshark_destroy_cb(GtkWidget *win _U_, gpointer user_data _U_)
   about_wireshark_w = NULL;
 }
 
-
