@@ -1,13 +1,12 @@
 /* capture_dlg.h
  * Definitions for packet capture windows
  *
- * $Id: capture_dlg.h 26747 2008-11-11 11:37:53Z stig $
+ * $Id: capture_dlg.h 29757 2009-09-07 07:30:42Z jmayer $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
  * Copyright 1998 Gerald Combs
  *
- *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
  * as published by the Free Software Foundation; either version 2
@@ -26,7 +25,7 @@
 #ifndef __CAPTURE_DLG_H__
 #define __CAPTURE_DLG_H__
 
-extern GtkWidget* airpcap_tb;
+/* extern GtkWidget* airpcap_tb; */
 
 /** @file
  *  "Capture Options" dialog box.
@@ -64,14 +63,6 @@ void capture_restart_cb(GtkWidget *widget, gpointer data);
 /* capture start confirmed by "Save unsaved capture", so do it now */
 void capture_start_confirmed(void);
 
-/** User requested the "Capture Interfaces" dialog box by menu or toolbar.
- *
- * @param widget parent widget (unused)
- * @param data unused
- */
-void
-capture_if_cb(GtkWidget *widget, gpointer data);
-
 /** User requested the "Capture Airpcap" dialog box by menu or toolbar.
  *
  * @param widget parent widget (unused)
@@ -80,13 +71,6 @@ capture_if_cb(GtkWidget *widget, gpointer data);
 void
 capture_air_cb(GtkWidget *widget, gpointer data);
 
-/** User requested the "Capture Interfaces" dialog box by menu or toolbar.
- *
- * @param capture_in_progress capture is in progress
- */
-void
-set_capture_if_dialog_for_capture_in_progress(gboolean capture_in_progress);
-
 #ifdef HAVE_PCAP_REMOTE
 struct remote_host {
   gchar    *remote_host;          /**< Host name or network address for remote capturing */
