@@ -1,7 +1,7 @@
 /* color_edit_dlg.c
  * Definitions for single color filter edit dialog boxes
  *
- * $Id: color_edit_dlg.c 26494 2008-10-19 14:40:16Z stig $
+ * $Id: color_edit_dlg.c 30918 2009-11-10 12:05:25Z stig $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -405,18 +405,18 @@ edit_color_filter_ok_cb                (GtkButton       *button,
         color_filters = (GtkWidget *)g_object_get_data(G_OBJECT(button), COLOR_FILTERS_CL);
         colorf = (color_filter_t *)g_object_get_data(G_OBJECT(button), COLOR_FILTER);
 
-        if (colorf->filter_name != NULL)
-            g_free(colorf->filter_name);
+        g_free(colorf->filter_name);
         colorf->filter_name = filter_name;
-        if (colorf->filter_text != NULL)
-            g_free(colorf->filter_text);
+
+        g_free(colorf->filter_text);
         colorf->filter_text = filter_text;
+
 	colorf->disabled = filter_disabled;
         gdkcolor_to_color_t(&colorf->fg_color, &new_fg_color);
         gdkcolor_to_color_t(&colorf->bg_color, &new_bg_color);
-        g_snprintf(fg_str, 14, "#%04X%04X%04X",
+        g_snprintf(fg_str, sizeof(fg_str), "#%04X%04X%04X",
                 new_fg_color.red, new_fg_color.green, new_fg_color.blue);
-        g_snprintf(bg_str, 14, "#%04X%04X%04X",
+        g_snprintf(bg_str, sizeof(bg_str), "#%04X%04X%04X",
                 new_bg_color.red, new_bg_color.green, new_bg_color.blue);
         model = gtk_tree_view_get_model(GTK_TREE_VIEW(color_filters));
         gtk_tree_model_iter_nth_child(model, &iter, NULL, row_selected);
@@ -532,7 +532,7 @@ color_sel_ok_cb                        (GtkButton       *button _U_,
   GdkColor new_color; /* Color from color selection dialog */
   GtkWidget *color_dialog;
   GtkWidget *parent;
-  GtkWidget *color_selection_fg, *color_selection_bg;
+  GtkWidget *color_selection_bg;
   gboolean is_bg;
 
   color_dialog = (GtkWidget *)user_data;
@@ -550,7 +550,6 @@ color_sel_ok_cb                        (GtkButton       *button _U_,
 
 	/* Find that dialog box's foreground and background color selection
 	   boxes, if any. */
-	color_selection_fg = g_object_get_data(G_OBJECT(parent), COLOR_SELECTION_FG);
 	color_selection_bg = g_object_get_data(G_OBJECT(parent), COLOR_SELECTION_BG);
 	is_bg = (color_dialog == color_selection_bg);
 
@@ -559,7 +558,7 @@ color_sel_ok_cb                        (GtkButton       *button _U_,
 	/* now apply the change to the fore/background */
 	if (is_bg)
 	  gtk_widget_modify_base(filt_name_entry, GTK_STATE_NORMAL, &new_color);
-        else
+	else
 	  gtk_widget_modify_text(filt_name_entry, GTK_STATE_NORMAL, &new_color);
   }
 }
