@@ -7,7 +7,7 @@
  * Copyright 2000, Jeffrey C. Foster <jfoste@woodward.com> and
  * Guy Harris <guy@alum.mit.edu>
  *
- * $Id: dfilter_expr_dlg.c 30235 2009-10-01 14:44:59Z stig $
+ * $Id: dfilter_expr_dlg.c 30918 2009-11-10 12:05:25Z stig $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -455,13 +455,6 @@ display_value_fields(header_field_info *hfinfo, gboolean is_comparison,
 	 *
 	 * so we hide the value entry.
 	 */
-	show_value_list = is_comparison;
-	if (is_comparison) {
-		/*
-		 * If we're showing the entry; show the label as well.
-		 */
-		show_value_label = TRUE;
-	}
 
 	switch (hfinfo->type) {
 
