@@ -1,7 +1,7 @@
 /* win32-file-dlg.c
  * Native Windows file dialog routines
  *
- * $Id: file_dlg_win32.c 34942 2010-11-18 01:06:19Z gerald $
+ * $Id: file_dlg_win32.c 29635 2009-08-31 18:16:16Z krj $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -60,7 +60,7 @@
 #include "gtk/file_dlg.h"
 #include "gtk/capture_file_dlg.h"
 #include "gtk/main.h"
-#include "gtk/main_menu.h"
+#include "gtk/menus.h"
 #include "gtk/drag_and_drop.h"
 #include "gtk/capture_dlg.h"
 #include "gtk/file_dlg_win32.h"
@@ -139,7 +139,8 @@ static print_args_t   print_args;
  *       being opened/saved/etc.).
  */
 static HWND           g_sf_hwnd = NULL;
-static char *dfilter_str = NULL;
+char *dfilter_open_str = NULL;
+char *dfilter_merge_str = NULL;
 
 gboolean
 win32_open_file (HWND h_wnd) {
@@ -225,7 +226,7 @@ win32_open_file (HWND h_wnd) {
         }
 
         /* apply our filter */
-        if (dfilter_compile(dfilter_str, &dfp)) {
+        if (dfilter_compile(dfilter_open_str, &dfp)) {
             cf_set_rfcode(&cfile, dfp);
         }
 
@@ -479,7 +480,7 @@ win32_merge_file (HWND h_wnd) {
         }
 
         /* apply our filter */
-        if (dfilter_compile(dfilter_str, &dfp)) {
+        if (dfilter_compile(dfilter_merge_str, &dfp)) {
             cf_set_rfcode(&cfile, dfp);
         }
 
@@ -946,7 +947,7 @@ preview_set_filename(HWND of_hwnd, gchar *preview_file) {
     TCHAR       string_buff[PREVIEW_STR_MAX];
     gint64      data_offset;
     guint       packet = 0;
-    guint64     filesize;
+    gint64      filesize;
     time_t      ti_time;
     struct tm  *ti_tm;
     guint       elapsed_time;
@@ -992,7 +993,7 @@ preview_set_filename(HWND of_hwnd, gchar *preview_file) {
 
         /* size */
         filesize = wtap_file_size(wth, &err);
-        _snwprintf(string_buff, PREVIEW_STR_MAX, _T("%") _T(PRIu64) _T(" bytes"), filesize);
+        utf_8to16_snprintf(string_buff, PREVIEW_STR_MAX, "%" G_GINT64_FORMAT " bytes", filesize);
         cur_ctrl = GetDlgItem(of_hwnd, EWFD_PTX_SIZE);
         SetWindowText(cur_ctrl, string_buff);
 
@@ -1095,11 +1096,11 @@ filter_tb_get(HWND hwnd) {
         len++;
         strval = g_malloc(len*sizeof(TCHAR));
         len = GetWindowText(hwnd, strval, len);
-        ret = g_utf16_to_utf8(strval, -1, NULL, NULL, NULL);
+        ret = utf_16to8(strval);
         g_free(strval);
         return ret;
     } else {
-        return NULL;
+        return "";
     }
 }
 
@@ -1160,9 +1161,9 @@ open_file_hook_proc(HWND of_hwnd, UINT msg, WPARAM w_param, LPARAM l_param) {
     switch(msg) {
         case WM_INITDIALOG:
             /* Retain the filter text, and fill it in. */
-            if(dfilter_str != NULL) {
+            if(dfilter_open_str != NULL) {
                 cur_ctrl = GetDlgItem(of_hwnd, EWFD_FILTER_EDIT);
-                SetWindowText(cur_ctrl, utf_8to16(dfilter_str));
+                SetWindowText(cur_ctrl, utf_8to16(dfilter_open_str));
             }
 
             /* Fill in our resolution values */
@@ -1180,9 +1181,7 @@ open_file_hook_proc(HWND of_hwnd, UINT msg, WPARAM w_param, LPARAM l_param) {
                 case CDN_FILEOK:
                     /* Fetch the read filter */
                     cur_ctrl = GetDlgItem(of_hwnd, EWFD_FILTER_EDIT);
-                    if (dfilter_str)
-                        g_free(dfilter_str);
-                    dfilter_str = filter_tb_get(cur_ctrl);
+                    dfilter_open_str = filter_tb_get(cur_ctrl);
 
                     /* Fetch our resolution values */
                     g_resolv_flags = prefs.name_resolve & RESOLV_CONCURRENT;
@@ -1667,9 +1666,9 @@ merge_file_hook_proc(HWND mf_hwnd, UINT msg, WPARAM w_param, LPARAM l_param) {
     switch(msg) {
         case WM_INITDIALOG:
             /* Retain the filter text, and fill it in. */
-            if(dfilter_str != NULL) {
+            if(dfilter_merge_str != NULL) {
                 cur_ctrl = GetDlgItem(mf_hwnd, EWFD_FILTER_EDIT);
-                SetWindowText(cur_ctrl, utf_8to16(dfilter_str));
+                SetWindowText(cur_ctrl, utf_8to16(dfilter_merge_str));
             }
 
             /* Append by default */
@@ -1684,9 +1683,7 @@ merge_file_hook_proc(HWND mf_hwnd, UINT msg, WPARAM w_param, LPARAM l_param) {
                 case CDN_FILEOK:
                     /* Fetch the read filter */
                     cur_ctrl = GetDlgItem(mf_hwnd, EWFD_FILTER_EDIT);
-                    if (dfilter_str)
-                        g_free(dfilter_str);
-                    dfilter_str = filter_tb_get(cur_ctrl);
+                    dfilter_merge_str = filter_tb_get(cur_ctrl);
 
                     cur_ctrl = GetDlgItem(mf_hwnd, EWFD_MERGE_CHRONO_BTN);
                     if(SendMessage(cur_ctrl, BM_GETCHECK, 0, 0) == BST_CHECKED) {
