@@ -6,7 +6,7 @@
  * With several usability improvements:
  * Copyright 2008, Stig Bjorlykke <stig@bjorlykke.org>
  *
- * $Id: filter_autocomplete.c 29337 2009-08-08 12:40:59Z krj $
+ * $Id: filter_autocomplete.c 30918 2009-11-10 12:05:25Z stig $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -263,7 +263,6 @@ autocompletion_list_lookup(GtkWidget *filter_te, GtkWidget *popup_win, GtkWidget
   GtkRequisition requisition;
   GtkListStore *store;
   GtkTreeIter iter;
-  GtkTreeSelection *selection;
   gchar *curr_str;
   unsigned int str_len = (unsigned int) strlen(str);
   gchar *first = NULL;
@@ -275,8 +274,6 @@ autocompletion_list_lookup(GtkWidget *filter_te, GtkWidget *popup_win, GtkWidget
 
   if( gtk_tree_model_get_iter_first(GTK_TREE_MODEL(store), &iter) ) {
 
-    selection = gtk_tree_view_get_selection(GTK_TREE_VIEW(list));
-
     do {
 
       gtk_tree_model_get(GTK_TREE_MODEL(store), &iter, 0, &curr_str,  -1);
@@ -754,10 +751,8 @@ filter_autocomplete_new(GtkWidget *filter_te, const gchar *protocol_name, gboole
   gtk_widget_set_size_request(popup_win, filter_te->allocation.width, (requisition.height<200? requisition.height+8:200));
   gtk_window_resize(GTK_WINDOW(popup_win), filter_te->allocation.width, (requisition.height<200? requisition.height+8:200));
 
-  gtk_window_get_position(GTK_WINDOW(w_toplevel), &x_pos, &y_pos); 
-  x_pos = x_pos + filter_te->allocation.x;
-  y_pos = y_pos + filter_te->allocation.y + filter_te->allocation.height + 22;
-
+  gdk_window_get_origin(filter_te->window, &x_pos, &y_pos);
+  y_pos = y_pos + filter_te->allocation.height;
   gtk_window_move(GTK_WINDOW(popup_win), x_pos, y_pos);
 
   gtk_widget_show_all (popup_win);
