@@ -1,7 +1,7 @@
 /* filter_dlg.c
  * Dialog boxes for (display and capture) filter editing
  *
- * $Id: filter_dlg.c 30200 2009-09-29 19:20:48Z stig $
+ * $Id: filter_dlg.c 30918 2009-11-10 12:05:25Z stig $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -129,8 +129,7 @@ capture_filter_construct_cb(GtkWidget *w, gpointer user_data _U_)
     parent_filter_te = g_object_get_data(G_OBJECT(w), E_FILT_TE_PTR_KEY);
 
     /* Now create a new dialog, without an "Add Expression..." button. */
-    filter_browse_w = filter_dialog_new(w, parent_filter_te,
-        CFILTER_LIST, &args);
+    filter_dialog_new(w, parent_filter_te, CFILTER_LIST, &args);
 }
 #endif
 
@@ -167,8 +166,7 @@ display_filter_construct_cb(GtkWidget *w, gpointer construct_args_ptr)
 
     /* Now create a new dialog, possibly with an "Apply" button, and
        definitely with an "Add Expression..." button. */
-    filter_browse_w = filter_dialog_new(w, parent_filter_te,
-                                        DFILTER_LIST, construct_args);
+    filter_dialog_new(w, parent_filter_te, DFILTER_LIST, construct_args);
 }
 
 /* Should be called when a button that creates filters is destroyed; it
@@ -1339,7 +1337,7 @@ filter_te_syntax_check_cb(GtkWidget *w)
                  */
                 msg = g_strdup_printf(" \"%s\" may have unexpected results (see the User's Guide)",
                                       (const char *) g_ptr_array_index(depr, 0));
-                statusbar_push_filter_msg(msg);
+                statusbar_push_temporary_msg(msg);
                 g_free(msg);
             }
         } else {
