@@ -5,7 +5,7 @@
  *
  * MUCH code modified from service_response_time_table.c.
  *
- * $Id: gsm_a_stat.c 27649 2009-03-08 11:00:46Z jake $
+ * $Id: gsm_a_stat.c 29028 2009-07-08 18:36:31Z etxrab $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -97,7 +97,7 @@ static gsm_a_stat_t		gsm_a_stat;
 
 /* Create list */
 static
-GtkWidget* create_list()
+GtkWidget* create_list(void)
 {
 
     GtkListStore *list_store;
@@ -409,7 +409,8 @@ gsm_a_stat_gtk_win_create(
     GtkWidget		*bbox;
 
 
-    dlg_p->win = window_new(GTK_WINDOW_TOPLEVEL, title);
+	dlg_p->win = dlg_window_new(title);  /* transient_for top_level */
+	gtk_window_set_destroy_with_parent (GTK_WINDOW(dlg_p->win), TRUE);
     gtk_window_set_default_size(GTK_WINDOW(dlg_p->win), 490, 500);
 
     vbox = gtk_vbox_new(FALSE, 3);
@@ -666,7 +667,7 @@ register_tap_listener_gtkgsm_a_stat(void)
     memset((void *) &gsm_a_stat, 0, sizeof(gsm_a_stat_t));
 
     err_p =
-	register_tap_listener("gsm_a", &gsm_a_stat, NULL,
+	register_tap_listener("gsm_a", &gsm_a_stat, NULL, 0,
 	    gsm_a_stat_reset,
 	    gsm_a_stat_packet,
 	    gsm_a_stat_draw);
@@ -679,43 +680,43 @@ register_tap_listener_gtkgsm_a_stat(void)
 	exit(1);
     }
 
-    register_stat_menu_item("GSM/A-Interface BSSMAP", REGISTER_STAT_GROUP_TELEPHONY,
+    register_stat_menu_item("_GSM/A-Interface BSSMAP", REGISTER_STAT_GROUP_TELEPHONY,
 	gsm_a_stat_gtk_bssmap_cb, NULL, NULL, NULL);
     register_stat_cmd_arg("gsm_a,bssmap", gsm_a_stat_gtk_bssmap_init,NULL);
 
-    register_stat_menu_item("GSM/A-Interface DTAP/Mobility Management", REGISTER_STAT_GROUP_TELEPHONY,
+    register_stat_menu_item("_GSM/A-Interface DTAP/Mobility Management", REGISTER_STAT_GROUP_TELEPHONY,
 	gsm_a_stat_gtk_dtap_mm_cb, NULL, NULL, NULL);
     register_stat_cmd_arg("gsm_a,dtap_mm", gsm_a_stat_gtk_dtap_mm_init,NULL);
 
-    register_stat_menu_item("GSM/A-Interface DTAP/Radio Resource Management", REGISTER_STAT_GROUP_TELEPHONY,
+    register_stat_menu_item("_GSM/A-Interface DTAP/Radio Resource Management", REGISTER_STAT_GROUP_TELEPHONY,
 	gsm_a_stat_gtk_dtap_rr_cb, NULL, NULL, NULL);
     register_stat_cmd_arg("gsm_a,dtap_rr", gsm_a_stat_gtk_dtap_rr_init,NULL);
 
-    register_stat_menu_item("GSM/A-Interface DTAP/Call Control", REGISTER_STAT_GROUP_TELEPHONY,
+    register_stat_menu_item("_GSM/A-Interface DTAP/Call Control", REGISTER_STAT_GROUP_TELEPHONY,
 	gsm_a_stat_gtk_dtap_cc_cb, NULL, NULL, NULL);
     register_stat_cmd_arg("gsm_a,dtap_cc", gsm_a_stat_gtk_dtap_cc_init,NULL);
 
-    register_stat_menu_item("GSM/A-Interface DTAP/GPRS Mobility Management", REGISTER_STAT_GROUP_TELEPHONY,
+    register_stat_menu_item("_GSM/A-Interface DTAP/GPRS Mobility Management", REGISTER_STAT_GROUP_TELEPHONY,
 	gsm_a_stat_gtk_dtap_gmm_cb, NULL, NULL, NULL);
     register_stat_cmd_arg("gsm_a,dtap_gmm", gsm_a_stat_gtk_dtap_gmm_init,NULL);
 
-    register_stat_menu_item("GSM/A-Interface DTAP/Short Message Service", REGISTER_STAT_GROUP_TELEPHONY,
+    register_stat_menu_item("_GSM/A-Interface DTAP/Short Message Service", REGISTER_STAT_GROUP_TELEPHONY,
 	gsm_a_stat_gtk_dtap_sms_cb, NULL, NULL, NULL);
     register_stat_cmd_arg("gsm_a,dtap_sms", gsm_a_stat_gtk_dtap_sms_init,NULL);
 
-    register_stat_menu_item("GSM/A-Interface DTAP/GPRS Session Management", REGISTER_STAT_GROUP_TELEPHONY,
+    register_stat_menu_item("_GSM/A-Interface DTAP/GPRS Session Management", REGISTER_STAT_GROUP_TELEPHONY,
 	gsm_a_stat_gtk_dtap_sm_cb, NULL, NULL, NULL);
     register_stat_cmd_arg("gsm_a,dtap_sm", gsm_a_stat_gtk_dtap_sm_init,NULL);
 
-    register_stat_menu_item("GSM/A-Interface DTAP/Supplementary Services", REGISTER_STAT_GROUP_TELEPHONY,
+    register_stat_menu_item("_GSM/A-Interface DTAP/Supplementary Services", REGISTER_STAT_GROUP_TELEPHONY,
 	gsm_a_stat_gtk_dtap_ss_cb, NULL, NULL, NULL);
     register_stat_cmd_arg("gsm_a,dtap_ss", gsm_a_stat_gtk_dtap_ss_init,NULL);
 
-    register_stat_menu_item("GSM/A-Interface DTAP/Special Conformance Testing Functions", REGISTER_STAT_GROUP_TELEPHONY,
+    register_stat_menu_item("_GSM/A-Interface DTAP/Special Conformance Testing Functions", REGISTER_STAT_GROUP_TELEPHONY,
 	gsm_a_stat_gtk_dtap_tp_cb, NULL, NULL, NULL);
     register_stat_cmd_arg("gsm_a,dtap_tp", gsm_a_stat_gtk_dtap_tp_init,NULL);
 
-    register_stat_menu_item("GSM/A-Interface SACCH", REGISTER_STAT_GROUP_TELEPHONY,
+    register_stat_menu_item("_GSM/A-Interface SACCH", REGISTER_STAT_GROUP_TELEPHONY,
 	gsm_a_stat_gtk_sacch_rr_cb, NULL, NULL, NULL);
     register_stat_cmd_arg("gsm_a,sacch", gsm_a_stat_gtk_sacch_rr_init,NULL);
 }
