@@ -3,7 +3,7 @@
  * and some with GUI-independent APIs, with this file containing the GTK+
  * implementations of them (declared in ui_util.h)
  *
- * $Id: gui_utils.c 30421 2009-10-09 09:06:22Z etxrab $
+ * $Id: gui_utils.c 30825 2009-11-04 21:16:38Z gerald $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -522,6 +522,15 @@ GtkWidget *xpm_to_widget(const char ** xpm) {
     return xpm_to_widget_from_parent(top_level, xpm);
 }
 
+/* Convert an pixbuf data to a GtkWidget */
+/* Data should be created with "gdk-pixbuf-csource --raw" */
+GtkWidget *pixbuf_to_widget(const char * pb_data) {
+    GdkPixbuf *pixbuf;
+    
+    pixbuf = gdk_pixbuf_new_from_inline (-1, pb_data, FALSE, NULL);
+    return gtk_image_new_from_pixbuf(pixbuf);
+}
+
 /*
  * Key to attach the "un-decorated" title to the window, so that if the
  * user-specified decoration changes, we can correctly update the
