@@ -1,7 +1,7 @@
 /* keys.h
  * Key definitions for various objects
  *
- * $Id: keys.h 29101 2009-07-15 18:39:09Z gerald $
+ * $Id: keys.h 30832 2009-11-05 10:16:49Z stig $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -45,22 +45,25 @@
 #define PM_MENU_LIST_KEY				"popup_menu_menu_list"
 #define PM_PACKET_LIST_KEY				"popup_menu_packet_list"
 #define PM_TREE_VIEW_KEY				"popup_menu_tree_view"
-#define PM_HEXDUMP_KEY					"popup_menu_hexdump"
+#define PM_BYTES_VIEW_KEY				"popup_menu_bytes_view"
+
+#define E_TB_MAIN_KEY					"toolbar_main"
+#define E_TB_FILTER_KEY					"toolbar_filter"
 
 #ifdef HAVE_AIRPCAP
-#define AIRPCAP_TOOLBAR_KEY				"airpcap_toolbar_key"
-#define AIRPCAP_TOOLBAR_INTERFACE_KEY	"airpcap_toolbar_if_key"
-#define AIRPCAP_TOOLBAR_LINK_TYPE_KEY	"airpcap_toolbar_lt_key" 
-#define AIRPCAP_TOOLBAR_CHANNEL_KEY		"airpcap_toolbar_ch_key"
-#define AIRPCAP_TOOLBAR_CHANNEL_LABEL_KEY "airpcap_toolbar_ch_lb_key"
-#define AIRPCAP_TOOLBAR_CHANNEL_OFFSET_KEY	"airpcap_toolbar_ch_offset_key"
+#define AIRPCAP_TOOLBAR_KEY						"airpcap_toolbar_key"
+#define AIRPCAP_TOOLBAR_INTERFACE_KEY			"airpcap_toolbar_if_key"
+#define AIRPCAP_TOOLBAR_LINK_TYPE_KEY			"airpcap_toolbar_lt_key" 
+#define AIRPCAP_TOOLBAR_CHANNEL_KEY				"airpcap_toolbar_ch_key"
+#define AIRPCAP_TOOLBAR_CHANNEL_LABEL_KEY		"airpcap_toolbar_ch_lb_key"
+#define AIRPCAP_TOOLBAR_CHANNEL_OFFSET_KEY		"airpcap_toolbar_ch_offset_key"
 #define AIRPCAP_TOOLBAR_CHANNEL_OFFSET_LABEL_KEY "airpcap_toolbar_ch_offset_lb_key"
 #define AIRPCAP_TOOLBAR_FCS_CHECK_KEY	"airpcap_toolbar_fcs_check_key"
 #define AIRPCAP_TOOLBAR_FCS_FILTER_LABEL_KEY	"airpcap_toolbar_fcs_filter_lb_key"
-#define AIRPCAP_TOOLBAR_FCS_FILTER_KEY	"airpcap_toolbar_fcs_filter_key"
-#define AIRPCAP_TOOLBAR_ADVANCED_KEY    "airpcap_toolbar_advanced_key"
-#define AIRPCAP_TOOLBAR_KEY_MANAGEMENT_KEY    "airpcap_toolbar_key_management_key"
-#define AIRPCAP_TOOLBAR_DECRYPTION_KEY  "airpcap_toolbar_decryption_key"
+#define AIRPCAP_TOOLBAR_FCS_FILTER_KEY		"airpcap_toolbar_fcs_filter_key"
+#define AIRPCAP_TOOLBAR_ADVANCED_KEY		"airpcap_toolbar_advanced_key"
+#define AIRPCAP_TOOLBAR_KEY_MANAGEMENT_KEY	"airpcap_toolbar_key_management_key"
+#define AIRPCAP_TOOLBAR_DECRYPTION_KEY		"airpcap_toolbar_decryption_key"
 #define AIRPCAP_TOOLBAR_DECRYPTION_LABEL_KEY  "airpcap_toolbar_decryption_lb_key"
 
 #define AIRPCAP_ADVANCED_KEY				"airpcap_advanced_key"
@@ -80,32 +83,33 @@
 #define AIRPCAP_ADVANCED_ADD_KEY_KEY_LABEL_KEY	"airpcap_advanced_add_key_key_label_key"
 #define AIRPCAP_ADVANCED_ADD_KEY_SSID_LABEL_KEY	"airpcap_advanced_add_key_ssid_label_key"
 #define AIRPCAP_ADVANCED_EDIT_KEY_SELECTED_KEY	"airpcap_advanced_edit_key_selected_key"
-#define AIRPCAP_ADVANCED_EDIT_KEY_OK_KEY	"airpcap_advanced_edit_key_ok_key"
-#define AIRPCAP_ADVANCED_EDIT_KEY_LIST_KEY	"airpcap_advanced_edit_key_list_key"
-#define AIRPCAP_ADVANCED_EDIT_KEY_TYPE_KEY	"airpcap_advanced_edit_key_type_key"
-#define AIRPCAP_ADVANCED_EDIT_KEY_KEY_KEY	"airpcap_advanced_edit_key_key_key"
-#define AIRPCAP_ADVANCED_EDIT_KEY_SSID_KEY	"airpcap_advanced_edit_key_ssid_key"
+#define AIRPCAP_ADVANCED_EDIT_KEY_OK_KEY		"airpcap_advanced_edit_key_ok_key"
+#define AIRPCAP_ADVANCED_EDIT_KEY_LIST_KEY		"airpcap_advanced_edit_key_list_key"
+#define AIRPCAP_ADVANCED_EDIT_KEY_TYPE_KEY		"airpcap_advanced_edit_key_type_key"
+#define AIRPCAP_ADVANCED_EDIT_KEY_KEY_KEY		"airpcap_advanced_edit_key_key_key"
+#define AIRPCAP_ADVANCED_EDIT_KEY_SSID_KEY		"airpcap_advanced_edit_key_ssid_key"
 #define AIRPCAP_ADVANCED_EDIT_KEY_KEY_LABEL_KEY	"airpcap_advanced_edit_key_key_label_key"
 #define AIRPCAP_ADVANCED_EDIT_KEY_SSID_LABEL_KEY	"airpcap_advanced_edit_key_ssid_label_key"
 #define AIRPCAP_ADVANCED_DECRYPTION_MODE_KEY	"airpcap_advanced_decryption_mode_key"
-#define AIRPCAP_ADVANCED_WPA_DECRYPTION_KEY	"airpcap_advanced_wpa_decryption_key"
-#define AIRPCAP_ADVANCED_NOTEBOOK_KEY		"airpcap_advanced_notebook_key"
-#define AIRPCAP_ADVANCED_CANCEL_KEY	        "airpcap_advanced_cancel_key"
-#define AIRPCAP_ADVANCED_OK_KEY		        "airpcap_advanced_ok_key"
-#define AIRPCAP_ADVANCED_KEYLIST_KEY	    "airpcap_advanced_keylist_key"
-#define AIRPCAP_CHECK_WINDOW_RADIO_KEEP_KEY "airpcap_check_window_radio_keep_key"
-#define AIRPCAP_CHECK_WINDOW_RADIO_MERGE_KEY "airpcap_check_window_radio_merge_key"
-#define AIRPCAP_CHECK_WINDOW_RADIO_IMPORT_KEY "airpcap_check_window_radio_import_key"
-#define AIRPCAP_CHECK_WINDOW_RADIO_IGNORE_KEY "airpcap_check_window_radio_ignore_key"
-#define AIRPCAP_CHECK_WINDOW_RADIO_GROUP_KEY "airpcap_check_window_radio_group_key"
+#define AIRPCAP_ADVANCED_WPA_DECRYPTION_KEY		"airpcap_advanced_wpa_decryption_key"
+#define AIRPCAP_ADVANCED_NOTEBOOK_KEY			"airpcap_advanced_notebook_key"
+#define AIRPCAP_ADVANCED_CANCEL_KEY				"airpcap_advanced_cancel_key"
+#define AIRPCAP_ADVANCED_OK_KEY					"airpcap_advanced_ok_key"
+#define AIRPCAP_ADVANCED_KEYLIST_KEY			"airpcap_advanced_keylist_key"
+#define AIRPCAP_CHECK_WINDOW_RADIO_KEEP_KEY		"airpcap_check_window_radio_keep_key"
+#define AIRPCAP_CHECK_WINDOW_RADIO_MERGE_KEY	 "airpcap_check_window_radio_merge_key"
+#define AIRPCAP_CHECK_WINDOW_RADIO_IMPORT_KEY	"airpcap_check_window_radio_import_key"
+#define AIRPCAP_CHECK_WINDOW_RADIO_IGNORE_KEY	"airpcap_check_window_radio_ignore_key"
+#define AIRPCAP_CHECK_WINDOW_RADIO_GROUP_KEY	"airpcap_check_window_radio_group_key"
 
-#define AIRPCAP_CHECK_WINDOW_KEY            "airpcap_check_window_key"
+#define AIRPCAP_CHECK_WINDOW_KEY				"airpcap_check_window_key"
 
 #define AIRPCAP_ADVANCED_SELECTED_KEY_LIST_ITEM_KEY		"airpcap_advanced_selected_key_list_item_key"
 
-#define AIRPCAP_OPTIONS_ADVANCED_KEY    "airpcap_options_advanced_key"
+#define AIRPCAP_OPTIONS_ADVANCED_KEY			"airpcap_options_advanced_key"
 
-#define AIRPCAP_ADVANCED_FROM_KEY		"airpcap_advanced_from_key"
-#endif
+#define AIRPCAP_ADVANCED_FROM_KEY				"airpcap_advanced_from_key"
+#endif /* HAVE_AIRPCAP */
+
+#endif /* __KEYS_H__ */
 
-#endif
