@@ -1,7 +1,7 @@
 /* main_packet_list.c
  * packet list related functions   2002 Olivier Abad
  *
- * $Id: main_packet_list.c 26942 2008-12-09 00:03:09Z stig $
+ * $Id: main_packet_list.c 30316 2009-10-04 18:33:23Z etxrab $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -26,7 +26,11 @@
 # include "config.h"
 #endif
 
+#ifndef NEW_PACKET_LIST
+
 #include <gtk/gtk.h>
+
+#include <stdio.h>
 #include <string.h>
 
 #include <epan/epan.h>
@@ -50,7 +54,7 @@
 #include "gtk/packet_history.h"
 #include "gtk/recent.h"
 #include "gtk/main.h"
-#include "gtk/main_menu.h"
+#include "gtk/menus.h"
 #include "gtk/main_packet_list.h"
 #include "gtk/main_statusbar.h"
 #include "gtk/packet_win.h"
@@ -71,27 +75,6 @@ static gboolean last_at_end = FALSE;
 
 /* GtkClist compare routine, overrides default to allow numeric comparison */
 
-#define COMPARE_FRAME_NUM()     ((fdata1->num < fdata2->num) ? -1 : \
-                                 (fdata1->num > fdata2->num) ? 1 : \
-                                 0)
-
-#define COMPARE_NUM(f)  ((fdata1->f < fdata2->f) ? -1 : \
-                         (fdata1->f > fdata2->f) ? 1 : \
-                         COMPARE_FRAME_NUM())
-
-/* Compare time stamps.
-   A packet whose time is a reference time is considered to have
-   a lower time stamp than any frame with a non-reference time;
-   if both packets' times are reference times, we compare the
-   times of the packets. */
-#define COMPARE_TS(ts) \
-                ((fdata1->flags.ref_time && !fdata2->flags.ref_time) ? -1 : \
-                 (!fdata1->flags.ref_time && fdata2->flags.ref_time) ? 1 : \
-                 (fdata1->ts.secs < fdata2->ts.secs) ? -1 : \
-                 (fdata1->ts.secs > fdata2->ts.secs) ? 1 : \
-                 (fdata1->ts.nsecs < fdata2->ts.nsecs) ? -1 :\
-                 (fdata1->ts.nsecs > fdata2->ts.nsecs) ? 1 : \
-                 COMPARE_FRAME_NUM())
 static gint
 packet_list_compare(GtkCList *clist, gconstpointer  ptr1, gconstpointer  ptr2)
 {
@@ -122,53 +105,20 @@ packet_list_compare(GtkCList *clist, gconstpointer  ptr1, gconstpointer  ptr2)
   switch (col_fmt) {
 
   case COL_NUMBER:
-    return COMPARE_FRAME_NUM();
-
   case COL_CLS_TIME:
-    switch (timestamp_get_type()) {
-
-    case TS_ABSOLUTE:
-    case TS_ABSOLUTE_WITH_DATE:
-    case TS_EPOCH:
-      return COMPARE_TS(abs_ts);
-
-    case TS_RELATIVE:
-      return COMPARE_TS(rel_ts);
-
-    case TS_DELTA:
-      return COMPARE_TS(del_cap_ts);
-
-    case TS_DELTA_DIS:
-      return COMPARE_TS(del_dis_ts);
-
-    case TS_NOT_SET:
-      return 0;
-    }
-    return 0;
-
   case COL_ABS_TIME:
   case COL_ABS_DATE_TIME:
-    return COMPARE_TS(abs_ts);
-
   case COL_REL_TIME:
-    return COMPARE_TS(rel_ts);
-
   case COL_DELTA_TIME:
-    return COMPARE_TS(del_cap_ts);
-
   case COL_DELTA_TIME_DIS:
-    return COMPARE_TS(del_dis_ts);
-
   case COL_PACKET_LENGTH:
-    return COMPARE_NUM(pkt_len);
-
   case COL_CUMULATIVE_BYTES:
-    return COMPARE_NUM(cum_bytes);
+    return frame_data_compare(fdata1, fdata2, col_fmt);
 
   case COL_CUSTOM:
     hfi = proto_registrar_get_byname(cfile.cinfo.col_custom_field[clist->sort_column]);
     if (hfi == NULL) {
-        return COMPARE_FRAME_NUM();
+        return frame_data_compare(fdata1, fdata2, COL_NUMBER);
     } else if ((hfi->strings == NULL) &&
                (((IS_FT_INT(hfi->type) || IS_FT_UINT(hfi->type)) &&
                  ((hfi->display == BASE_DEC) || (hfi->display == BASE_DEC_HEX) ||
@@ -176,7 +126,7 @@ packet_list_compare(GtkCList *clist, gconstpointer  ptr1, gconstpointer  ptr2)
                 (hfi->type == FT_DOUBLE) || (hfi->type == FT_FLOAT) ||
                 (hfi->type == FT_BOOLEAN) || (hfi->type == FT_FRAMENUM) ||
                 (hfi->type == FT_RELATIVE_TIME))) {
-      
+
       /* Compare numeric column */
       custom_numeric = TRUE;
     }
@@ -185,9 +135,9 @@ packet_list_compare(GtkCList *clist, gconstpointer  ptr1, gconstpointer  ptr2)
     num1 = atof(text1);
     num2 = atof(text2);
     if ((col_fmt == COL_UNRES_SRC_PORT) || (col_fmt == COL_UNRES_DST_PORT) ||
-        (custom_numeric) || 
+        (custom_numeric) ||
         ((num1 != 0) && (num2 != 0) && ((col_fmt == COL_DEF_SRC_PORT) ||
-                                        (col_fmt == COL_RES_SRC_PORT) || 
+                                        (col_fmt == COL_RES_SRC_PORT) ||
                                         (col_fmt == COL_DEF_DST_PORT) ||
                                         (col_fmt == COL_RES_DST_PORT)))) {
 
@@ -198,7 +148,7 @@ packet_list_compare(GtkCList *clist, gconstpointer  ptr1, gconstpointer  ptr2)
       else if (num1 > num2)
         return 1;
       else
-        return COMPARE_FRAME_NUM();
+        return frame_data_compare(fdata1, fdata2, COL_NUMBER);
     }
 
     else {
@@ -208,7 +158,7 @@ packet_list_compare(GtkCList *clist, gconstpointer  ptr1, gconstpointer  ptr2)
         if (text1)
           return 1;
         else
-          return COMPARE_FRAME_NUM();
+          return frame_data_compare(fdata1, fdata2, COL_NUMBER);
       }
 
       if (!text1)
@@ -216,7 +166,7 @@ packet_list_compare(GtkCList *clist, gconstpointer  ptr1, gconstpointer  ptr2)
 
       ret = strcmp(text1, text2);
       if (ret == 0)
-        return COMPARE_FRAME_NUM();
+        return frame_data_compare(fdata1, fdata2, COL_NUMBER);
       else
         return ret;
     }
@@ -264,7 +214,7 @@ packet_list_resize_column_cb(GtkCList *clist _U_, gint column, gint width, gpoin
 
 /* What to do when a list item is selected/unselected */
 static void
-packet_list_select_cb(GtkWidget *w _U_, gint row, gint col _U_, GdkEventButton *event _U_, gpointer evt _U_) 
+packet_list_select_cb(GtkWidget *w _U_, gint row, gint col _U_, GdkEventButton *event _U_, gpointer evt _U_)
 {
   frame_data *fdata;
 
@@ -287,7 +237,7 @@ packet_list_select_cb(GtkWidget *w _U_, gint row, gint col _U_, GdkEventButton *
 }
 
 static void
-packet_list_unselect_cb(GtkWidget *w _U_, gint row _U_, gint col _U_, GdkEventButton *event _U_, gpointer evt _U_) 
+packet_list_unselect_cb(GtkWidget *w _U_, gint row _U_, gint col _U_, GdkEventButton *event _U_, gpointer evt _U_)
 {
   cf_unselect_packet(&cfile);
 }
@@ -307,7 +257,7 @@ set_frame_mark(gboolean set, frame_data *frame, gint row)
     gtk_clist_set_foreground(GTK_CLIST(packet_list), row, &fg);
     gtk_clist_set_background(GTK_CLIST(packet_list), row, &bg);
   } else {
-    color_filter_t *cfilter = frame->color_filter;
+    const color_filter_t *cfilter = frame->color_filter;
 
     cf_unmark_frame(&cfile, frame);
     /* Restore the color from the matching color filter if any */
@@ -324,13 +274,13 @@ set_frame_mark(gboolean set, frame_data *frame, gint row)
 }
 
 /* call this after last set_frame_mark is done */
-static void mark_frames_ready(void) 
+static void mark_frames_ready(void)
 {
   file_save_update_dynamics();
   packets_bar_update();
 }
 
-void packet_list_mark_frame_cb(GtkWidget *w _U_, gpointer data _U_) 
+void packet_list_mark_frame_cb(GtkWidget *w _U_, gpointer data _U_)
 {
   if (cfile.current_frame) {
     set_frame_mark(!cfile.current_frame->flags.marked,
@@ -339,12 +289,12 @@ void packet_list_mark_frame_cb(GtkWidget *w _U_, gpointer data _U_)
   }
 }
 
-static void mark_all_frames(gboolean set) 
+static void mark_all_frames(gboolean set)
 {
   frame_data *fdata;
 
   /* XXX: we might need a progressbar here */
-  for (fdata = cfile.plist; fdata != NULL; fdata = fdata->next) {
+  for (fdata = cfile.plist_start; fdata != NULL; fdata = fdata->next) {
     set_frame_mark(set,
                    fdata,
                    gtk_clist_find_row_from_data(GTK_CLIST(packet_list), fdata));
@@ -352,14 +302,14 @@ static void mark_all_frames(gboolean set)
   mark_frames_ready();
 }
 
-void packet_list_update_marked_frames(void) 
+void packet_list_update_marked_frames(void)
 {
   frame_data *fdata;
 
-  if (cfile.plist == NULL) return;
+  if (cfile.plist_start == NULL) return;
 
   /* XXX: we might need a progressbar here */
-  for (fdata = cfile.plist; fdata != NULL; fdata = fdata->next) {
+  for (fdata = cfile.plist_start; fdata != NULL; fdata = fdata->next) {
     if (fdata->flags.marked)
       set_frame_mark(TRUE, fdata,
                      gtk_clist_find_row_from_data(GTK_CLIST(packet_list),
@@ -368,16 +318,17 @@ void packet_list_update_marked_frames(void)
   mark_frames_ready();
 }
 
-void packet_list_mark_all_frames_cb(GtkWidget *w _U_, gpointer data _U_) 
+void packet_list_mark_all_frames_cb(GtkWidget *w _U_, gpointer data _U_)
 {
   mark_all_frames(TRUE);
 }
 
-void packet_list_unmark_all_frames_cb(GtkWidget *w _U_, gpointer data _U_) 
+void packet_list_unmark_all_frames_cb(GtkWidget *w _U_, gpointer data _U_)
 {
   mark_all_frames(FALSE);
 }
 
+#ifndef NEW_PACKET_LIST
 gboolean
 packet_list_get_event_row_column(GtkWidget *w, GdkEventButton *event_button,
                                  gint *row, gint *column)
@@ -386,6 +337,7 @@ packet_list_get_event_row_column(GtkWidget *w, GdkEventButton *event_button,
                                  (gint) event_button->x, (gint) event_button->y,
                                   row, column);
 }
+#endif /* NEW_PACKET_LIST */
 
 static gint
 packet_list_button_pressed_cb(GtkWidget *w, GdkEvent *event, gpointer data _U_)
@@ -522,10 +474,10 @@ packet_list_new(e_prefs *prefs)
         custom_right_justify = FALSE;
         if (cfile.cinfo.col_fmt[i] == COL_CUSTOM) {
           hfi = proto_registrar_get_byname(cfile.cinfo.col_custom_field[i]);
-          if ((hfi != NULL) && (hfi->strings == NULL) && 
+          if ((hfi != NULL) && (hfi->strings == NULL) &&
               ((hfi->type == FT_BOOLEAN) || (hfi->type == FT_FRAMENUM) ||
                (((hfi->display == BASE_DEC) || (hfi->display == BASE_OCT)) &&
-                (IS_FT_INT(hfi->type) || IS_FT_UINT(hfi->type)  || 
+                (IS_FT_INT(hfi->type) || IS_FT_UINT(hfi->type)  ||
                  (hfi->type == FT_INT64) || (hfi->type == FT_UINT64))))) {
             custom_right_justify = TRUE;
           }
@@ -536,7 +488,6 @@ packet_list_new(e_prefs *prefs)
             cfile.cinfo.col_fmt[i] == COL_PACKET_LENGTH ||
             cfile.cinfo.col_fmt[i] == COL_CUMULATIVE_BYTES ||
             cfile.cinfo.col_fmt[i] == COL_DCE_CALL ||
-            cfile.cinfo.col_fmt[i] == COL_DCE_CTX ||
             custom_right_justify)
             gtk_clist_set_column_justification(GTK_CLIST(packet_list), i,
                                                GTK_JUSTIFY_RIGHT);
@@ -559,7 +510,7 @@ packet_list_recreate(void)
 
     prefs.num_cols = g_list_length(prefs.col_list);
 
-    build_column_format_array(&cfile.cinfo, FALSE);
+    build_column_format_array(&cfile.cinfo, prefs.num_cols, FALSE);
 
     pkt_scrollw = packet_list_new(&prefs);
     gtk_widget_show(pkt_scrollw);
@@ -569,7 +520,7 @@ packet_list_recreate(void)
     main_widgets_rearrange();
 
     if(cfile.state != FILE_CLOSED)
-        cf_redissect_packets(&cfile);
+       redissect_packets();
 }
 
 void
@@ -599,14 +550,14 @@ packet_list_set_column_titles(void)
         gtk_table_attach(GTK_TABLE(col_arrows[i].table), column_lb, 0, 1, 0, 2,
                          GTK_SHRINK, GTK_SHRINK, 0, 0);
         gtk_widget_show(column_lb);
-        col_arrows[i].ascend_pm = gtk_pixmap_new(ascend_pm, ascend_bm);
+        col_arrows[i].ascend_pm = gtk_image_new_from_pixmap(ascend_pm, ascend_bm);
         gtk_table_attach(GTK_TABLE(col_arrows[i].table),
                          col_arrows[i].ascend_pm,
                          1, 2, 1, 2, GTK_SHRINK, GTK_SHRINK, 0, 0);
         if (i == 0) {
             gtk_widget_show(col_arrows[i].ascend_pm);
         }
-        col_arrows[i].descend_pm = gtk_pixmap_new(descend_pm, descend_bm);
+        col_arrows[i].descend_pm = gtk_image_new_from_pixmap(descend_pm, descend_bm);
         gtk_table_attach(GTK_TABLE(col_arrows[i].table),
                          col_arrows[i].descend_pm,
                          1, 2, 0, 1, GTK_SHRINK, GTK_SHRINK, 0, 0);
@@ -635,7 +586,7 @@ packet_list_freeze(void)
 }
 
 static void
-packet_list_resize_columns(void) 
+packet_list_resize_columns(void)
 {
     int         i;
     int         progbar_nextstep;
@@ -652,7 +603,7 @@ packet_list_resize_columns(void)
        bump that value by this amount. */
     progbar_quantum = cfile.cinfo.num_cols/N_PROGBAR_UPDATES;
     /* Progress so far. */
-    progbar_val = 0.0;
+    progbar_val = 0.0f;
 
     progbar_stop_flag = FALSE;
     g_get_current_time(&progbar_start_time);
@@ -752,7 +703,7 @@ void
 packet_list_moveto_end(void)
 {
     gtk_clist_moveto(GTK_CLIST(packet_list),
-                     GTK_CLIST(packet_list)->rows - 1, -1, 1.0, 1.0);
+                     GTK_CLIST(packet_list)->rows - 1, -1, 1.0f, 1.0f);
 }
 
 gboolean
@@ -843,7 +794,7 @@ packet_list_get_row_data(gint row)
 
 /* get the first fully visible row number, given row MUST be visible */
 static gint
-packet_list_first_full_visible_row(gint row) 
+packet_list_first_full_visible_row(gint row)
 {
         g_assert(gtk_clist_row_is_visible(GTK_CLIST(packet_list), row) == GTK_VISIBILITY_FULL);
 
@@ -856,7 +807,7 @@ packet_list_first_full_visible_row(gint row)
 
 /* get the last fully visible row number, given row MUST be visible */
 static gint
-packet_list_last_full_visible_row(gint row) 
+packet_list_last_full_visible_row(gint row)
 {
         g_assert(gtk_clist_row_is_visible(GTK_CLIST(packet_list), row) == GTK_VISIBILITY_FULL);
 
@@ -890,7 +841,7 @@ packet_list_set_selected_row(gint row)
     if (!full_visible) {
         gtk_clist_freeze(GTK_CLIST(packet_list));
 
-        gtk_clist_moveto(GTK_CLIST(packet_list), row, -1, 0.0, 0.0);
+        gtk_clist_moveto(GTK_CLIST(packet_list), row, -1, 0.0f, 0.0f);
 
         /* even after move still invisible (happens with empty list) -> give up */
         if(gtk_clist_row_is_visible(GTK_CLIST(packet_list), row) != GTK_VISIBILITY_FULL) {
@@ -910,7 +861,7 @@ packet_list_set_selected_row(gint row)
         visible_rows = packet_list_last_full_visible_row(row) - packet_list_first_full_visible_row(row);
         first_row = row - visible_rows / 3;
 
-        gtk_clist_moveto(GTK_CLIST(packet_list), first_row >= 0 ? first_row : 0, -1, 0.0, 0.0);
+        gtk_clist_moveto(GTK_CLIST(packet_list), first_row >= 0 ? first_row : 0, -1, 0.0f, 0.0f);
 
         gtk_clist_thaw(GTK_CLIST(packet_list));
     }
@@ -988,3 +939,5 @@ packet_list_recent_write_all(FILE *rf)
    }
    fprintf (rf, "\n");
 }
+
+#endif /* NEW_PACKET_LIST */
