@@ -1,7 +1,7 @@
 /* proto_draw.c
  * Routines for GTK+ packet display
  *
- * $Id: main_proto_draw.c 29647 2009-09-01 07:29:16Z etxrab $
+ * $Id: main_proto_draw.c 30836 2009-11-05 19:45:51Z gerald $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -70,6 +70,7 @@
 #include "gtk/main.h"
 #include "gtk/menus.h"
 #include "gtk/main_proto_draw.h"
+#include "gtk/recent.h"
 
 #if _WIN32
 #include <gdk/gdkwin32.h>
@@ -81,6 +82,8 @@
 #define BYTE_VIEW_WIDTH    16
 #define BYTE_VIEW_SEP      8
 
+#define BIT_VIEW_WIDTH     8
+
 #define E_BYTE_VIEW_TREE_PTR      "byte_view_tree_ptr"
 #define E_BYTE_VIEW_TREE_VIEW_PTR "byte_view_tree_view_ptr"
 #define E_BYTE_VIEW_NDIGITS_KEY   "byte_view_ndigits"
@@ -158,7 +161,7 @@ set_notebook_page(GtkWidget *nb_ptr, tvbuff_t *tvb)
 
 /* Redraw a given byte view window. */
 void
-redraw_hex_dump(GtkWidget *nb, frame_data *fd, field_info *finfo)
+redraw_packet_bytes(GtkWidget *nb, frame_data *fd, field_info *finfo)
 {
   GtkWidget *bv;
   const guint8 *data;
@@ -174,12 +177,12 @@ redraw_hex_dump(GtkWidget *nb, frame_data *fd, field_info *finfo)
 
 /* Redraw all byte view windows. */
 void
-redraw_hex_dump_all(void)
+redraw_packet_bytes_all(void)
 {
     if (cfile.current_frame != NULL)
-            redraw_hex_dump( byte_nb_ptr, cfile.current_frame, cfile.finfo_selected);
+            redraw_packet_bytes( byte_nb_ptr, cfile.current_frame, cfile.finfo_selected);
 
-  redraw_hex_dump_packet_wins();
+  redraw_packet_bytes_packet_wins();
 
   /* XXX - this is a hack, to workaround a bug in GTK2.x!
      when changing the font size, even refilling of the corresponding
@@ -238,6 +241,7 @@ collapse_tree(GtkTreeView *tree_view, GtkTreeIter *iter,
 
 #define MAX_OFFSET_LEN	8	/* max length of hex offset of bytes */
 #define BYTES_PER_LINE	16	/* max byte values in a line */
+#define BITS_PER_LINE	8	/* max bit values in a line */
 #define HEX_DUMP_LEN	(BYTES_PER_LINE*3 + 1)
 				/* max number of characters hex dump takes -
 				   2 digits plus trailing blank
@@ -262,6 +266,11 @@ byte_num(int offset, int start_point)
 {
 	return (offset - start_point) / 3;
 }
+static int
+bit_num(int offset, int start_point)
+{
+	return (offset - start_point) / 9;
+}
 
 struct field_lookup_info {
     field_info  *fi;
@@ -296,23 +305,10 @@ GtkTreePath *tree_find_by_field_info(GtkTreeView *tree_view, field_info *finfo)
   return gtk_tree_model_get_path(model, &fli.iter);
 }
 
-/* If the user selected a certain byte in the byte view, try to find
- * the item in the GUI proto_tree that corresponds to that byte, and:
- *
- *	if we succeed, select it, and return TRUE;
- *	if we fail, return FALSE. */
-gboolean
-byte_view_select(GtkWidget *widget, GdkEventButton *event)
+static gboolean
+hex_view_get_byte(guint ndigits, int row, int column)
 {
-    proto_tree   *tree;
-    GtkTreeView  *tree_view;
-    GtkTextView  *bv = GTK_TEXT_VIEW(widget);
-    gint          x, y;
-    GtkTextIter   iter;
-    int           row, column;
     int           byte;
-    tvbuff_t     *tvb;
-    guint         ndigits;
     int           digits_start_1;
     int           digits_end_1;
     int           digits_start_2;
@@ -322,12 +318,6 @@ byte_view_select(GtkWidget *widget, GdkEventButton *event)
     int           text_start_2;
     int           text_end_2;
 
-    /*
-     * Get the number of digits of offset being displayed, and
-     * compute the columns of various parts of the display.
-     */
-    ndigits = GPOINTER_TO_UINT(g_object_get_data(G_OBJECT(bv), E_BYTE_VIEW_NDIGITS_KEY));
-
     /*
      * The column of the first hex digit in the first half.
      * That starts after "ndigits" digits of offset and two
@@ -340,20 +330,15 @@ byte_view_select(GtkWidget *widget, GdkEventButton *event)
      * There are BYTES_PER_LINE/2 bytes displayed in the first
      * half; there are 2 characters per byte, plus a separating
      * blank after all but the last byte's characters.
-     *
-     * Then subtract 1 to get the last column of the first half
-     * rather than the first column after the first half.
      */
     digits_end_1 = digits_start_1 + (BYTES_PER_LINE/2)*2 +
-        (BYTES_PER_LINE/2 - 1) - 1;
+        (BYTES_PER_LINE/2 - 1);
 
     /*
      * The column of the first hex digit in the second half.
-     * Add back the 1 to get the first column after the first
-     * half, and then add 2 for the 2 separating blanks between
-     * the halves.
+     * Add 2 for the 2 separating blanks between the halves.
      */
-    digits_start_2 = digits_end_1 + 3;
+    digits_start_2 = digits_end_1 + 2;
 
     /*
      * The column of the last hex digit in the second half.
@@ -361,15 +346,13 @@ byte_view_select(GtkWidget *widget, GdkEventButton *event)
      * "digits_start_1".
      */
     digits_end_2 = digits_start_2 + (BYTES_PER_LINE/2)*2 +
-        (BYTES_PER_LINE/2 - 1) - 1;
+        (BYTES_PER_LINE/2 - 1);
 
     /*
      * The column of the first "text dump" character in the first half.
-     * Add back the 1 to get the first column after the second
-     * half's hex dump, and then add 3 for the 3 separating blanks
-     * between the hex and text dummp.
+     * Add 3 for the 3 separating blanks between the hex and text dump.
      */
-    text_start_1 = digits_end_2 + 4;
+    text_start_1 = digits_end_2 + 3;
 
     /*
      * The column of the last "text dump" character in the first half.
@@ -395,6 +378,119 @@ byte_view_select(GtkWidget *widget, GdkEventButton *event)
      */
     text_end_2 = text_start_2 + BYTES_PER_LINE/2 - 1;
 
+    /* Given the column and row, determine which byte offset
+     * the user clicked on. */
+    if (column >= digits_start_1 && column <= digits_end_1) {
+        byte = byte_num(column, digits_start_1);
+        if (byte == -1) {
+            return byte;
+        }
+    }
+    else if (column >= digits_start_2 && column <= digits_end_2) {
+        byte = byte_num(column, digits_start_2);
+        if (byte == -1) {
+            return byte;
+        }
+        byte += 8;
+    }
+    else if (column >= text_start_1 && column <= text_end_1) {
+        byte = column - text_start_1;
+    }
+    else if (column >= text_start_2 && column <= text_end_2) {
+        byte = 8 + column - text_start_2;
+    }
+    else {
+        /* The user didn't select a hex digit or
+         * text-dump character. */
+        return -1;
+    }
+
+    /* Add the number of bytes from the previous rows. */
+    byte += row * BYTES_PER_LINE;
+
+    return byte;
+}
+
+static int
+bit_view_get_byte(guint ndigits, int row, int column)
+{
+    int           byte;
+    int           digits_start;
+    int           digits_end;
+    int           text_start;
+    int           text_end;
+
+    /*
+     * The column of the first bit digit.
+     * That starts after "ndigits" digits of offset and two
+     * separating blanks.
+     */
+    digits_start = ndigits + 2;
+
+    /*
+     * The column of the last bit digit.
+     * There are BITS_PER_LINE bytes displayed; there are
+     * 8 characters per byte, plus a separating blank
+     * after all but the last byte's characters.
+     */
+    digits_end = digits_start + (BITS_PER_LINE)*8 +
+        (BITS_PER_LINE - 1);
+
+    /*
+     * The column of the first "text dump" character.
+     * Add 3 for the 3 separating blanks between the bit and text dump.
+     */
+    text_start = digits_end + 3;
+
+    /*
+     * The column of the last "text dump" character.
+     * There are BITS_PER_LINE bytes displayed; there is 1 character per byte.
+     *
+     * Then subtract 1 to get the last column.
+     */
+    text_end = text_start + BITS_PER_LINE - 1;
+
+    /* Given the column and row, determine which byte offset
+     * the user clicked on. */
+    if (column >= digits_start && column <= digits_end) {
+        byte = bit_num(column, digits_start);
+        if (byte == -1) {
+            return byte;
+        }
+    }
+    else if (column >= text_start && column <= text_end) {
+        byte = column - text_start;
+    }
+    else {
+        /* The user didn't select a hex digit or
+         * text-dump character. */
+        return -1;
+    }
+
+    /* Add the number of bytes from the previous rows. */
+    byte += row * BITS_PER_LINE;
+
+    return byte;
+}
+
+/* If the user selected a certain byte in the byte view, try to find
+ * the item in the GUI proto_tree that corresponds to that byte, and:
+ *
+ *	if we succeed, select it, and return TRUE;
+ *	if we fail, return FALSE. */
+gboolean
+byte_view_select(GtkWidget *widget, GdkEventButton *event)
+{
+    GtkTextView  *bv = GTK_TEXT_VIEW(widget);
+    proto_tree   *tree;
+    GtkTreeView  *tree_view;
+    GtkTextIter   iter;
+    int           row, column;
+    guint         ndigits;
+    gint          x, y;
+    int           byte;
+    tvbuff_t     *tvb;
+
     tree = g_object_get_data(G_OBJECT(widget), E_BYTE_VIEW_TREE_PTR);
     if (tree == NULL) {
         /*
@@ -413,35 +509,26 @@ byte_view_select(GtkWidget *widget, GdkEventButton *event)
     row = gtk_text_iter_get_line(&iter);
     column = gtk_text_iter_get_line_offset(&iter);
 
-    /* Given the column and row, determine which byte offset
-     * the user clicked on. */
-    if (column >= digits_start_1 && column <= digits_end_1) {
-        byte = byte_num(column, digits_start_1);
-        if (byte == -1) {
-            return FALSE;
-        }
-    }
-    else if (column >= digits_start_2 && column <= digits_end_2) {
-        byte = byte_num(column, digits_start_2);
-        if (byte == -1) {
-            return FALSE;
-        }
-        byte += 8;
-    }
-    else if (column >= text_start_1 && column <= text_end_1) {
-        byte = column - text_start_1;
-    }
-    else if (column >= text_start_2 && column <= text_end_2) {
-        byte = 8 + column - text_start_2;
-    }
-    else {
-        /* The user didn't select a hex digit or
-         * text-dump character. */
-        return FALSE;
+    /*
+     * Get the number of digits of offset being displayed, and
+     * compute the byte position in the buffer.
+     */
+    ndigits = GPOINTER_TO_UINT(g_object_get_data(G_OBJECT(bv), E_BYTE_VIEW_NDIGITS_KEY));
+
+    switch (recent.gui_bytes_view) {
+    case BYTES_HEX:
+        byte = hex_view_get_byte(ndigits, row, column);
+	break;
+    case BYTES_BITS:
+        byte = bit_view_get_byte(ndigits, row, column);
+	break;
+    default:
+        g_assert_not_reached();
     }
 
-    /* Add the number of bytes from the previous rows. */
-    byte += row * 16;
+    if (byte == -1) {
+        return FALSE;
+    }
 
     /* Get the data source tvbuff */
     tvb = g_object_get_data(G_OBJECT(widget), E_BYTE_VIEW_TVBUFF_KEY);
@@ -607,7 +694,7 @@ add_byte_tab(GtkWidget *byte_nb, const char *name, tvbuff_t *tvb,
 
   g_signal_connect(byte_view, "show", G_CALLBACK(byte_view_realize_cb), NULL);
   g_signal_connect(byte_view, "button_press_event", G_CALLBACK(byte_view_button_press_cb),
-                 g_object_get_data(G_OBJECT(popup_menu_object), PM_HEXDUMP_KEY));
+                 g_object_get_data(G_OBJECT(popup_menu_object), PM_BYTES_VIEW_KEY));
 
   g_object_set_data(G_OBJECT(byte_view), E_BYTE_VIEW_TREE_PTR, tree);
   g_object_set_data(G_OBJECT(byte_view), E_BYTE_VIEW_TREE_VIEW_PTR, tree_view);
@@ -1030,11 +1117,13 @@ static void
 packet_hex_print_common(GtkWidget *bv, const guint8 *pd, int len, int bstart,
 			int bend, int astart, int aend, int encoding)
 {
-  int            i = 0, j, k, cur;
+  int            i = 0, j, k = 0, b, cur;
   guchar         line[MAX_LINES_LEN + 1];
   static guchar  hexchars[16] = {
       '0', '1', '2', '3', '4', '5', '6', '7',
       '8', '9', 'a', 'b', 'c', 'd', 'e', 'f'};
+  static const guint8 bitmask[8] = {
+      0x80, 0x40, 0x20, 0x10, 0x08, 0x04, 0x02, 0x01 };
   guchar         c = '\0';
   unsigned int   use_digits;
   gboolean       reverse, newreverse;
@@ -1156,7 +1245,16 @@ packet_hex_print_common(GtkWidget *bv, const guint8 *pd, int len, int bstart,
     /* Do we start in reverse? */
     reverse = (i >= bstart && i < bend) || (i >= astart && i < aend);
     j   = i;
-    k   = i + BYTE_VIEW_WIDTH;
+    switch (recent.gui_bytes_view) {
+    case BYTES_HEX:
+      k = i + BYTE_VIEW_WIDTH;
+      break;
+    case BYTES_BITS:
+      k = i + BIT_VIEW_WIDTH;
+      break;
+    default:
+      g_assert_not_reached();
+    }
     if (reverse) {
       gtk_text_buffer_insert_with_tags_by_name(buf, &iter, line, cur,
 					     "plain", NULL);
@@ -1165,10 +1263,32 @@ packet_hex_print_common(GtkWidget *bv, const guint8 *pd, int len, int bstart,
     /* Print the hex bit */
     while (i < k) {
       if (i < len) {
-        line[cur++] = hexchars[(pd[i] & 0xf0) >> 4];
-        line[cur++] = hexchars[pd[i] & 0x0f];
+	switch (recent.gui_bytes_view) {
+	case BYTES_HEX:
+	  line[cur++] = hexchars[(pd[i] & 0xf0) >> 4];
+	  line[cur++] = hexchars[pd[i] & 0x0f];
+	  break;
+	case BYTES_BITS:
+	  for (b = 0; b < 8; b++) {
+	    line[cur++] = (pd[i] & bitmask[b]) ? '1' : '0';
+	  }
+	  break;
+	default:
+	  g_assert_not_reached();
+	}
       } else {
-        line[cur++] = ' '; line[cur++] = ' ';
+	switch (recent.gui_bytes_view) {
+	case BYTES_HEX:
+	  line[cur++] = ' '; line[cur++] = ' ';
+	  break;
+	case BYTES_BITS:
+	  for (b = 0; b < 8; b++) {
+	    line[cur++] = ' ';
+	  }
+	  break;
+	default:
+	  g_assert_not_reached();
+	}
       }
       i++;
       newreverse = (i >= bstart && i < bend) || (i >= astart && i < aend);
@@ -1413,13 +1533,17 @@ set_ptree_font_all(PangoFontDescription *font)
 }
 
 
+/*
+ * Each expert_color_* level below should match the light gradient
+ * colors in image/expert_indicators.svg.
+ */
 gboolean colors_ok = FALSE;
-GdkColor	expert_color_chat	= { 0, 0xcc00, 0xcc00, 0xe000 };	/* a pale bluegrey */
-GdkColor	expert_color_note	= { 0, 0xa000, 0xff00, 0xff00 };	/* a bright turquoise */
-GdkColor	expert_color_warn	= { 0, 0xff00, 0xff00, 0 };			/* yellow */
-GdkColor	expert_color_error	= { 0, 0xff00, 0x5c00, 0x5c00 };	/* pale red */
+GdkColor	expert_color_chat	= { 0, 0x8080, 0xb7b7, 0xf7f7 };	/* light blue */
+GdkColor	expert_color_note	= { 0, 0xa0a0, 0xffff, 0xffff };	/* bright turquoise */
+GdkColor	expert_color_warn	= { 0, 0xf7f7, 0xf2f2, 0x5353 };	/* yellow */
+GdkColor	expert_color_error	= { 0, 0xffff, 0x5c5c, 0x5c5c };	/* pale red */
 GdkColor	expert_color_foreground	= { 0, 0x0000, 0x0000, 0x0000 };	/* black */
-GdkColor	hidden_proto_item	= { 0, 0x4400, 0x4400, 0x4400 };	/* gray */
+GdkColor	hidden_proto_item	= { 0, 0x4444, 0x4444, 0x4444 };	/* gray */
 
 gchar *expert_color_chat_str;
 gchar *expert_color_note_str;
@@ -1506,20 +1630,22 @@ static void tree_cell_renderer(GtkTreeViewColumn *tree_column _U_,
         g_object_set (cell, "foreground-set", TRUE, NULL);
     }
 
-    if(fi->hfinfo->type == FT_PROTOCOL) {
-        g_object_set (cell, "background", "gray90", NULL);
-        g_object_set (cell, "background-set", TRUE, NULL);
-        g_object_set (cell, "foreground", "black", NULL);
-        g_object_set (cell, "foreground-set", TRUE, NULL);
-        /*g_object_set (cell, "weight", PANGO_WEIGHT_BOLD, NULL);
-        g_object_set (cell, "weight-set", TRUE, NULL);*/
-	}
-
-    if((fi->hfinfo->type == FT_FRAMENUM) ||
-       (FI_GET_FLAG(fi, FI_URL) && IS_FT_STRING(fi->hfinfo->type))) {
-        render_as_url(cell);
+    if (fi && fi->hfinfo) {
+        if(fi->hfinfo->type == FT_PROTOCOL) {
+            g_object_set (cell, "background", "gray90", NULL);
+            g_object_set (cell, "background-set", TRUE, NULL);
+            g_object_set (cell, "foreground", "black", NULL);
+            g_object_set (cell, "foreground-set", TRUE, NULL);
+            /*g_object_set (cell, "weight", PANGO_WEIGHT_BOLD, NULL);
+			g_object_set (cell, "weight-set", TRUE, NULL);*/
+        }
+		
+        if((fi->hfinfo->type == FT_FRAMENUM) ||
+           (FI_GET_FLAG(fi, FI_URL) && IS_FT_STRING(fi->hfinfo->type))) {
+            render_as_url(cell);
+        }
     }
-
+	
 	if(FI_GET_FLAG(fi, PI_SEVERITY_MASK)) {
 		switch(FI_GET_FLAG(fi, PI_SEVERITY_MASK)) {
 		case(PI_CHAT):
@@ -1792,3 +1918,11 @@ clear_tree_and_hex_views(void)
   gtk_tree_store_clear(GTK_TREE_STORE(gtk_tree_view_get_model(GTK_TREE_VIEW(tree_view))));
 }
 
+void
+select_bytes_view (GtkWidget *w _U_, gpointer data _U_, gint view)
+{
+  if (recent.gui_bytes_view != view) {
+    recent.gui_bytes_view = view;
+    redraw_packet_bytes_all();
+  }
+}
