@@ -1,6 +1,6 @@
 /* main_statusbar.c
  *
- * $Id: main_statusbar.c 27259 2009-01-18 13:51:00Z jake $
+ * $Id: main_statusbar.c 30922 2009-11-10 18:02:05Z gerald $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -54,12 +54,8 @@
 #include "gtk/gtkglobals.h"
 #include "gtk/expert_comp_dlg.h"
 #include "gtk/profile_dlg.h"
-
-#include "../image/expert_error.xpm"
-#include "../image/expert_warn.xpm"
-#include "../image/expert_note.xpm"
-#include "../image/expert_chat.xpm"
-#include "../image/expert_none.xpm"
+#include "gtk/main_welcome.h"
+#include "gtk/expert_indicators.h"
 
 /*
  * The order below defines the priority of info bar contexts.
@@ -81,7 +77,7 @@ typedef enum {
 
 
 static GtkWidget    *status_pane_left, *status_pane_right;
-static GtkWidget    *info_bar, *packets_bar, *profile_bar, *profile_bar_event;
+static GtkWidget    *info_bar, *info_bar_event, *packets_bar, *profile_bar, *profile_bar_event;
 static GtkWidget    *expert_info_error, *expert_info_warn, *expert_info_note;
 static GtkWidget    *expert_info_chat, *expert_info_none;
 
@@ -96,7 +92,12 @@ static void packets_bar_new(void);
 static void profile_bar_new(void);
 static void status_expert_new(void);
 
-
+/* Temporary message timeouts */
+#define TEMPORARY_MSG_TIMEOUT (7 * 1000)
+#define TEMPORARY_FLASH_TIMEOUT (1 * 1000)
+#define TEMPORARY_FLASH_INTERVAL (TEMPORARY_FLASH_TIMEOUT / 4)
+static gint flash_time;
+static gboolean flash_highlight = FALSE;
 
 /*
  * Push a message referring to file access onto the statusbar.
@@ -112,6 +113,7 @@ statusbar_push_file_msg(const gchar *msg)
             return;
     }
     status_levels[STATUS_LEVEL_FILE]++;
+
     gtk_statusbar_push(GTK_STATUSBAR(info_bar), file_ctx, msg);
 }
 
@@ -186,6 +188,62 @@ statusbar_pop_filter_msg(void)
     gtk_statusbar_pop(GTK_STATUSBAR(info_bar), filter_ctx);
 }
 
+/*
+ * Timeout callbacks for statusbar_push_temporary_msg
+ */
+static gboolean
+statusbar_remove_temporary_msg(gpointer data)
+{
+    guint msg_id = GPOINTER_TO_UINT(data);
+    
+    gtk_statusbar_remove(GTK_STATUSBAR(info_bar), main_ctx, msg_id);
+
+    return FALSE;
+}
+
+static gboolean
+statusbar_flash_temporary_msg(gpointer data _U_)
+{
+    gboolean retval = TRUE;
+
+    if (flash_time > 0) {
+        flash_highlight = !flash_highlight;
+    } else {
+        flash_highlight = FALSE;
+        retval = FALSE;
+    }
+
+    /*
+     * As of 2.18.3 gtk_drag_highlight just draws a border around the widget
+     * so we can abuse it here.
+     */
+    if (flash_highlight) {
+        gtk_drag_highlight(info_bar);
+    } else {
+        gtk_drag_unhighlight(info_bar);
+    }
+
+    flash_time -= TEMPORARY_FLASH_INTERVAL;    
+
+    return retval;
+}
+
+/*
+ * Push a temporary message onto the statusbar.
+ */
+void
+statusbar_push_temporary_msg(const gchar *msg)
+{
+    guint msg_id;
+    
+    msg_id = gtk_statusbar_push(GTK_STATUSBAR(info_bar), main_ctx, msg);
+    
+    flash_time = TEMPORARY_FLASH_TIMEOUT - 1;
+    g_timeout_add(TEMPORARY_FLASH_INTERVAL, statusbar_flash_temporary_msg, NULL);
+
+    g_timeout_add(TEMPORARY_MSG_TIMEOUT, statusbar_remove_temporary_msg, GUINT_TO_POINTER(msg_id));
+}
+
 
 GtkWidget *
 statusbar_new(void)
@@ -245,17 +303,18 @@ foreach_remove_a_child(GtkWidget *widget, gpointer data) {
 void
 statusbar_widgets_emptying(GtkWidget *statusbar)
 {
-    gtk_widget_ref(info_bar);
-    gtk_widget_ref(packets_bar);
-    gtk_widget_ref(profile_bar);
-    gtk_widget_ref(profile_bar_event);
-    gtk_widget_ref(status_pane_left);
-    gtk_widget_ref(status_pane_right);
-    gtk_widget_ref(expert_info_error);
-    gtk_widget_ref(expert_info_warn);
-    gtk_widget_ref(expert_info_note);
-    gtk_widget_ref(expert_info_chat);
-    gtk_widget_ref(expert_info_none);
+    g_object_ref(G_OBJECT(info_bar));
+    g_object_ref(G_OBJECT(info_bar_event));
+    g_object_ref(G_OBJECT(packets_bar));
+    g_object_ref(G_OBJECT(profile_bar));
+    g_object_ref(G_OBJECT(profile_bar_event));
+    g_object_ref(G_OBJECT(status_pane_left));
+    g_object_ref(G_OBJECT(status_pane_right));
+    g_object_ref(G_OBJECT(expert_info_error));
+    g_object_ref(G_OBJECT(expert_info_warn));
+    g_object_ref(G_OBJECT(expert_info_note));
+    g_object_ref(G_OBJECT(expert_info_chat));
+    g_object_ref(G_OBJECT(expert_info_none));
 
     /* empty all containers participating */
     gtk_container_foreach(GTK_CONTAINER(statusbar),     foreach_remove_a_child, statusbar);
@@ -266,13 +325,13 @@ statusbar_widgets_emptying(GtkWidget *statusbar)
 void
 statusbar_widgets_pack(GtkWidget *statusbar)
 {
-    gtk_box_pack_start(GTK_BOX(statusbar), expert_info_error, FALSE, FALSE, 0);
-    gtk_box_pack_start(GTK_BOX(statusbar), expert_info_warn, FALSE, FALSE, 0);
-    gtk_box_pack_start(GTK_BOX(statusbar), expert_info_note, FALSE, FALSE, 0);
-    gtk_box_pack_start(GTK_BOX(statusbar), expert_info_chat, FALSE, FALSE, 0);
-    gtk_box_pack_start(GTK_BOX(statusbar), expert_info_none, FALSE, FALSE, 0);
+    gtk_box_pack_start(GTK_BOX(statusbar), expert_info_error, FALSE, FALSE, 2);
+    gtk_box_pack_start(GTK_BOX(statusbar), expert_info_warn, FALSE, FALSE, 2);
+    gtk_box_pack_start(GTK_BOX(statusbar), expert_info_note, FALSE, FALSE, 2);
+    gtk_box_pack_start(GTK_BOX(statusbar), expert_info_chat, FALSE, FALSE, 2);
+    gtk_box_pack_start(GTK_BOX(statusbar), expert_info_none, FALSE, FALSE, 2);
     gtk_box_pack_start(GTK_BOX(statusbar), status_pane_left, TRUE, TRUE, 0);
-    gtk_paned_pack1(GTK_PANED(status_pane_left), info_bar, FALSE, FALSE);
+    gtk_paned_pack1(GTK_PANED(status_pane_left), info_bar_event, FALSE, FALSE);
     gtk_paned_pack2(GTK_PANED(status_pane_left), status_pane_right, TRUE, FALSE);
     gtk_paned_pack1(GTK_PANED(status_pane_right), packets_bar, TRUE, FALSE);
     gtk_paned_pack2(GTK_PANED(status_pane_right), profile_bar_event, FALSE, FALSE);
@@ -311,8 +370,9 @@ info_bar_new(void)
 {
     int i;
 
-    /* tip: tooltips don't work on statusbars! */
+    info_bar_event = gtk_event_box_new();
     info_bar = gtk_statusbar_new();
+    gtk_container_add(GTK_CONTAINER(info_bar_event), info_bar);
     main_ctx = gtk_statusbar_get_context_id(GTK_STATUSBAR(info_bar), "main");
     file_ctx = gtk_statusbar_get_context_id(GTK_STATUSBAR(info_bar), "file");
     help_ctx = gtk_statusbar_get_context_id(GTK_STATUSBAR(info_bar), "help");
@@ -325,6 +385,7 @@ info_bar_new(void)
     }
 
     gtk_widget_show(info_bar);
+    gtk_widget_show(info_bar_event);
 }
 
 static void
@@ -363,10 +424,9 @@ profile_bar_new(void)
 /*
  * update the packets statusbar to the current values
  */
-void 
+void
 packets_bar_update(void)
 {
-
     if(packets_bar) {
         /* remove old status */
         if(packets_str) {
@@ -380,8 +440,14 @@ packets_bar_update(void)
                 packets_str = g_strdup_printf(" Packets: %u Displayed: %u Marked: %u Dropped: %u",
                     cfile.count, cfile.displayed_count, cfile.marked_count, cfile.drops);
             } else {
-                packets_str = g_strdup_printf(" Packets: %u Displayed: %u Marked: %u",
-                    cfile.count, cfile.displayed_count, cfile.marked_count);
+                gulong computed_elapsed = cf_get_computed_elapsed();
+
+                packets_str = g_strdup_printf(" Packets: %u Displayed: %u Marked: %u  Time: %02lu:%02lu:%02lu.%03lu",
+                    cfile.count, cfile.displayed_count, cfile.marked_count,
+                    computed_elapsed/3600000,
+                    computed_elapsed%3600000/60000,
+                    computed_elapsed%60000/1000,
+                    computed_elapsed%1000);
             }
         } else {
             packets_str = g_strdup(" No Packets");
@@ -418,35 +484,35 @@ status_expert_new(void)
 
     tooltips = gtk_tooltips_new();
 
-    expert_image = xpm_to_widget_from_parent(top_level, expert_error_xpm);
+    expert_image = pixbuf_to_widget(expert_error_pb_data);
     gtk_tooltips_set_tip(tooltips, expert_image, "ERROR is the highest expert info level", NULL);
     gtk_widget_show(expert_image);
     expert_info_error = gtk_event_box_new();
     gtk_container_add(GTK_CONTAINER(expert_info_error), expert_image);
     g_signal_connect(expert_info_error, "button_press_event", G_CALLBACK(expert_comp_dlg_cb), NULL);
 
-    expert_image = xpm_to_widget_from_parent(top_level, expert_warn_xpm);
+    expert_image = pixbuf_to_widget(expert_warn_pb_data);
     gtk_tooltips_set_tip(tooltips, expert_image, "WARNING is the highest expert info level", NULL);
     gtk_widget_show(expert_image);
     expert_info_warn = gtk_event_box_new();
     gtk_container_add(GTK_CONTAINER(expert_info_warn), expert_image);
     g_signal_connect(expert_info_warn, "button_press_event", G_CALLBACK(expert_comp_dlg_cb), NULL);
 
-    expert_image = xpm_to_widget_from_parent(top_level, expert_note_xpm);
+    expert_image = pixbuf_to_widget(expert_note_pb_data);
     gtk_tooltips_set_tip(tooltips, expert_image, "NOTE is the highest expert info level", NULL);
     gtk_widget_show(expert_image);
     expert_info_note = gtk_event_box_new();
     gtk_container_add(GTK_CONTAINER(expert_info_note), expert_image);
     g_signal_connect(expert_info_note, "button_press_event", G_CALLBACK(expert_comp_dlg_cb), NULL);
 
-    expert_image = xpm_to_widget_from_parent(top_level, expert_chat_xpm);
+    expert_image = pixbuf_to_widget(expert_chat_pb_data);
     gtk_tooltips_set_tip(tooltips, expert_image, "CHAT is the highest expert info level", NULL);
     gtk_widget_show(expert_image);
     expert_info_chat = gtk_event_box_new();
     gtk_container_add(GTK_CONTAINER(expert_info_chat), expert_image);
     g_signal_connect(expert_info_chat, "button_press_event", G_CALLBACK(expert_comp_dlg_cb), NULL);
 
-    expert_image = xpm_to_widget_from_parent(top_level, expert_none_xpm);
+    expert_image = pixbuf_to_widget(expert_none_pb_data);
     gtk_tooltips_set_tip(tooltips, expert_image, "No expert info", NULL);
     gtk_widget_show(expert_image);
     expert_info_none = gtk_event_box_new();
@@ -571,7 +637,9 @@ statusbar_cf_file_read_finished_cb(capture_file *cf)
 static void
 statusbar_capture_prepared_cb(capture_options *capture_opts _U_)
 {
-    statusbar_push_file_msg(" Waiting for capture input data ...");
+    gchar *msg = " Waiting for capture input data ...";
+    statusbar_push_file_msg(msg);
+    welcome_header_push_msg(msg);
 }
 
 static void
@@ -581,6 +649,7 @@ statusbar_capture_update_started_cb(capture_options *capture_opts)
 
 
     statusbar_pop_file_msg();
+    welcome_header_pop_msg();
 
     if(capture_opts->iface) {
         capture_msg = g_strdup_printf(" %s: <live capture in progress> to file: %s",
@@ -678,6 +747,7 @@ statusbar_capture_fixed_finished_cb(capture_options *capture_opts _U_)
 
     /* Pop the "<live capture in progress>" message off the status bar. */
     statusbar_pop_file_msg();
+    welcome_header_pop_msg();
 
     /* Pop the "<capturing>" message off the status bar */
     gtk_statusbar_pop(GTK_STATUSBAR(packets_bar), packets_ctx);
