@@ -3,7 +3,7 @@
  * Copyright 2008-2009, Stephen Fisher (see AUTHORS file)
  * Co-authors Anders Broman and Kovarththanan Rajaratnam.
  *
- * $Id: new_packet_list.c 30529 2009-10-12 07:55:24Z stig $
+ * $Id: new_packet_list.c 31062 2009-11-24 00:16:26Z stig $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -62,6 +62,7 @@
 #include "gtk/capture_file_dlg.h"
 #include "gtk/main_statusbar.h"
 #include "gtk/packet_win.h"
+#include "gtk/main.h"
 
 static PacketList *packetlist;
 static gboolean last_at_end = FALSE;
@@ -79,7 +80,7 @@ static void show_cell_data_func(GtkTreeViewColumn *col,
 				GtkTreeModel *model,
 				GtkTreeIter *iter,
 				gpointer data);
-static guint row_number_from_iter(GtkTreeIter *iter);
+static gint row_number_from_iter(GtkTreeIter *iter);
 
 void new_packet_list_set_sel_browse(gboolean val, gboolean force_set);
 
@@ -101,6 +102,25 @@ new_packet_list_create(void)
 	return scrollwin;
 }
 
+/* XXX - implement a smarter solution for recreating the packet list */
+void
+new_packet_list_recreate(void)
+{
+	gtk_widget_destroy(pkt_scrollw);
+
+	prefs.num_cols = g_list_length(prefs.col_list);
+
+	build_column_format_array(&cfile.cinfo, prefs.num_cols, FALSE);
+
+	pkt_scrollw = new_packet_list_create();
+	gtk_widget_show_all(pkt_scrollw);
+
+	main_widgets_rearrange();
+
+	if(cfile.state != FILE_CLOSED)
+		redissect_packets();
+}
+
 guint
 new_packet_list_append(column_info *cinfo _U_, frame_data *fdata, packet_info *pinfo _U_)
 {
@@ -296,20 +316,17 @@ new_packet_list_recreate_visible_rows(void)
 
 void new_packet_list_resize_column(gint col)
 {
-	PangoLayout *layout;
 	GtkTreeViewColumn *column;
 	gint col_width;
 	const gchar *long_str;
 
 	long_str = packet_list_get_widest_column_string(packetlist, col);
-	if(strcmp("",long_str)==0)
-		/* If we get an empty string levae the width unchanged */
+	if(!long_str || strcmp("",long_str)==0)
+		/* If we get an empty string leave the width unchanged */
 		return;
 	column = gtk_tree_view_get_column (GTK_TREE_VIEW(packetlist->view), col);
-	layout = gtk_widget_create_pango_layout(packetlist->view, long_str );
-	pango_layout_get_pixel_size(layout, &col_width, NULL);
+	col_width = get_default_col_size (packetlist->view, long_str);
 	gtk_tree_view_column_set_fixed_width(column, col_width);
-	g_object_unref(G_OBJECT(layout));
 }
 
 static void
@@ -551,10 +568,10 @@ new_packet_list_set_selected_row(gint row)
 	gtk_tree_path_free(path);
 }
 
-static guint
+static gint
 row_number_from_iter(GtkTreeIter *iter)
 {
-	guint row;
+	gint row;
 	gint *indices;
 	GtkTreePath *path;
 	GtkTreeModel *model;
@@ -576,18 +593,23 @@ new_packet_list_select_cb(GtkTreeView *tree_view, gpointer data _U_)
 {
 	GtkTreeSelection *selection;
 	GtkTreeIter iter;
-	guint row;
+	gint row;
 
 	selection = gtk_tree_view_get_selection(tree_view);
 	if (!gtk_tree_selection_get_selected(selection, NULL, &iter))
 		return;
 
+	row = row_number_from_iter(&iter);
+
+	/* Check if already selected 
+	 */
+	if (cfile.current_frame && cfile.current_row == row)
+		return;
+
 	/* Remove the hex display tab pages */
 	while(gtk_notebook_get_nth_page(GTK_NOTEBOOK(byte_nb_ptr), 0))
 		gtk_notebook_remove_page(GTK_NOTEBOOK(byte_nb_ptr), 0);
 
-	row = row_number_from_iter(&iter);
-
 	cf_select_packet(&cfile, row);
 	gtk_widget_grab_focus(packetlist->view);
 
