@@ -3,7 +3,7 @@
  *
  * Copyright 2000, Jeffrey C. Foster <jfoste@woodward.com>
  *
- * $Id: packet_win.c 27630 2009-03-06 23:02:27Z wmeier $
+ * $Id: packet_win.c 30832 2009-11-05 10:16:49Z stig $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -131,6 +131,19 @@ void new_window_cb(GtkWidget *w _U_)
   struct PacketWinData *DataPtr;
   int i;
 
+#ifdef NEW_PACKET_LIST
+  int err;
+  gchar *err_info;
+
+  /* With the new packetlists "lazy columns" it's neccesary to reread the frame */
+  if (!wtap_seek_read(cfile.wth, cfile.current_frame->file_off, &cfile.pseudo_header,
+        cfile.pd, cfile.current_frame->cap_len, &err, &err_info)) {
+            simple_dialog(ESD_TYPE_ERROR, ESD_BTN_OK,
+            cf_read_error_message(err, err_info), cfile.filename);
+            return;
+  }
+#endif
+
   /* Allocate data structure to represent this window. */
   DataPtr = (struct PacketWinData *) g_malloc(sizeof(struct PacketWinData));
 
@@ -141,7 +154,7 @@ void new_window_cb(GtkWidget *w _U_)
   DataPtr->edt = epan_dissect_new(TRUE, TRUE);
   epan_dissect_run(DataPtr->edt, &DataPtr->pseudo_header, DataPtr->pd,
           DataPtr->frame, &cfile.cinfo);
-  epan_dissect_fill_in_columns(DataPtr->edt);
+  epan_dissect_fill_in_columns(DataPtr->edt, FALSE, TRUE);
 
   /*
    * Build title of window by getting column data constructed when the
@@ -280,16 +293,16 @@ destroy_packet_wins(void)
 }
 
 static void
-redraw_hex_dump_cb(gpointer data, gpointer user_data _U_)
+redraw_packet_bytes_cb(gpointer data, gpointer user_data _U_)
 {
 	struct PacketWinData *DataPtr = (struct PacketWinData *)data;
 
-	redraw_hex_dump(DataPtr->bv_nb_ptr, DataPtr->frame, DataPtr->finfo_selected);
+	redraw_packet_bytes(DataPtr->bv_nb_ptr, DataPtr->frame, DataPtr->finfo_selected);
 }
 
-/* Redraw the hex dump part of all the popup packet windows. */
+/* Redraw the packet bytes part of all the popup packet windows. */
 void
-redraw_hex_dump_packet_wins(void)
+redraw_packet_bytes_packet_wins(void)
 {
-	g_list_foreach(detail_windows, redraw_hex_dump_cb, NULL);
+	g_list_foreach(detail_windows, redraw_packet_bytes_cb, NULL);
 }
