@@ -1,7 +1,7 @@
 /* layout_prefs.c
  * Dialog box for layout preferences
  *
- * $Id: prefs_layout.c 28751 2009-06-15 23:39:57Z stig $
+ * $Id: prefs_layout.c 30832 2009-11-05 10:16:49Z stig $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -105,7 +105,7 @@ static GtkWidget *layout_content_radio_vbox(GtkWidget *main_vb, GtkTooltips *too
 
     radio_pbytes_rb = gtk_radio_button_new_with_mnemonic_from_widget(GTK_RADIO_BUTTON(radio_none_rb), "Packet Bytes");
     gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(radio_pbytes_rb), content == layout_pane_content_pbytes);
-    gtk_tooltips_set_tip (tooltips, radio_pbytes_rb, "Put the packet bytes hexdump in this pane.", NULL);
+    gtk_tooltips_set_tip (tooltips, radio_pbytes_rb, "Put the packet bytes dump in this pane.", NULL);
     gtk_container_add(GTK_CONTAINER(radio_vb), radio_pbytes_rb);
 
     g_object_set_data(G_OBJECT(radio_vb), LAYOUT_NONE_RB_KEY,       radio_none_rb);
@@ -252,10 +252,11 @@ layout_defaults_cb (GtkWidget * w _U_, gpointer data _U_)
 #define HEX_DUMP_HIGHLIGHT_STYLE_KEY	"hex_dump_highlight_style"
 #define FILTER_TOOLBAR_PLACEMENT_KEY    "filter_toolbar_show_in_statusbar"
 #define GUI_TOOLBAR_STYLE_KEY           "toolbar_style"
+#define GUI_FILTER_TOOLBAR_STYLE_KEY    "filter_toolbar_style"
 #define GUI_WINDOW_TITLE_KEY            "window_title"
 
 
-#define GUI_TABLE_ROWS 5
+#define GUI_TABLE_ROWS 6
 
 static const enum_val_t scrollbar_placement_vals[] = {
     { "FALSE", "Left", FALSE },
@@ -293,11 +294,12 @@ layout_prefs_show(void)
     GtkWidget	*default_vb, *default_bt;
     GtkWidget   *main_tb, *hbox;
     GtkWidget	*scrollbar_om;
-    GtkWidget *altern_colors_om;
-    GtkWidget *highlight_style_om;
-    GtkWidget *toolbar_style_om;
-    GtkWidget *filter_toolbar_placement_om;
-    GtkWidget *window_title_te;
+    GtkWidget	*altern_colors_om;
+    GtkWidget	*highlight_style_om;
+    GtkWidget	*toolbar_style_om;
+	GtkWidget	*filter_toolbar_style_om;
+    GtkWidget	*filter_toolbar_placement_om;
+    GtkWidget	*window_title_te;
 
     GtkTooltips   *tooltips = gtk_tooltips_new();
 
@@ -400,10 +402,10 @@ layout_prefs_show(void)
         altern_colors_vals, prefs.gui_altern_colors);
     g_object_set_data(G_OBJECT(main_vb), ALTERN_COLORS_KEY, altern_colors_om);
 
-    /* Hex Dump highlight style */
+    /* Packet Bytes Dump highlight style */
     highlight_style_om = create_preference_option_menu(main_tb, pos++,
-        "Hex display highlight style:", 
-        "Select the style in which the hex dump will be displayed.",
+        "Packet bytes highlight style:", 
+        "Select the style in which the packet bytes dump will be displayed.",
         highlight_style_vals, prefs.gui_hex_dump_highlight_style);
     g_object_set_data(G_OBJECT(main_vb), HEX_DUMP_HIGHLIGHT_STYLE_KEY, highlight_style_om);
 
@@ -414,6 +416,13 @@ layout_prefs_show(void)
         toolbar_style_vals, prefs.gui_toolbar_main_style);
     g_object_set_data(G_OBJECT(main_vb), GUI_TOOLBAR_STYLE_KEY, toolbar_style_om);
 
+    /* Filter toolbar prefs */
+    filter_toolbar_style_om = create_preference_option_menu(main_tb, pos++,
+        "Filter toolbar style:", 
+        "Select the style in which the filter toolbar will be displayed.",
+        toolbar_style_vals, prefs.gui_toolbar_filter_style);
+    g_object_set_data(G_OBJECT(main_vb), GUI_FILTER_TOOLBAR_STYLE_KEY, filter_toolbar_style_om);
+
     /* Placement of Filter toolbar */
     filter_toolbar_placement_om = create_preference_option_menu(main_tb, pos++,
         "Filter toolbar placement:",
@@ -465,6 +474,8 @@ layout_prefs_fetch(GtkWidget *w)
         g_object_get_data(G_OBJECT(w), HEX_DUMP_HIGHLIGHT_STYLE_KEY),  highlight_style_vals);
     prefs.gui_toolbar_main_style = fetch_enum_value(
         g_object_get_data(G_OBJECT(w), GUI_TOOLBAR_STYLE_KEY), toolbar_style_vals);
+    prefs.gui_toolbar_filter_style = fetch_enum_value(
+        g_object_get_data(G_OBJECT(w), GUI_FILTER_TOOLBAR_STYLE_KEY), toolbar_style_vals);
 
     g_free(prefs.gui_window_title);
     prefs.gui_window_title = g_strdup(gtk_entry_get_text(
