@@ -1,7 +1,7 @@
 /* print_dlg.c
  * Dialog boxes for printing and exporting to text files
  *
- * $Id: print_dlg.c 27686 2009-03-09 23:38:44Z wmeier $
+ * $Id: print_dlg.c 28915 2009-07-01 23:36:51Z gerald $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -628,7 +628,7 @@ open_print_dialog(const char *title, output_action_e action, print_args_t *args)
 #ifndef _WIN32
   cmd_lb = gtk_label_new("Print command:");
   g_object_set_data(G_OBJECT(dest_cb), PRINT_CMD_LB_KEY, cmd_lb);
-  gtk_misc_set_alignment(GTK_MISC(cmd_lb), 1.0, 0.5);
+  gtk_misc_set_alignment(GTK_MISC(cmd_lb), 1.0f, 0.5f);
   gtk_table_attach_defaults(GTK_TABLE(printer_tb), cmd_lb, 0, 1, 1, 2);
   gtk_widget_set_sensitive(cmd_lb, !args->to_file);
   if(action == output_action_print)
@@ -908,7 +908,7 @@ print_ok_cb(GtkWidget *ok_bt, gpointer parent_w)
 #ifdef _WIN32
   gboolean          win_printer = FALSE;
   int               tmp_fd;
-  char              tmp_namebuf[128+1];  /* XX: see create_tmpfile which says [128+1]; why ? */
+  char              *tmp_namebuf;
   char              *tmp_oldfile;
 #endif
   cf_print_status_t status;
@@ -951,10 +951,10 @@ print_ok_cb(GtkWidget *ok_bt, gpointer parent_w)
     /* Don't use tmpnam() or such, as this will fail under some ACL           */
     /* circumstances: http://bugs.wireshark.org/bugzilla/show_bug.cgi?id=358  */
     /* Also: tmpnam is "insecure" and should not be used.                     */
-    tmp_fd = create_tempfile(tmp_namebuf, sizeof(tmp_namebuf), "wshprint");
+    tmp_fd = create_tempfile(&tmp_namebuf, "wshprint");
     if(tmp_fd == -1) {
         simple_dialog(ESD_TYPE_ERROR, ESD_BTN_OK,
-            "Couldn't create a temporary file for printing.");
+            "Couldn't create a temporary file for printing:\n%s", tmp_namebuf);
         return;
     }
     /* remember to restore these values later! */
