@@ -1,6 +1,6 @@
 /* proto_dlg.c
  *
- * $Id: proto_dlg.c 25673 2008-07-08 02:43:40Z wmeier $
+ * $Id: proto_dlg.c 28878 2009-06-28 20:01:37Z wmeier $
  *
  * Laurent Deniel <laurent.deniel@free.fr>
  *
@@ -57,6 +57,8 @@ static void show_proto_selection(GtkListStore *proto_store);
 static gboolean set_proto_selection(GtkWidget *);
 static gboolean revert_proto_selection(void);
 
+static void proto_col_clicked_cb(GtkWidget *col _U_, GtkWidget *proto_list);
+
 static void toggle_all_cb(GtkWidget *button, gpointer parent_w);
 static void enable_all_cb(GtkWidget *button, gpointer parent_w);
 static void disable_all_cb(GtkWidget *button, gpointer parent_w);
@@ -97,7 +99,7 @@ proto_cb(GtkWidget *w _U_, gpointer data _U_)
   }
 
   proto_w = dlg_conf_window_new("Wireshark: Enabled Protocols");
-  gtk_window_set_default_size(GTK_WINDOW(proto_w), DEF_WIDTH * 2/3, DEF_HEIGHT);
+  gtk_window_set_default_size(GTK_WINDOW(proto_w), DEF_WIDTH , DEF_HEIGHT);
 
   /* Container for each row of widgets */
 
@@ -131,23 +133,27 @@ proto_cb(GtkWidget *w _U_, gpointer data _U_)
   /* default sort on "abbrev" column */
   gtk_tree_sortable_set_sort_column_id(GTK_TREE_SORTABLE(proto_store), 1,
                                        GTK_SORT_ASCENDING);
+
   proto_list = tree_view_new(GTK_TREE_MODEL(proto_store));
   gtk_container_add(GTK_CONTAINER(proto_sw), proto_list);
+
   proto_rend = gtk_cell_renderer_toggle_new();
   g_signal_connect(proto_rend, "toggled", G_CALLBACK(status_toggled), proto_store);
-  proto_col = gtk_tree_view_column_new_with_attributes(titles[0], proto_rend,
-                                                    "active", 0, NULL);
+  proto_col = gtk_tree_view_column_new_with_attributes(titles[0], proto_rend, "active", 0, NULL);
   gtk_tree_view_column_set_sort_column_id(proto_col, 0);
+  g_signal_connect(proto_col, "clicked", G_CALLBACK(proto_col_clicked_cb), proto_list);
   gtk_tree_view_append_column(GTK_TREE_VIEW(proto_list), proto_col);
+
   proto_rend = gtk_cell_renderer_text_new();
-  proto_col = gtk_tree_view_column_new_with_attributes(titles[1], proto_rend,
-                                                    "text", 1, NULL);
+  proto_col = gtk_tree_view_column_new_with_attributes(titles[1], proto_rend, "text", 1, NULL);
   gtk_tree_view_column_set_sort_column_id(proto_col, 1);
+  g_signal_connect(proto_col, "clicked", G_CALLBACK(proto_col_clicked_cb), proto_list);
   gtk_tree_view_append_column(GTK_TREE_VIEW(proto_list), proto_col);
+
   proto_rend = gtk_cell_renderer_text_new();
-  proto_col = gtk_tree_view_column_new_with_attributes(titles[2], proto_rend,
-                                                    "text", 2, NULL);
+  proto_col = gtk_tree_view_column_new_with_attributes(titles[2], proto_rend, "text", 2, NULL);
   gtk_tree_view_column_set_sort_column_id(proto_col, 2);
+  g_signal_connect(proto_col, "clicked", G_CALLBACK(proto_col_clicked_cb), proto_list);
   gtk_tree_view_append_column(GTK_TREE_VIEW(proto_list), proto_col);
 
   gtk_tree_view_set_search_column(GTK_TREE_VIEW(proto_list), 1); /* col 1 in the *model* */
@@ -156,11 +162,10 @@ proto_cb(GtkWidget *w _U_, gpointer data _U_)
 
   label = gtk_label_new("Disabling a protocol prevents higher "
 			"layer protocols from being displayed");
-  gtk_misc_set_alignment(GTK_MISC(label), 0.5, 0.5);
+  gtk_misc_set_alignment(GTK_MISC(label), 0.5f, 0.5f);
   gtk_widget_show(label);
   gtk_box_pack_start(GTK_BOX(proto_vb), label, FALSE, FALSE, 5);
 
-
   bbox = gtk_hbutton_box_new();
   gtk_button_box_set_layout(GTK_BUTTON_BOX(bbox), GTK_BUTTONBOX_END);
   gtk_box_set_spacing(GTK_BOX(bbox), 5);
@@ -214,6 +219,17 @@ proto_cb(GtkWidget *w _U_, gpointer data _U_)
 
   gtk_widget_show(proto_w);
 
+  gtk_widget_grab_focus(proto_list); /* XXX: force focus to the tree_view. This hack req'd so "type-ahead find"
+                                      *  will be effective after the window is displayed. The issue is
+                                      *  that any call to gtk_tree_view_column_set_sort_column_id above
+                                      *  apparently sets the focus to the column header button and thus
+                                      *  type-ahead find is, in effect, disabled on the column.
+                                      *  Also required: a grab_focus whenever the column header is
+                                      *  clicked to change the column sort order since the click
+                                      *  also changes the focus to the column header button.
+                                      *  Is there a better way to do this ?
+                                      */
+
   /* hide the Save button if the user uses implicit save */
   if(!prefs.gui_use_pref_save) {
     gtk_widget_hide(save_bt);
@@ -222,6 +238,15 @@ proto_cb(GtkWidget *w _U_, gpointer data _U_)
   window_present(proto_w);
 } /* proto_cb */
 
+/* protocol list column header clicked (to change sort)       */
+/*  grab_focus(treeview) req'd so that type-ahead find works. */
+/*  (See comment above).                                      */
+static void
+proto_col_clicked_cb(GtkWidget *col _U_, GtkWidget *proto_list) {
+  gtk_widget_grab_focus(proto_list);
+}
+
+/* Status toggled */
 static void
 status_toggled(GtkCellRendererToggle *cell _U_, gchar *path_str, gpointer data)
 {
@@ -245,7 +270,6 @@ status_toggled(GtkCellRendererToggle *cell _U_, gchar *path_str, gpointer data)
 
 /* XXX - We need callbacks for Gtk2 */
 
-
 /* Toggle All */
 static void
 toggle_all_cb(GtkWidget *button _U_, gpointer pl)
@@ -322,6 +346,18 @@ proto_delete_event_cb(GtkWidget *proto_w, GdkEvent *event _U_,
   return FALSE;
 }
 
+/* Update protocol_list 'was_enabled' to current value of 'enabled' */
+static void
+update_was_enabled(void)
+{
+  GSList *entry;
+
+  for (entry = protocol_list; entry != NULL; entry = g_slist_next(entry)) {
+    protocol_data_t *p = entry->data;
+    p->was_enabled = p->enabled;
+  }
+}
+
 static void
 proto_write(gpointer parent_w _U_)
 {
@@ -332,17 +368,17 @@ proto_write(gpointer parent_w _U_)
   /* Create the directory that holds personal configuration files, if
      necessary.  */
   if (create_persconffile_dir(&pf_dir_path) == -1) {
-     simple_dialog(ESD_TYPE_ERROR, ESD_BTN_OK,
-      "Can't create directory\n\"%s\"\nfor disabled protocols file: %s.", pf_dir_path,
-      strerror(errno));
-     g_free(pf_dir_path);
+    simple_dialog(ESD_TYPE_ERROR, ESD_BTN_OK,
+                  "Can't create directory\n\"%s\"\nfor disabled protocols file: %s.", pf_dir_path,
+                  strerror(errno));
+    g_free(pf_dir_path);
   } else {
     save_disabled_protos_list(&pf_path, &pf_save_errno);
     if (pf_path != NULL) {
-	simple_dialog(ESD_TYPE_ERROR, ESD_BTN_OK,
-	    "Could not save to your disabled protocols file\n\"%s\": %s.",
-	    pf_path, strerror(pf_save_errno));
-	g_free(pf_path);
+      simple_dialog(ESD_TYPE_ERROR, ESD_BTN_OK,
+                    "Could not save to your disabled protocols file\n\"%s\": %s.",
+                    pf_path, strerror(pf_save_errno));
+      g_free(pf_path);
     }
   }
 }
@@ -357,12 +393,12 @@ proto_ok_cb(GtkWidget *ok_bt _U_, gpointer parent_w)
 
   /* if we don't have a Save button, just save the settings now */
   if (!prefs.gui_use_pref_save) {
-      proto_write(parent_w);
+    proto_write(parent_w);
   }
 
   window_destroy(GTK_WIDGET(parent_w));
   if (redissect)
-    cf_redissect_packets(&cfile);
+    redissect_packets();
 }
 
 static void
@@ -375,11 +411,12 @@ proto_apply_cb(GtkWidget *apply_bt _U_, gpointer parent_w)
 
   /* if we don't have a Save button, just save the settings now */
   if (!prefs.gui_use_pref_save) {
-      proto_write(parent_w);
+    proto_write(parent_w);
+    update_was_enabled();
   }
 
   if (redissect)
-    cf_redissect_packets(&cfile);
+    redissect_packets();
 }
 
 static void
@@ -390,7 +427,7 @@ proto_save_cb(GtkWidget *save_bt _U_, gpointer parent_w)
 
   if (set_proto_selection(GTK_WIDGET(parent_w))) {
     /* Redissect all the packets, and re-evaluate the display filter. */
-    cf_redissect_packets(&cfile);
+    redissect_packets();
   }
 }
 
@@ -402,7 +439,7 @@ proto_cancel_cb(GtkWidget *cancel_bt _U_, gpointer parent_w)
   redissect = revert_proto_selection();
   window_destroy(GTK_WIDGET(parent_w));
   if (redissect)
-    cf_redissect_packets(&cfile);
+    redissect_packets();
 }
 
 static gboolean
@@ -523,7 +560,7 @@ proto_disable_dialog_cb(gpointer dialog _U_, gint btn, gpointer data)
     if (proto_is_protocol_enabled(protocol) == TRUE) {
       if (proto_can_toggle_protocol(id) == TRUE) {
         proto_set_decoding(id, FALSE);
-        cf_redissect_packets(&cfile);
+        redissect_packets();
       }
     }
   }
