@@ -1,7 +1,7 @@
 /*
  * Copyright 2004, Irene Ruengeler <i.ruengeler [AT] fh-muenster.de>
  *
- * $Id: sctp_stat.c 26641 2008-10-31 09:53:56Z stig $
+ * $Id: sctp_stat.c 29537 2009-08-24 14:30:55Z wmeier $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -56,6 +56,8 @@
 #define SCTP_ECNE_CHUNK_ID              12
 #define SCTP_CWR_CHUNK_ID               13
 #define SCTP_SHUTDOWN_COMPLETE_CHUNK_ID 14
+#define SCTP_AUTH_CHUNK_ID              15 
+#define SCTP_NR_SACK_CHUNK_ID           16 
 #define SCTP_FORWARD_TSN_CHUNK_ID      192
 #define SCTP_ASCONF_ACK_CHUNK_ID      0x80
 #define SCTP_PKTDROP_CHUNK_ID         0X81
@@ -119,6 +121,8 @@ static const value_string chunk_type_values[] = {
   { SCTP_PKTDROP_CHUNK_ID,           "PKTDROP" },
   { SCTP_ASCONF_CHUNK_ID,            "ASCONF" },
   { SCTP_IETF_EXT,                   "IETF_EXTENSION" },
+  { SCTP_NR_SACK_CHUNK_ID,           "NR_SACK" },
+  { SCTP_AUTH_CHUNK_ID,              "AUTH" },
   { 0,                               NULL } };
 
 
@@ -296,14 +300,21 @@ static sctp_assoc_info_t *calc_checksum(struct _sctp_info *check_data, sctp_asso
 }
 
 
+/* XXX: Some versions of gcc warn about "breaking strict aliasing rules" 
+        for 'a' in the following (given the way this function is called).
+        As a workaround we'll define the function parameters to match 
+        how this function is actually called.  */
+/*******
 static gint sctp_assoc_vtag_cmp(gconstpointer aa, gconstpointer bb)
 {
-
 	const struct _sctp_assoc_info* a = aa;
 	const struct _sctp_assoc_info* b = bb;
-
 	if (a == b)
 		return(FORWARD_STREAM);
+********/
+
+static gint sctp_assoc_vtag_cmp(const sctp_tmp_info_t *a, const sctp_assoc_info_t *b)
+{
 
 	if (a == NULL || b == NULL)
 		return(ASSOC_NOT_FOUND);
@@ -469,8 +480,11 @@ static sctp_assoc_info_t * add_chunk_count(address * vadd, sctp_assoc_info_t * i
 		{
 			v = (address *) (ch->addr);
 			if (ADDRESSES_EQUAL(vadd, v))
-			{
-				ch->addr_count[type]++;
+			{	
+				if (type <= UPPER_BOUND_CHUNK_TYPE)
+					ch->addr_count[type]++;
+				else
+					ch->addr_count[OTHER_CHUNKS_INDEX]++;
 				return info;
 			}
 			else
@@ -489,11 +503,15 @@ static sctp_assoc_info_t * add_chunk_count(address * vadd, sctp_assoc_info_t * i
 	dat = g_malloc(vadd->len);
 	memcpy(dat, vadd->data, vadd->len);
 	ch->addr->data = dat;
-	for (i=0; i<13; i++)
+	for (i=0; i < NUM_CHUNKS; i++)
 		ch->addr_count[i] = 0;
-	ch->addr_count[type]++;
-	info->addr_chunk_count = g_list_append(info->addr_chunk_count, ch);
 
+	if (type <= UPPER_BOUND_CHUNK_TYPE)
+		ch->addr_count[type]++;
+	else
+		ch->addr_count[OTHER_CHUNKS_INDEX]++;
+	
+	info->addr_chunk_count = g_list_append(info->addr_chunk_count, ch);
 	return info;
 }
 
@@ -545,6 +563,7 @@ packet(void *tapdata _U_, packet_info *pinfo , epan_dissect_t *edt _U_ , const v
 	struct tsn_sort *tsn_s;
 	guint8* addr = NULL;
 	int i;
+	guint8 index = 0;
 
 	sctp_allassocs_info_t *assoc_info=NULL;
 	assoc_info = &sctp_tapinfo_struct;
@@ -682,7 +701,8 @@ packet(void *tapdata _U_, packet_info *pinfo , epan_dissect_t *edt _U_ , const v
 			if (((tvb_get_guint8(sctp_info->tvb[0],0)) == SCTP_INIT_CHUNK_ID) ||
 			    ((tvb_get_guint8(sctp_info->tvb[0],0)) == SCTP_INIT_ACK_CHUNK_ID) ||
 			    ((tvb_get_guint8(sctp_info->tvb[0],0)) == SCTP_DATA_CHUNK_ID) ||
-			    ((tvb_get_guint8(sctp_info->tvb[0],0)) == SCTP_SACK_CHUNK_ID))
+			    ((tvb_get_guint8(sctp_info->tvb[0],0)) == SCTP_SACK_CHUNK_ID) ||
+			    ((tvb_get_guint8(sctp_info->tvb[0],0)) == SCTP_NR_SACK_CHUNK_ID))
 			{
 				tsn  = g_malloc(sizeof(tsn_t));
 				sack = g_malloc(sizeof(tsn_t));
@@ -709,7 +729,8 @@ packet(void *tapdata _U_, packet_info *pinfo , epan_dissect_t *edt _U_ , const v
 				sack->secs=tsn->secs   = (guint32)pinfo->fd->rel_ts.secs;
 				sack->usecs=tsn->usecs = (guint32)pinfo->fd->rel_ts.nsecs/1000;
 				if (((tvb_get_guint8(sctp_info->tvb[0],0)) == SCTP_DATA_CHUNK_ID) ||
-					((tvb_get_guint8(sctp_info->tvb[0],0)) == SCTP_SACK_CHUNK_ID))
+				    ((tvb_get_guint8(sctp_info->tvb[0],0)) == SCTP_SACK_CHUNK_ID) ||
+				    ((tvb_get_guint8(sctp_info->tvb[0],0)) == SCTP_NR_SACK_CHUNK_ID))
 				{
 					if (tsn->secs < info->min_secs)
 					{
@@ -768,16 +789,22 @@ packet(void *tapdata _U_, packet_info *pinfo , epan_dissect_t *edt _U_ , const v
 					info->initack_dir = 1;
 					info->initack     = TRUE;
 				}
-				info->chunk_count[tvb_get_guint8(sctp_info->tvb[0],0)]++;
-				info->ep1_chunk_count[tvb_get_guint8(sctp_info->tvb[0],0)]++;
-				info = add_chunk_count(&tmp_info.src, info, 1, tvb_get_guint8(sctp_info->tvb[0],0));
+
+				index = tvb_get_guint8(sctp_info->tvb[0],0); 
+				if (index > UPPER_BOUND_CHUNK_TYPE)
+					index = OTHER_CHUNKS_INDEX;
+
+				info->chunk_count[index]++;
+				info->ep1_chunk_count[index]++;
+				info = add_chunk_count(&tmp_info.src, info, 1, index);
 			}
 			else
 			{
 				if (((tvb_get_guint8(sctp_info->tvb[0],0)) != SCTP_INIT_CHUNK_ID) &&
 				    ((tvb_get_guint8(sctp_info->tvb[0],0)) != SCTP_INIT_ACK_CHUNK_ID) &&
 				    ((tvb_get_guint8(sctp_info->tvb[0],0)) != SCTP_DATA_CHUNK_ID) &&
-				    ((tvb_get_guint8(sctp_info->tvb[0],0)) != SCTP_SACK_CHUNK_ID))
+				    ((tvb_get_guint8(sctp_info->tvb[0],0)) != SCTP_SACK_CHUNK_ID) &&
+				    ((tvb_get_guint8(sctp_info->tvb[0],0)) != SCTP_NR_SACK_CHUNK_ID))
 				{
 					tsn  = g_malloc(sizeof(tsn_t));
 					sack = g_malloc(sizeof(tsn_t));
@@ -788,18 +815,14 @@ packet(void *tapdata _U_, packet_info *pinfo , epan_dissect_t *edt _U_ , const v
 				}
 				for (chunk_number = 0; chunk_number < sctp_info->number_of_tvbs; chunk_number++)
 				{
-					if ((tvb_get_guint8(sctp_info->tvb[chunk_number],0)) < 12)
-					{
-						info->chunk_count[tvb_get_guint8(sctp_info->tvb[0],0)]++;
-						info->ep1_chunk_count[tvb_get_guint8(sctp_info->tvb[0],0)]++;
-						info = add_chunk_count(&tmp_info.src, info, 1, tvb_get_guint8(sctp_info->tvb[0],0));
-					}
-					else
-					{
-						info->chunk_count[12]++;
-						info->ep1_chunk_count[12]++;
-						info = add_chunk_count(&tmp_info.src, info, 1, 12);
-					}
+					index = tvb_get_guint8(sctp_info->tvb[0],0); 
+					if ( index > UPPER_BOUND_CHUNK_TYPE )
+						index = OTHER_CHUNKS_INDEX;
+
+					info->chunk_count[index]++;
+					info->ep1_chunk_count[index]++;
+					info = add_chunk_count(&tmp_info.src, info, 1, index);
+
 					if (tvb_get_guint8(sctp_info->tvb[chunk_number],0) == SCTP_DATA_CHUNK_ID)
 					{
 						length = tvb_get_ntohs(sctp_info->tvb[chunk_number], CHUNK_LENGTH_OFFSET)-DATA_CHUNK_HEADER_LENGTH;
@@ -824,15 +847,31 @@ packet(void *tapdata _U_, packet_info *pinfo , epan_dissect_t *edt _U_ , const v
 						datachunk = TRUE;
 						tsn_s = g_malloc(sizeof(struct tsn_sort));
 						tsn_s->tsnumber = tsnumber;
-						tsn_s->secs     = tsn->secs;
-						tsn_s->usecs    = tsn->usecs;
+						tsn_s->secs     = tsn->secs = (guint32)pinfo->fd->rel_ts.secs;
+						tsn_s->usecs    = tsn->usecs = (guint32)pinfo->fd->rel_ts.nsecs/1000;
 						tsn_s->offset   = 0;
 						tsn_s->framenumber = framenumber;
 						tsn_s->length   = length-DATA_CHUNK_HEADER_LENGTH;
+						if (tsn->secs < info->min_secs)
+						{
+							info->min_secs  = tsn->secs;
+							info->min_usecs = tsn->usecs;
+						}
+						else if (tsn->secs == info->min_secs && tsn->usecs < info->min_usecs)
+							info->min_usecs = tsn->usecs;
+
+						if (tsn->secs > info->max_secs)
+						{
+							info->max_secs  = tsn->secs;
+							info->max_usecs = tsn->usecs;
+						}
+						else if (tsn->secs == info->max_secs && tsn->usecs > info->max_usecs)
+							info->max_usecs = tsn->usecs;
 						g_ptr_array_add(info->sort_tsn1, tsn_s);
 						info->n_array_tsn1++;
 					}
-					if (tvb_get_guint8(sctp_info->tvb[chunk_number],0) == SCTP_SACK_CHUNK_ID)
+					if ((tvb_get_guint8(sctp_info->tvb[chunk_number],0) == SCTP_SACK_CHUNK_ID) ||
+					    (tvb_get_guint8(sctp_info->tvb[chunk_number],0) == SCTP_NR_SACK_CHUNK_ID) )
 					{
 						tsnumber = tvb_get_ntohl((sctp_info->tvb)[chunk_number], SACK_CHUNK_CUMULATIVE_TSN_ACK_OFFSET);
 						if (tsnumber < info->min_tsn2)
@@ -849,13 +888,28 @@ packet(void *tapdata _U_, packet_info *pinfo , epan_dissect_t *edt _U_ , const v
 						sackchunk = TRUE;
 						tsn_s = g_malloc(sizeof(struct tsn_sort));
 						tsn_s->tsnumber = tsnumber;
-						tsn_s->secs     = tsn->secs;
-						tsn_s->usecs    = tsn->usecs;
+						tsn_s->secs     = tsn->secs = (guint32)pinfo->fd->rel_ts.secs;
+						tsn_s->usecs    = tsn->usecs = (guint32)pinfo->fd->rel_ts.nsecs/1000;
 						tsn_s->offset   = 0;
 						tsn_s->framenumber = framenumber;
 						tsn_s->length   =  tvb_get_ntohl(sctp_info->tvb[chunk_number], SACK_CHUNK_ADV_REC_WINDOW_CREDIT_OFFSET);
 						if (tsn_s->length > info->max_window1)
 							info->max_window1 = tsn_s->length;
+						if (tsn->secs < info->min_secs)
+						{
+							info->min_secs  = tsn->secs;
+							info->min_usecs = tsn->usecs;
+						}
+						else if (tsn->secs == info->min_secs && tsn->usecs < info->min_usecs)
+							info->min_usecs = tsn->usecs;
+
+						if (tsn->secs > info->max_secs)
+						{
+							info->max_secs  = tsn->secs;
+							info->max_usecs = tsn->usecs;
+						}
+						else if (tsn->secs == info->max_secs && tsn->usecs > info->max_usecs)
+							info->max_usecs = tsn->usecs;
 						g_ptr_array_add(info->sort_sack2, tsn_s);
 						info->n_sack_chunks_ep2++;
 					}
@@ -905,7 +959,8 @@ packet(void *tapdata _U_, packet_info *pinfo , epan_dissect_t *edt _U_ , const v
 		if (((tvb_get_guint8(sctp_info->tvb[0],0)) == SCTP_INIT_CHUNK_ID) ||
 		    ((tvb_get_guint8(sctp_info->tvb[0],0)) == SCTP_INIT_ACK_CHUNK_ID) ||
 		    ((tvb_get_guint8(sctp_info->tvb[0],0)) == SCTP_DATA_CHUNK_ID) ||
-		    ((tvb_get_guint8(sctp_info->tvb[0],0)) == SCTP_SACK_CHUNK_ID))
+		    ((tvb_get_guint8(sctp_info->tvb[0],0)) == SCTP_SACK_CHUNK_ID) ||
+		    ((tvb_get_guint8(sctp_info->tvb[0],0)) == SCTP_NR_SACK_CHUNK_ID))
 		{
 
 			tsn  = g_malloc(sizeof(tsn_t));
@@ -933,7 +988,8 @@ packet(void *tapdata _U_, packet_info *pinfo , epan_dissect_t *edt _U_ , const v
 			sack->secs=tsn->secs = (guint32)pinfo->fd->rel_ts.secs;
 			sack->usecs=tsn->usecs = (guint32)pinfo->fd->rel_ts.nsecs/1000;
 			if (((tvb_get_guint8(sctp_info->tvb[0],0)) == SCTP_DATA_CHUNK_ID) ||
-			((tvb_get_guint8(sctp_info->tvb[0],0)) == SCTP_SACK_CHUNK_ID))
+			((tvb_get_guint8(sctp_info->tvb[0],0)) == SCTP_SACK_CHUNK_ID) ||
+			((tvb_get_guint8(sctp_info->tvb[0],0)) == SCTP_NR_SACK_CHUNK_ID))
 			{
 				if (tsn->secs < info->min_secs)
 				{
@@ -1006,12 +1062,16 @@ packet(void *tapdata _U_, packet_info *pinfo , epan_dissect_t *edt _U_ , const v
 				/*info->initack_dir=1;*/
 				info->tsn1 = g_list_prepend(info->tsn1, tsn);
 			}
-			info->chunk_count[tvb_get_guint8(sctp_info->tvb[0],0)]++;
+			
+			index = tvb_get_guint8(sctp_info->tvb[0],0);
+			if (index > UPPER_BOUND_CHUNK_TYPE)
+				index = OTHER_CHUNKS_INDEX;
+			info->chunk_count[index]++;
 			if (info->direction == 1)
-				info->ep1_chunk_count[tvb_get_guint8(sctp_info->tvb[0],0)]++;
+				info->ep1_chunk_count[index]++;
 			else
-				info->ep2_chunk_count[tvb_get_guint8(sctp_info->tvb[0],0)]++;
-			info = add_chunk_count(&tmp_info.src, info, info->direction, tvb_get_guint8(sctp_info->tvb[0],0));
+				info->ep2_chunk_count[index]++;
+			info = add_chunk_count(&tmp_info.src, info, info->direction, index);
 			for (chunk_number = 1; chunk_number < sctp_info->number_of_tvbs; chunk_number++)
 			{
 				type = tvb_get_ntohs(sctp_info->tvb[chunk_number],0);
@@ -1049,7 +1109,8 @@ packet(void *tapdata _U_, packet_info *pinfo , epan_dissect_t *edt _U_ , const v
 		{
 			if (((tvb_get_guint8(sctp_info->tvb[0],0)) != SCTP_INIT_ACK_CHUNK_ID) &&
 			    ((tvb_get_guint8(sctp_info->tvb[0],0)) != SCTP_DATA_CHUNK_ID) &&
-			    ((tvb_get_guint8(sctp_info->tvb[0],0)) != SCTP_SACK_CHUNK_ID))
+			    ((tvb_get_guint8(sctp_info->tvb[0],0)) != SCTP_SACK_CHUNK_ID) &&
+			    ((tvb_get_guint8(sctp_info->tvb[0],0)) != SCTP_NR_SACK_CHUNK_ID))
 			{
 				sack = g_malloc(sizeof(tsn_t));
 				sack->tsns = NULL;
@@ -1060,24 +1121,17 @@ packet(void *tapdata _U_, packet_info *pinfo , epan_dissect_t *edt _U_ , const v
 			}
 			for (chunk_number = 0; chunk_number < sctp_info->number_of_tvbs; chunk_number++)
 			{
-				if ((tvb_get_guint8(sctp_info->tvb[chunk_number],0)) < 12)
-				{
-					info->chunk_count[tvb_get_guint8(sctp_info->tvb[chunk_number],0)]++;
-					if (info->direction == 1)
-						info->ep1_chunk_count[tvb_get_guint8(sctp_info->tvb[chunk_number],0)]++;
-					else
-						info->ep2_chunk_count[tvb_get_guint8(sctp_info->tvb[chunk_number],0)]++;
-					info = add_chunk_count(&tmp_info.src, info,info->direction, tvb_get_guint8(sctp_info->tvb[chunk_number],0));
-				}
+				index = tvb_get_guint8(sctp_info->tvb[chunk_number],0);
+				if (index > UPPER_BOUND_CHUNK_TYPE)
+					index = OTHER_CHUNKS_INDEX;
+
+				info->chunk_count[index]++;
+				if (info->direction == 1)
+					info->ep1_chunk_count[index]++;
 				else
-				{
-					info->chunk_count[12]++;
-					if (info->direction == 1)
-						info->ep1_chunk_count[12]++;
-					else
-						info->ep2_chunk_count[12]++;
-					info = add_chunk_count(&tmp_info.src, info, info->direction,12);
-				}
+					info->ep2_chunk_count[index]++;
+				info = add_chunk_count(&tmp_info.src, info,info->direction, index);
+
 				if ((tvb_get_guint8(sctp_info->tvb[chunk_number],0)) == SCTP_DATA_CHUNK_ID)
 				{
 					tsnumber = tvb_get_ntohl((sctp_info->tvb)[chunk_number], DATA_CHUNK_TSN_OFFSET);
@@ -1092,11 +1146,27 @@ packet(void *tapdata _U_, packet_info *pinfo , epan_dissect_t *edt _U_ , const v
 					info->n_data_bytes+=length;
 					tsn_s = g_malloc(sizeof(struct tsn_sort));
 					tsn_s->tsnumber = tsnumber;
-					tsn_s->secs  = tsn->secs;
-					tsn_s->usecs = tsn->usecs;
+					tsn_s->secs  = tsn->secs = (guint32)pinfo->fd->rel_ts.secs;
+					tsn_s->usecs = tsn->usecs = (guint32)pinfo->fd->rel_ts.nsecs/1000;
 					tsn_s->offset = 0;
 					tsn_s->framenumber = framenumber;
 					tsn_s->length = length;
+					
+					if (tsn->secs < info->min_secs)
+					{
+						info->min_secs  = tsn->secs;
+						info->min_usecs = tsn->usecs;
+					}
+					else if (tsn->secs == info->min_secs && tsn->usecs < info->min_usecs)
+						info->min_usecs = tsn->usecs;
+
+					if (tsn->secs > info->max_secs)
+					{
+						info->max_secs  = tsn->secs;
+						info->max_usecs = tsn->usecs;
+					}
+					else if (tsn->secs == info->max_secs && tsn->usecs > info->max_usecs)
+						info->max_usecs = tsn->usecs;
 
 					if (info->direction == 1)
 					{
@@ -1151,7 +1221,8 @@ packet(void *tapdata _U_, packet_info *pinfo , epan_dissect_t *edt _U_ , const v
 						info->n_array_tsn2++;
 					}
 				}
-				else if (tvb_get_guint8(sctp_info->tvb[chunk_number],0) == SCTP_SACK_CHUNK_ID)
+				else if ((tvb_get_guint8(sctp_info->tvb[chunk_number],0) == SCTP_SACK_CHUNK_ID) ||
+				         (tvb_get_guint8(sctp_info->tvb[chunk_number],0) == SCTP_NR_SACK_CHUNK_ID))
 				{
 					tsnumber = tvb_get_ntohl((sctp_info->tvb)[chunk_number], SACK_CHUNK_CUMULATIVE_TSN_ACK_OFFSET);
 					length = tvb_get_ntohs(sctp_info->tvb[chunk_number], CHUNK_LENGTH_OFFSET);
@@ -1163,12 +1234,28 @@ packet(void *tapdata _U_, packet_info *pinfo , epan_dissect_t *edt _U_ , const v
 					sackchunk = TRUE;
 					tsn_s = g_malloc(sizeof(struct tsn_sort));
 					tsn_s->tsnumber = tsnumber;
-					tsn_s->secs   = tsn->secs;
-					tsn_s->usecs  = tsn->usecs;
+					tsn_s->secs   = tsn->secs = (guint32)pinfo->fd->rel_ts.secs;
+					tsn_s->usecs  = tsn->usecs = (guint32)pinfo->fd->rel_ts.nsecs/1000;
 					tsn_s->offset = 0;
 					tsn_s->framenumber = framenumber;
 					tsn_s->length = tvb_get_ntohl(sctp_info->tvb[chunk_number], SACK_CHUNK_ADV_REC_WINDOW_CREDIT_OFFSET);
 
+					if (tsn->secs < info->min_secs)
+					{
+						info->min_secs  = tsn->secs;
+						info->min_usecs = tsn->usecs;
+					}
+					else if (tsn->secs == info->min_secs && tsn->usecs < info->min_usecs)
+						info->min_usecs = tsn->usecs;
+
+					if (tsn->secs > info->max_secs)
+					{
+						info->max_secs  = tsn->secs;
+						info->max_usecs = tsn->usecs;
+					}
+					else if (tsn->secs == info->max_secs && tsn->usecs > info->max_usecs)
+						info->max_usecs = tsn->usecs;
+
 
 					if (info->direction == 2)
 					{
@@ -1259,7 +1346,7 @@ register_tap_listener_sctp_stat(void)
 
 	if (!sctp_tapinfo_struct.is_registered)
 	{
-		if ((error_string = register_tap_listener("sctp", &sctp_tapinfo_struct, NULL, reset, packet, sctp_update))) {
+		if ((error_string = register_tap_listener("sctp", &sctp_tapinfo_struct, NULL, 0, reset, packet, sctp_update))) {
 			simple_dialog(ESD_TYPE_ERROR, ESD_BTN_OK, "%s", error_string->str);
 			g_string_free(error_string, TRUE);
 			return;
