@@ -2,7 +2,7 @@
  * GTK Tap implementation of stats_tree
  * 2005, Luis E. G. Ontanon
  *
- * $Id: stats_tree_stat.c 27407 2009-02-10 03:54:55Z ulfl $
+ * $Id: stats_tree_stat.c 28645 2009-06-05 22:42:47Z guy $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -190,7 +190,7 @@ init_gtk_tree(const char* optarg, void *userdata _U_)
 	gchar* window_name = NULL;
 	GString* error_string;
 	GtkWidget *scr_win;
-	guint init_strlen;
+	size_t init_strlen;
 	GtkWidget *main_vb, *bbox, *bt_close;
 	GtkTreeViewColumn* column;
 	GtkCellRenderer* renderer;
@@ -301,6 +301,7 @@ init_gtk_tree(const char* optarg, void *userdata _U_)
 	error_string = register_tap_listener( cfg->tapname,
 					      st,
 					      st->filter,
+					      cfg->flags,
 					      reset_tap,
 					      stats_tree_packet,
 					      draw_gtk_tree);
@@ -326,7 +327,7 @@ init_gtk_tree(const char* optarg, void *userdata _U_)
 	gtk_widget_show_all(st->pr->win);
 	window_present(st->pr->win);
 
-	cf_retap_packets(&cfile, FALSE);
+	cf_retap_packets(&cfile);
 	gdk_window_raise(st->pr->win->window);
 }
 
