@@ -2,7 +2,7 @@
  * Routines for Dynamic Service Addition Response dissection
  * Copyright 2002, Anand V. Narwani <anand[AT]narwani.org>
  *
- * $Id: packet-dsarsp.c 32662 2010-05-04 21:44:03Z gerald $
+ * $Id: packet-dsarsp.c 30415 2009-10-09 07:24:33Z etxrab $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -27,14 +27,6 @@
 # include "config.h"
 #endif
 
-#include "moduleinfo.h"
-
-#include <stdio.h>
-#include <stdlib.h>
-#include <string.h>
-
-#include <gmodule.h>
-
 #include <epan/packet.h>
 
 /* Initialize the protocol and registered fields */
@@ -56,7 +48,7 @@ dissect_dsarsp (tvbuff_t * tvb, packet_info * pinfo, proto_tree * tree)
 {
 
   proto_item *it;
-  proto_tree *dsarsp_tree;
+  proto_tree *dsarsp_tree = NULL;
   guint16 transid;
   guint8 response;
   tvbuff_t *next_tvb;
@@ -69,7 +61,7 @@ dissect_dsarsp (tvbuff_t * tvb, packet_info * pinfo, proto_tree * tree)
       col_clear (pinfo->cinfo, COL_INFO);
       col_add_fstr (pinfo->cinfo, COL_INFO,
 		    "Dynamic Service Add Response ID = %u (%s)", transid,
-		    val_to_str (response, docsis_conf_code, "%d"));
+		    val_to_str (response, docsis_conf_code, "%s"));
     }
 
   if (tree)
@@ -83,10 +75,10 @@ dissect_dsarsp (tvbuff_t * tvb, packet_info * pinfo, proto_tree * tree)
       proto_tree_add_item (dsarsp_tree, hf_docsis_dsarsp_response, tvb, 2, 1,
 			   FALSE);
 
-      /* Call dissector for Appendix C TLV's */
-      next_tvb = tvb_new_subset (tvb, 3, -1, -1);
-      call_dissector (docsis_tlv_handle, next_tvb, pinfo, dsarsp_tree);
     }
+    /* Call dissector for Appendix C TLV's */
+    next_tvb = tvb_new_subset_remaining (tvb, 3);
+    call_dissector (docsis_tlv_handle, next_tvb, pinfo, dsarsp_tree);
 
 
 
@@ -110,8 +102,8 @@ proto_register_docsis_dsarsp (void)
   static hf_register_info hf[] = {
     {&hf_docsis_dsarsp,
      {"Dynamic Service Add Request", "docsis_dsarsp",
-      FT_BYTES, BASE_HEX, NULL, 0x0,
-      "Dynamic Service Add Request", HFILL}
+      FT_BYTES, BASE_NONE, NULL, 0x0,
+      NULL, HFILL}
      },
     {&hf_docsis_dsarsp_tranid,
      {"Transaction Id", "docsis_dsarsp.tranid",
@@ -121,7 +113,7 @@ proto_register_docsis_dsarsp (void)
     {&hf_docsis_dsarsp_response,
      {"Confirmation Code", "docsis_dsarsp.confcode",
       FT_UINT8, BASE_DEC, VALS (docsis_conf_code), 0x0,
-      "Confirmation Code", HFILL}
+      NULL, HFILL}
      },
   };
 
