@@ -2,7 +2,7 @@
  * Routines for Upstream Channel Change Request dissection
  * Copyright 2002, Anand V. Narwani <anand[AT]narwani.org>
  *
- * $Id: packet-uccreq.c 23088 2007-10-07 23:46:44Z richardv $
+ * $Id: packet-uccreq.c 30415 2009-10-09 07:24:33Z etxrab $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -27,14 +27,6 @@
 # include "config.h"
 #endif
 
-#include <stdio.h>
-#include <stdlib.h>
-#include <string.h>
-
-#include "moduleinfo.h"
-
-#include <gmodule.h>
-
 #include <epan/packet.h>
 
 /* Initialize the protocol and registered fields */
@@ -53,7 +45,7 @@ dissect_uccreq (tvbuff_t * tvb, packet_info * pinfo, proto_tree * tree)
 {
 
   proto_item *it;
-  proto_tree *uccreq_tree;
+  proto_tree *uccreq_tree = NULL;
   guint8 chid;
   tvbuff_t *next_tvb;
 
@@ -76,10 +68,10 @@ dissect_uccreq (tvbuff_t * tvb, packet_info * pinfo, proto_tree * tree)
       proto_tree_add_item (uccreq_tree, hf_docsis_uccreq_upchid, tvb, 0, 1,
 			   FALSE);
 
-      /* call dissector for Appendix C TLV's */
-      next_tvb = tvb_new_subset (tvb, 1, -1, -1);
-      call_dissector (docsis_tlv_handle, next_tvb, pinfo, uccreq_tree);
     }
+    /* call dissector for Appendix C TLV's */
+    next_tvb = tvb_new_subset_remaining (tvb, 1);
+    call_dissector (docsis_tlv_handle, next_tvb, pinfo, uccreq_tree);
 
 
 }
@@ -102,13 +94,13 @@ proto_register_docsis_uccreq (void)
   static hf_register_info hf[] = {
     {&hf_docsis_uccreq,
      {"Upstream Channel Change Request", "docsis_uccreq",
-      FT_BYTES, BASE_HEX, NULL, 0x0,
-      "Upstream Channel Change Request", HFILL}
+      FT_BYTES, BASE_NONE, NULL, 0x0,
+      NULL, HFILL}
      },
     {&hf_docsis_uccreq_upchid,
      {"Upstream Channel Id", "docsis_uccreq.upchid",
       FT_UINT8, BASE_DEC, NULL, 0x0,
-      "Upstream Channel Id", HFILL}
+      NULL, HFILL}
      },
   };
 
