@@ -6,7 +6,7 @@
  * Extended by Jan Kiszka <jan.kiszka@web.de>
  * Copyright 2003 Jan Kiszka
  *
- * $Id: packet-irda.c 25259 2008-05-08 18:24:08Z etxrab $
+ * $Id: packet-irda.c 30995 2009-11-17 18:35:27Z dimeg $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -31,14 +31,12 @@
 # include "config.h"
 #endif
 
-#include <stdio.h>
-#include <stdlib.h>
 #include <string.h>
 
 #include <glib.h>
 #include <epan/packet.h>
-#include <epan/proto.h>
 #include <epan/conversation.h>
+#include <epan/emem.h>
 #include <epan/xdlc.h>
 
 #include "irda-appl.h"
@@ -140,6 +138,8 @@
 #define TTP_PARAMETERS         0x80
 #define TTP_MORE               0x80
 
+static dissector_handle_t data_handle;
+
 /* Initialize the protocol and registered fields */
 static int proto_irlap = -1;
 static int hf_lap_a = -1;
@@ -267,9 +267,6 @@ typedef struct lmp_conversation {
     dissector_t                 proto_dissector;
 } lmp_conversation_t;
 
-static GMemChunk* iap_conv_chunk = NULL;
-static GMemChunk* lmp_conv_chunk = NULL;
-
 static const true_false_string lap_cr_vals = {
     "Command",
     "Response"
@@ -467,8 +464,7 @@ static unsigned dissect_ttp(tvbuff_t* tvb, packet_info* pinfo, proto_tree* root,
         return 0;
 
     /* Make entries in Protocol column on summary display */
-    if (check_col(pinfo->cinfo, COL_PROTOCOL))
-        col_set_str(pinfo->cinfo, COL_PROTOCOL, "TTP");
+    col_set_str(pinfo->cinfo, COL_PROTOCOL, "TTP");
 
     head = tvb_get_guint8(tvb, offset);
 
@@ -528,8 +524,7 @@ static void dissect_iap_request(tvbuff_t* tvb, packet_info* pinfo, proto_tree* r
         return;
 
     /* Make entries in Protocol column on summary display */
-    if (check_col(pinfo->cinfo, COL_PROTOCOL))
-        col_set_str(pinfo->cinfo, COL_PROTOCOL, "IAP");
+    col_set_str(pinfo->cinfo, COL_PROTOCOL, "IAP");
 
     op = tvb_get_guint8(tvb, offset) & IAP_OP;
 
@@ -562,7 +557,7 @@ static void dissect_iap_request(tvbuff_t* tvb, packet_info* pinfo, proto_tree* r
                     }
                     if (iap_conv->pnext == NULL)
                     {
-                        iap_conv->pnext = g_mem_chunk_alloc(iap_conv_chunk);
+                        iap_conv->pnext = se_alloc(sizeof(iap_conversation_t));
                         iap_conv = iap_conv->pnext;
                         break;
                     }
@@ -572,7 +567,7 @@ static void dissect_iap_request(tvbuff_t* tvb, packet_info* pinfo, proto_tree* r
             else
             {
                 conv = conversation_new(pinfo->fd->num, &srcaddr, &destaddr, PT_NONE, pinfo->srcport, pinfo->destport, 0);
-                iap_conv = g_mem_chunk_alloc(iap_conv_chunk);
+                iap_conv = se_alloc(sizeof(iap_conversation_t));
                 conversation_add_proto_data(conv, proto_iap, (void*)iap_conv);
             }
 
@@ -662,7 +657,7 @@ static void dissect_iap_request(tvbuff_t* tvb, packet_info* pinfo, proto_tree* r
     }
 
     /* If any bytes remain, send it to the generic data dissector */
-    tvb = tvb_new_subset(tvb, offset, -1, -1);
+    tvb = tvb_new_subset_remaining(tvb, offset);
     call_dissector(data_handle, tvb, pinfo, root);
 }
 
@@ -694,8 +689,7 @@ static void dissect_iap_result(tvbuff_t* tvb, packet_info* pinfo, proto_tree* ro
         return;
 
     /* Make entries in Protocol column on summary display */
-    if (check_col(pinfo->cinfo, COL_PROTOCOL))
-        col_set_str(pinfo->cinfo, COL_PROTOCOL, "IAP");
+    col_set_str(pinfo->cinfo, COL_PROTOCOL, "IAP");
 
     op      = tvb_get_guint8(tvb, offset) & IAP_OP;
     retcode = tvb_get_guint8(tvb, offset + 1);
@@ -737,7 +731,7 @@ static void dissect_iap_result(tvbuff_t* tvb, packet_info* pinfo, proto_tree* ro
 
     if (check_col(pinfo->cinfo, COL_INFO))
     {
-        col_add_str(pinfo->cinfo, COL_INFO, "Result: ");
+        col_set_str(pinfo->cinfo, COL_INFO, "Result: ");
         col_append_str(pinfo->cinfo, COL_INFO, val_to_str(retcode, iap_return_vals, "0x%02X"));
 
         switch (op)
@@ -826,8 +820,7 @@ static void dissect_iap_result(tvbuff_t* tvb, packet_info* pinfo, proto_tree* ro
                         }
 
                         ti = proto_tree_add_item(tree, hf_iap_list_entry, tvb, offset, 2 + 1 + attr_len, FALSE);
-                        g_snprintf(buf, sizeof(buf) - 1, "%d", n + 1);
-                        proto_item_append_text(ti, buf);
+                        proto_item_append_text(ti, "%d", n + 1);
                         entry_tree = proto_item_add_subtree(ti, ett_iap_entry[n]);
 
                         proto_tree_add_item(entry_tree, hf_iap_obj_id, tvb, offset, 2, FALSE);
@@ -921,7 +914,7 @@ static void dissect_iap_result(tvbuff_t* tvb, packet_info* pinfo, proto_tree* ro
     }
 
     /* If any bytes remain, send it to the generic data dissector */
-    tvb = tvb_new_subset(tvb, offset, -1, -1);
+    tvb = tvb_new_subset_remaining(tvb, offset);
     call_dissector(data_handle, tvb, pinfo, root);
 }
 
@@ -1032,7 +1025,7 @@ static void dissect_appl_proto(tvbuff_t* tvb, packet_info* pinfo, proto_tree* ro
         {
             offset += dissect_ttp(tvb, pinfo, root, (pdu_type == DATA_PDU));
 
-            tvb = tvb_new_subset(tvb, offset, -1, -1);
+            tvb = tvb_new_subset_remaining(tvb, offset);
         }
 
         pinfo->private_data = (void *)pdu_type;
@@ -1057,8 +1050,7 @@ static void dissect_irlmp(tvbuff_t* tvb, packet_info* pinfo, proto_tree* root)
 
 
     /* Make entries in Protocol column on summary display */
-    if (check_col(pinfo->cinfo, COL_PROTOCOL))
-        col_set_str(pinfo->cinfo, COL_PROTOCOL, "IrLMP");
+    col_set_str(pinfo->cinfo, COL_PROTOCOL, "IrLMP");
 
     dlsap = tvb_get_guint8(tvb, offset);
     cbit  = dlsap & CONTROL_BIT;
@@ -1153,7 +1145,7 @@ static void dissect_irlmp(tvbuff_t* tvb, packet_info* pinfo, proto_tree* root)
             }
         }
 
-        tvb = tvb_new_subset(tvb, offset, -1, -1);
+        tvb = tvb_new_subset_remaining(tvb, offset);
         proto_item_set_len(tree, offset);
     }
     else
@@ -1182,7 +1174,7 @@ static void dissect_irlmp(tvbuff_t* tvb, packet_info* pinfo, proto_tree* root)
             }
         }
 
-        tvb = tvb_new_subset(tvb, offset, -1, -1);
+        tvb = tvb_new_subset_remaining(tvb, offset);
     }
 
     if (cbit == 0)
@@ -1251,7 +1243,7 @@ void add_lmp_conversation(packet_info* pinfo, guint8 dlsap, gboolean ttp, dissec
 
             if (lmp_conv->pnext == NULL)
             {
-                lmp_conv->pnext = g_mem_chunk_alloc(lmp_conv_chunk);
+                lmp_conv->pnext = se_alloc(sizeof(lmp_conversation_t));
                 lmp_conv = lmp_conv->pnext;
                 break;
             }
@@ -1261,7 +1253,7 @@ void add_lmp_conversation(packet_info* pinfo, guint8 dlsap, gboolean ttp, dissec
     else
     {
         conv = conversation_new(pinfo->fd->num, &destaddr, &srcaddr, PT_NONE, dlsap, 0, NO_PORT_B);
-        lmp_conv = g_mem_chunk_alloc(lmp_conv_chunk);
+        lmp_conv = se_alloc(sizeof(lmp_conversation_t));
         conversation_add_proto_data(conv, proto_irlmp, (void*)lmp_conv);
     }
 
@@ -1323,7 +1315,7 @@ static unsigned dissect_negotiation(tvbuff_t* tvb, proto_tree* tree, unsigned of
 
                     g_strlcat(buf, " bps)", 256);
 
-                    proto_item_append_text(ti, buf+2);
+                    proto_item_append_text(ti, "%s", buf+2);
 
                     break;
 
@@ -1341,7 +1333,7 @@ static unsigned dissect_negotiation(tvbuff_t* tvb, proto_tree* tree, unsigned of
 
                     g_strlcat(buf, " ms)", 256);
 
-                    proto_item_append_text(ti, buf+2);
+                    proto_item_append_text(ti, "%s", buf+2);
 
                     break;
 
@@ -1363,7 +1355,7 @@ static unsigned dissect_negotiation(tvbuff_t* tvb, proto_tree* tree, unsigned of
 
                     g_strlcat(buf, " bytes)", 256);
 
-                    proto_item_append_text(ti, buf+2);
+                    proto_item_append_text(ti, "%s", buf+2);
 
                     break;
 
@@ -1387,7 +1379,7 @@ static unsigned dissect_negotiation(tvbuff_t* tvb, proto_tree* tree, unsigned of
 
                     g_strlcat(buf, " frame window)", 256);
 
-                    proto_item_append_text(ti, buf+2);
+                    proto_item_append_text(ti, "%s", buf+2);
 
                     break;
 
@@ -1413,7 +1405,7 @@ static unsigned dissect_negotiation(tvbuff_t* tvb, proto_tree* tree, unsigned of
 
                     g_strlcat(buf, " additional BOFs at 115200)", 256);
 
-                    proto_item_append_text(ti, buf+2);
+                    proto_item_append_text(ti, "%s", buf+2);
 
                     break;
 
@@ -1439,7 +1431,7 @@ static unsigned dissect_negotiation(tvbuff_t* tvb, proto_tree* tree, unsigned of
 
                     g_strlcat(buf, " ms)", 256);
 
-                    proto_item_append_text(ti, buf+2);
+                    proto_item_append_text(ti, "%s", buf+2);
 
                     break;
 
@@ -1465,7 +1457,7 @@ static unsigned dissect_negotiation(tvbuff_t* tvb, proto_tree* tree, unsigned of
 
                     g_strlcat(buf, " s)", 256);
 
-                    proto_item_append_text(ti, buf+2);
+                    proto_item_append_text(ti, "%s", buf+2);
 
                     break;
 
@@ -1618,7 +1610,7 @@ static void dissect_xid(tvbuff_t* tvb, packet_info* pinfo, proto_tree* root, pro
                 service_hints[0] = ' ';
                 service_hints[1] = '(';
 
-                proto_item_append_text(ti, service_hints);
+                proto_item_append_text(ti, "%s", service_hints);
             }
         }
         offset += hints_len;
@@ -1671,15 +1663,12 @@ static void dissect_xid(tvbuff_t* tvb, packet_info* pinfo, proto_tree* root, pro
 static void dissect_log(tvbuff_t* tvb, packet_info* pinfo, proto_tree* root)
 {
     /* Make entries in Protocol column on summary display */
-    if (check_col(pinfo->cinfo, COL_PROTOCOL))
-        col_set_str(pinfo->cinfo, COL_PROTOCOL, "Log");
+    col_set_str(pinfo->cinfo, COL_PROTOCOL, "Log");
 
     /* missed messages? */
     if (pinfo->pseudo_header->irda.pkttype == IRDA_MISSED_MSG)
     {
-        if (check_col(pinfo->cinfo, COL_INFO))
-            col_set_str(pinfo->cinfo, COL_INFO,
-                "WARNING: Missed one or more messages while capturing!");
+        col_set_str(pinfo->cinfo, COL_INFO, "WARNING: Missed one or more messages while capturing!");
     }
     else if (check_col(pinfo->cinfo, COL_INFO))
     {
@@ -1729,12 +1718,10 @@ static void dissect_irlap(tvbuff_t* tvb, packet_info* pinfo, proto_tree* root)
     guint8   ca;
 
     /* Make entries in Protocol column on summary display */
-    if (check_col(pinfo->cinfo, COL_PROTOCOL))
-        col_set_str(pinfo->cinfo, COL_PROTOCOL, "IrLAP");
+    col_set_str(pinfo->cinfo, COL_PROTOCOL, "IrLAP");
 
     /* Clear Info column */
-    if (check_col(pinfo->cinfo, COL_INFO))
-        col_clear(pinfo->cinfo, COL_INFO);
+    col_clear(pinfo->cinfo, COL_INFO);
 
     /* set direction column */
     if (check_col(pinfo->cinfo, COL_IF_DIR))
@@ -1800,7 +1787,7 @@ static void dissect_irlap(tvbuff_t* tvb, packet_info* pinfo, proto_tree* root)
     if ((c & XDLC_I_MASK) == XDLC_I) {
         /* I frame */
         proto_item_set_len(tree, offset);
-        tvb = tvb_new_subset(tvb, offset, -1, -1);
+        tvb = tvb_new_subset_remaining(tvb, offset);
         dissect_irlmp(tvb, pinfo, root);
         return;
     }
@@ -1853,7 +1840,7 @@ static void dissect_irlap(tvbuff_t* tvb, packet_info* pinfo, proto_tree* root)
                 break;
 
             case IRDA_XID_CMD:
-                tvb = tvb_new_subset(tvb, offset, -1, -1);
+                tvb = tvb_new_subset_remaining(tvb, offset);
                 dissect_xid(tvb, pinfo, root, tree, TRUE);
                 return;
 
@@ -1887,7 +1874,7 @@ static void dissect_irlap(tvbuff_t* tvb, packet_info* pinfo, proto_tree* root)
                 break;
 
             case XDLC_XID:
-                tvb = tvb_new_subset(tvb, offset, -1, -1);
+                tvb = tvb_new_subset_remaining(tvb, offset);
                 dissect_xid(tvb, pinfo, root, tree, FALSE);
                 return;
          }
@@ -1896,7 +1883,7 @@ static void dissect_irlap(tvbuff_t* tvb, packet_info* pinfo, proto_tree* root)
     /* If any bytes remain, send it to the generic data dissector */
     if (tvb_reported_length_remaining(tvb, offset) > 0)
     {
-        tvb = tvb_new_subset(tvb, offset, -1, -1);
+        tvb = tvb_new_subset_remaining(tvb, offset);
         call_dissector(data_handle, tvb, pinfo, root);
     }
 }
@@ -1922,23 +1909,6 @@ static void dissect_irda(tvbuff_t* tvb, packet_info* pinfo, proto_tree* root)
 }
 
 
-/*
- * Re-initialize the IrDA dissector
- */
-static void init_irda(void)
-{
-    if (iap_conv_chunk)
-        g_mem_chunk_destroy(iap_conv_chunk);
-    if (lmp_conv_chunk)
-        g_mem_chunk_destroy(lmp_conv_chunk);
-
-    iap_conv_chunk = g_mem_chunk_new("iap_conversation", sizeof(iap_conversation_t),
-                                     10 * sizeof(iap_conversation_t), G_ALLOC_AND_FREE);
-    lmp_conv_chunk = g_mem_chunk_new("lmp_conversation", sizeof(lmp_conversation_t),
-                                     10 * sizeof(lmp_conversation_t), G_ALLOC_AND_FREE);
-}
-
-
 /*
  * Register the protocol with Wireshark
  * This format is required because a script is used to build the C function
@@ -1953,295 +1923,295 @@ void proto_register_irda(void)
         { &hf_lap_a,
             { "Address Field", "irlap.a",
                 FT_UINT8, BASE_HEX, NULL, 0,
-                "", HFILL }},
+                NULL, HFILL }},
         { &hf_lap_a_cr,
             { "C/R", "irlap.a.cr",
                 FT_BOOLEAN, 8, TFS(&lap_cr_vals), CMD_FRAME,
-                "", HFILL }},
+                NULL, HFILL }},
         { &hf_lap_a_address,
             { "Address", "irlap.a.address",
                 FT_UINT8, BASE_HEX, NULL, ~CMD_FRAME,
-                "", HFILL }},
+                NULL, HFILL }},
         { &hf_lap_c,
             { "Control Field", "irlap.c",
                 FT_UINT8, BASE_HEX, NULL, 0,
-                "", HFILL }},
+                NULL, HFILL }},
         { &hf_lap_c_nr,
             { "N(R)", "irlap.c.n_r",
                 FT_UINT8, BASE_DEC, NULL, XDLC_N_R_MASK,
-                "", HFILL }},
+                NULL, HFILL }},
         { &hf_lap_c_ns,
             { "N(S)", "irlap.c.n_s",
                 FT_UINT8, BASE_DEC, NULL, XDLC_N_S_MASK,
-                "", HFILL }},
+                NULL, HFILL }},
         { &hf_lap_c_p,
             { "Poll", "irlap.c.p",
                 FT_BOOLEAN, 8, TFS(&set_notset), XDLC_P_F,
-                "", HFILL }},
+                NULL, HFILL }},
         { &hf_lap_c_f,
             { "Final", "irlap.c.f",
                 FT_BOOLEAN, 8, TFS(&set_notset), XDLC_P_F,
-                "", HFILL }},
+                NULL, HFILL }},
         { &hf_lap_c_s,
             { "Supervisory frame type", "irlap.c.s_ftype",
                 FT_UINT8, BASE_HEX, VALS(lap_c_s_vals), XDLC_S_FTYPE_MASK,
-                "", HFILL }},
+                NULL, HFILL }},
         { &hf_lap_c_u_cmd,
             { "Command", "irlap.c.u_modifier_cmd",
                 FT_UINT8, BASE_HEX, VALS(lap_c_u_cmd_vals), XDLC_U_MODIFIER_MASK,
-                "", HFILL }},
+                NULL, HFILL }},
         { &hf_lap_c_u_rsp,
             { "Response", "irlap.c.u_modifier_resp",
                 FT_UINT8, BASE_HEX, VALS(lap_c_u_rsp_vals), XDLC_U_MODIFIER_MASK,
-                "", HFILL }},
+                NULL, HFILL }},
         { &hf_lap_c_i,
             { "Frame Type", "irlap.c.ftype",
                 FT_UINT8, BASE_HEX, VALS(lap_c_ftype_vals), XDLC_I_MASK,
-                "", HFILL }},
+                NULL, HFILL }},
         { &hf_lap_c_s_u,
             { "Frame Type", "irlap.c.ftype",
                 FT_UINT8, BASE_HEX, VALS(lap_c_ftype_vals), XDLC_S_U_MASK,
-                "", HFILL }},
+                NULL, HFILL }},
         { &hf_lap_i,
             { "Information Field", "irlap.i",
                 FT_NONE, BASE_NONE, NULL, 0,
-                "", HFILL }},
+                NULL, HFILL }},
         { &hf_snrm_saddr,
             { "Source Device Address", "irlap.snrm.saddr",
                 FT_UINT32, BASE_HEX, NULL, 0,
-                "", HFILL }},
+                NULL, HFILL }},
         { &hf_snrm_daddr,
             { "Destination Device Address", "irlap.snrm.daddr",
                 FT_UINT32, BASE_HEX, NULL, 0,
-                "", HFILL }},
+                NULL, HFILL }},
         { &hf_snrm_ca,
             { "Connection Address", "irlap.snrm.ca",
                 FT_UINT8, BASE_HEX, NULL, 0,
-                "", HFILL }},
+                NULL, HFILL }},
         { &hf_negotiation_param,
             { "Negotiation Parameter", "irlap.negotiation",
                 FT_NONE, BASE_NONE, NULL, 0,
-                "", HFILL }},
+                NULL, HFILL }},
         { &hf_param_pi,
             { "Parameter Identifier", "irlap.pi",
                 FT_UINT8, BASE_HEX, NULL, 0,
-                "", HFILL }},
+                NULL, HFILL }},
         { &hf_param_pl,
             { "Parameter Length", "irlap.pl",
                 FT_UINT8, BASE_HEX, NULL, 0,
-                "", HFILL }},
+                NULL, HFILL }},
         { &hf_param_pv,
             { "Parameter Value", "irlap.pv",
-                FT_BYTES, BASE_HEX, NULL, 0,
-                "", HFILL }},
+                FT_BYTES, BASE_NONE, NULL, 0,
+                NULL, HFILL }},
         { &hf_ua_saddr,
             { "Source Device Address", "irlap.ua.saddr",
                 FT_UINT32, BASE_HEX, NULL, 0,
-                "", HFILL }},
+                NULL, HFILL }},
         { &hf_ua_daddr,
             { "Destination Device Address", "irlap.ua.daddr",
                 FT_UINT32, BASE_HEX, NULL, 0,
-                "", HFILL }},
+                NULL, HFILL }},
         { &hf_xid_ident,
             { "Format Identifier", "irlap.xid.fi",
                 FT_UINT8, BASE_HEX, NULL, 0,
-                "", HFILL }},
+                NULL, HFILL }},
         { &hf_xid_saddr,
             { "Source Device Address", "irlap.xid.saddr",
                 FT_UINT32, BASE_HEX, NULL, 0,
-                "", HFILL }},
+                NULL, HFILL }},
         { &hf_xid_daddr,
             { "Destination Device Address", "irlap.xid.daddr",
                 FT_UINT32, BASE_HEX, NULL, 0,
-                "", HFILL }},
+                NULL, HFILL }},
         { &hf_xid_flags,
             { "Discovery Flags", "irlap.xid.flags",
                 FT_UINT8, BASE_HEX, NULL, 0,
-                "", HFILL }},
+                NULL, HFILL }},
         { &hf_xid_s,
             { "Number of Slots", "irlap.xid.s",
-                FT_UINT8, BASE_DEC, VALS(&xid_slot_numbers), S_MASK,
-                "", HFILL }},
+                FT_UINT8, BASE_DEC, VALS(xid_slot_numbers), S_MASK,
+                NULL, HFILL }},
         { &hf_xid_conflict,
             { "Conflict", "irlap.xid.conflict",
                 FT_BOOLEAN, 8, TFS(&set_notset), CONFLICT,
-                "", HFILL }},
+                NULL, HFILL }},
         { &hf_xid_slotnr,
             { "Slot Number", "irlap.xid.slotnr",
                 FT_UINT8, BASE_DEC, NULL, 0,
-                "", HFILL }},
+                NULL, HFILL }},
         { &hf_xid_version,
             { "Version Number", "irlap.xid.version",
                 FT_UINT8, BASE_HEX, NULL, 0,
-                "", HFILL }}
+                NULL, HFILL }}
     };
 
     static hf_register_info hf_log[] = {
         { &hf_log_msg,
             { "Message", "log.msg",
                 FT_STRING, BASE_NONE, NULL, 0,
-                "", HFILL }},
+                NULL, HFILL }},
         { &hf_log_missed,
             { "WARNING: Missed one or more messages while capturing!", "log.missed",
                 FT_NONE, BASE_NONE, NULL, 0,
-                "", HFILL }}
+                NULL, HFILL }}
     };
 
     static hf_register_info hf_lmp[] = {
         { &hf_lmp_xid_hints,
             { "Service Hints", "irlmp.xid.hints",
-                FT_BYTES, BASE_HEX, NULL, 0,
-                "", HFILL }},
+                FT_BYTES, BASE_NONE, NULL, 0,
+                NULL, HFILL }},
         { &hf_lmp_xid_charset,
             { "Character Set", "irlmp.xid.charset",
                 FT_UINT8, BASE_HEX, NULL, 0,
-                "", HFILL }},
+                NULL, HFILL }},
         { &hf_lmp_xid_name,
             { "Device Nickname", "irlmp.xid.name",
                 FT_STRING, BASE_NONE, NULL, 0,
-                "", HFILL }},
+                NULL, HFILL }},
         { &hf_lmp_xid_name_no_ascii,
             { "Device Nickname (unsupported character set)", "irlmp.xid.name",
                 FT_BYTES, BASE_NONE, NULL, 0,
-                "", HFILL }},
+                NULL, HFILL }},
         { &hf_lmp_dst,
             { "Destination", "irlmp.dst",
                 FT_UINT8, BASE_HEX, NULL, 0,
-                "", HFILL }},
+                NULL, HFILL }},
         { &hf_lmp_dst_control,
             { "Control Bit", "irlmp.dst.c",
                 FT_BOOLEAN, 8, TFS(&set_notset), CONTROL_BIT,
-                "", HFILL }},
+                NULL, HFILL }},
         { &hf_lmp_dst_lsap,
             { "Destination LSAP", "irlmp.dst.lsap",
                 FT_UINT8, BASE_DEC, NULL, ~CONTROL_BIT,
-                "", HFILL }},
+                NULL, HFILL }},
         { &hf_lmp_src,
             { "Source", "irlmp.src",
                 FT_UINT8, BASE_HEX, NULL, 0,
-                "", HFILL }},
+                NULL, HFILL }},
         { &hf_lmp_src_r,
             { "reserved", "irlmp.src.r",
                 FT_UINT8, BASE_DEC, NULL, RESERVED_BIT,
-                "", HFILL }},
+                NULL, HFILL }},
         { &hf_lmp_src_lsap,
             { "Source LSAP", "irlmp.src.lsap",
                 FT_UINT8, BASE_DEC, NULL, ~RESERVED_BIT,
-                "", HFILL }},
+                NULL, HFILL }},
         { &hf_lmp_opcode,
             { "Opcode", "irlmp.opcode",
                 FT_UINT8, BASE_HEX, VALS(lmp_opcode_vals), 0x0,
-                "", HFILL }},
+                NULL, HFILL }},
         { &hf_lmp_rsvd,
             { "Reserved", "irlmp.rsvd",
                 FT_UINT8, BASE_HEX, NULL, 0x0,
-                "", HFILL }},
+                NULL, HFILL }},
         { &hf_lmp_reason,
             { "Reason", "irlmp.reason",
                 FT_UINT8, BASE_HEX, VALS(lmp_reason_vals), 0x0,
-                "", HFILL }},
+                NULL, HFILL }},
         { &hf_lmp_mode,
             { "Mode", "irlmp.mode",
                 FT_UINT8, BASE_HEX, VALS(lmp_mode_vals), 0x0,
-                "", HFILL }},
+                NULL, HFILL }},
         { &hf_lmp_status,
             { "Status", "irlmp.status",
                 FT_UINT8, BASE_HEX, VALS(lmp_status_vals), 0x0,
-                "", HFILL }}
+                NULL, HFILL }}
     };
 
     static hf_register_info hf_iap[] = {
         { &hf_iap_ctl,
             { "Control Field", "iap.ctl",
                 FT_UINT8, BASE_HEX, NULL, 0,
-                "", HFILL }},
+                NULL, HFILL }},
         { &hf_iap_ctl_lst,
             { "Last Frame", "iap.ctl.lst",
                 FT_BOOLEAN, 8, TFS(&set_notset), IAP_LST,
-                "", HFILL }},
+                NULL, HFILL }},
         { &hf_iap_ctl_ack,
             { "Acknowledge", "iap.ctl.ack",
                 FT_BOOLEAN, 8, TFS(&set_notset), IAP_ACK,
-                "", HFILL }},
+                NULL, HFILL }},
         { &hf_iap_ctl_opcode,
             { "Opcode", "iap.ctl.opcode",
                 FT_UINT8, BASE_HEX, VALS(iap_opcode_vals), IAP_OP,
-                "", HFILL }},
+                NULL, HFILL }},
         { &hf_iap_class_name,
             { "Class Name", "iap.classname",
                 FT_UINT_STRING, BASE_NONE, NULL, 0x0,
-                "", HFILL }},
+                NULL, HFILL }},
         { &hf_iap_attr_name,
             { "Attribute Name", "iap.attrname",
                 FT_UINT_STRING, BASE_NONE, NULL, 0x0,
-                "", HFILL }},
+                NULL, HFILL }},
         { &hf_iap_return,
             { "Return", "iap.return",
                 FT_UINT8, BASE_HEX, VALS(iap_return_vals), 0x0,
-                "", HFILL }},
+                NULL, HFILL }},
         { &hf_iap_list_len,
             { "List Length", "iap.listlen",
                 FT_UINT16, BASE_DEC, NULL, 0x0,
-                "", HFILL }},
+                NULL, HFILL }},
         { &hf_iap_list_entry,
-            { "List Entry ", "iap.listentry",
+            { "List Entry", "iap.listentry",
                 FT_NONE, BASE_NONE, NULL, 0x0,
-                "", HFILL }},
+                NULL, HFILL }},
         { &hf_iap_obj_id,
             { "Object Identifier", "iap.objectid",
                 FT_UINT16, BASE_HEX, NULL, 0x0,
-                "", HFILL }},
+                NULL, HFILL }},
         { &hf_iap_attr_type,
             { "Type", "iap.attrtype",
                 FT_UINT8, BASE_DEC, VALS(iap_attr_type_vals), 0x0,
-                "", HFILL }},
+                NULL, HFILL }},
         { &hf_iap_int,
             { "Value", "iap.int",
                 FT_INT32, BASE_DEC, NULL, 0x0,
-                "", HFILL }},
+                NULL, HFILL }},
         { &hf_iap_seq_len,
             { "Sequence Length", "iap.seqlen",
                 FT_UINT16, BASE_DEC, NULL, 0x0,
-                "", HFILL }},
+                NULL, HFILL }},
         { &hf_iap_oct_seq,
             { "Sequence", "iap.octseq",
-                FT_BYTES, BASE_HEX, NULL, 0x0,
-                "", HFILL }},
+                FT_BYTES, BASE_NONE, NULL, 0x0,
+                NULL, HFILL }},
         { &hf_iap_char_set,
             { "Character Set", "iap.charset",
                 FT_UINT8, BASE_HEX, NULL, 0x0,
-                "", HFILL }},
+                NULL, HFILL }},
         { &hf_iap_string,
             { "String", "iap.string",
                 FT_UINT_STRING, BASE_NONE, NULL, 0x0,
-                "", HFILL }},
+                NULL, HFILL }},
         { &hf_iap_invaloctet,
-            { "Mailformed IAP result: \"", "iap.invaloctet",
+            { "Malformed IAP result: \"", "iap.invaloctet",
                 FT_NONE, BASE_NONE, NULL, 0,
-                "", HFILL }},
+                NULL, HFILL }},
         { &hf_iap_invallsap,
-            { "Mailformed IAP result: \"", "iap.invallsap",
+            { "Malformed IAP result: \"", "iap.invallsap",
                 FT_NONE, BASE_NONE, NULL, 0,
-                "", HFILL }}
+                NULL, HFILL }}
     };
 
     static hf_register_info hf_ttp[] = {
         { &hf_ttp_p,
             { "Parameter Bit", "ttp.p",
                 FT_BOOLEAN, 8, TFS(&set_notset), TTP_PARAMETERS,
-                "", HFILL }},
+                NULL, HFILL }},
         { &hf_ttp_icredit,
             { "Initial Credit", "ttp.icredit",
                 FT_UINT8, BASE_DEC, NULL, ~TTP_PARAMETERS,
-                "", HFILL }},
+                NULL, HFILL }},
         { &hf_ttp_m,
             { "More Bit", "ttp.m",
                 FT_BOOLEAN, 8, TFS(&set_notset), TTP_MORE,
-                "", HFILL }},
+                NULL, HFILL }},
         { &hf_ttp_dcredit,
             { "Delta Credit", "ttp.dcredit",
                 FT_UINT8, BASE_DEC, NULL, ~TTP_MORE,
-                "", HFILL }}
+                NULL, HFILL }}
     };
 
     /* Setup protocol subtree arrays */
@@ -2260,13 +2230,10 @@ void proto_register_irda(void)
         &ett_ttp
     };
 
-    static gint* ett_p[MAX_PARAMETERS];
-    static gint* ett_iap_e[MAX_IAP_ENTRIES];
+    gint* ett_p[MAX_PARAMETERS];
+    gint* ett_iap_e[MAX_IAP_ENTRIES];
 
 
-    /* Register re-init routine */
-    register_init_routine(init_irda);
-
     /* Register protocol names and descriptions */
     proto_irlap = proto_register_protocol("IrDA Link Access Protocol", "IrLAP", "irlap");
     proto_log   = proto_register_protocol("Log Message", "Log", "log");
