@@ -2,7 +2,7 @@
  * Routines for PN-MRRT (PROFINET Media Redundancy for cyclic realtime data) 
  * packet dissection.
  *
- * $Id: packet-pn-mrrt.c 20825 2007-02-16 21:53:36Z ulfl $
+ * $Id: packet-pn-mrrt.c 30127 2009-09-24 20:21:23Z krj $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -81,8 +81,7 @@ dissect_PNMRRT_Common(tvbuff_t *tvb, int offset,
     /* MRRT_DomainUUID */
     offset = dissect_pn_uuid(tvb, offset, pinfo, tree, hf_pn_mrrt_domain_uuid, &uuid);
 
-    if (check_col(pinfo->cinfo, COL_INFO))
-      col_append_fstr(pinfo->cinfo, COL_INFO, "Common");
+    col_append_str(pinfo->cinfo, COL_INFO, "Common");
 
     proto_item_append_text(item, "Common");
 
@@ -103,8 +102,7 @@ dissect_PNMRRT_Test(tvbuff_t *tvb, int offset,
     /* Padding */
     offset = dissect_pn_align4(tvb, offset, pinfo, tree);
 
-    if (check_col(pinfo->cinfo, COL_INFO))
-      col_append_fstr(pinfo->cinfo, COL_INFO, "Test");
+    col_append_str(pinfo->cinfo, COL_INFO, "Test");
 
     proto_item_append_text(item, "Test");
 
@@ -133,8 +131,7 @@ dissect_PNMRRT_PDU(tvbuff_t *tvb, int offset,
 
 
         if(i != 0) {
-            if (check_col(pinfo->cinfo, COL_INFO))
-              col_append_fstr(pinfo->cinfo, COL_INFO, ", ");
+            col_append_str(pinfo->cinfo, COL_INFO, ", ");
 
             proto_item_append_text(item, ", ");
         }
@@ -144,8 +141,7 @@ dissect_PNMRRT_PDU(tvbuff_t *tvb, int offset,
         switch(type) {
         case(0x00):
             /* no content */
-            if (check_col(pinfo->cinfo, COL_INFO))
-              col_append_fstr(pinfo->cinfo, COL_INFO, "End");
+            col_append_str(pinfo->cinfo, COL_INFO, "End");
             proto_item_append_text(item, "End");
             return offset;
             break;
@@ -190,7 +186,7 @@ dissect_PNMRRT_Data_heur(tvbuff_t *tvb,
     }
 
 	if (check_col(pinfo->cinfo, COL_PROTOCOL))
-	    col_add_str(pinfo->cinfo, COL_PROTOCOL, "PN-MRRT");
+	    col_set_str(pinfo->cinfo, COL_PROTOCOL, "PN-MRRT");
     if (check_col(pinfo->cinfo, COL_INFO))
       col_add_str(pinfo->cinfo, COL_INFO, "");
 
@@ -213,17 +209,17 @@ proto_register_pn_mrrt (void)
 	static hf_register_info hf[] = {
 
 	{ &hf_pn_mrrt_type,
-		{ "Type", "pn_mrrt.type", FT_UINT8, BASE_HEX, VALS(pn_mrrt_block_type_vals), 0x0, "", HFILL }},
+		{ "Type", "pn_mrrt.type", FT_UINT8, BASE_HEX, VALS(pn_mrrt_block_type_vals), 0x0, NULL, HFILL }},
 	{ &hf_pn_mrrt_length,
-		{ "Length", "pn_mrrt.length", FT_UINT8, BASE_DEC, NULL, 0x0, "", HFILL }},
+		{ "Length", "pn_mrrt.length", FT_UINT8, BASE_DEC, NULL, 0x0, NULL, HFILL }},
 	{ &hf_pn_mrrt_version,
-		{ "Version", "pn_mrrt.version", FT_UINT16, BASE_DEC, NULL, 0x0, "", HFILL }},
+		{ "Version", "pn_mrrt.version", FT_UINT16, BASE_DEC, NULL, 0x0, NULL, HFILL }},
 	{ &hf_pn_mrrt_sequence_id,
 		{ "SequenceID", "pn_mrrt.sequence_id", FT_UINT16, BASE_HEX, NULL, 0x0, "Unique sequence number to each outstanding service request", HFILL }},
 	{ &hf_pn_mrrt_sa,
-        { "SA", "pn_mrrt.sa", FT_ETHER, BASE_HEX, 0x0, 0x0, "", HFILL }},
+        { "SA", "pn_mrrt.sa", FT_ETHER, BASE_NONE, 0x0, 0x0, NULL, HFILL }},
 	{ &hf_pn_mrrt_domain_uuid,
-		{ "DomainUUID", "pn_mrrt.domain_uuid", FT_GUID, BASE_NONE, NULL, 0x0, "", HFILL }},
+		{ "DomainUUID", "pn_mrrt.domain_uuid", FT_GUID, BASE_NONE, NULL, 0x0, NULL, HFILL }},
     };
 
 
