@@ -5,7 +5,7 @@
  *
  * Author: Lu Pan <lu.pan@intel.com>
  *
- * $Id: mac_hd_generic_decoder.c 29296 2009-08-04 19:01:34Z wmeier $
+ * $Id: mac_hd_generic_decoder.c 30309 2009-10-04 17:21:45Z krj $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -47,12 +47,12 @@
 #include <epan/address.h>
 #include <epan/reassemble.h>
 #include "crc.h"
+#include "wimax_utils.h"
 
 extern gint proto_wimax;
 
 extern gint seen_a_service_type;
 extern gboolean first_gmh;			/* defined in wimax_pdu_decoder.c */
-guint get_service_type( void ); 		/* defined in wimax_utils.c */
 
 extern gint8 arq_enabled;                       /* declared in packet-wmx.c */
 extern gint  scheduling_service_type;           /* declared in packet-wmx.c */
@@ -1252,7 +1252,7 @@ check_crc:
 			{	/* get the CRC */
 				mac_crc = tvb_get_ntohl(tvb, mac_len - sizeof(mac_crc));
 				/* calculate the CRC */
-        	                calculated_crc = wimax_mac_calc_crc32((guint8 *)tvb_get_ptr(tvb, 0, mac_len - sizeof(mac_crc)), mac_len - sizeof(mac_crc));
+        	    calculated_crc = wimax_mac_calc_crc32(tvb_get_ptr(tvb, 0, mac_len - sizeof(mac_crc)), mac_len - sizeof(mac_crc));
 				/* display the CRC */
 				generic_item = proto_tree_add_item(tree, hf_mac_header_generic_crc, tvb, mac_len - sizeof(mac_crc), sizeof(mac_crc), FALSE);
 				if (mac_crc != calculated_crc)
