@@ -5,7 +5,7 @@
  *
  * Author: John R. Underwood <junderx@yahoo.com>
  *
- * $Id: msg_rng_req.c 26103 2008-08-29 01:40:32Z wmeier $
+ * $Id: msg_rng_req.c 29296 2009-08-04 19:01:34Z wmeier $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -32,8 +32,6 @@
 #include "config.h"
 #endif
 
-#include "moduleinfo.h"
-
 #include <glib.h>
 #include <epan/packet.h>
 #include "crc.h"
@@ -46,18 +44,9 @@ extern gboolean include_cor2_changes;
 
 extern gint man_ofdma;
 
-/* Forward reference */
-void dissect_mac_mgmt_msg_rng_req_decoder(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree);
-
 gint proto_mac_mgmt_msg_rng_req_decoder = -1;
 static gint ett_mac_mgmt_msg_rng_req_decoder = -1;
 
-/* Setup protocol subtree array */
-static gint *ett[] =
-{
-	&ett_mac_mgmt_msg_rng_req_decoder,
-};
-
 /* RNG-REQ fields */
 static gint hf_rng_req_message_type                          = -1;
 static gint hf_rng_req_reserved                              = -1;
@@ -134,249 +123,6 @@ static const true_false_string tfs_rng_timing_adj = {
     "Sum of commanded timing adjustments is within bounds"
 };
 
-/* RNG-REQ fields display */
-static hf_register_info hf[] =
-{
-	{
-		&hf_rng_activation_of_power_saving_class,
-		{
-			"Activation of Power Saving Class (Types 1 and 2 only)", "wmx.rng.power_save.activate",
-			FT_BOOLEAN, 8, TFS(&tfs_rng_activate), 0x02, "", HFILL
-		}
-	},
-	{
-		&hf_rng_power_saving_class_id,
-		{
-			"Power Saving Class ID", "wmx.rng.power_save.class_id",
-			FT_UINT8, BASE_DEC, NULL, 0x0, "", HFILL
-		}
-	},
-	{
-		&hf_rng_power_saving_class_type,
-		{
-			"Power Saving Class Type", "wmx.rng.power_save.class_type",
-			FT_UINT8, BASE_DEC, NULL, 0x0, "", HFILL
-		}
-	},
-	{
-		&hf_rng_definition_of_power_saving_class_present,
-		{
-			"Definition of Power Saving Class present", "wmx.rng.power_save.definition_present",
-			FT_UINT8, BASE_DEC, NULL, 0x01, "", HFILL
-		}
-	},
-	{
-		&hf_rng_power_saving_final_sleep_window_base,
-		{
-			"Final-sleep window base (measured in frames)", "wmx.rng.power_save.final_sleep_window_base",
-			FT_UINT8, BASE_DEC, NULL, 0x0, "", HFILL
-		}
-	},
-	{
-		&hf_rng_power_saving_final_sleep_window_exp,
-		{
-			"Final-sleep window exponent (measured in frames)", "wmx.rng.power_save.final_sleep_window_exp",
-			FT_UINT8, BASE_DEC, NULL, 0x0, "", HFILL
-		}
-	},
-	{
-		&hf_rng_power_saving_first_sleep_window_frame,
-		{
-			"Start frame number for first sleep window", "wmx.rng.power_save.first_sleep_window_frame",
-			FT_UINT8, BASE_DEC, NULL, 0x0, "", HFILL
-		}
-	},
-	{
-		&hf_rng_power_saving_included_cid,
-		{
-			"CID of connection to be included into the Power Saving Class.", "wmx.rng.power_save.included_cid",
-			FT_UINT16, BASE_DEC, NULL, 0x0, "", HFILL
-		}
-	},
-	{
-		&hf_rng_power_saving_initial_sleep_window,
-		{
-			"Initial-sleep window", "wmx.rng.power_save.initial_sleep_window",
-			FT_UINT8, BASE_DEC, NULL, 0x0, "", HFILL
-		}
-	},
-	{
-		&hf_rng_power_saving_listening_window,
-		{
-			"Listening window duration (measured in frames)", "wmx.rng.power_save.listening_window",
-			FT_UINT8, BASE_DEC, NULL, 0x0, "", HFILL
-		}
-	},
-	{
-		&hf_rng_power_saving_mgmt_connection_direction,
-		{
-			"Direction for management connection added to Power Saving Class", "wmx.rng.power_save.mgmt_connection_direction",
-			FT_UINT8, BASE_DEC, NULL, 0x0, "", HFILL
-		}
-	},
-	{
-		&hf_rng_power_saving_class_reserved,
-		{
-			"Reserved", "wmx.rng.power_save.reserved",
-			FT_UINT8, BASE_DEC, NULL, 0xF8, "", HFILL
-		}
-	},
-	{
-		&hf_rng_power_saving_slpid,
-		{
-			"SLPID assigned by the BS whenever an MS is instructed to enter sleep mode", "wmx.rng.power_save.slpid",
-			FT_UINT8, BASE_DEC, NULL, 0x0, "", HFILL
-		}
-	},
-	{
-		&hf_rng_trf_ind_required,
-		{
-			"BS shall transmit at least one TRF-IND message during each listening window of the Power Saving Class", "wmx.rng.power_save.trf_ind_required",
-			FT_BOOLEAN, 8, TFS(&tfs_rng_activate), 0x04, "", HFILL
-		}
-	},
-	{
-		&hf_rng_req_message_type,
-		{
-			"MAC Management Message Type", "wmx.macmgtmsgtype.rng_req",
-			FT_UINT8, BASE_DEC, NULL, 0x0, "", HFILL
-		}
-	},
-	{
-		&hf_rng_req_aas_broadcast,
-		{
-			"AAS broadcast capability", "wmx.rng_req.aas_broadcast",
-			FT_BOOLEAN, 8, TFS(&tfs_rng_req_aas_broadcast), 0x00, "", HFILL
-		}
-	},
-	{
-		&hf_rng_req_ranging_anomalies_max_power,
-		{
-			"Meaning", "wmx.rng_req.anomalies.max_power",
-			FT_BOOLEAN, 8, TFS(&tfs_rng_max_power), 0x04, "", HFILL
-		}
-	},
-	{
-		&hf_rng_req_ranging_anomalies_min_power,
-		{
-			"Meaning", "wmx.rng_req.anomalies.min_power",
-			FT_BOOLEAN, 8, TFS(&tfs_rng_min_power), 0x02, "", HFILL
-		}
-	},
-	{
-		&hf_rng_req_ranging_anomalies_timing_adj,
-		{
-			"Meaning", "wmx.rng_req.anomalies.timing_adj",
-			FT_BOOLEAN, 8, TFS(&tfs_rng_timing_adj), 0x01, "", HFILL
-		}
-	},
-	{
-		&hf_rng_req_cmac_key_count,
-		{
-			"CMAC Key Count", "wmx.rng_req.cmac_key_count",
-			FT_UINT16, BASE_DEC, NULL, 0x00, "", HFILL
-		}
-	},
-	{
-		&hf_rng_req_dl_burst_profile_lsb_ccc,
-		{
-			"LSB of CCC of DCD associated with DIUC", "wmx.rng_req.dl_burst_profile.ccc",
-			FT_UINT8, BASE_DEC, NULL, 0xF0, "", HFILL
-		}
-	},
-	{
-		&hf_rng_req_dl_burst_profile_diuc,
-		{
-			"DIUC", "wmx.rng_req.dl_burst_profile.diuc",
-			FT_UINT8, BASE_DEC, NULL, 0x0F, "", HFILL
-		}
-	},
-	{
-		&hf_tlv_type,
-		{
-			"Unknown TLV Type", "wmx.rng_req.unknown_tlv_type",
-			FT_BYTES, BASE_HEX, NULL, 0, "", HFILL
-		}
-	},
-	{
-		&hf_rng_invalid_tlv,
-		{
-			"Invalid TLV", "wmx.rng_req.invalid_tlv",
-			FT_BYTES, BASE_HEX, NULL, 0, "", HFILL
-		}
-	},
-	{
-		&hf_rng_req_ho_id,
-		{
-			"ID from the target BS for use in initial ranging during MS handover to it", "wmx.rng_req.ho_id",
-			FT_UINT8, BASE_DEC, NULL, 0x0, "", HFILL
-		}
-	},
-	{
-		&hf_rng_req_power_down_indicator,
-		{
-			"Power down Indicator", "wmx.rng_req.power_down_indicator",
-			FT_UINT8, BASE_DEC, NULL, 0x00, "", HFILL
-		}
-	},
-	{
-		&hf_rng_req_ranging_purpose_ho_indication,
-		{
-			"MS HO indication", "wmx.rng_req.ranging_purpose.ho_indication",
-			FT_UINT8, BASE_DEC, NULL, 0x01, "", HFILL
-		}
-	},
-	{
-		&hf_rng_req_ranging_purpose_reserved,
-		{
-			"Reserved", "wmx.rng_req.ranging_purpose.reserved",
-			FT_UINT8, BASE_DEC, NULL, 0xFC, "", HFILL
-		}
-	},
-	{
-		&hf_rng_req_ranging_purpose_location_update_request,
-		{
-			"Location Update Request", "wmx.rng_req.ranging_purpose.loc_update_req",
-			FT_UINT8, BASE_DEC, VALS(vals_rng_req_ranging_purpose_location_update_request), 0x02, "", HFILL
-		}
-	},
-	{
-		&hf_rng_req_repetition_coding_level,
-		{
-			"Repetition coding level", "wmx.rng_req.repetition_coding_level",
-			FT_UINT8, BASE_DEC, VALS(vals_rng_req_repetition_coding_level), 0x03, "", HFILL
-		}
-	},
-	{
-		&hf_rng_req_requested_downlink_repetition_coding_level_reserved,
-		{
-			"Reserved", "wmx.rng_req.reserved",
-			FT_UINT8, BASE_DEC, NULL, 0xFC, "", HFILL
-		}
-	},
-	{
-		&hf_rng_req_reserved,
-		{
-			"Reserved", "wmx.rng_req.reserved",
-			FT_UINT8, BASE_DEC, NULL, 0x0, "", HFILL
-		}
-	},
-	{
-		&hf_rng_req_serving_bs_id,
-		{
-			"Former serving BS ID", "wmx.rng_req.serving_bs_id",
-			FT_ETHER, BASE_HEX, NULL, 0x00, "", HFILL
-		}
-	},
-	{
-		&hf_rng_req_ss_mac_address,
-		{
-			"SS MAC Address", "wmx.rng_req.ss_mac_address",
-			FT_ETHER, BASE_HEX, NULL, 0x00, "", HFILL
-		}
-	}
-};
-
 /* Decode RNG Power Saving Class parameters (Sub TLV's). */
 void dissect_power_saving_class(proto_tree *rng_req_tree, gint tlv_type, tvbuff_t *tvb, guint compound_tlv_len, packet_info *pinfo, guint offset)
 {
@@ -404,7 +150,7 @@ void dissect_power_saving_class(proto_tree *rng_req_tree, gint tlv_type, tvbuff_
 		tlv_len = get_tlv_length(&tlv_info);
 		if(tlv_type == -1 || tlv_len > MAX_TLV_LEN || tlv_len < 1)
 		{	/* invalid tlv info */
-			if(pinfo->cinfo)
+			if(check_col(pinfo->cinfo, COL_INFO))
 			{
 				col_append_sep_str(pinfo->cinfo, COL_INFO, NULL, "RNG-REQ TLV error");
 			}
@@ -474,21 +220,6 @@ void dissect_power_saving_class(proto_tree *rng_req_tree, gint tlv_type, tvbuff_
 	}	/* end of TLV process while loop */
 }
 
-/* Register Wimax Mac Payload Protocol and Dissector */
-void proto_register_mac_mgmt_msg_rng_req(void)
-{
-	if (proto_mac_mgmt_msg_rng_req_decoder == -1)
-	{
-		proto_mac_mgmt_msg_rng_req_decoder = proto_register_protocol (
-							"WiMax RNG-REQ/RSP Messages", /* name */
-							"WiMax RNG-REQ/RSP (rng)", /* short name */
-							"wmx.rng" /* abbrev */
-							);
-
-		proto_register_field_array(proto_mac_mgmt_msg_rng_req_decoder, hf, array_length(hf));
-		proto_register_subtree_array(ett, array_length(ett));
-	}
-}
 
 /* Decode RNG-REQ messages. */
 void dissect_mac_mgmt_msg_rng_req_decoder(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
@@ -534,7 +265,7 @@ void dissect_mac_mgmt_msg_rng_req_decoder(tvbuff_t *tvb, packet_info *pinfo, pro
 			tlv_len = get_tlv_length(&tlv_info);
 			if(tlv_type == -1 || tlv_len > MAX_TLV_LEN || tlv_len < 1)
 			{	/* invalid tlv info */
-				if(pinfo->cinfo)
+				if(check_col(pinfo->cinfo, COL_INFO))
 				{
 					col_append_sep_str(pinfo->cinfo, COL_INFO, NULL, "RNG-REQ TLV error");
 				}
@@ -633,3 +364,265 @@ void dissect_mac_mgmt_msg_rng_req_decoder(tvbuff_t *tvb, packet_info *pinfo, pro
 		}	/* end of TLV process while loop */
 	}
 }
+
+/* Register Wimax Mac Payload Protocol and Dissector */
+void proto_register_mac_mgmt_msg_rng_req(void)
+{
+	/* RNG-REQ fields display */
+	static hf_register_info hf[] =
+	{
+		{
+			&hf_rng_activation_of_power_saving_class,
+			{
+				"Activation of Power Saving Class (Types 1 and 2 only)", "wmx.rng.power_save.activate",
+				FT_BOOLEAN, 8, TFS(&tfs_rng_activate), 0x02, NULL, HFILL
+			}
+		},
+		{
+			&hf_rng_power_saving_class_id,
+			{
+				"Power Saving Class ID", "wmx.rng.power_save.class_id",
+				FT_UINT8, BASE_DEC, NULL, 0x0, NULL, HFILL
+			}
+		},
+		{
+			&hf_rng_power_saving_class_type,
+			{
+				"Power Saving Class Type", "wmx.rng.power_save.class_type",
+				FT_UINT8, BASE_DEC, NULL, 0x0, NULL, HFILL
+			}
+		},
+		{
+			&hf_rng_definition_of_power_saving_class_present,
+			{
+				"Definition of Power Saving Class present", "wmx.rng.power_save.definition_present",
+				FT_UINT8, BASE_DEC, NULL, 0x01, NULL, HFILL
+			}
+		},
+		{
+			&hf_rng_power_saving_final_sleep_window_base,
+			{
+				"Final-sleep window base (measured in frames)", "wmx.rng.power_save.final_sleep_window_base",
+				FT_UINT8, BASE_DEC, NULL, 0x0, NULL, HFILL
+			}
+		},
+		{
+			&hf_rng_power_saving_final_sleep_window_exp,
+			{
+				"Final-sleep window exponent (measured in frames)", "wmx.rng.power_save.final_sleep_window_exp",
+				FT_UINT8, BASE_DEC, NULL, 0x0, NULL, HFILL
+			}
+		},
+		{
+			&hf_rng_power_saving_first_sleep_window_frame,
+			{
+				"Start frame number for first sleep window", "wmx.rng.power_save.first_sleep_window_frame",
+				FT_UINT8, BASE_DEC, NULL, 0x0, NULL, HFILL
+			}
+		},
+		{
+			&hf_rng_power_saving_included_cid,
+			{
+				"CID of connection to be included into the Power Saving Class.", "wmx.rng.power_save.included_cid",
+				FT_UINT16, BASE_DEC, NULL, 0x0, NULL, HFILL
+			}
+		},
+		{
+			&hf_rng_power_saving_initial_sleep_window,
+			{
+				"Initial-sleep window", "wmx.rng.power_save.initial_sleep_window",
+				FT_UINT8, BASE_DEC, NULL, 0x0, NULL, HFILL
+			}
+		},
+		{
+			&hf_rng_power_saving_listening_window,
+			{
+				"Listening window duration (measured in frames)", "wmx.rng.power_save.listening_window",
+				FT_UINT8, BASE_DEC, NULL, 0x0, NULL, HFILL
+			}
+		},
+		{
+			&hf_rng_power_saving_mgmt_connection_direction,
+			{
+				"Direction for management connection added to Power Saving Class", "wmx.rng.power_save.mgmt_connection_direction",
+				FT_UINT8, BASE_DEC, NULL, 0x0, NULL, HFILL
+			}
+		},
+		{
+			&hf_rng_power_saving_class_reserved,
+			{
+				"Reserved", "wmx.rng.power_save.reserved",
+				FT_UINT8, BASE_DEC, NULL, 0xF8, NULL, HFILL
+			}
+		},
+		{
+			&hf_rng_power_saving_slpid,
+			{
+				"SLPID assigned by the BS whenever an MS is instructed to enter sleep mode", "wmx.rng.power_save.slpid",
+				FT_UINT8, BASE_DEC, NULL, 0x0, NULL, HFILL
+			}
+		},
+		{
+			&hf_rng_trf_ind_required,
+			{
+				"BS shall transmit at least one TRF-IND message during each listening window of the Power Saving Class", "wmx.rng.power_save.trf_ind_required",
+				FT_BOOLEAN, 8, TFS(&tfs_rng_activate), 0x04, NULL, HFILL
+			}
+		},
+		{
+			&hf_rng_req_message_type,
+			{
+				"MAC Management Message Type", "wmx.macmgtmsgtype.rng_req",
+				FT_UINT8, BASE_DEC, NULL, 0x0, NULL, HFILL
+			}
+		},
+		{
+			&hf_rng_req_aas_broadcast,
+			{
+				"AAS broadcast capability", "wmx.rng_req.aas_broadcast",
+				FT_BOOLEAN, BASE_NONE, TFS(&tfs_rng_req_aas_broadcast), 0x0, NULL, HFILL
+			}
+		},
+		{
+			&hf_rng_req_ranging_anomalies_max_power,
+			{
+				"Meaning", "wmx.rng_req.anomalies.max_power",
+				FT_BOOLEAN, 8, TFS(&tfs_rng_max_power), 0x04, NULL, HFILL
+			}
+		},
+		{
+			&hf_rng_req_ranging_anomalies_min_power,
+			{
+				"Meaning", "wmx.rng_req.anomalies.min_power",
+				FT_BOOLEAN, 8, TFS(&tfs_rng_min_power), 0x02, NULL, HFILL
+			}
+		},
+		{
+			&hf_rng_req_ranging_anomalies_timing_adj,
+			{
+				"Meaning", "wmx.rng_req.anomalies.timing_adj",
+				FT_BOOLEAN, 8, TFS(&tfs_rng_timing_adj), 0x01, NULL, HFILL
+			}
+		},
+		{
+			&hf_rng_req_cmac_key_count,
+			{
+				"CMAC Key Count", "wmx.rng_req.cmac_key_count",
+				FT_UINT16, BASE_DEC, NULL, 0x00, NULL, HFILL
+			}
+		},
+		{
+			&hf_rng_req_dl_burst_profile_lsb_ccc,
+			{
+				"LSB of CCC of DCD associated with DIUC", "wmx.rng_req.dl_burst_profile.ccc",
+				FT_UINT8, BASE_DEC, NULL, 0xF0, NULL, HFILL
+			}
+		},
+		{
+			&hf_rng_req_dl_burst_profile_diuc,
+			{
+				"DIUC", "wmx.rng_req.dl_burst_profile.diuc",
+				FT_UINT8, BASE_DEC, NULL, 0x0F, NULL, HFILL
+			}
+		},
+		{
+			&hf_tlv_type,
+			{
+				"Unknown TLV Type", "wmx.rng_req.unknown_tlv_type",
+				FT_BYTES, BASE_NONE, NULL, 0, NULL, HFILL
+			}
+		},
+		{
+			&hf_rng_invalid_tlv,
+			{
+				"Invalid TLV", "wmx.rng_req.invalid_tlv",
+				FT_BYTES, BASE_NONE, NULL, 0, NULL, HFILL
+			}
+		},
+		{
+			&hf_rng_req_ho_id,
+			{
+				"ID from the target BS for use in initial ranging during MS handover to it", "wmx.rng_req.ho_id",
+				FT_UINT8, BASE_DEC, NULL, 0x0, NULL, HFILL
+			}
+		},
+		{
+			&hf_rng_req_power_down_indicator,
+			{
+				"Power down Indicator", "wmx.rng_req.power_down_indicator",
+				FT_UINT8, BASE_DEC, NULL, 0x00, NULL, HFILL
+			}
+		},
+		{
+			&hf_rng_req_ranging_purpose_ho_indication,
+			{
+				"MS HO indication", "wmx.rng_req.ranging_purpose.ho_indication",
+				FT_UINT8, BASE_DEC, NULL, 0x01, NULL, HFILL
+			}
+		},
+		{
+			&hf_rng_req_ranging_purpose_reserved,
+			{
+				"Reserved", "wmx.rng_req.ranging_purpose.reserved",
+				FT_UINT8, BASE_DEC, NULL, 0xFC, NULL, HFILL
+			}
+		},
+		{
+			&hf_rng_req_ranging_purpose_location_update_request,
+			{
+				"Location Update Request", "wmx.rng_req.ranging_purpose.loc_update_req",
+				FT_UINT8, BASE_DEC, VALS(vals_rng_req_ranging_purpose_location_update_request), 0x02, NULL, HFILL
+			}
+		},
+		{
+			&hf_rng_req_repetition_coding_level,
+			{
+				"Repetition coding level", "wmx.rng_req.repetition_coding_level",
+				FT_UINT8, BASE_DEC, VALS(vals_rng_req_repetition_coding_level), 0x03, NULL, HFILL
+			}
+		},
+		{
+			&hf_rng_req_requested_downlink_repetition_coding_level_reserved,
+			{
+				"Reserved", "wmx.rng_req.reserved",
+				FT_UINT8, BASE_DEC, NULL, 0xFC, NULL, HFILL
+			}
+		},
+		{
+			&hf_rng_req_reserved,
+			{
+				"Reserved", "wmx.rng_req.reserved",
+				FT_UINT8, BASE_DEC, NULL, 0x0, NULL, HFILL
+			}
+		},
+		{
+			&hf_rng_req_serving_bs_id,
+			{
+				"Former serving BS ID", "wmx.rng_req.serving_bs_id",
+				FT_ETHER, BASE_NONE, NULL, 0x00, NULL, HFILL
+			}
+		},
+		{
+			&hf_rng_req_ss_mac_address,
+			{
+				"SS MAC Address", "wmx.rng_req.ss_mac_address",
+				FT_ETHER, BASE_NONE, NULL, 0x00, NULL, HFILL
+			}
+		}
+	};
+
+	/* Setup protocol subtree array */
+	static gint *ett[] =
+		{
+			&ett_mac_mgmt_msg_rng_req_decoder,
+		};
+
+	proto_mac_mgmt_msg_rng_req_decoder = proto_register_protocol (
+		"WiMax RNG-REQ/RSP Messages", /* name       */
+		"WiMax RNG-REQ/RSP (rng)",    /* short name */
+		"wmx.rng"                     /* abbrev     */
+		);
+
+	proto_register_field_array(proto_mac_mgmt_msg_rng_req_decoder, hf, array_length(hf));
+	proto_register_subtree_array(ett, array_length(ett));
+}
