@@ -2,7 +2,7 @@
  * tshark's tap implememntation of stats_tree
  * 2005, Luis E. G. Ontanon
  *
- * $Id: tap-stats_tree.c 21253 2007-03-28 21:55:11Z sfisher $
+ * $Id: tap-stats_tree.c 28645 2009-06-05 22:42:47Z guy $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -36,28 +36,30 @@
 
 /* actually unused */
 struct _st_node_pres {
-	void* dummy;
+	void *dummy;
 };
 
 struct _tree_pres {
-	void* dummy;
+	void** dummy;
 };
 
 struct _tree_cfg_pres {
-	guint8* init_string;	
+	gchar *init_string;	
 };
 
-static void draw_stats_tree(void *psp) {
+static void
+draw_stats_tree(void *psp)
+{
 	stats_tree *st = psp;
-	GString* s;
-	gchar* fmt;
-	stat_node* child;
+	GString *s;
+	gchar *fmt;
+	stat_node *child;
 	
 	s = g_string_new("\n===================================================================\n");
 	fmt = g_strdup_printf(" %%s%%-%us%%12s\t%%12s\t%%12s\n",stats_tree_branch_max_namelen(&st->root,0));
-	g_string_sprintfa(s,fmt,"",st->cfg->name,"value","rate","percent");
+	g_string_append_printf(s,fmt,"",st->cfg->name,"value","rate","percent");
 	g_free(fmt);
-	g_string_sprintfa(s,"-------------------------------------------------------------------\n");
+	g_string_append_printf(s,"-------------------------------------------------------------------\n");
 	
 	for (child = st->root.children; child; child = child->next ) {
 		stats_tree_branch_to_str(child,s,0);
@@ -69,11 +71,13 @@ static void draw_stats_tree(void *psp) {
 	
 }
 
-static void  init_stats_tree(const char *optarg,void* userdata _U_) {
-	guint8* abbr = stats_tree_get_abbr(optarg);
+static void
+init_stats_tree(const char *optarg, void *userdata _U_)
+{
+	char *abbr = stats_tree_get_abbr(optarg);
 	GString	*error_string;
 	stats_tree_cfg *cfg = NULL;
-	stats_tree* st = NULL;
+	stats_tree *st = NULL;
 	
 	if (abbr) {
 		cfg = stats_tree_get_cfg_by_abbr(abbr);
@@ -100,6 +104,7 @@ static void  init_stats_tree(const char *optarg,void* userdata _U_) {
 	error_string = register_tap_listener(st->cfg->tapname,
 					     st,
 					     st->filter,
+					     st->cfg->flags,
 					     stats_tree_reset,
 					     stats_tree_packet,
 					     draw_stats_tree);
@@ -113,17 +118,21 @@ static void  init_stats_tree(const char *optarg,void* userdata _U_) {
 
 }
 
-void register_stats_tree_tap (gpointer k _U_, gpointer v, gpointer p _U_) {
-	stats_tree_cfg* cfg = v;
+void
+register_stats_tree_tap (gpointer k _U_, gpointer v, gpointer p _U_)
+{
+	stats_tree_cfg *cfg = v;
 	
 	cfg->pr = g_malloc(sizeof(tree_cfg_pres));
-	cfg->pr->init_string = g_strdup_printf("%s,tree",cfg->abbr);
+	cfg->pr->init_string = g_strdup_printf("%s,tree", cfg->abbr);
 
 	register_stat_cmd_arg(cfg->pr->init_string, init_stats_tree, NULL);
 	
 }
 
-static void free_tree_presentation(stats_tree* st) {
+static void
+free_tree_presentation(stats_tree *st)
+{
 	g_free(st->pr);
 }
 
@@ -131,7 +140,6 @@ static void free_tree_presentation(stats_tree* st) {
 void
 register_tap_listener_stats_tree_stat(void)
 {
-	stats_tree_presentation(register_stats_tree_tap,
-							NULL, NULL, NULL, NULL, NULL,
-							free_tree_presentation, NULL, NULL, NULL);
+	stats_tree_presentation(register_stats_tree_tap, NULL, NULL, NULL, NULL,
+				NULL, free_tree_presentation, NULL, NULL, NULL);
 }
