@@ -50,8 +50,12 @@ my $scalar_alignment = {
 	'uint8' => 1,
 	'int16' => 2,
 	'uint16' => 2,
+	'int1632' => 3,
+	'uint1632' => 3,
 	'int32' => 4,
 	'uint32' => 4,
+	'int3264' => 5,
+	'uint3264' => 5,
 	'hyper' => 8,
 	'double' => 8,
 	'pointer' => 8,
@@ -363,7 +367,10 @@ sub find_largest_alignment($)
 		my $a = 1;
 
 		if ($e->{POINTERS}) {
-			$a = 4; 
+			# this is a hack for NDR64
+			# the NDR layer translates this into
+			# an alignment of 4 for NDR and 8 for NDR64
+			$a = 5;
 		} elsif (has_property($e, "subcontext")) { 
 			$a = 1;
 		} elsif (has_property($e, "transmit_as")) {
@@ -401,6 +408,8 @@ sub align_type($)
 
 	if ($dt->{TYPE} eq "TYPEDEF") {
 		return align_type($dt->{DATA});
+	} elsif ($dt->{TYPE} eq "CONFORMANCE") {
+		return $dt->{DATA}->{ALIGN};
 	} elsif ($dt->{TYPE} eq "ENUM") {
 		return align_type(Parse::Pidl::Typelist::enum_type_fn($dt));
 	} elsif ($dt->{TYPE} eq "BITMAP") {
@@ -506,7 +515,8 @@ sub ParseUnion($$)
 		ELEMENTS => undef,
 		PROPERTIES => $e->{PROPERTIES},
 		HAS_DEFAULT => $hasdefault,
-		ORIGINAL => $e
+		ORIGINAL => $e,
+		ALIGN => undef
 	} unless defined($e->{ELEMENTS});
 
 	CheckPointerTypes($e, $pointer_default);
@@ -530,6 +540,11 @@ sub ParseUnion($$)
 		push @elements, $t;
 	}
 
+	my $align = undef;
+	if ($e->{NAME}) {
+		$align = align_type($e->{NAME});
+	}
+
 	return {
 		TYPE => "UNION",
 		NAME => $e->{NAME},
@@ -537,7 +552,8 @@ sub ParseUnion($$)
 		ELEMENTS => \@elements,
 		PROPERTIES => $e->{PROPERTIES},
 		HAS_DEFAULT => $hasdefault,
-		ORIGINAL => $e
+		ORIGINAL => $e,
+		ALIGN => $align
 	};
 }
 
@@ -928,7 +944,7 @@ my %property_list = (
 	"bitmap64bit"		=> ["BITMAP"],
 
 	# array
-	"range"			=> ["ELEMENT"],
+	"range"			=> ["ELEMENT", "PIPE"],
 	"size_is"		=> ["ELEMENT"],
 	"string"		=> ["ELEMENT"],
 	"noheader"		=> ["ELEMENT"],
@@ -1119,6 +1135,18 @@ sub ValidUnion($)
 	}
 }
 
+#####################################################################
+# validate a pipe
+sub ValidPipe($)
+{
+	my ($pipe) = @_;
+	my $data = $pipe->{DATA};
+
+	ValidProperties($pipe, "PIPE");
+
+	fatal($pipe, $pipe->{NAME} . ": 'pipe' is not yet supported by pidl");
+}
+
 #####################################################################
 # parse a typedef
 sub ValidTypedef($)
@@ -1164,7 +1192,8 @@ sub ValidType($)
 		STRUCT => \&ValidStruct,
 		UNION => \&ValidUnion,
 		ENUM => \&ValidEnum,
-		BITMAP => \&ValidBitmap
+		BITMAP => \&ValidBitmap,
+		PIPE => \&ValidPipe
 	}->{$t->{TYPE}}->($t);
 }
 
@@ -1206,7 +1235,8 @@ sub ValidInterface($)
 		 $d->{TYPE} eq "STRUCT" or
 	 	 $d->{TYPE} eq "UNION" or 
 	 	 $d->{TYPE} eq "ENUM" or
-		 $d->{TYPE} eq "BITMAP") && ValidType($d);
+		 $d->{TYPE} eq "BITMAP" or
+		 $d->{TYPE} eq "PIPE") && ValidType($d);
 	}
 
 }
